(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 14.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   3837045,      68246]
NotebookOptionsPosition[   3821554,      67970]
NotebookOutlinePosition[   3821952,      67986]
CellTagsIndexPosition[   3821909,      67983]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Molecules", "Chapter",
 CellChangeTimes->{{3.919945623936616*^9, 
  3.919945625344589*^9}},ExpressionUUID->"c3becc60-a414-4e31-b898-\
e9ff186ac154"],

Cell["\<\
Application of some of Mathematica\[CloseCurlyQuote]s capabilities for \
chemistry, and modeling molecules in particular.  Mostly this is used to \
generate images of molecules.  Attempt is made to demonstrate movement of \
some angles, but this doesn\[CloseCurlyQuote]t work well as an animation \
because generated images are consistent in perspective and size.\
\>", "Text",
 CellChangeTimes->{{3.920402851958138*^9, 
  3.9204029225643253`*^9}},ExpressionUUID->"303d5679-6697-47a0-974f-\
6e4501a8e4d3"],

Cell[CellGroupData[{

Cell["Ethane", "Section",
 CellChangeTimes->{{3.9198515927996264`*^9, 
  3.919851593762348*^9}},ExpressionUUID->"e0af7971-f712-4943-88f3-\
f88ce517ce80"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"ethane", "=", 
  RowBox[{"Molecule", "[", "\"\<ethane\>\"", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"AtomList", "[", "ethane", "]"}], "\[IndentingNewLine]", 
 RowBox[{"BondList", "[", "ethane", "]"}], "\[IndentingNewLine]", 
 RowBox[{"torsionIndices", "=", 
  RowBox[{"{", 
   RowBox[{"3", ",", "1", ",", "2", ",", "6"}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"relaxedScan", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"ethane", "=", 
      RowBox[{"MoleculeModify", "[", 
       RowBox[{"ethane", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<EnergyMinimizeAtomCoordinates\>\"", ",", 
          RowBox[{"torsionIndices", "->", "ang"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ang", ",", 
       RowBox[{"-", "180"}], ",", "180", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"torsionList", "=", 
   RowBox[{"MoleculePlot3D", "/@", "relaxedScan"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListAnimate", "[", "torsionList", "]"}], "\[IndentingNewLine]", 
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"MoleculeValue", "[", 
     RowBox[{"relaxedScan", ",", "\"\<MMFFEnergy\>\""}], "]"}], "-", 
    RowBox[{"MoleculeValue", "[", 
     RowBox[{
      RowBox[{"relaxedScan", "[", 
       RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<MMFFEnergy\>\""}], "]"}]}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Axes", "->", "False"}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"BaseStyle", "->", "15"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Torsion angle\[ThinSpace](\>\"", ",", 
           RowBox[{"Quantity", "[", 
            RowBox[{"\"\<\>\"", ",", "\"\<Degrees\>\""}], "]"}], ",", 
           "\"\<)\>\""}], "}"}], "]"}], ",", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Energy\[ThinSpace](\>\"", ",", 
           RowBox[{"Quantity", "[", 
            RowBox[{"\"\<\>\"", ",", 
             RowBox[{
             "\"\<KilocaloriesThermochemical\>\"", "/", "\"\<Moles\>\""}]}], 
            "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"DataRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "180"}], ",", "180"}], "}"}]}]}], "}"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.919850108985312*^9, 3.919850158932712*^9}, {
  3.91985020674454*^9, 3.919850337520555*^9}, {3.919850387647703*^9, 
  3.919850402048278*^9}, {3.919850443865606*^9, 3.919850474571083*^9}, {
  3.920893931716132*^9, 
  3.920893967359931*^9}},ExpressionUUID->"d33609fe-c0cf-4c91-8140-\
f51cfa15855b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.43301270189221935`, -0.24999999999999992`}, {
                   0.43301270189221935`, 0.24999999999999992`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-0.43301270189221935`, -0.24999999999999992`}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.43301270189221935`, 0.24999999999999992`}, 0.2]},
                  "2"], Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "2"], 
                    SubscriptBox["\"H\"", "6"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["8", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["7", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.43301270189221935`, -0.24999999999999992`}, {
                   0.43301270189221935`, 0.24999999999999992`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-0.43301270189221935`, -0.24999999999999992`}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.43301270189221935`, 0.24999999999999992`}, 0.2]},
                  "2"], Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "2"], 
                    SubscriptBox["\"H\"", "6"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["8", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["7", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C(C([H])([H])[H])([H])([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"OTMSDBZUPAUEDD-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"C", "C", "H", "H", "H", "H", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{1, 3}, "Single"], 
    Bond[{1, 4}, "Single"], 
    Bond[{1, 5}, "Single"], 
    Bond[{2, 6}, "Single"], 
    Bond[{2, 7}, "Single"], 
    Bond[{2, 8}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.920893942978322*^9}},
 CellLabel->
  "Out[2540]=",ExpressionUUID->"e8d089f4-6aea-423c-be2e-4c889f11da58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Atom", "[", "\<\"C\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"C\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.92089394308433*^9}},
 CellLabel->
  "Out[2541]=",ExpressionUUID->"f4025117-86f6-415d-8c7b-1752420e6404"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "3"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "4"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "6"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "7"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "8"}], "}"}], ",", "\<\"Single\"\>"}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.920893943162945*^9}},
 CellLabel->
  "Out[2542]=",ExpressionUUID->"ada7b532-a09d-4d48-b367-fe393cf2148c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "1", ",", "2", ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.920893943236966*^9}},
 CellLabel->
  "Out[2543]=",ExpressionUUID->"3d0930b5-c679-473e-a5fa-19c68cdac5fc"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i11825$$ = 23, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i11825$$ = 1}, 
     "\"max\"" :> {$CellContext`i11825$$ = 73}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i11825$$], 1, ""}, 1, 73, 1, ControlType -> 
      Animator}}, Typeset`size$$ = Automatic, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i11825$$], {1, 73, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->1.5581107139587402`,
                 AnimationRunning->False,
                 AnimationTimeIndex->1.5581107139587402`,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIH718PStGb3P9sc2Sp7SVTq8X6W8Zrlw6Fl7f6fl
d4Di9so/dxjpKR22zxNL7QGK72fR7V3gWfNtf8fdPwdT9j+y58yxKj2099j+
qxbtCQ0zXuw3lfD8UJK1b/+p7YdFZyt9tT9xsKP4gd2H/ZZGPve3eX/a/+Vs
+P+lprv3l976sBRojr3tzs2rgebsf1B9YCrQHPsjl1fEAc2x7/1k8bs4a599
jvB8XqA5++c0cSUDzbGXVmD+AzTH/vC3jYmLTXfb/+n7ydb98MP+xF9v5m16
e9q+QIfjpEvsLPuE3pVzeSY/37+HTV5xi/bB/evdNnfZnn1hv3fTuwdrWl/v
T03qn/Fn/ZP9IQoL/RtL1tufs1XiAppj//Irlx3QnP0WWZNuOcfO2s/FvQJk
jr3pTi0JoDn2Vtu064Hm7D+iHHcRaI69vX3UIaA59hJmEtubS9bvBwCxd7gd

                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.992508793551766, -3.0514670874964023`, 
                 1.0620145519947652`}], 2->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAve1yWsqU5r8BRGzQmanCvyT4R6X8
S80/teYVOuia5j+gW1YzfRHDP3O+0Q08vMy/xpITvWiL9r/RreVVUwDiPyWx
CGFaBsy/lqdmVSYa6b9xj+NU3Lmzv7qRIc2VFfU/KzHHcXsH8L+x54S31Hjy
v9dxXxanKrO/zuIKq3Jc9j+ZUGwzGI/jv58clmYrZ8M/IdDBl+F56D/Sk6L+
OwHDP2mHhU1NE/W/Jru054SD8D85SQMlsQ7yP2heOx99ksE/0oQm9ebq8L+h
OZXD2avKPwBw9EMkWnQ/qsrsV3jX57+6C976h4a8v7+QymEVv+g/CqgAn+BR
678xcJLxB87kvzg/GBqptrM/FOsKZPPU8D9icy3NcZXNv6hDd04hqqK/a9vr
6GSK5z+5d/yYXAnDPzi/P8/Uqui/gK6/BPnQ6z+tFG7L4HDkPxTALN19U6a/
5xW28g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1174457795537698`, -2.6730343751746757`, 
                 1.7408624755827204`}], 3->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAE/27GroB5r98RtesK129v8W9pu/V
uNI/QHA1on0R5j/IUlfaNjm/P1dmDVPePNK//07IFdvt9r+mYzmjQJ3fP4a6
2KiTMM2/lYdpZCq25r9t5HijkZXAP5x7HFYHvPU/9dVrmGQt778YsSPYGKHy
v3RRp/wHR8Y//tZUCslx9j9jPxOMTXfjv6zqy4Kc47s/Q9oYMtxp5T/LlMLb
FMGJP8K4HlT4+vW/7Rb5oQmx8D+/lf6JehHyP4m0lsGqIqi/xCaTEVz38L8G
kgO49UXIPwiC6WwwgqA/VMKSP/Jb5r/wEtTQvG9+Pw4rBtI8auo/hOmTWY+X
6r+AJfGS63bkv39m+u1Z3M0/j8e37UO98D8UqpBhTSDPv1jXtGTuh7a/QiUn
6qy95T+w0ue6rDixP1gS4ugviuq/Dc8Tc8i56z/rCqT3DQXkP+g8QKszQcW/
AUm68g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2563129404704885`, -2.417097845570353, 
                 2.0009287344994457`}], 4->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvW2tFYH45b/HnorlAX29v0eOjAsX
5NI/iGHXXy0P5j+uiBjd+RPAP+gbADR1MdK/EBYWuu0M978gSxi6TmrdP5Rz
vByzDNC/yVFVd8kA57/baY7xl2zEP9+GtoalpvU/lcvHtoSL7r+0tt6f/cPy
v8pNUn34bso/UPMFa6NS9j+vUmp7+y/kv1+cXnwqVbI/Te8PUBoL5T+l7HP+
URisP1iqfMneBPa/o9blDY7v8D//OTwpY+jxPxKcDdAeOo+/d2Z2IpcE8b9u
o7VADgvGP5DVgHYfu5Y/w1+BRqV85r/caST7W7iWP3CqmUmrX+o/qZw65gJC
6r+hYDe+zZvkv5baGqXJDdA/CtJ4DR2t8D+DMCQE/SrQv6Dp0ClVOLu/aqjz
1yON5T/Xg7VcDhq3P1KxfBY8keq/Z4fRvST36z8US99k4urjP8mIgCpGK8O/
BIOyWg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2664590684090196`, -2.419751180777233, 
                 1.9913025011714682`}], 5->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA2rJbLvUZ5r/wISH9fSi5v1Rfjygg
sNI/RY81vfc15j+vohJLiJu8Px0slpf41tG/sGjnfXQH979tmTr8ambbP86u
QikQsNO/sLw9WX3U579dnOVennPPP/4HeFq6QfU/k122Pitn7r/+dEwhU5by
v/hua7/aQdE/5CvlszYS9j/opTgMDUDlv2/iQ5QSVrM/Fky3y5tP5T9ZJr0/
0YelPzlctv2h7/W/N8yX3UJd8T8mrz4T3IrxP68vOwgVG4G/DqGKijcK8b/w
UPJ8SxzFP0DvaRYA/n+/xbfMQzn35r9kC1VgX9+yP9Pfm2TC7ek/NgiJNpBA
6r8dhx4B2yjkvyZn/XP9+NE/w/k/SZmW8D+SUdYCnKzRvwJnCuXnArq/rm12
xMnC5T/umnh1uK+zP0DnmyNgZeq/2pMyvD547D9R2e+XlFTjP5oF2D/RX8K/
wCa0BA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2248564693583337`, -2.3616303978813065`, 
                 2.0849049122859333`}], 6->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGZS5Ewkg5r8Z157Vi5S4v9Jnq92X
pNI/uHTG4KdA5j9PoG7TFX+8P47b9KR+qdG//NPMFdgR978q6Dop28LZP8yx
z/KQF9W/uQ6Bf5g56L+o+P4XKJHRPyibBfApFvU/kasNSzMU7r+/088UNpny
v434Qpep79I/3Tfn9fPZ9T9k80OCyT3mvzkF+ql1r6I/opHido4l5T+xG3/y
Tg+3PwxrQzBX7PW/s1YZWLO78T//qDycfDPxP4doLyygfKE/BM/UT+4Q8b9k
MtMzuJ3DP9BPIqnIl5O/aVGdydAs57/DhS5FCti2Px11cOdPv+k/1Z9jLx4a
6r8wwSnSfiLkvzAwd7ogytI/HDkl8yN98D9aH9bH5q3Sv841a98fp76/LYPU
Kxuz5T8A3vZiMse5P++hgNm2Vuq/D5F8SAfc7D8Ek3P5bfviP/rc3T7V876/
l9i50A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2121188292765186`, -2.385013887859852, 
                 2.0656419579464766`}], 7->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAwnOeUn4l5r//yG7orBW4v20VBaVV
mtI/wtc+GldI5j/xouy340O8P+EcH5M5jtG/BmEHjW4f97+1+Ymc64nXP7bB
wCeDtta/5eLsdKyu6L+Nl9g4eQrUP2mpaxQf1vQ/p8CyWuui7b9+3D4Qmpvy
v5lMmVBGW9U/KhrWGUWo9T+qVoAHcAXnv46BN/iTx2Q/mflmblUH5T+Hu3f4
uq7APxhOPl5j5fW/g4DhNN4K8j930D04fuDwP6SCTW6JirE/dE0r2xYZ8b92
R25igITBPyix7gq2cKC/VKvFYxVq57+bynn9Gwq8P8TurH20fOk/NJqo1jTk
6b8OycXe9BzkvwMxz/rN+tM/BsN6Uzhm8D9MwoKQ83zTv96tLmuqZMG/ruhS
RNan5T8ADW7UrNC+P1AVBsPxSOq/ZOwAwgkv7T+mmrxzvKTiP3B4F28uV7q/
hG63Og==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.206512472523818, -2.3861714637707556`, 
                 2.0675863704161404`}], 8->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAOeKeseAw5r9pTHC3Fm+3v9EYfSGX
dtI/+YDtXaVT5j99YUtlaJq7P80o67Ila9G/hMcbQhIm97/2KFBPoVnVP+cO
EKCAbNi/rey0IG806b/uljmZQrPWP5Midub+g/Q/wfMV0VdG7b9t0B2QXJLy
v4IFcvti3Nc/nZvx4T9v9T9oTWiGR9Tnv4Mk6dg6Hp+/G9ILXYQF5T9lRs9j
uefFP9qafgzK1fW/73lGSRFg8j+hLnY3m3nwP4490Urw9ro/UJx1TUEf8b+3
K+hCt/u+P1jYS/ql16e/c+cp6aey57/Ug13rfNfAP8ho1a6kIek//WpaQZy7
6b8z1ZT7TQnkvyqPdw59KdU/DS50SIlM8D854b55+mDUvxW7eWAJXcO/iql8
3ZSs5T+SezrLdtrBPw5lOXmTMOq/bDo9+OOJ7T+55Mq9QTPiP9SybUDTWrW/
LMK47w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1936184260474716`, -2.388363187615591, 
                 2.072533796357167}], 9->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAtYJOxMIu5r9er4yVJm24v5/icYk8
cdI/e8AIl1FN5j/C8DP2GVm8P2U7EsXDfdG/rQiQ2oI9978wL4gD5FvRP90z
80QIMdq/8IKIuPrc6b/Zi3ppPN/ZP7rmrnJEEPQ/R4B8nQVf7L+sO+nt/Z3y
vx2GItXFsNs/Z2RKkmVf9T/AIfWV9ATovzURjEOtjqy/Wif/xtjk5D+KcuH2
sBvKP90eb3sK0fW/SYpPm2l68j8cvVruek/wP1NLthtuQ8A/BKVbHnIq8b+y
Bkq8NIG2P/hEBe4u/66/0oJrvt4F6L8BYBfE8sPDP2JfC5WTrOg/foHlMORG
6b+iBkJX0CTkv140Si8BEdc/UmLnLgdD8D+ooy5X0XnUv4y9g22ZD8W/6vMD
LxWZ5T92tf34HiTEP7ats2x7MOq/hurTZhKh7T8o/L2NDBXiP3grbm4ZuLK/
4cKylg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2169658692823662`, -2.343261476884767, 
                 2.1100994583075066`}], 10->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJ5axwD1B5r9VYJ3Pt863vyNnsab+
KNI/V7e+xdBa5j+gD3jvtRa7Pyf50wlSXdG/su6VxqE497/2IrrItCrOPxQ6
5JCk59u/oAYl2RJ76r/ibTmUgsvcP6BJqfnnlPM/lSn0mQ4d7L9TRJmHHXzy
vxtUq9omed4/HzPAMTMd9T/7JLyDF9jov8gr14TEoba/xvWB5lwK5T8haVbh
xLjPP03WRoBis/W/zt9+TYfV8j8aAY9ls4jvP+Vi/tdXisU/41x3U6As8b/L
cuvgWEOyP+SlZdRLfbO/ZE7rTChe6L/OFVKg1NfGP2ijVaMnH+g/3t9SLSYv
6b9ZGpMECfnjv59drsASUdg/ZcdPyk0l8D8HI83FQHXVvxnECSvDBce/jlYg
1pay5T94OInsD6LGP5bUuwK3Cuq/ejtesO8C7j+HAb8RxXXhP9AeU3eYYKq/
NnO2Mw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1948199591560291`, -2.346426047116679, 
                 2.1192192124966174`}], 11->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAN6WnhERL5r8gXwQuIvu3v4gl0Mxs
99E/Kk0ZNZBd5j8qJipBQlW6Pyb1zaF1ZdG/kekTPwo597+RzWSpkODIP2OH
ES6pRt2/o0INsjMN67+GW/z7y4zfP/6ehmLgEfM/tHS4za+0679Fy08RDF3y
v6HoIEU7wuA/ZJgOFm3h9D8zyvfcjH3pv0WpwkHiMcC/mv+7084W5T8z/VFW
jwPTP3bAi0Odk/W/unC1mwEk8z+Oy+50D2zuPz44dmk/oMo/Ft6zQFYv8b8A
PMUk/8WpP7jDgsJ4nra/7XNaGzys6L++Q3twA47JP2CoupW7j+c/9gwwKfr/
6L83ETA0vtzjv2X7iKvxvdk/fJ9NmBoI8D9uhdKU5DLWv8hJr8Jmfsm/YqZq
hC+65T++hpzm35jJP789/6v67Om/TxdCtslS7j8qCIreW9vgPxxkS7RXVaC/
Jxu14Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1846080806912167`, -2.3474090207781524`, 
                 2.12385841908787}], 12->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0p2IsRVd5r9p21sL0jm4v5ekAQoB
m9E/i7U2HFJm5j9P+/IoJXK5P9Y/6InfT9G/b6Jf8acv9787DlSnUfLCP/Te
vaW29N6/2d+uy+TN67/Lo8RmAUXhP1n9DQX0ZvI/OAeV4p5U678huDvC/Szy
vzP1vKv9YeI/xduzlPyp9D/tutUGyw7qvz8ticfTJsS/+U3SbLlU5T/fLmEI
JfzVP6IEVuZaZPW/25/xPPJn8z+MiQweFELtP8frDZw93c8/rPgRZRkv8b8c
gpiGolWbP7x0eDdrs7q/1r6bPn0V6b+8ULJKjnvMP35mjke0zeY/hdIOStrY
6L/XdfHimrDjv37HvTB+L9s/ijbPoiXd7z+DW7dhhuDWv3bWrG1JY8u/woGE
xIXd5T+y7Z1SrljMP5cU0MhSuOm/oPoMSxub7j97dJVhLDjgPyCfFL4LFIa/
kLu86A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1677220856506443`, -2.3383917048075222`, 
                 2.1430700794820217`}], 13->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAy0C7PUCC5r90dEzB1BW3v6bUD4TP
89A/YkSnRECC5j9ozkyj1RW3P8w4sJ7P89C/FQsKUMER978kqbCzomq+P1yF
dN3QfOC/GT/SNWGP7L8vAdw5jMziP/Tbn3Q6pvE/wMiaLWd2679yUFQ/Ytnx
vxgTHWD4qOM/Se1FCZBS9D8LsWfUgffqv5nTI/YU88e/F9vYpQT45T9EpiX+
LRHZP626A0tHEfW/oUr8FhPG8z9936fyzofrP2xf6IBuTdM/vdVzt3Ap8b/A
0pDJN1ONPxI22TbSBcC/8r/GudCI6b9C5WRDo9PPPx7Ro1Uu4+U/xgSrtVP8
6L+6F2mLv0rjv2v9JCLgItw/eo+ZK7CT7z8+F/4fxxTYv5giwhla7cy/vA9A
dSI95j/e2fhmo9bOP+DIrzI7Tum/0uxPOTMH7z9KeRGniWrePwA1wRH3zJI/
B6O2jw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9195192477567636, -2.9110401561774895`, 
                 1.4507686108153055`},
                ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 14->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvZY/uP565r+B8/At0Wa4v1E2roHm
+9A/U6MdI1Ry5j/tO3P+y0K3P9qLuhzIQtG/uXBaCwsX978mXKeQEqSxP5kP
cKkpv+C/4g0z43oI7b8xLX0uBuDjP5FjW7pEE/E/0zxSWNbQ6r/F+T3gC6rx
vwBQmctoVuU/tW7zSmYe9D9+Xm9eSzzrv78Y8BN1OM6/jxtIyS7V5T9j6wqi
3K3cPy8uBbmW2/S/fKv6OAv/8z/E/H8+bUnqPz6+UHLlVdU/DB69M0Uq8b9o
XSZ1+gqLv+LoMdFsgsC/UFK5zbzB6b/BDr8ILNPQPybxxlo+UuU/yOlIiOql
6L/9CB3zeDDjvyhrcAxc1N0/XkCCXJBX7z8B96De8VPYvx1MWVOBL9C/cd8y
dsEj5j8v3dPQRz/RPyXRM8BILOm/Jn2JSjU47z9BZE6+xjHdP5DJWFZ1TKA/
SdiwhQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5675621371263786, 2.3906199476485357`, 
                 2.3210362957966537`}], 15->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAfKihuxJ35r/t0JLbNGO5v7We8KzS
9tA/ISdynlFn5j9P0BN4CE+3P0T8m4X6d9G/WgAT8egT978G36YjG4OUP4T3
LqOfBeG/evV7nXGO7b916B7Ax+bkP0t+7W5wdvA/SG6E3Uo/6r/scngFZGrx
v7i9o/U+7eY/WkZwlnHm8z8Ujr4Sx3nrv+kAIy2IDtK/t8DA4jDL5T91CjFm
uwbgP5PTtTdLl/S/RGQ+qp029D9NrO71eP/oP4/Z/RrcQ9c/TOpxJ7kn8b8s
GakSbkKkv1JQbZlsFMG/+86OLMIC6r9YjqwkYbrRP/ilKRoltOQ/YguTzC5b
6L/7nzFTlwDjvxINHEyoaN8/6lmpZRoa7z8KFLwD5o/Yv5Z+X1lBw9G/7HOZ
QEEZ5j9/hDN1nPDSP6TSHNlJ9ei/1Hd3eUZq7z9XJvEEWunbPzB1h1WGL6c/
RLqzCw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5662382878987149, -2.390926961998522, \
-2.3210433997894246`}], 16->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKCM8r/h15r9oW3v62eG5v6IRc0Bp
7NA/RGcsnDdh5j/xDwlp8iS3P8BqQDiCltG/+w5XEdcJ979PyRnPi8qav/8m
fT4HSOG/+UpwtzwU7r8z06RU/9/lP0pYUxRxru8/mxw+1yjI6b8X4xwPVBvx
v/LsYL3GZug/SMirwiOo8z8jgXeSi7brv74+CHPQ3dS/zqg6CqLW5T9iL5MW
E5HhP0LGdzfPR/S/+htRj/Vu9D/R3lzhEqrnP64mPrnEDNk/SJB6tGki8b/e
5iB3Pkqwv1w8hzylo8G/EDdWsxpF6r/GZ1UVxKPSP45wRtpSEuQ/4h89wxAf
6L/OmMSucbniv+I6za59buA/6vvBkL/Y7j8lX1ZF7dHYv79UpFUpOtO/CYgz
0+wb5j9gUbRjsXXUP/Lgh8Vvrei/nE9nXZGf7z/PAH4usY7aP7jv9gMK2a0/
B/61UA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5663998131127178, -2.390947054432604, \
-2.320983290462457}], 17->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAISMafXxu5r+RfuysxZm6vw1eMpPY
/NA/75VHGAdX5j9Whyq1voC3P/e5M5xUvdG/oocoZPH+9r/dDbxIIw6zv/mU
BiqUZOG/Rete0i2W7r9uxxMreKjmP6E9JBu0i+4/K1bOg2c56b/3tvcpYs7w
v2GjrEW4y+k/ZSbOzvhs8z+mnteIi8rrv4MvAZ+jzde/EmT7+R3I5T/8rR0q
uRDjP+zoDu+p9fO/Ya7A6m6h9D+y2eEaBHPmP3dKoY0Wf9o/mcxa0Rcb8b83
RtR69NO2v+bL2sBPzMG/M4e8J1WC6r+cN3Z1P1XTP1S2XjIQheM/pjx0APLT
57/gfsaE/nfivzTpokcSJeE/XPHxWnyY7j+8TTKyc9rYv710mh18xdS/AH0h
iZIP5j/m/sIA0QDWP2rXGxb/ZOi/WHnkdvLM7z+cKofxG2PZPwAh2+KDg7E/
+Da76w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5657891454180122, 2.390849609974954, 
                 2.321232600453855}], 18->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAU3IO4DBx5r/m+Q+YNZu6vzqbFwdZ
6NA/MsEAKAhZ5j+5+GL72nC3P/jh/ArCrtG/2NuCaOHp9r+Nx9jS5DS9vzur
5zvFmuG/QbUbQE0X778Eev4mb1/nP5KkbDIocO0/26r9vwzr6L+yjpybBHvw
v8rzieoy5Oo/rmNRwSMm8z8q+Uc+/Orrvwj9NGZGoNq/Xd8U0tbx5T+xKUU7
aX7kP2vhZiv/jPO/1KgejxPY9D+jrWpMFQ/lP5qij+x/J9w/gQpF7DwR8b+6
YHQ1Dei7vzy7t3AxTcK/yhMVED/E6r/IevxzCAzUPxg5/Foq8uI/lw4G0B6u
579Qjh31tyTiv7TgCrcvrOE/R8RR1adS7j8Tmtve4PzYv4DvmDiEJ9a/SNAK
fW8l5j/IiLGahGzXP+kZJq6v+Oe/toSP0UsC8D+6DNerMP3XP0SBJcN78bQ/
x+257g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.567752570592848, -2.380481711754108, \
-2.3313866771922327`}], 19->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABcVr3xKI5r+2zY2kdzy5vyA1TRsD
idA/uNZZoElx5j+r7QqBTDm2P2IcEg7sRdG/+f4JQLHC9r8KkzZe0CPDv9l6
ypUlF+K/BThSrDaw779qIh7T0lDoPz/4ayE3AOw/ZGnODD0B6b/FwhlM5QLw
v7hMtt9Y4us/VqnFtfHb8j+FD3JE8zjsv7Z2PFCCgdy/t5x7AjyE5j9pP+V4
JH/lP0qaQ+5jGfO/LucD+r8I9T8QstxXIJjjP4bhV7wlDd4/vvDfV10D8b/l
eX0wDMK/v5LARxBIpcO/hf7exSQc67+0aIzeQynVP2hJiVdcIuI/NBcd9qfE
57+gn2LGrJbhv6RzrjZtE+I/spTyhZYU7j/PsVC0yXHZv4xJJy+349a/uLlq
0cJ65j8fnQYJTkbYP2IhyPHeaue/RWkYZbIg8D/GD/7nSV/WP0iKi1xzjrk/
OU+wpA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5627327340278557, -2.38048703635731, \
-2.332597980747717}], 20->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0RCY5M7B5r+z1aCxsji1v9WhNWCj
NM8/jiq4EDat5j9Rf2DCE5WyP63X1k6DRNC/eNf0smaK9r/RZhvTxrHDvya7
bpkZE+O/BBNwMb0N8L/8YjqhInnpP55CmuK3fOo/qC9TdYL86b+QRvlWGOnu
v7ZZa0P6Luw/8wBEKPVo8j897k9o2fLsv45jjmBqHN6/wZ2JAtTn5z+pcBN6
CWHmPxjZmOjUY/K/oL1ZVNJD9T8BxOaBq0LhPxjeuw9fkuA/8G+gEqf18L+q
0esrIE6+v2GlwoLhi8a/bBu8o6Ru679FSAZLDNLWP4rVU13wJOE/PKD1rChf
6L+jsJZWF8jgvxZhvI0R/uE/OhagMJC/7T9T3gPwNqDav56dstd2MNe/KOSg
CYVK5z+TgF/yq7PYPwSPTrz1dOa/dOlarjZN8D/r0zL6TZXTP4LkoNA64MA/
/Hq73A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5723108334790381, 2.3465719455767338`, 
                 2.3644154487134346`}], 21->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAWKEWHEsj57+qIdnIlLGjv8HLSF7U
7Ms/7/68VG4R5z9yuYy+/YCeP/n0MYFuAM2/3D/XCyYy9r+JVCWkC5jCv7JZ
DVVEoeS/KFgMcoIR8L8Cv8AyR2rsP2cQiqMRVuc/YIRqelxG7L/OFnM+Iurr
v7gJjWR6B+0/RVkjLfmz8T9Rn5vEUxrvv3N+dBmyD9y/97HYIoSM6j8caLM6
LQzlP3p4JtDm1/G/NxEa1Yl19T/vHPNQLPbcPwqSM05FQOI/REjxzOXh8L/0
nFvWcIS3v4NN9noeTMu/1KgXACij67/oLDPmLS/bP1hDHLtGUd4/3JJAy9O0
6b/oqACLOyXdv1SeD75XAeI/vNiBV7A87T+FOafWSybev3i8Bq30R9W/c9jK
O/nO6D/nzacoNQDWPxm3TKD0d+W/V0i8fyB/8D+G6NssPN7OP5cpzltTAMY/
neiwIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.6002455638212141, 2.3881787992922727`, 
                 2.315320125970462}], 22->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKMzEDV0l578zO5lJ1Fagv+SHhJT4
6cs/m0k/bRwX5z92PlyT4iaaPwTTbHYpv8y/FuXQLhEr9r8rnk2dqY/Dv7hG
ZqoGn+S/4Acg21YN8L+c7GvZc9TsP8vrV9+t9+Y/5kQj20hc7L9ZbFGc73Hr
v15rq7kLU+0/zsfRDQND8T9fcsfB3Q7vv5NYFfwYE+C/FzB6lm8B6z+gBfhU
TXvmPzJggJoMMvG/aoia4/Gp9T8QB4ckWpLYP4H8bkbLAOM/laXZ2t/e8L/4
7LOvXqW3v35JigoRScu/9G0CYgWg67/pWNKUBs/bP8QNeQQs8t0/hwh09NLA
6b8MAOvgXHfcv6xGZu/EJuI/nGxxRJHO7D9skCytpj3ev1SNsFnjQte/2bzc
AUYM6T+T55JphEzXP5L6TcnxyeS/nBYdDcCa8D/4yrxNyDTKP4CPp9EBosc/
k3a2bw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6341980435021852, 2.323292359624117, 
                 2.3716039832421867`}], 23->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJUO+CdLI57/xNHbNQWu7P5Ah7WVd
h7Y/BXxJgoC/5z/6XSBeEKi8v/xu97Cfbbe/Bp1DbuyL9L9Slpx9UyvEv1BJ
+zMCauq/+/bwxatc7r+/XViDn5DyP/smRU4kadM/FmFVnqkM8r/FvARCBKff
v1B/xtwRU+0/J3nFqRcE7z8nBHHAQ+Tyv24EW9Vs2cK/5VVFc0ia8T9Sk2Kl
qQ7YP31wnw7VCvC/suQHYECv9D9jm3aKyUvTP6gIhZcrS+g/TF+RuSo48L9k
74VbytaZvx6lPYcWmde/EJ3X574S678OwS+gU0fkP19vwKf7Csk/qII0oxLx
7b+KL6fOM8zIv8ERwsT+EeA/lnoHFsxh6z8GClPGxK7kv+y71q08kL6/6BNq
tAh67T/Te9qNpeTAP2znrgmvgeG/WlGWUIBH8D/KB93likO4P8kaZqF3XdU/
oDGzVA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
                    
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6320101800727966, 2.685898531783721, 
                 1.9521557850864262`}], 24->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvv920tDS57/Uc8pBOE+2PyUaJxVp
Rrk/2PLvMaTO5z/5GlMqfOG2v/GoCNhEvrm/FDXDa6ec9L+Y+wnoOG7Gv+TX
cOebCeq/P+2n3Zw+778PJZu72AzyP+WNv7VW/tU/qQTgqCen8b+ZU5HDA37h
vzCcauBVR+0/MwZMsKaX7z8xhrzV9knyv8EnKQIqENG/qgtELT1y8T80fGlv
9FzfP3h9KA4vw+6/TsY0QyOn9D/A3r0Jc97PPwKjO/9ZHek/elp/6gdD8L9c
g0mOOY2mv6D0y8TO4Na/fnYP2LaI679MzLc/zHHjP25UCfvwT8w/iIQbEpCQ
7b8+CrB2OWjNv7q/h4EROOA/hvwdcSWz6z/gt2GYDrjjv/5RKzi7f8e/FgU8
Ro9Z7T92tdRklaTJP0vJlNR7/eC/3V8WrjpH8D9DUZT0tG20P+SNOmSR5dU/
A3C2yA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5877920305185216, 2.5745166101246175`, 
                 2.10968356704302}], 25->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIPYVeSwT8e35fl3X7/Un7261T189PcK5aZ39248O
5kBxe/Pd51Yev7t1f4DAOUeHpnX7pWUE1rw7/Hm/opPk/e7K3fvVXosve3bt
zX6WuXklMXff77f92ChlsPqjfUNl/0v769ft61hPK3G0ftqv9uQy8/GOx/vP
cpRXW/a8tNctUwgCqrc/9CpYDKh+/7EMjutA9ft5Zf6KANXbt9o67TzW8dh+
u/Rmdquel/tXWu3aBLTXPjK6raSvcre9k4nCYaC99k7LGndJ7X+//8Ln9hrO
/Lb9+QV9BYfe3dq/4sYKj1svX++fkNq4iYfzsf3bvEUhHctP2y/ptzE0aXi3
v/H3lcu8Zy/sb2lm2Bhbctued8sGF6B6+7JrHyYA1e+/oOV0v3356f0sU+ca
ANXby6VxHAGqt9/z5zx3XMnt/Qs2R50D2mvf0XBPSzq/zd42mHk/0F57AKdj
tnA=
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.36390375882917525`, 
                 3.352315980148783, -0.23227488790031783`}], 26->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/qEMakXZ578ytZA8Tda4PyH6sU8+
CrU/03SIJrPc5z+pv3xJdke4vwD6X8CFt7S/h0JDtZyY9L+wTYVEyAPZvzwl
haCAeOe/W0XGe0EB8L8XFsoijJLyP3CHumO5zLU/W40nxjJg8b+P8vdtbt7V
v6pUbbJHZvA/z0jZEFSs7z+EPYhEyYfyvy/z9hwD8sS/TNI34uSR8T9UxjLr
ienZP/SBzsXSoO+/c2MyI0uQ9D/Wqfkn7KnUP8HU0FVWxeg/w8kktZ9C8L9j
IGH1NM7Cv/jljtY419S/WpbMMOTt679qIZP28B/kP8hAttl7a7U/Wt4te9VM
7b+Giqc9tlG/v0x0aJfrtuE/0d6wm4PE6z9+CSCpQAzkvy/wJv3FTb+/tgx8
dT6A7T9qltNYrNfDP5pA7b7hG+G/7k47W1I/8D/X8zQrHTC9P4HVxJ1lLtY/
pbW+DA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.1073138557885786, -1.7084774888329732`, 
                 2.9144447852904616`}], 27->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAAPk2zNzY579mJPrbl+e9P3hGfptP
XKo/ABwNyhff5z8F9uMnTuS8vyZwv0byNqm/fZXnpfVU9L/KeU6XjDXav1FE
7HTEB+i/4NVLye1Z77/m//vzHO/yP6Q+odLXr4O/lshMClf/8b/2a6Nqtf3Q
v3KUXanoEPA/r1ILrHHi7j9LdGN7IuLyv8LmTkG4/sK/kePT14lj8j+ZPmbp
oiLZP7kiMUMS1O2/q1j5XGMp9D+If59f45vRP/03MMsctuo//ogBBrIg8L+x
8E+gprvCv+lfNHv/Yda/cGfBSmWZ678tortxls3kP8/21aZZcJU/FkVocMXr
7b+6xUnnngezv6aGOSbL4+A/WDcMu8Rg6z+ss+FdZ7Dkv8zC/tJ0TLm/kXHa
vBVT7j8YQW1fj+nBP7wZnWeBZ9+/VvP/oHcM8D8NBE2rn8W0P/pAxKatItk/
0qPCdA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.03977244140280435, -1.6583709165937601`, 
                 2.9449319272100047`}], 28->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHoNGZzTN57/XoEdMfgLBPwm0z12q
vZ0/si+tQZjV5z8+0GwbA1fAv5nzvFj1v5q/NaSx+HQy9L/MVMPNDVnbv8vu
Fv6bJ+i/B8lPRGiy7r+TkNlzIi7zP1qy3NcfQ7a/j7loSM5l8r+WNVLazFfJ
v+IXVfKlr+8//HXlPzE67j+UbLfLNyPzvydUG2rPXcO/wHKkts//8j9RCGU/
jffYPyfg9E0wQey/qmxbFF3Q8z8bBRqy/hfNPxc0jFIQQew/4nIqlocM8L9h
hJ+nztfCvypxKKuuOde/EibLVc4/67+uhGI9ck7lP6+K0YBqp52/HvsLfGhM
7r98KRUcnaqgv8HKoaLJTuA/11LJwOQH6z+cBiUvGC7lv5ryMhXOtba/mQp7
15vq7j8yoK6xC8zAP8THuvgvF92/gwQyNSm77z+4aVot94GpP3pMxqcQa9s/
Rs+z+g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.14957163507466617`, -1.623380344457142, 
                 2.960855380326993}], 29->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAZsQByUuk579Xs3AZjI3EP0MJlBbU
z4+/FRXdkfWt5z+Gp4n3BszDv/cAjid7Y5M/ZBmac8DM879TfTzAKHfav2MG
uBkjrOm/2Hsaxf8e7b+zM5fSeabzP2gwGD2558a/U+GPF65K87/nHHi3Kxm/
v3NLPiVy4O0/T/rIApMi7T942DVHBJTzv/lmrx05/sG/o4DlDOYb9D+G2ICz
9SPYP/rdZkMKKum/0j/j7+n08j97nTily93CP8kFLBFbE+8/l/saWOae77+n
I4SzYjDAv4hWEmpiK9q/HyAOx6Vh6r8eSsVVKzjmP/xwgX625Li/hsMQ/NMc
77+Qk9L22AOUP07749QyYd0/sgdTSkRo6j9oDScmhQ3mv7RNe3GTI6+/LgvU
1eDy7z+ECXhv5Hu8P/NtKmrujti/XMrRuOTL7j+AQSFKasdtv9B1aOp2rt8/
7lm1hA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.3812366236282519, -1.6185284782456857`, 
                 2.9426899602085563`}], 30->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAnDgEas1x5r90NHAKsPjRPwHB+++F
vKG/jzt2Au155j8X5NzIGcLRv5AGjMra6KQ/AIfsXMRw8b8sjhq02DrLPxDw
Fus24vC/Adpqrkpt579H5sN2jSH1P0Vres9qUtM/o1CXzH/39b+U6ERXXpTT
v8eu1E6ROOM/jP4EekIx6j8wlQFdfP/xv/LJSlrQh+S/X0KNq2TP9j9e9K95
euneP08WrH5bXNG/CRWkgadl7j/WJGJHsdjiv7DMf9vv8vA/TqPuEaup7L+K
e31kHJbPPxjOlhobcOG/Tok3DIzv5r9k8195uZ/pPyXzehHaGsE/eLbMQDOY
8L8AQkvN5LqJv7fy1O/IHNI/Dp09vpdV6D82zjjPAnDmv4kJoq1COdO/EzBk
li0G8T+MIKZhwU66P/oqtUqAfr2/TCgNQspv6j/iltArvrnbv+Us1LE2muE/
6e24Mg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1321505430373722`, 
                 2.726056777995848, -1.6465872558243244`}], 31->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATVhE+3Vo4r/AzkWqGGvTP7hqFnJv
uNi/9f4kTBRS4j8kwZFcy0fTv0b/KQfhFdk//w9VhEEk1b8YrxFXjHbXP5Im
6n2sNve/QuvVJyim6r9v4YV2Trz0Px+XGeBJy3u/voY+kU9f97+lRHus2HjV
v04/mE6MfNO/Xi15I5kt8j/hfexKhgjwvxFUGHnonM2/KXQUsm1f9D80U8AA
Iu/eP0f/1XtgROY/SHBB6u/Myz+tyHuIoe/pv6ifIS2rq/Q/TOBuvZb63L/s
vquA0nDVP0DBb1rIZO2/yCGNEU+H5r8fVRehFJfpPxTRlpmcJ8m/cllwR8VJ
8L8gr6sRAG6QvwNVV+B9Gta/2KyLSaNW6z8q7hAiedrkv3yqO5XZjrQ/pPMm
2HeI7T8gJF1IrU63P3V/tX+oZ+E/B1u1RlBF2T+gVGKbw8nhv3of7G4j8eo/
Z0ix3A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.6822183917042866`, 
                 2.916663387316241, -0.2959999454405246}], 32->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/Xn3UtW44L8zd81Jd5DYP39hGLPl
8ti/MGG1aRas4D9UK0W4LGPYv96a3+j4QNk/CDNL85Wp178A3FdeYl3QP6If
MWy2c/e/ihy2xwFE4L9d+8+xWCr3P6cQFYHbuMG/cw9KHjxU+L9ZX9wWf85+
v3yuM8FYRsW/Amw0wLMo7T9NgVMtF3zzvyDlUJN2rMi/FrHie0D49T8zpE+1
uD/RP+3k/A5oxeM/6tg2ynimvT8wvyaSGATovwBDstfycvU/gROdTKCN3L+a
qRLU7HbUPwI499hvsO2/RMtWjWt+4L8qWUOEdk7tP+l00bmp59C/OebiY1NY
8L+2BXJNPRXIP14c2QkJy9G/meb0FGXq5j8izGRb4pTpv5xQbj571bk/rmG9
sEtO7j+AHNYL0I2svy5ZtkHyMuA/TTz8guVg1D9tqiR31xriv7gp6hExw+s/
y121BQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.238332650245279, 
                 2.4385790057092698`, -0.6838123863750435}], 33->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAqlh78u944L/+2+iP/QjZP8lDYyj3
KNm/OHhSxQZv4D8aYVE9nebYv1yjdqW5ZNk/nWODU0tF2L+M5XQVHwbOP08U
G61ge/e/7GuNdQCc3b+41XZIe1v3P1XH+q7LbsW/7zg/bulb+L+pTWoVkfGj
P5vSqWw4DcO/hqHoL3nq7T/cMysxzCvzvwPT19poksq/5RDDNhiS9T+fw0m7
l9nQP3KKVmZ/k+U/7YV+1sEdtT/0Xf/A+p3pv8mJON99BPU/eAo9nJWb3L9i
p1GNBgbUP0LlM3eexe2/oA5CLfBG37+3DHGsup3tP7pT8H8u8NG/onK+szBM
8L+zJZayL4fLP4sWXK/JV9G/34yd+r8s5z8ijH+Ac2Xpv7RzFXAKN7g/AU1s
mZvJ7T/4Og8ECxqwvxDuiBzuIuE/9kgiAL8S0z9AB9SvpAjjv6AylkisXes/
RzO07g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.268477816287621, 
                 2.422308536287064, -0.6409600237470113}], 34->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzky4yR4g4L8CtL+PcrfZP6E9zDng
Ytm/U81FGq0Z4D+EWWeRCKHZvzWYaybJidk/+8+vHaTx2L81SSkyym7LP753
dSnVf/e/QuWaLX6y2b8/Ma1GMJH3P+x0d1xVw8m/YobSO1hb+L+7vx/zLQ+6
P3UbCFGVdcC/q1J5VkBb7j/5+RQD8/ryv1/Z//Dz+8u/MOlnxOUp9T/RmpXA
LWXPP46MZRtGZec/gsEpeHUCpj9B6TP2ki7rvx3NKJoTivQ/zDSQ2PCY3L9O
LGrUa7fTPyaH6DeN2O2/b7+F4F353L8/Hp3qDP/tPwz8A3RFItO/ZFZX0LM1
8L/40UMGnx3QP64lKHHVztC//49fuHY65z9a0G4nNWPpvwxX11ueF7c/2s+K
Ubw27T84GDli49yzv1SsTVcVFeI/a2nIcdR50T8Cy3Ofi//jvyqzw+OF7Oo/
RUC2ow==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.320003137206787, 
                 2.38267231651475, -0.6040348296786365}], 35->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAFTbyaS0P4L+oKMXtes7ZP4rAfXrj
edm/1sWQfhMM4D+f5QIvIcPZv6mUMu4pjdk/AGuhHDMr27+W2iOoGivGP6UE
PtYmcfe/AamJA6KK1r/Iw0aA1KD3P0GjAf2EFtC/Hb5Xmgda+L+8Y6ehIOrD
Px1mrItzUba/h8ideEsA7z/8ImrvA7Xyvzz69OI4+cy/4UjWQNjX9D9W3yKJ
DHPPP6l3U9bjmOg/lKxe/fNCnD+0iZmqXz/sv5HnPsjCKfQ/letC+Mak3b/6
iusgBHLSP8d03bSfz+2/lgq3a35U27/yDbg7cxTuP+axvzs0yNS/lGyoJ88w
8L9DbUyfxeHRPxHaaF1ADs+/LkeXey+G5z9k3Co7zCXpvxQvcPkaIbY/zKse
AOLd7D/o6+LUNRO0v/9gtma8r+I/Ort7Hivu0D9Cfg0heJDkv7yMy0MNjeo/
plK3VA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.345903034788885, 
                 2.3505784331770303`, -0.6292217263026727}], 36->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAR+vXuXxb3b8uelLWYnLRP4aI28GH
LuG/CXZZT1hY3T+vRBQsLG/Rv4YUrPivMOE/DvN9LjlIw78JLt/woGy0v1UV
t9Pmavi/1Mdcj6MS3b+i4RnWxN31PypBGYWEOOG/MJxxkwnL97+/C1VMLk6w
v/XTwt0rv9e/6pwtNTfq8j/Ht+M2Kynvv+Dl1YfPU7w/UO9YfjRa8D+qvOPj
wDzhP1qZu5SKJfA/ByD6apCuvL+0AKp7YDnpv+/JeEoYC/U/Z3KLqMx/079Y
XTU0da64P8xsUloVgfC/jlmaJBA33b8tgK6LXTrqP9hkeiOGM+G/Apfnwegh
7798bnqGrr26P4DyvLAdDt2/bPoDSU1A6j8Q7XamYPDjv0LRpukpu9Q/0kwv
kkqw5z+mNLObVQrBP52jEZHiveg/CO6aNLQsxj+GEdpIe/jgvzLUzkZwo+0/
Dz+1kg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.0697684925130178`, 
                 2.6336182666891386`, -0.45223137082878667`}], 37->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAB04WrM4l3b/bOzNP4MDRP5nB4w+b
MeG/r4u+lc4l3T/vpe864MDRv5ELgPSaMeE/fmB6ePJMx7//OjLNdkG+v2KT
l1s5U/i/p0/LfGDL2L+eCfQGuOb1P1e2TIZMg+K/RHqE+1D297+WJO/2WS6B
P4d860Dkv9W/fu2usOYi8z+znF9JK6Tuv5s3MMAdALs/5Rl5rFmz7z/FaoSz
c/HgP7XAc86UwfA/TPYCJ8Kcvr81xmHFQpfqvzqBmfdBk/Q/I78p9CNm1L82
Ws03BWG0Pxe6xHEDdvC/185wlJf42r+U2MAa8FbqP/g7GMtz2uG/xg2KpsQ/
778AteoeU0rCP9x/WTCNEdy/apAeVlps6j/Wt2uzTcLjv4QShqyekdQ/3i+s
eyAj5z+aLxksByLAP37Gs0hiWuk/HM79C55+xT+WzGxx2bvhvwKH2XEPLO0/
zH+4ww==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6674233470295085, 2.6795414804749638`, 
                 1.949103263106899}], 38->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAavT96pKw3b/sa+bjZxHRP1L6F4NQ
IuG/Mm8SH4Ct3T/27W8+HA7RvyF//Al3JOE/jT4uS9HPzL/dG1cvYvnFv+Hx
tB75Jfi/qQZ3k2Ae17+TXxD3SKT1P0oIN2z/D+S/684vjxkg+L8nfcGbKKOl
PwmfffnrBNO/ZMtmOTu88z8T1x049RntvwLj6RF5D7k/5gV5SEuJ7j+jsGXB
yqPhP+d5KlLsJvE/oFplgQXnt7/uygf95q/rv6Qe2pE8NvQ/2IlKyD0M1r/4
d+sw21KoP4V3ILCQW/C/in06v3ln2r+O+gnwoujpP06Bp/cnmeK/BUzvST6M
77+Rm173zMXDP9bJ1n/GpNq/MGcrQZsn6z8H56qrgdDiv4G7OSxmRtQ/wB4B
rAWw5j9Qc1tEeTnCP3i5KNcnuek/ihi5vr6zxz/04B+OehvivzRe2BZ4yOw/
S/q2PQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.0960075536491747`, 
                 2.6045330798082444`, -0.4975537872734799}], 39->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAIzi2PkG83r/FJpU4rz3QP6CBdwBV
3uC/kzspbDmv3j8H3WYR6jPQvyCbZUWa5uA/bp6NuWPSyb+A8yrKDMq+vyE5
6TMZRvi/Up/A8T7Y3L/AeFKq8o31PyhBdWPkY+K/wgtZF1Ae+L/UpaF/Ooyp
vyZxdPxUjdO/ylMG18mF9T/YELKnypTnv8m+EhP5xLA/OfqUgQlq6j+FuHw0
zvThP/hdV7d6vfI/tXrziTFwhL8KbWL0Ygfwv+UAJ59zjfI/rYO+jbnS1b/K
0xQMWBaxP/h8EtqhWvC/ums7GEDK3b9ywnd4Xp3pP2Rh9rEcoeG/ypkGZ2DN
778U5EHRTxi6PzO6sX7/pNq/rqIQMpgx7T9cf2Wwv67fv/nyx2c5/9I/AczU
G9Pg5D8ClJJXsrXDP4grCtrHMOs/vZ/Z37cLzj9MJLx4XRTkv3XO2cHAAOs/
3gS5SQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
                    
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8156403561119783`, 
                 2.8402183067071003`, -0.24700216092864502`}], 40->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAaL+hWzKs3r9ppMb7fGTQP67u+yfz
2uC/fXrvhPeR3j9gF6n+1lDQv6sVILeY6+A/aEQD9Bf9zL+YvJAB+27Dv9gX
tPOjKfi/GllXs8QB2r/6uo0AL4j1P2ZHBaVpauO/VAqnPjI5+L/w8dVNHzFK
P5jvNzI6A9K/R44zyLDS9T+iaOXpm2fmv3YDi7qM/7A/MGLTi8QY6T/Z2M5w
wHbhP7fNPKJ2UvM/s/3Ra9VAKD+cQ4BhEarwv4fHsgLl9PE/zrDRKl+V1r90
GPnr/bOqP5gH2cOOS/C/QYx8h/tW3L8UZH8/TqHpPwqbgGauIuK/LnqP1T7k
779ij22LlXHAP3rmF0GQ3Nm/5mxvqS537T9S9DlpB5Devxp2cU6KC9M/t48l
J+Aw5D9SmvTiqZzCP4zYzP1CyOs/vfScn/+Uzj90iSohR77kv1zSQl6xauo/
JoC9Kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.827785325827179, 
                 2.8336739761174465`, -0.23214779724471674`}], 41->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGLGh1IXO3r9F8ChVlEDQPzqOOfx/
0uC/CZQVIlWm3j8raKmQTSLQv3eX2yQQ7OA/gSaxI7Z80L8rgQeS3HzIv5yY
qVe0//e/vitmlzvn178YThDrtWX1P/uk3iMOlOS/MrxvOpFN+L/5SeDxd1ul
P5wtwAgTOtC/K0tvBdwl9j+DK+65XQnlvz4Zw7zeFLE/r9+2PJDw5z8fAybA
Hj/hP0XgtvTxvvM/GCsoy2mdlD+o+BgnaCPxv6mBWhw4e/E/zGsp/J2l17/A
vpQwmAigP9wv4yp6NPC/a+4DtuBa278qiloA23XpP5oZDBBHs+K/PBTMV5kA
8L+E+WRTA+zCPwilmYCJ79i/LrD0TXHP7T+Y30KChBrdv5/6c/yrDtM/2tTg
Zt2h4z8SnqLv71vCPwCsJAf6NOw/uhbIvivwzz+yUkOL+yvlv2RNyC5A8ek/
YD+zTA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.826095351531008, 
                 2.8338825902130154`, -0.24266279484999417`}], 42->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATFV84Mzd3r9bbk5uhS/QP/HxzyAZ
zuC/znBvADGp3j/Z/ACd/wfQv6CnV/OD7+A/JwcDWXdJ0r8o3DkLDu3MvwGx
BzPd0/e/Uyyx1PL91b9ddNWIU0L1P3k7c0muneW/V2w4/qBW+L9xQAgL1W+0
P96kKMa3m82/o7phMdtz9j+wbU7oXqLjv5cLfwIEyLE/SkGQKKDB5j+Bg+Ue
AuvgP3BM9l6BKvQ/PmWzI+YepD+ebjwC4pnxv+rsiS10/vA/Oq6/HKKT2L9w
BBiL5o+LP/3Ut+F0HfC/0MCW2t9t2r/0D2nkNE7pP7WWIbXjNeO/1cArGwoH
8L93fhCxekvFPygbWhIHNdi/1pZ9cSce7j8c7M62XqbbvxOJp3OEKNM/2Pxj
VBwL4z8qCsqgBM7BP0AgolhDouw/u+5y4oaW0D/UrXzp4Zvlv7rANSc2duk/
1X60GQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
                    
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8213127223170156`, 
                 2.8368523025521375`, -0.2439036306224676}], 43->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHfRSlcsc37+ZDMqXR4bPPyhyGfRf
yeC/H0XeJXLf3j8bt+sOlynPvxmZudZU8OA/y+PNA1tr1L+X7dJwo1nRv659
VRM7lve/tCRwHa7M1L/UuMJtSwD1P1DKVdX53ea/XVp43ppd+L9fcufwcaW7
P+ACSWCAWcq/bB0olWvG9j83ckpVkgXiv7NzbAJLVLI/VDvmGpS75T8+AJjJ
ffDgP3XQeYcVcPQ/LA+JUt1rsT9i0V1WReXxv0x4fkaTp/A/9GuQTBPE2b+w
dN5O+meJv8I2Yg3r+u+/aIxh2bz02b9n+rtgFPHoPzyet+Ss0+O/sovm4WYS
8L/k4h5IgKzGP+CyKwzAX9e/tK6fHkh+7j/+XwUZ+M/Zv5AnBzfeOtM/8q7q
lqaV4j/vJLoLMEzCPwKd1vI/6Ow/dURAvTSd0T9FSDs4eMrlv9hE27G9H+k/
KPe5tw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8023645037145133`, 
                 2.8462118013761573`, -0.2737892939050491}], 44->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAS6N/2lFV378qkbYJBNbOP57/lwBA
wuC/tDTHZi0U3z9AqHYmG3POv8y0CWat6+A/bVdqRGmU1r9WGAIUsADUv7AH
tYaTUve/sSJi7PK107+EOLrAlL70PyOMIsNDBei/l5tFR0de+L9lfByJiG7B
P8E1CS/cUse/+MgAzd0P9z8Lp382WHHgv9MyFXbNtrI/uGxyO7jK5D9v4zfK
KNvgP5uk90fhr/Q/A6K5rNe+uD8zKKANfy3yv7ZCewGMT/A/XP10j9302r8I
P5s8uFaiv38HAYezs++//uJwY6KF2b+qCvFBVZnoP+BF3eHBY+S/NcLy3s0Z
8L/IhmlJRiLIPw5NWgz3lta/JZayJunU7j8bUR0AHw7YvyZbzBSHQtM/iQNr
d2cq4j++cjQBxHzCPwF//Pq3Je0/ms76qPGh0j87/W5y4vvlvxwdgLRixeg/
c4WySg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7845630313499794`, 
                 2.854689789140926, -0.3008005899487306}], 45->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAyOB9lzqx3786ELwZPK3NP+biDC9l
t+C/glA4Bqlx3z/n+hmOpk3Nv/zPJE/B3+A/JLBqXqCu2L+8ryhTR7/Wv3PY
G4R2Bve/VZg2chxy07+O4ZMEfG/0P/VMWgXmIOm/raJLfFtf+L/VFMtMAWfD
P3Xkl6KUTcS/gqoHoEBh9z9hcV0lbwHdv6lyI6bJwrI/p6Q2qJPT4z/rtJ6t
A+TgP5P4GawA5vQ/b/0IriRjwT9+I87yImryv+3r8lOB9O8/dkj0eu0v3L94
nioZpaKvv+ZJohspYu+/jjzahKuR2b+WY8uHIyXoP+6XM5ol7OS/cI0VEdUl
8L+IkkOzHorIPwPcslfKytW/or6V4ao97z9qNzU2IdTVv1E+6YMaONM/dGap
FTTG4T9jbDAUNCHDP5FgrFPhVe0/nWeerp0R1D/bYpHE1xPmv/Tdi1Ehaug/
Xou1Eg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7435135179845498`, 
                 2.876726345905426, -0.33016078413214167`}], 46->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAmY23v9Iu4b95vFgRwWTNPwRgLyUD
vd6/3X3r0qQQ4T88GQArBzzNvz5r+D2ZCd8/Da8LKPM92L9sm5De0h3Lv0rO
ULFUgPe/tI33vTju379ukzxTRhP1P6SQ/5PWJOO/pQ1Jgn2F+L8Od7S6cdul
v1GPPPgQdb6/FL50xINY+D9DqHhzrDvGv9Xp3DZBL5M/KG2bfQfr4D9ksE4O
SGjYP7P4vvjbSPY/LW4okF9G1z86fv31Y1j0v/+XlNikoug/IGW9U8xN3b9w
CEGWcTeCP0umnHqVL++/OqpZj/eS4L/9qmd13r/oP1OgSxOsQeG/OWoScXOO
8L+2nqui5O23P+xBn7EjLdO/gT71Fmtw8D/AYDzP2bvJv+4cs6hGHtA/gnVD
KNb94D+MR53xiJSzP4ITPUhCC+4/9LT/mtSz3D9hgV3b5P/nv89myLu4E+Q/
ZmW3fQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.245328058769693, 3.1387849531603607`, 
                 0.1469253002549984}], 47->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAegeWUkk24b/Vg028xvjMP5KnZatx
xN6//Aa0Ndwg4T9ApMvhSMzMvyq+ni2A/t4/InwaYkXB3b9eQOGSH9DUv0cR
CIf/w/a/1GmAzw3s2r8nn2XZYKX0P7y8/KUrrOa/j7YTrLaJ+L+B54A/PKuy
P3K5X83GK6y/+GLdy/1A+D/QGHq23jTMv6zyFVa5MFC/LbXx1qk44j9x8OzE
/l3bP2v+07kOyPU/w3DHEr2J1T8wjdoogPLzvxiCTpPaUeo/xqLRAXYL4L/M
+enS8E6pvyx74fEbde6/ZDxWOlCs3r+hT++weUToP0LI1z0yB+O/Jl2vqm2S
8L/L+wZuMifDP2DPiEL1JNG/O7Nb87Vo8D+I3iLMk4DMvzeoSHRP7s4/FN5S
BsOs4T+gPA6otO+5P/atO8Wuh+0/Xr8Xv7rl2z+4ARRFCYznv5bwDlWN6OQ/
Hdy/2Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.4227949974249705`, 
                 3.0634569121063864`, -0.12363714235649467`}], 48->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAdbknwWJN4b8MaJCY3vjLP8/z1EHk
yt6/23m1mINB4T+mtu3hPeDLv2rmPTsO694/3hl1TxqT379huYcvlpvXv1Yb
JZuIcva/X38PXh2A2r8WQDwTDF70P8YZuR/Y1ee/MlBZ1TyB+L9vFJINgGq3
P6G+sMvYHaK/zFEfWWBf+D8jCSS5DCfFv4tXR7P6tH8/MQ8k7ENx4T+dhrZP
QOPaP11cZw+i8vU/rJh769/P1z8q5En20AT0vya/WZwDqOk/MiNx9HeL4L+4
Cn/GTT6zv0pYmqtBJe6/JHkvcHGN3r8XTU7mJ93nP9fJUSClneO/dpb2GveT
8L8iuaxPD9fDP9KFpa1Ph9C/XQe9EhGA8D/k34hNpYPIv8gDCybiac8/hsRs
wmNZ4T+UVn+9Qua5P/jVNp5lre0/MUZzjnMp3T/+moey2IDnvy5Z/FzFjuQ/
oe6z+Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.390202550062198, 
                 3.077125614920644, -0.15177226294620422`}], 49->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmII6UuLflZMGj/Xpaky0W/zlgH74tsWyG6r39Nj9W
bAWK2/d23WMDiu/vnlxpDxS3j3p661u/2aP95qFlFyeufLRfqH5LssCxL/vn
VZxwd7d+sL8wrOfZc5dP9vHb5q/Mzn6zf9sib7/Uhh/7tXVletPLltpLmOyx
eCy5xp7r5PN4oLj9+YSzqUDx/TvYBHY/kVyz/+aN9G1A8+1nsbXITVr5yJ6r
Py4UaL69+OZCP6D59k+s/74Dmr8/iyvrCNB8+1t1d66uCX60P0x0MdulK2f2
r3jj01jm/2Z/jUdwHUfYw/3bds/zrUl5Yn/UI+OT9P6n+wvDY0VS73zYX2l6
S9o2apv9FX0v/phFp/ZPUYqTBYrbH3wU+MAmatv+LZPEV0QvOmXflcGxDWi+
/dvjM3YCzbd/89kmFWi+/apQ3iag+famvDf9gebvl8gSBplvDwCFobPC
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8969838528865911, 2.680938979738597, 
                 1.85267000693024}], 50->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAjAqZC5HY4b8ItJgJZJXDPwDBwScl
K9+/jgyzFIjm4T8FVVq4K7HDv+vftkWnBt8/P5SEgU7X4L9PSZ1hHxXhv8C7
hfKwaPW/FzNOLddi3r9Xl5GARNjyPxulICn1ieu/Ss5Qgcx8+L9QfJ9+762l
P8perWMVjVw/iTPTHQ6I+D+PB14aU+qgP2D+P0GN/5Y/kaWAYYuh3j9sxNBx
R8XePzXS5Ff69fU/q+yaD3qT4D9cFJWlTzDzv3rWTCVeu+k/Zs+Oxu9X4b+a
OG6+jF/IvwAsdjx6M+2/DBIgUf6E4L/YrcQB8UrlP87CgN7Dj+W/yKmOg4q0
8L8ck0Dp3wC5P6ETXhKYDs+/6FwWFKm98D9CpoXjLe2uv+hv5QxQO9A/q6+5
4qab4D/pmaOVsezEPzCKUimkt+0/nPwmEgE94T/8XqAcdablvzgjFORYn+Q/
/h2zxA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.9664480244747824`, -0.9779941318188181, \
-2.5692430101427113`}], 51->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA+qwIc8WF4b9ETdZrOa7HPylRj6EM
Mt+/sME/jc2i4T81EEU8+uTHvwAZVMrO5d4/zrP0JIir4b8DT3FKFNDfv/7x
iWJTfPW/ieTBmaOz2r9fg4fLf1fzP8QN9iWYLuu/bPwHKzRm+L9grN6+0UO9
PzFaMWpp+Ne+/IgIRICI+D8b0NmYWaWhPzcG6fTQ7as/vF96clwC3T8z9Bms
8AXZP00faULog/Y/tXyvVosi4D/ixQaNhv/zvxuZXAm8huc/ZLD+y6aY4b9g
KIaU9/jDv0jG7YrWSO2/Pp/pP5ff3r8HTQL5Rk3mPyzbXjvPY+W/dClGcouU
8L+60aIlESjDP1q7+JkkMs+/6jRUhfOs8D8unA7Wo3uzv+SceHTEMdE/x3g+
4/0R4D8y2O4b5ya6P40l/vRbPe4/Mp/3cazi4D/oZ4/UJfzmv85SQ7fRfOM/
7VW79A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.9690884101162824`, -0.9284328550772332, \
-2.585556664774312}], 52->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkeNIktNi4b/d2ygyT3/IP5Oq1hBv
Wd+/3Np4LhuP4T8PORmuS9PIv7zPEQZc5d4/KfYAOHeN4r9ZrvLgpmngv/pr
Mm2IOPW/x8ome16f2L9K2qC5ETzzPxXmkxk1Cey/4uXgFWRN+L8o9WRWnb/E
P2MMLOnHmHc/CenAuhCF+D9IaY7NqkyvPxO686us3LM/AI6f4Ht42z+SY1o5
3rHWP9UzxpJbwvY/WtSjiUeF4D9nXacjjzv0v3YcH/nQhOY/3ewkZSX44b/D
7tAoppPEv54WaDHkDu2/9Ejcz4Ky3b/F9eWf+0vmP6+d/1D22uW/1auC72Z/
8L+C6EZEdp/GP2H6MfEL+86/PKv+KE+m8D++nrX6IACxvyBfh5hD7tE/3KHI
HllL3z8WjpvEcJC0P8SnSpSye+4/m1cOXDEK4T+JhGqZ+FXnvyoCFH6/++I/
hRu8Dw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.9703328171418877`, -0.9343041568932107, \
-2.5824918842284443`}], 53->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAt1uda7I34r+8vu6wJD2+P3w3WgC6
8t6/Z34e9ZRy4j8TQC3evxG/v05+BQeKWN4/XGMqc8Tw4r/aFkbKx/Dkv1S5
973UIPS/ltFbUcdl37+OVwiMdaTxP1ia16mXfu6/tQP2NSth+L92I4Jq/F+x
P/gwyZDsz6k/ZGUMnQVI+D/g8AMjM0nOP9IAww0Gl6c/5ibVGzNv2j+w2m1c
4bzbPyZRkGOndfY/TnuNIHdj5T8kvaJQJu3yv5kXCfyaC+c/it9jbzuU4r8D
Pyg0IynRvzNHDj6D3eu/QaIlCkv14L96QxfXR4jjPwtbAlX6++a/yFjiNYK+
8L8ZcbiNkM63P1wRQW68uMu/TNLNC6jA8D+uodpnpoCtPzTvXmS1pdA/2hEJ
gy6q3z+qiuJkcfjDP7qwUeXJC+4/2vzVCgbr4z8lkYVOQt7kv2Drxf/vG+M/
IJ6yyw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.978752901382878, 0.8930537541357196, 
                 2.5906354331501253`}], 54->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzLdYMocl4r+++W1h6LW/P2gHJaGd
CN+/U4DaPrFs4j9uKP/qYFvAv1yh70IJTt4/+pYTAind478bAc1H1mPlv5yb
Gi4FzfO/oNe08WeS3b/zt1w6Nn/xP/s9PdC0Ve+/68pTPx9Q+L9kHiZMSKi9
P/kzaGVUNaw/UbaDz/wz+D+qSRUDnwbRP0sGqaMqfLE/HAjYm8M72T+OMS5g
zRPZP/cW2rCEuPY/QAdu6pX55T/ktC33XB7zv6dprikl6eU/Yyc2GlgB47/k
QZ87GW3Rv3bdY5Ysj+u/zpGZlV134L+Pl3PAlHrjP9jgZ9ABbee/aBNAbHGx
8L8RDMpWGK++P+gAeBTzgcu/PXt4tyq18D/maisb3bGxP3jx7PWJVtE/YYTG
DJMK3z9Wna7qHObAP07/lQEHTO4/ykOklCMz5D/ymY0UySnlvyodk+UUiOI/
YuWvSw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.977315781861854, 0.8920812559872141, 
                 2.5920673856048415`}], 55->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKQGnIEw24r9hGjqk+oy9P/0kN8OY
Bt+/rSx5pluG4j8rv2noOK6+v7wnQc+tNN4/GXp9Yjqr5L9Yren6FI7mv8fR
qzLiRvO/NYhP7OkI3b/PK8objgTxP/wwP7h9RfC/S0oL10FC+L/ZZTpt5nLC
P/4M/IZzbrA/MEwUxZ0K+D932uHTXlnUP6sPK0S36bQ/SgChGNwY2D800J/s
E7fXP3TqWOzd4PY/wja+1HlC5z91VEcS6f3yvwtfW+jzFOU/oT2SQcNw478M
amKmddzSvwabeWOICOu/omJni2Bd4L91zQ3GXd3iPzz6DOkjB+i/cGWv87Ou
8L+FuavfsZzAP74heOH76sq/Q3EozOWm8D9Z1Y4zoVu5P9T1JdCNt9E/0qzJ
ssmS3j9qYIWyhQvAP2M0KWAJbu4/uLGbvWrk5D9n8M2gzOjkv3T5/WelF+I/
yVe5hw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.9770970439290763`, 0.8928765902800303, 
                 2.5919603919459906`}], 56->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA08w+9M084r8Temr245+8P0dYluyN
CN+/HzC7bPiQ4j9ioehof8+9v9tPkb/+K94/WnxC3QWC5b+NmTS9rGfnv7Pm
xLOAy/K/7HKIBYn9279dMVsZspnwP/QdDMw70/C/SQzQNdUw+L93Y4/epUjH
P+2T3xTkr7E/Ay7EEore9z/tsSQnlifXP0GGMQFDxLk/w2+qAwDt1j8940lT
6qbVPxMKOVTAFPc/EX8aFrZa6D8v1nO4lu/yvzlqkdW6E+Q/lqTA6Gnf479K
Smc+sNPTv8R86i6kjeq/JIOBO8kd4L/+2MFYsGPiPwa0MUdflei/Wbn3F56n
8L9AUOLsS8zCP0xzXueUnMq/CeOQJIOT8D8qE9WZbGe/P7bY7r+HTtI/AGiQ
bngH3j/KdR/yFGa8PwpeHQTAn+4/mNdqQdd15T9FYAKvjszkvxMJrRrdlOE/
PVC2Hw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.9779606819850422`, 0.8918818119571635, 
                 2.5916439520160313`},
                ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 57->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQWfGy0Q44r+lZQx8CFy9PwxcbY2G
C9+/5KR+U0eK4j/DKR9GeYO+v1MezWmYNN4/DscPLA9z5r+N1yckl9vnvw/e
klF2X/K/MBfy0lpP2r/UKHqgfUXwP3hqWkXoUPG/VX/5FmgX+L9keVIK0L/N
P6K8Rg9LBLI/36tjGNm09z9hY1VodDvZP2SGdIdxI8A/AKsYbDK61T9B96Se
orzSP3zPURomU/c/HZA9v74w6T8LOjufOvvyv0gr4hGC3OI/KBfr+6lV5L/Z
SqYUFjDUvxI17vRXIuq/2XI/NfJf378u7zooPhviP3vBtejJE+m/e1luPsWZ
8L8bViwk6jbGP+Ssm8lzisq/KH8RYf588D/wmM0WlprBP8Kww5YoI9M/ZPqK
iWBn3T+hWTqaiDe2PxAXxTRM4O4/gBpeCYPd5T+nLJ0zcuPkvzldZCNn++A/
Qc+pJA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.9780309537088736`, 0.8908182918033151, 
                 2.591956079326613}], 58->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQgQFdyI84r89W6aDWC6+P2MdpD/F
+N6/wbrEwuCE4j/O9sbr7yi/v7GTICRTOt4/u46t81E9579DgSIy8Bvov/tU
E0AOCfK/PvUtygj82L+tISAR7/3vP+G5EHOVr/G/9aWXBBUA+L/wM9e3/J7R
P8GAZN5YZrI/Bmt8Mtx49z+uDhTyoM3bP0Fkiq7VKcQ/w0RJXHFh1D/jKlJc
WuLNP/UNCzrkmPc/EVZk7VBQ6j+UIW+JyPjyv6WrJUN3R+E/fklZNbq85L/c
ta0hJVbUv1Rc/I8/x+m/4f4b3Ca63r+KdsoQ3eHhPzrB+cLGbem/CxQNIBOP
8L/AysDYkirJPzL9CggvX8q/M2TvSaZd8D/7UCL3ZAPEP+nisv2eJ9Q/Il3p
cJm13D/4Xt3MxJusP+IyEwN5J+8/aYgU2Jhq5j8BkSuIV+vkv7/6mmpQMuA/
PBq1Cw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.9851613028017856`, -0.8548328303463973, \
-2.598614137193186}], 59->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkfeIFqxc4r+bGhK/b/G7P9ALzXe1
z96/2/c4otmT4j9/ix/FmbC8v8swricZP94/Vk6HrQsb6L9mXZiAvh3pv1L7
UxrjYfG/czzSdHpI2L81OCpvZJjuP6AREKoJVfK/ZIhIunLp979XtT6dPi7U
PxNKFH677bI/eOFFFZwu9z8+XF8mIPTePyOJ24hrY8Y/iwZ0o+WA0z8KqHvx
55bJP4wew0sKw/c/82bZvlW96z/jVGzg1Kzyv9Ts+JGAOeA/9CII4ts75b8S
GraIkJ/Vv0Y+R3jQFem/yhXyUOmA3r/EPYYzSQvhP5RUAwj3COq/FoLGYuSL
8L/+OwONmirLP0z5R5hGFMq/sy4xc0Q88D9eeRe1+cfHP676DXZnuNQ/IPvy
c0xU3D+WxNcdNn2mP76qrpXQUu8/Zy+JsJco5z+bTb583nfkvzoF0CUNWd8/
C/uxkw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.9831952277478089`, -0.8588529176922721, \
-2.598789786498667}], 60->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABDvAp0JW4r9F/9JFff26P55E4c0C
7t6/W/Qw6hh14j8Pz3Kb0167v0Sff57mnt4/dRkmk/xa6L+xNd7gQJfpv5HT
Vgf2GfG/uzvO1L4U1780BTgS07ftP73ABSfMv/K/bLSYytTd9793R9BEWBTW
P/2OYIORhK8/aPlj7hnA9j+gc/+STT/hP6xXVahrUcw/nAnFDdx40T+u+sMN
E2TBP2+cMbaiBvg/mUnyVo1F7T/gASzKclvyvxKutqBRgt0/PCpznZ9Y5b/J
1SM4kTfWv7gkz7p21ei/4lgnEqLg3b+OMnldwYvgP+QRftpMe+q/92g8D3uE
8L9IB0WWt9PMP74ydZ1w/cq/lnN8Y6b67z98MyI/5qbLP40lVTnOY9Y/KXkT
8YYx2z84mVQASqWNP0CE0V1cru8/+p6RIFPd5z/RLuMDYBHkv6smmx+cEN4/
kXC05g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-2.0195637418032493`, 0.7968861559336123, 
                 2.5905085885352714`}], 61->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA7JcadUdq4r8AF9EVVL+6P8+ffnIx
wt6/hPSRdEdq4j9FD64rU7+6v+G2u1Ixwt4/Kq02LwJW6b8zBtr8sRTqv1p6
HZOph/C/XwlrcsCp1b/MSBytb3bsP80ojUXwSPO/Z2tkcPm097/vFNHIDpbZ
P83U/V2iPK0/gX7fAddx9j9PTDH5lljiP30rPNVB3M8/fQkrpjad0D968nkc
dmm1P+bU/ZNdLvg/HgQ43Yti7j9hqMRRRRnyv6I2WJE789o/i6Io0iTg5b9T
4x96x7zWv04ive81OOi/nBxQric/3b+sa9YvWs7fP8DQLKJ8+eq/rtt4lQ51
8L9YrSLn8SLQPzblviadGsu/w3govPqm7z/OFHcnWQHOP1DmrB4pWNc/Qnmn
x+K42j8oc9A8dFeFv57CrOjp3u8/UfzkqGlm6D9WiX+EOsXjv8L2CXK22tw/
Ic62cg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.6069546013452312`, 1.8516290067288985`, 
                 2.32670731521082}], 62->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA4djBez2B4r9hhhAZafe5P19jw54q
ld6/MVoWnWhg4j+1yw7dOo+5v+ep9YNi6d4//cUroqlE6r8H9Y2YNqDqv3ox
uLKm1e+/77kwANl11L+SQZwWkwjrP2ayI4El0fO/QZdHYUKI97+fI2C1L93c
P9/TuGVRZ6k/D0WA4GQZ9j85cvjWlIPjP6098NDGrNE/MtXKPTa/zz/llcYO
KWehPyR9vpt0TPg/dGpaXViO7z+8hH6eAL/xv9p+a60nkNg/b8/2jvNi5r87
5Gt1SWHXv5TxDAEekOe/2DXa+ym83L9eUr45gEfePz6L1Chwduu/2UGUj3Bk
8L+cItL9hK3RP+RIDHJAaMu/KHILL5lJ7z/DmFZ7rVHQP8rzcqoUS9g/fg+J
LDZQ2j/CgKtVptugv8/zXZ5mA/A/UmI4fWD36D94cU9M9Ffjv2CUsBjFvNs/
CPa2yA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8578347510111645, 
                 3.25193264328275, -0.3368287747649862}], 63->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAANB4Z+p+S4r+nlZQhSL+5PxOdiDmA
bN6/cejIfQhT4j+7mb50gvW4v/GPHByMD98/hneafQY567/qdj/Hxvzqv87u
p8fvq+6/HqEK2SU707/k7Hdg86zpPzYwhpGCSPS/Ikb9VIxR978lCyOEzRTg
P/F/hIsIh6Q/tSp0B6LA9T/O0vHVkIfkP1XKlbWqmNM/DdbrG6drzj+6oEBR
NDaTvzhbOaGrYPg/WQxr0o1O8D8505vdCGbxv3nJKDyjKtY/3crZO9Pl5r81
5AzD3cTXv6weNvIX8ea/w26e5jIw3L+Zf6pk3OTcP3pX6J+i4+u/nuoEKW5N
8L/anVWItkzTPxQNGCif28u/7p5YRibq7j+W/1mH4GjRPyMt2WgbVNk/9N3D
RPLt2T/qwQ6JD8Otv5o/IFRHEvA/koBPERJ46T/VvOcEYfXiv7WsIqwXndo/
6ey5rA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8563633964399463, 
                 3.252180336897317, -0.3381786355408894}], 64->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA6fyktVGh4r82+jCAhq+5P3VE6b0x
R96/7LXo0KdI4j+x1cJA8JS4vwR8tQK1Kt8/gfGkFfk07L/NVZzKlkLrvw92
J2Sgfe2/282N1DQh0r/slriK1FHoPy74p6LUtfS/C5aA5j8S978W4sxxtqvh
Pzz//TaxNp4/tmPJAqZo9T/Uk7VreXDlP3BvX5iBfdU/kxHUH09tzT9iFAja
E8Cxv/64pHDCaPg/tyw4pw7L8D9xiJLPXgvxv/JGADUZ69M/NfekZSVr57+G
Npb6pQzYvyUMjqGcUOa/1uPrH+yx278ytr5axYfbP0xJIhKhR+y/QIqpYHQx
8L9cAdNBp+HUP4JkearGY8y/rL496/mM7j8eOZ1j213SP7p1ik0bVNo/Ubrd
mPuj2T8KdWUNgiq1vwAMqdi3GfA/rYesj2Lv6T/MtZ7TrZTiv3vh2hvnitk/
WMu8sw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.8573893152780458, 
                 3.2515740099543757`, -0.34139422935407027`}], 65->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQxD4ITCv4r/TOs6YPFi5P0Cg+1bZ
Jt6/55waO0VF4j91o1VhHAe4v40PGH/vNt8/XSGcmiEh7b/28Viq9IXrvw9D
enlMTuy/SVF47whT0b8uVshwv/nmP8+Jra95GPW/dbm5EuXS9r+AvJyYOAnj
P1sPuTGXCJM/W8x1A8cJ9T/q04VzRl/mPxSbSBVRWtc/pclNX/nJzD8CD42K
oue9vwn43MteZfg/h38cVSdK8T/MfoSevKTwv9IW9mYTztE/0BhK3ijo57+b
Kj8X7VrYv5gJfJLcsOW/6Di0mbRY27+JHeIDxyTaP99xbAUwouy/y+DakT4V
8L/ag7YrQDTWP0oP4ONP9sy/zhoDoWks7j98H1vnYl7TP1BVMEqgSNs/UA/u
ksN32T88WfF1X/e6v/Z90VWNGfA/+s2p8sls6j8D2ZlkLiXivzATB3OBgtg/
MAaxKg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8506908284373658, 
                 3.2529201527482576`, -0.34530507418338874`},
                ImageCache->GraphicsData["CompressedBitmap", "\<\
eJzsvQecLFWZ/l//6p65ERBcd93VXe+aSKKuYVcRcCTnzL0XLmGISg6KZBxF
yTnnIQdJZjIjSFSCIChKGOPu6qoYVjfp1u/9njpv9VunTlVXzwzofj5/Pp8e
+vZ091Q953mf9znvSZvs/LGP7L7vzh/bc9edF6x30M4HfGTPXT+6YN39D5KX
Ov9fkqTflMeLC5KuPM+SJP7jqST5/1/483rhi+5pZ8H7RkYWjOSPpLtgZP31
3W9fa955o3u6NO8ced9qq42uOjIyvvqaa06MrL129qH11svWlM+svcEG2Tob
bpitu9FG2Xobb5ytv8km2QabbpptsNlmabbh5psnQ5Pyc2KjzTcfk/+Prb/p
piPrb7xx/v3Lmr91nXv6F/yt0VVXX3181Q9+cHL1D30ok7+XfZC/t+662Zry
N4u/J39rPflb6+d/iz+VbbTFFtnGW26ZbbLVVtmmPLbeOs0222abZFa22cKF
2eb6WLRoUv49Jr/uXctS5lqudk9fx7WMrbrGGhPvX331TK4n+8DISOP16L1X
rmXrrbmM4iK2WLQo22Lx4mxLHttum2217bZJmm213XbJcLb1dtvxjMek/G5M
3rNgffk+rmiuucYr3dO/4xrBKpPrdI/pXqNen7k2d01bL1mSbcNj++2zhdtv
n2YLd9ihky3aYYeky1Nem1y4ZAnX665vtrnWy3qMo23BM+lwtcnfZKtJG6+x
1lrZiL/etTynCj759hUC9b/W8Drluhbx2HHHNFu8007yR7fdaads29FRHnLh
/Ozwm2zxjjuOyS3k1ztsrn08v3aue9JjLG3Fz7/OPiC4r67Xv846Dmuuv4iH
JqxzIuY80GuXB9e+UK99xx0Td+EpV5pm2+28cydbsssunWz7XXdNeSZXLy/y
27GF8mZ3xV1z9Zf0kM9ZLNedI//aElOKq29gyiZy9THklSEl1BVxh7G7Rh5y
xSnXLtew/W67ZTvIY8fdd5d7lJ/yY4893DP5EL+R903KB8akady9pOa+Lurd
15i2StczqtV9GcWoY5S9L1rEM8nRRZsjmcM9cal6M9lOe+yRjX74w9noRz6S
7bznntkue+6ZDGW77LWXBLc8z3aW13eS38v7ub2RxfLV5s4u7N3ZZPnO3tS7
M8u3mjvbuO7ObJz0Wiu/Kx8cNFXpluzt7LVXtuvee0ub7bbPPtKOu++7b7bH
fvvxkNvMf/Labnvv7W5X4BjbToj6v+Yez4+03pD7+Zb4PWpMxVg56D2G9+eb
i2bx98adFff14f33l3v9yAEHyL3ueeCB2Z4HHZTtddBBcr38HHavyW+zD8t7
5XOT8h0jWy9e/Adzu+dFmjS/3ZWdhKxmJORD/nbXbpCQ2O0WRA1uVdlZMJPb
lGbZVW6VJjK36W6D29mLW/zoR7O95bHPxz6W7XPwwdm+Bx8sMOz78Y8nc7P9
Pv5xnuUP+R2/5718ju/ZY999RyS8/8dAcG4tBG9zmVUh+GBDFtiQLGAg0Nsv
4tTHKHpRamV/69rCTbcd3LK7RW53/0MOyfY/9NDsgEMPTbMDDjtMyHDgYYdl
Bx5+OP9P8teG3Vv2k7fyMb5Kvn5sx912+2+DxDk9JDRnywf5uXy2Wl3utij4
PKg5JIpAwHMaH467hjd3X9w5jS13zR2X7pZbzG9TNOigI46Q2/7oEUdkHz3y
SB7Sgh876igxV+7f8vpBAgef2S+//XH5O8l/mXs/O793jXlz72/N474ml3Lv
G/jWJ96V/Ki03vdCc9+W9O6+aXWJaSGma3Ft7X30ns39cg96j3J3aXbw0UfL
bX/8E5/IPj42lh0yNiZQ8DN/7RD/Wup+znbv4XX5FB93X3NgDsmE/Nn/NGic
1XMWARorxWPCMwEFJBasFCgLVALCGLAMcEiY1nec15YXFCD1QT0E3K24W//k
J7ND5XHYpz6VHXbMMdnhxxzTyY749Kflx2c+k7in2eE8jjlG4ODnHPc+9355
8Fng4vv4bkEbSJL/MJicGcFklkqliQ6NjHVNVGxidMEyAzkks3kD4vSgwEKi
QbFw8Q8jfAQUbJBrdRj45nYYcP9yr3Ln2ZHHHpsdxeO447Kjjz8++8Txx8s1
f+KEEwQT/n20vC6/E0zknUKRI+UzfI7P8z18H98vmE9IW/zewHFGRCxmebFQ
86lwFIEicNhAKQRCqREEiUqjCoMGCLTYVykBFEIJpYPCII3smp1bAgJ3+3Lj
aTZ24oly+5886aTsUyefzEOi5phTTuHnqadmn5aH/ItH6n45z7117IQTQK+H
mnwlX324R0n+PAglvzMQnW4gAooeRHkURSGyWoKG4vZ8AlX9tNnDakgJHoma
gikeHmUJjOe6A2gApoAFCASKNPvMaacJWseefnp27BlnZMedcYYgKD/lx5ln
+mfyy2Q+byzA41s+Kd/GN/LNIMZfg1PSSGOibv9ugDotkoJzoN4Z55I3kwBV
G1ZWbAMeaUghskhLLUjKH7n8EkA5OO6WQeY4kDnzzOz4s87KTuBx9tnZiTzO
OaeTnXTOOWl20rnnJq/iKa+53/Ee3s9n+Q6FDvD5G/w9/i4clusZkQb+bRUy
27/2ruUduUIHimRh2ziEzfciFhvY8J87BapcCT2jQAqZCzk45SEr+BTAdbzA
dUIOkYNFAMpOPu88Idcp558/lJ16wQXCutMuuIBn7l/uF8lSvMm9mQ+CNbiH
1CNQaTe5qAXiKpPfGOBOjch4DtzbnYy71Gal3ANn05oDLtAta9wJSlysalbB
NQlI9OqjyjW0SnkWAc1xLAZYDhaIgE2anXbhhQLX6RddlJ1x8cU8JHzOvOSS
1D1dyv1C3uKw5DOKH9/J939a8IPT8FuuYwK/YDE7JaL1ecfvvSWyqSXQFKiC
1gY3ZwN8jO6hMapCFpLNp7kjTGxGMRN+EGsQzODlsFCwBKbszEsvzc6Sx9nj
49nZl10mXDvnssuGsnMuv1yCVp7yovslb+IDfPA0+QK+jC/mj9hA5mJEWcc+
duSRvzY4ntzDsSh55Dj+U9Hbsh1MrJVaidrAjeCoWhcGrXQRSjpX4p7EDO1f
YCicKGHoORfDT7EDKgEtO/eKK7LzeFx5ZXb+lVcKNc+/6qo0u4Af8kxAlVfd
b3nXufIJPnmWfAPfdrp8K3+Fv3iCV0iuhiuT1h4RZvyqCmopoDuenEUXNqy5
iHun/6aGpC2ou1lQTfIgoAsVjBATYXLqZwI5BDQG5rk9EAEuu+Dqq4WcF15z
TSe76NprhTsXX3ttdvF11+kj5WX3Bol6ebP7EF8AxpAYptNyRIJVALnICbnw
xAJ7ko36PM14YP+xVF60XULXLaIjALAYX7ExNjs3AfthD2xJKX3Eq6OLMdWl
FAXVR3oFVAVUcIBzAAo+glR2EY8cxzS75Prr0+zSz35W7vTSG27IxvOH/Et+
ul+4twi6IM4nFWWa6mzPYP4yzUvsHJujOyKxl7xURbeUwPPi7bsrhSaHrhnQ
cN0sj+5mFl2SeB26mEOfhzCGqqdOB0BXdAAzSO6sUBYNMBrq4j9EVqma09Rh
IxglOV5doMvRvPHG7LIbb0yzy2+6SX7cfHM3u+Lmm5Nlecpr2WU85E28mQ/J
xx3NaSoHtDQhMcIFcEE0u1B4EltvAT4xB5jRoQDg1aIAr2UAtomr6Kh4c4lL
atIFC7AVWpxRTBOOM3qgCcqJq2qB0hbKyv1f2KOrw0aBBTPwA8crbrklu5LH
5z6XXfW5z3Wyqz7/+U529ec/nyzHU15zv+M9vJfPKOYOb/luGpG/yd8/w2At
ZmHs8E9+8pcVqD+oOa034KPePSic2MJRSYK1VBB4+B0iOS0G82EGZjpsViFQ
OvLYyR7mQh283CrE54cQB/AKWXvQCpRX8/jCF4Ra13zxi7Oza7/0JUlv8jS7
5gtf4BfuTbz5Cs9vxfgiz+dzDL4EmvDCYntCjq31XiVsw6LU2sGAZ0mFfRmG
jqQ1+qMRbPeLYevTWkl9A31Q+obaUOiCxzWk7RUWU4ENCK/lIYCm2XVf/nKa
Xf+Vr8zKPnvrre5Zsgwv8mv3Voc0KMvXoCB8vbKYS1C1EDMxeqjY219UIP5Q
aaySRwVeO57sx3c3NCoRcw9FdyB0DhZe7TsJvEcbeNWCYYJIbKfI9RfSG9BW
k5mqQgGtVwOwgaqwElivE9zAT5AE0uyzt92W3XDbbZLobrz9dn7ecUd2U/4Q
+Pm5nHtNfpvdwEPez+f4vLaDsh2mK8sL/IUScg+Tck8W+uNz6B27P2DgXy2A
Phxa30Ch98qhAh1mQCpIu/ieGD0KnDCmTb2FZXYUeiPMqhiIsmX1hZ7VKsaW
0QXsOZNLkAMhcN5YwHzznXd2slvuuqub3XL33SnP3GtC9ZsUeg+7hRw14m+i
VAo31yoROQLVf17Be62xkpII9lGaW6zNkFZJSYxKu2S4557Z7vvsU2C9rxrk
AOujBsQaz6bJr6TKqshNOCvGd94JmsAKvtnn7rkn+/w99wjZPz8x0c2+MDGR
8kysiLzqfvs5eRfv5lO0gEWfQOKv0tK0PEwgIEVkxqmZRVDv5Ue02wymNA0i
WguiDpqSsdVu9XfUGegv08/TLgnersiJqtt1iKtmG1Gxeq2CAuNUp0toe0aD
lSINhuApyGZf+OpXsy/yuPfeZHb2pfvuS16dfenee/m3e53f8z6wp4X4jhs9
7nw/rUtE0epcE9eIsAjTF8D0fzOYH+eerlnKm6v5OmJh9xow39QzXf1ISVV8
fafIl75GcZDB/HBj9zRXFmLuMdc8GQq5qkkdw0N2F3grqxVrwVVQzr78ta+l
2Vfuv39WdusDD7hnouZf+drX+IV7Aw/eLDHgGqsAX76cP3StAi8E4OIgiNzA
qNxgFfNi4LyiLDps2jRQrknUehTqtxQiVcVDf0K3W3uHFu9j++BNL/DCAO+S
cht+F4ptuS1QAZnBObv1/vvT7LYHHxRZuf2hh7I7Hn6Yh3SA5Kd7STh/m/xC
3pLdyuOBB2iQoim0Gfjum+Vv0AT8ba4DDnCNqKCo4/jxZ58d4XxPZ2zdvBiy
bsBex2M0i6rGuC6OH2Coy6DUW7XvqJ7bYo++VLC3au6zpmqLKrny3OmK1RRw
F46DGfiBowJ+59e/nt39jW9kdz/6qAB/z6OPpvwzze76+tfl3/z2zkceye7g
8fDDqWuUZfIG8Y2hDcEf4Q/S6FwEFwU5IAvpX27MCc/PTCMc656uXQjPaj4I
inFSMxhWN3+pCAKfXmOiUxJ67WNiY2gEEXr6l67j4825FflYI1yqjVAjNiXy
e1FHZBBwR3zfAEAL+Pc89lj21ccfz+795jez+558spN97cknk7/J7pN/3vvE
E9lX5TEhv+Zt0kK0lfvYXbSOtpC05e0aK/L1LkaCZuHSiFO44+NiVPJcpEUK
WSL1OkmyabfPRJYwLGJmh+4oo7Jaoj7cpF3t7btuqO8qFSbHp1yVo2hrqG83
UuRkvyYcgAz4gHNCIAby+596Knvw6aezh7797eyR73wnzR559tnkdTx1L/Gr
+7/1LdrJNRotRAPy8aKVaCF50ELaOqiYBk3RMhKtXCqXzq3I7Y3LrccCpZjC
qkFSyhLBxJpwIpzNFASJdrWoJTo35P2nZonDwixhnJD2XgvfGWbkWJOY7KDO
J8wMleAQHMH1a9IcDz3zTPb1Z5/NHnvuueyJF1/MnpycTLMnv/99aZZvTk5m
j7/wQvaN732PhnJN9IA0ER+7L2wiH0h8tWseHzy3RZoG5hDX3Ibc2sSp558f
aZadXbNgmIgULesWBRsz4zU2u20bGykmeReFG2+WPh7qliYPk7iLgoJ2BUKT
FGmS622T2GRdo1dQmwh5QOhPONAc0grZMz/+cfbsv/xL9r2f/jR77mc/c///
7r/+a/btn/wke+oHP3BNFmsfQsi2Ual9CB35m5gA1zZe0LhOxIzkx30JBUvt
8hn3dFeXV2xOCeeaFDN5a2YdFuESdh40saupiimYzycn+XxSGCrtokXMVF27
VPKIGihtF8HJtYtg6NpFMCYenv7Rj1wbvPiLX2Q//PWvs5/8+79n//y737n/
/+g3v8kmf/lL1060EW342PPPZ1//7nezh6VdH5Rwe0BlLogj10YmfrR9CGG4
wzVzD3hg6ewtGDvuuOSnlfZZx9WbMb42bqyUqeEqzec1M0K1vryjL13soXGj
+d6arlDKtMhpskuR6333udQ24mXI8zaz1LWNNVmVmJG2eULahnh5XuKEdvnp
f/5n9ss//jH7dZYlafYb+fn67KX//d/sp//1X66dXvj5z7Pv/PM/uzhSnXvY
x1FTO7k4kjZyMYS+CWe4RjIh149xv+iaa0YFi2rz7Dqm/cDS2Go4eZHQsVOt
zWRd+t6aaTR09jahc7CEjva5jzahY/2wkzSTZUIbdpn2QYwFqzRNjf8tMoxP
+ND+cQkBwgYJ+7FA//P/+Z/s37Ms+295/G+W/8f//0cevP6LP/zBhdMLEmJh
E9HUD6tjiDSTCyVpIsKIFIQ74Bo1hLgfoeC4mKBI+OSVKaTNTlrZMDLBcgs7
Dd5MpHahI+aslHLC0AlcgDVmTbKmNRD647G2ualF2EBdpAaswA9MwRdJI2z+
7b//O/td3h7JMA0jnvn3vk1+/NvfZs//27/1pI02kVSFvMXaxbYJYUPquV3a
hGtyISPXy/XLPY2LXFSbY82J94sxowtZGjE3odJvojcOYCc1ZUGWKYWKyf7W
kJVUzBdcSxnGZ/5rNMPQUzFGrKkpoKjzxibDkNGBl+zyr//xH+hW9scsm+1a
4q9ddPxMBOwHv/pV9l1JMk+L4GHUipYgQnxrPETC8aaACClaQqKT5EaCcZEh
jMGUScRPSFcgEhUfmtCEsrbvPGrt286k3NJMFVzoR9B0RqXrxUdMmI0IRn91
1KxI9KiVj4iYWpUSiW0C3z0pGa+wp+6bwHUUBRfnhwUvIgJ2a0T8XJj/n4L+
HN8GqNZL8viJJP1CoX74w+wJ3w6PitrZttCoeECiQtuBCNQkotHA9UoynGSS
RaQNJplE4lTJzm8IJvbabLEomNHKWAQdeO2bWLNVFwY2mTcqUpgttLPeYHwd
/t5kfdUrElwFr8c0Y4jakAl+JXj/QdCf69rgtdlv5X//Kgn++y+9VMTBkxhi
32nh849KG9CWznypQZY2oJ0JuQmvSLf5DIFywp+Lr7++Cv9IT4XMZKgS/SPJ
YFtTtHUJ2/fWwz5I6KVK9Pf9D+gf9VEkAxQokqgJ7bAbeJsvUnHrJOoJXyMB
FoQbuFChZ0SFoPe//P73qNA8jzy54WeSI34gkUHrfNuz/5sSMQ59+WgpCiz6
PicQbfxpLoPLQiSJ2ktvuCGGPOsfdTpfZRpkg+gUQ/dGeFzVynTID/c2qU77
C9L7Xp+1SFHRsfbIo/4VUPf1kDsVdS86lvSQFTEH0helF4H+/7aHPFn438Q5
/VAc1POYV+kYwvs26D/otUd5T/qBDMQlhJEYjkhOIfmlCT8RvldW1jB7V+VG
DaqpTh2qBdvAANGvs3KvfLd97dD8WKkPs20JdZ9tFXXgABZSJXAh+UA66ZH/
jTdBcw3xgf9HmCCJi2clPRAj3xKZogmQn6IZgiYgFVvyk3a4NhjC9UsKi8FP
HwEPGk4TtJPyQ6nR4uCor5mr3Fj/yViF7VYf25L0tjvNAH5FagLo8XqlcizQ
e6l5wBcCgQfG4kGBH+L/i8D/67w/UGRdMUFO9dGeH0oTIE3P0s2WYCEKGpvB
9xtwQxoFBOHt3gGRqSSDxbKuy7jOeJqJFpsb+i8MM62fdKGT1wvh8WMWsWwb
8/8x+lvvT5e55HQC0YmWwyP4gwv4oBzg96xvg38W2ae7bJ3Pf8n/fuUzLypE
G5B9aTdCoa4dVJG0DOJCARck16QOCA4JtyJtsKZLu078Awmyy7oWmWVdNgZ0
yMI5HiTIj5EeZiTI9o9P9ilXTb+6nWgM2HTr5Yc+cQz/kvQY/MHDxYDgg/iD
H9JCG+Awf/HHPzrlFyma5btjhAJqxK9oJlIxivRd6V5/h+qghERtc/gEgTI9
YhIDBgyV5LJRUqFYpCUmiQZaIpxbu5VZ+VJaRRUs43DJIPD+Vo2s7zzFqBGF
V/X9YSKwkRAqUViVsGZHE4BGAX4dz0gkABcQwu5J8Zi0BP2Af89VSVviP31A
IEo/lrd8X7pltMT3pCVoRAKjrjU0XWtgPOTFyeWHXktMijDFOsashqY2UZo+
bjWpIR6KcezADMU0qUjJfqDoXD8TpnD/xggV8aDpWPQI109825JqmIKJAdcC
AgPEJBZcKwhhgQwY8ZoQndwA8X39KC9RvM51yn7rY+JfkCdJETRc0RrIVEOL
FFJFa1AJ9DLlUoWEr2+NCeYKR5pjfM2gOSqrTmNLC4O1TftqXcJP4Sg5JCNP
xSiqT9GlzrDpDZSCAmkyTeE6Xr72cL93/o94KXpUm0B0Ar1AlmAsWIEdeCJP
P5KOGdVUIuD3eQdtyDXH63nqXnLBIabpJ8iUZIwXtUmkNb/rm6UuUFSyQrm6
z2dvHAZNIrceSdzjeFd8a2wOdWXda82iKU0YpRKFMU0qU8X4UCxhm15CERxe
okgU3AbyRIJwRTlh3SO+N0ALOPQFBgzSt4SpQANEQAVs2hokZBLzLyVp++Dw
BbzXu8Lq73zZ4qeiVciZbY7npDvB99Q1ybdMN8NpFs0hTHHNIdd8j28Okd4x
SZbV5njPGNUL2xx2zcCiyJJsO63dDnCTNXS+zVG24+b9U9F9UK0id3ut0txt
uw4EB3kbnSLItSnwJw/5+ihBAPwML1DtEY/UoTwkxogEAXJ0yOg50DuwrYCF
nWWCItYK6NQL2goSGLGWeMbYXM0eNnOQ0IhnbQVhYrUV3u0WKdEKm9RMGQ4l
yuZtrdtpT6I2Y0QclE4rQKLCvI17IlsQEAym0GGDULTAw3JrDIaCPmVRBtYY
uPn+Sy8lKVVQ6Z6RdKkDASPPyRI/Fmn6V5EmmuF3uTTN9q3AQMN/RKRpUj76
grTg8zUtYZ2VbQXkiYxhWwEiiSEcOe2ii2wr5EPbq7vqnYsD7562CSZtlxbA
mnxdzK+0/YhYkmhwTlaStA9H/4EEgWOCQHdLckBluSU3diOhD/IQnDEAusdU
oRkrwPqQBHiNUhGGlADg9Zc84f9YdKNnuT4EXet/Ezf1z/IZEjWt9qJrUQE/
WbYMvw+Cb5sgcFIUQK8yJAlu8qbbb49MKfiHyfW8/oRrESqL2iPrF3XOWVG+
8OW6ou9gUsFZQSoofJIfKCi0B9aLR1LWY8KRfxgP5gxlMlT5M8GTvthv3VCm
5NWk63DF8NBPlt+lUD3puH/+3kM+z7vUP/hhtZ97b0Te/r4ECeqvjEe/FPaC
8T4D2CLTY34YTiEnEUsWm5DsVkX8nePrSc+5hLhdWWPV3uhMabWyt0P01mzy
dX0E21u2ak9PLWKFnM5I4sUG3SYBiq1DY5j/8pTc2nNyy3Z0UqS76xDsOM34
71w3pAF+5177j1xW3Dvm+w4yjfJLOsgSED9Wdc/JXdKW5wy5VVeeZk6HQRli
P+hRpl705fvuG7vkhhsixH776IgkV5ynnTC8KFxNH0xitYubqcvZrtgntSum
HYA+cu7G8AMxket1TpNkCqkREpInQ1c/F3EQls7x8P7Bj/1C2qXda7MdvA1Q
5lKxTJmzKhMgKQrt3Ioi6Z0KXRAhwIj45hiSbnaLEraYeh3blyCyqEO3cVAk
i7pymBgD716RZWtNvDxgS5jtgDOErEgDcvvbvDTwN15df1+PmhBXcBPIbIKz
sD1tYHME9AaPLoKo06Q0amS279vYwzL3EjVwhcuPwvW1BVwRH8EODHVZ7MoQ
Lu8hbpUuDt0bYvsbcg/PyD19X4IP0kn2eZ2p5/4igMqpYiReo1CZWMUL01tE
wCX3T0gcRJByakjnUHOPm2rTZx1cscZQkfKOqyibm06hQ6ou7wRuizrVrV4F
6QA+KkGCw/qh3P5Lkij+oKT6axeev7X5w6AVU7cKWj5/qGdlQIKuv0/Xo5dc
e22MWCPMMnNweYuk0yti08LVGu1vtxjQ8R0DV8keRdL05TG4gqQBXKTo7wCX
YEBq/qPC9dpeUUjyCA6HdOvisA1cPt0+6eGi38vgAcZSpGtS+F1d2LPyJHae
/q1FSTcDiaF0gFksYm18zERqIfqCACVS67V9UHKkkttB838phu9/HJ9yqVJX
8gtBjxjEhzsz+JvfiFQJUMmr+kL1LT/s+7ifB0m+RK4k70yIJESgYpddJ+46
vX07P3NXoXITqv1EEbt6zE6qbgNVyYWY9Kjd/y/6/qZVKjwfEz/w1r8vDFzH
FXw1P871pu5/vdF7KWQaECrT6tjmbYd2ZUIZm8i7MCMX3XCDhTBfp7pynhul
6x4u493ZDDnZnBgu8+8Ln3EXtfB5+QI+Wpy8+KQEDN2UnwgEvyoNHw2re3Oq
D2z/lcOZd83nlupV9EyQOZIChDRSl7pEunQZUO+WbV4olM6Erlx1ddHv28ap
pCNw4bq6GJgHBmC2CtsWYLqet2TNO20fRC6f0J30E5F+beutOWD/4fPCrzwN
f+W7dr/z+Mp7UjeEOq9g8H/6oH/J4kzge40UnCvB78Cu00kf/GrxqCxL8I+O
33RTFey3u528XTYJFhiN1oD9Mbts1MwUCDNJa7C9RaHuhzcmA6KTdEFgL4Nv
lDIA/KUekqmj8nwH6u896PyaEQntf1NQAlHk1DdEB6gF/N/4tuFXSEVB7h7o
mpySKMNVMry3LkmGz+Wi+CSn6q4Mq4zjDan06cTiRsCD5ehHGcCPD1J3X6XV
upJYaC20OrkQjsCVR31diXleVDaYZwSav/zjHwWGlxzi1I9+4VGmqkGSoraE
0vJ//g2cHv0OHkmig4YAaZfXpC0rUmLkJLflS+U98Abn5KyAz29ix8fE/iZV
uN8+srZw3KmzSW6jZgZkE9xHB3Cf1GAsox5AB3380JstptpSHv1AJpJS+KHA
IdCnlEOTrkOVUjZVvO8D0aTwcdilM14CRQX+n3//+5S8l/IvSZM/6qEsDSg4
p1WQA9GupbQo4N2PPjr5pXvvjeya8/Zxxj4xW5W5dXaKacMafzrXtktY9HEi
AFsrqqPMxaiaKDZmy822ljAk4cBrqmNP6+IRytMC9gs//3lKnTmFailck242
YMA86s8ILjjDUJgqzZACaMq/eoAK0moset3KpSse7TuBTD9R9WjItEU330pr
lUk63qjFEp1Lbcbw61b027nuWh0qyha+91jXJ7pB57CYQTI3LGMGyR7w6Op4
ALfEDEXYI7cpoHyHUQGJXEEVtQQDsHAICzYo6ot5mXoIGLv8q1MDXqWjGXSd
pM0nJNiq+5C9c5S+APlN+wCx2W+1W0/ouJYvrRU1n0jX2xYybzLD7iq1dyg1
g6mdpGrMhRtZrI5rpSAq3QOoQ3SChA6yeDjzOvHcXhlo6Wjp0sa18wi4W9H9
iccfn7z1wQdHhA0Wv3yTwQ9MOPJ5b4Bu7h5OogrXjZmNDYpCsClLunpZQ5XH
1csiUxaKEVo/NbnAT0dog9HZpzyG9ImgDcVyKEQcPmv5qJwUIDsOvo6Lfm+1
8tdSh/NSVUxNp8sFtE9KCLyI/bjcVPLrKqgL1pekhMPV1RE2Ge1vZuWUdosw
C4uiub+hCFmagaAz0oIVEHbSq5uBwOwD5oDo0LcAC3csuFFgy+AKgIKdIqt1
9Zy28hYxFRrgFUBNr4Egv0s8lYh9dffQVUc233prl+CXEODipfaIzOnW6a2V
XSBa5p1rI3lHZ5fZ5b33RCZVtsIzRlQf7Q7Pn/0sR2yo4GzxkFfz3y1dHp/T
sDeIojXqUuVSJ4UKC8679lqLar6Z7fvdAS1kdLI57rRYu2MnDJu1O3avgRN9
2Ecls2bc2UqmXXYYzlQq5opF5sgUqAZTAwpUvYZ6pgpsAlg3B1eeASAjbOEA
ZwigFjilnaXtSdx2N+B8p+n3TVARIOcwzlCEd7hm0Ky1tXsEnGwGz+xQznig
mTrGcIuf227DO1zSYSn5kE4y8tO80E8FsBTiEQA9NVNw6gCYeybYuTC2o5Ph
4LAfoi/q6I88Mnb9l7/87xXs/omTjCbJOwX5vNmxM4LCRX26f5+O0Uw1nG/V
ybo15HvQT1S0IV3kn1AiNaxzYwQ0QjpBcQikBDM3rBiZXKI55dEAM7mocdFy
u7P5GT3Msu0kT+NxkEC7rKiYJBJsyqIz/JtydDi0EObofnyLBWydDDLkEuIm
VBLVw1Yu7WjlpkUpVGZqVDEXR/6OzlaTFIc1tHvl50cHvMvBRe+b7Iu27Wfp
FSyDP0b3LdRuoNLLdwObet0VeqFtNfSKhWcJLk+xb8ote8hS8OoAWAdUUp5J
Wq2beawLe1W/yFliWO3ZCvl5E+8c2VwSAKUJ/LLVLptKw9g70XDp7JZcqmiX
ptNg35Ii/moAshomt5xy7ykgCHuUV/qQfyf57+ZHJ8nrOgWdg8r10CES/bBQ
nW2gwnkg8+TIA4OlHdHtFAaVKe2T1cyptmEXhSqQq8d7cHW4/26OlzxL5laW
z3zd0+ZBv2TsnnyyekrDJW5H0wXHnZY7BytN+SE27yDWJug+0HVAxu3AcGml
Y2TZfCUF9nG4g8z51xnP3BpyXqJTjpPcnQAhP5/w1JL/C3V4bZnqCsdgXcVd
frLsV/woLNcmvofl8InVpPzkp7dPEG5Oi8zcPltqLenQoN1Ssy7iS7FUZzCy
eqQpDx6VcFKsnntuCBCENW6RoV3s6Ze6UUC6r7fEId/0bEj77u5K5CpHWYVu
UcmP/1p5DFTw8wiQzvSy04HDHfR0WkEsqq4MpgPfZBYGah3p1thqnd7mSTky
nj0FMnmUCTPkxrsEW7JcsfjY7qSgWNiVT8xp4A+rsfRjwVzk2CkXXGAxuSDH
ZGSxOHMV5RgmYSSdGmSsurpa3bK9cJ2qXbZXwsUzhtqCxyfpcvPJHIdVuEuB
W4Pn1/+y9VfKX0tmOyh0LMOMwnF949KuFpL8JLzlEZkxfA9daAdJuI40suOT
QhIbz42uqbMrGYOFXXflm5zlsECXHjRyW3KzAsTX5Lbv7z3yl5erbKnh9gYQ
tHWPLVB/xgynfcOP8IAclyD6N3HhVVdZVC52T9/CAWuTBUk8ImN+qt5ndCvm
CCLRwAmWNdwcLCgPV9XeqWQhiDwycsnJMDea/FVvtyS/mdWdfheRL/tdRJAl
KjpudSG1AcnctvrvB7hcahTZm9x0q63GNt5yS6r+ie2R5adbvmmUPcbo0lpp
/YSZDxEGjC2XVqpWPv2EC+zDndgKQZHrhCk0pdxn4jbA60Ca5C+Lfdb4pe6x
xod1uxu+mEgoqvU65O8reo+Wh0OcokmjddyJsZ1J6cqPbb5w4YLNN9+8dKhA
jsuCUVYHUMSn2kdvFa4cFk4ptwJbM9HQ7jJ0jZ9Se73ZFrO0GVePM3k+6Djq
ABUbNrptG1NeEnh01yxw1a1L4B6pNxyb02WQ9A4cNL6GdF9elHMRzPVtz/Go
C/NjabffniLx5FZLlgDTLysIvZGzj92cQooiuqyLrQNAyrGoRmNsKrIJ2u6W
YVdNF5u2sj2u302u2ESUPXEFAkm0uj9rsUcrW4T6PfhQbjj06AsvmNGepcsA
+eE0rO9jvpKOGhuP4rrdcptDvcNvJ+XOx7bebrvSdrqXuqdvcMsRmXVTFDZ9
z53ETbwdESwvtNuU2+nZ59VtvxNs8mY2bhYrwT7Zc8pbAqPe8h7Cyo3O/OpX
Zkz3VdkLOhXEjOmWYCmP5zr+8b30quX+3Km6XXdGbddVx+W1SY7XFXx+VoFn
3iTrDJgqAte283uAaM8TecYVfzyXpCQ/6mzZsiSZXVPDzQ/sDu7BrvhyceLN
k1n5pvfyGvARiigMYQE3ckg6CpEfyPIw+fAqBrL8OAwVNvKzWpa7e5bF9Xz8
LCJ3Tm+XMo40ErVuPbBX4KLXlPxrBaul3cxAxskZuNH9UhhPtM7Y+R0/B5rA
k/+7A9CSv84PHArOcYht7qub4NtjR3S7cOIPNgGTK8PKrVN39WNXDZC9uqdI
ZuxPk7e1NLo2AsYSGXq6bHF67l57SfNxhu6Qu32UmfcIjGNi/5J/qUD3+vG1
NtzQzRJkQtdivzkWn6PjtZ/veLnMJ9GoLoDOKDoFNnpEjR4YBNXUCYCTbtBL
kUMwctuiJ/McTI/rEJbcJkHkxqzaQFcE5XIlMQ+hi/oekUr6QcFhvKk7jXeu
m7rGnevDHTorqs3bBOFJoSVn8P6kAuSKzipsIkAyeUCB1B4+A4fag1XxB0iE
n9ToQBPwEHpEHimikbEpOv/CDWr5AcFi3IXV574YW4ckceiGqN3gFKj9VWl2
W2WGm3cLoX16MLBPWL7IQbfSMtLL6KJ64tr08F5+SfYT2DmW+scV/FbILcWW
WzpL4cZm/ACiFiYP1En2xoJhMQhWAhXyoWsEI7KPrtzkp4AX+LGdajCgCkMe
84XFJ/24yjOKHyOn+eBJmo+Xgt9rW+HX5LbIuAiHPSJ3n96hwCk9EmGjPxfY
/d89RMr280cjuyORDzhgdIfdd/9RBc2VKvZDZ1loae4AvxZHZ4674VdBk+SK
/cCkqbxhXB2akgU+b9Y53ek3p60MTyuaftGrLrV8toemxnYO6GuaAbUeTQEN
PZpcFgkMkrhzMw891B+d3C1OnXUnzx5xRNcdMDzs/nmgOVZY2mFcQvyHBszx
PLTd5hUlpyJpSZ3KAb6n5JbY6PwfySfkEXoD5A6AZBwGDcQR3BgsGHP7Mepq
YmrfOk7NOH8dkIhkD8jEO7cXSzN2lmnl4WhHfCEG3B2Gmh/PK2ohDOkSdBxJ
nB9H7P6Vup9Dbgc4dwyxwCjUdacy/6CKn1s41mRltKdJYU/nT+H0yMHIDHkE
q4IlcfiJiH/OTAIu9rMEP3FfujHKo7oQ3uD37Xb4iZl6wfCwn9+7y/s9zBLh
5E8zFtzcWcaiWUJEYs0fb8wj5R9CRO6cqdGIG9ALo6hKfL8K5Pg6A/ocumF4
Qewy3VLMC77vSu/rMCx2NrWbdOI3BlUgH/ETJops7cfxv62zS2JATsMb+rlj
TrNRHe7hyPwQ5BRsh8ie7pko5FF6lq9/FKcfC6bgKYCMSpRORrBsa3yOrDE+
FIDI13hnqu4OS12HK75WsdS98XSzpG9YLE2+Hsw0LtvfNGppUISF68FP4Hzc
SZv5aZvyXeWTk/0jf7lTHGbL2WypO3552LEbxLExMFckgsNtX6winDsiigRT
dUQe4Yoj8giT0XX2XgXhfo7II9zGEcV85deNr7zV+0rkCun6TO+0ZboVIpTs
nb6U62LoMaO8z54XrEctAy0EFljd2bcvVHDNndLGgzol+dvOKQmuFafElIDQ
KZl9Th9Qp2lyu+IaOqXnS06pT2Lv4zQpCnJdqFZxLvM55yT5ecwd18PFr+QH
D/NzKfcaqRem2zOaHd7C7uJ8ZsFFxGKCPGcxvsynfF1XwJSMQbyTc6IN3snO
pA6daMU7Kb6iksaJ6nSzWMoawIdSWkSvSKzmdN3EHUc8DJnzg4nnFecOn6zn
DvtzMZXD7tzhz3yG43KT5yNYsv/ay2qf/CwqxfIhO02ynQ+tYPkXA1nQO7wF
pV6iZWB7MvFZ4+MpSSMlC7tnQlV3GrE8sNt6xLM73tkf7AqlitOI84Nzk+eq
8E5S/FB3te0Muiu7pUfhTgN39cTU3FXuTpcdyJ2iVLr0151SnJ9ULF8tepa6
g4pf5VJGcTgxB+f6A4r5kJ7+rDiDgR4/zgG6koYi8I6zg2DMc32khec6p43n
ipjXR4x5/abfxelpA2/Ucxn2Ljdl8wpA5rhidxjxLHda8VJFOadyKrEH1R0x
2jszd/Sgww9PvldFdAxfUOe89g2dl58uEjovEHXVSeO8vljnvGIuto3zcoh2
BvGulH6Nd6X9K2cTD7kjiZd203+KE3I5UdSekuuPI0ZI4CqpzMMaQbQ3HNPk
tHT4yjotQdQ6rSus0zJe1q6TGMRpPRdxWtYNlBzBAD4WXO0JpJT8xc1Iq13h
TiS+5Rbp+roTW82pxHoisR797E5vFQqjwaoHn8lPx02+WwF5pRH20cV2bTlD
tquuwDcx9QIfO1k1Z7K+XjYfMXdErDkvt8PVp1QLBGRuBI9THEtsjiOG4MVR
xELoszzQ7hjiU08tgXy59wobTtN3sVcVjV3yXbqCbXoVwFrf9erBXK04Fq4K
ZGKn5XZIwh0u3p2bK0LBoGj0oFwwFkIjHFp6B1+J7FFJ+M9W4Z0ctJJ1rLVi
xtaqFQu3PqotCU7DisXhrbW10sgkA4CxI390ciTi5Nvzc3LdsaL5Q16Tn+4X
qXvPvN7ZxMGZuHpsJfEstJsUfJIYzlPxZCdFPNlVoSdjhUtYMcQ0TL9i2NLy
PmQsr5vfyMQ6QUmPw72pd1RrSg7pugGfV7l04g5i9YexuoMR/cGg1wVH4SrK
2D1hH8fgfqcKcs+Z+ZWEgLzLAM7swtCZmW0Y6pzZNMuKufFdrtn49la9uwSs
sWaPZPWH36bF2beC8Of96Z/h0bd68LAewXqlOQmUmD71/PPHP33KKRGEB3dq
gjBOzdUbcWoe4Sus9404Na03Rp1am3qjcWqvbuV73dwFSba0NcpLriudu5qf
Ccrssvvuy6eYLef2ZNLzVksH38bOXfWHfhLBdF6JaARaojyC9NQcnPfEZ/lh
2CYHd0eTg2vpiTu+plPn4CrO2J87FDpjyAypi8lODzyQzCpm77i5PTni8/Pj
VJmy4tG9yZ/kqcepQi5uXXRz5Mhjjvl2Fdlp2bazAtt2TYNtm9K47Ax7Y3cK
hEBSHJFjTlJ1h6gmQ+UTOvODBpP8ENWlS4eo6kxCnUKlExyAXg9RlRgfP+70
0y3sV7iny+eze7yRw2kMbOQE8ssGGcptX6BMehXK2upZW59MeOsBnV9z0zbv
f+opacni2LPg+MCmM1IVdZ3DB8tIkbAOKIToEyeff35ShXvFyfVn0NjFxnrv
ajPWW1OvrDMcK9X65qesb/b7kqhvJuyLTX7JFX5BWnGQozkn6F57Bqo/pbY4
/9TPnNTzTxX14iBH+Tt0y4WQMcDXfTkcXmRMmMUHM1XUXLmvky52ydCJHpJC
CPTH/RETbgtfkjGrrFhNpXsE+n10H4gdQKv0NwfP3haArqczIrJiGtzpjM9U
Ua+3fAzaNVk+UFfL52ud/L3oSPLM1jrDsnyTry5Pxs2ukMeL8pkfuglPP/rN
b5LXur3A7CFyun5NTyIY5FzMW/yZi3SWOXNROBoBvecCjTfp6wJ11LnJBfYb
dZ56BbTV9Aczf+QLfo4vc0dYOvPNF17wp17OdadgsqOQOzRO4oXdFh6znM+R
z2fmz+8B7xU/nKKOhhHwgsj4KeedFwG8NLuajTymbQbN9o5NQ9ODFEhzy/L2
ZjPYZL7NxGH2hNBtDO4QNcj83rBsdcUmyYr8U/479CCU8BBL5b1bHmKg1+PJ
4Lr0V8dF0iOwT9spnq9OEditU5zieHU97H85dQ/eWz2VSbe6tHvEhYxNsT/Z
X7qds9gWi42d2G2oOIk3coRobGGOOzqUA7I4GVkIL7ZiQoy0Rf3KKRrF46xR
9Ig3GkUtqUZGsvuUVI1RbGB6X3NuJjpjv/Y3u0eSqy6Wm8jyfWjdPmPsz8R3
clG6p4UexKfY68GU4WF8eiQT8ipSO3nhtddWMRe3yC6OL4Nb/LJ1izNRZW2C
vZ9L763/cuv9QtgRz3uEI5nfFa6gu0SOHg7+mF+p+Y1geaKF/h5/HhxNDO/8
eXAR2CfW2Xhj5xm3mYJnPDfmGV+B6msLk66bB5op1khiDHBy6xOiF//lt99j
T7LiIFa/Ij+2RLZy/KE5AY6/J5IbAdzN8ZqKXTxd7eJ0hsanWIaNA95o0kXx
UMIo4Kwjlzt7Xj4L4OwNh7hoxFROPgxA13XJbvk2500K1Vwv7JZbIoCPTssq
zsBg+VT8+Uqt/bldLHe6XHEFcLNw/3K5Cwu4fl8T6Ha9PCwnnpEVf6JYDPDQ
Ki6ZplVsHEufYoW2Y2Yxlre9W6HWoMcW4Z0lGX8fcQXYxYN1D9dgrwS2T2bz
vef0hM+aIyYL2M3RYcVhVRwCI7IqjiICuZtav3EwtX5Qm9g4rXHGSrWrTNud
nypJf0+hUrFtbrDNiW5PwZ6HQG43l63dUMT0WHVnCGRMmniSAVCL+VXu6QrF
WsHpmEQ73fHmiEmcRgG3Fdx9XDlJ/BChzh5iCJrg5tZI8g5u34S6d9LTsQ1u
ggPy8GVEtVjzSen4R+BevrU/PNr4w5Mj/nCqo/DtircNgLfx5DdJMv8IRwbI
o7KjY+Q8e2c4zU5p9sA1Bb20aQ67wfhTDe7IawwTzEypAr5ivoCxjTM0O8w6
Z6hTJDEqfaZIzkj5tgnzmCHX1YvekF8tRmpPVisKoep2NbOYk3XtDnV9T1Uz
GxX5us64dA6jmE/JHGoFt8kcxsboZ6iCu2JrN36rhNoxcuV7yR3tJtkpRPsT
kaPqyUR1RwuGW7M96re1M9uMgfYYJ8NE0I46Q9atsuIy5gw/PQPOcLqV2zja
MSt+leTyg0Qc95aY3UXurA3a5Ce78ep3f1o9r65yopFH+658bgAnpEXRft+q
q5ZtIbu8tbSFZ1tb2GeK5XRKtnnSfNvA6/5IlmOCK3jvI0lpF7m3tniDZ2Wz
W3OClN3I2uLtJ3izZVUE7gUrrLBCtvYGG7SzhGz84OdfNlrCFqP3lYKt3zSw
3hLGXPhfFVsahC6cAYlT5ToPQQ450UMs124ik1QNC7jtbp5+XyWFm61bavfC
NYJSHEDi4RZLNimeoTTSebW3glDbjnROxwq2GcsfsELb8SNtgzjvq+VyjpCI
PJT98tj+nBXnkiEPiMBst69SmKFIeDaaMtvukGth9kOqE0K3CMzLT6688sru
qMuBLWDT4uG68fupl2XrgX4u8NzXy4UcLdw4UqTiMHakZbNLkcMPs8ucAO42
8je70xZb/PgNvQGaRBM7UCfcrD08U4M9Xy+8+uoI0CuOAzScHsj6NayOGXjk
vnUtdqW+1o8DCm6U5PxJsU2fEOIq1gezCzDbKQjWewrWh9RhbTbCoY5vj1ds
PL+kNw+GMwe+E4F5pZVWyt75zndmI2ut5WDefhC3V7dK5uUYr09e3wjzE9Js
N0k8HSPw1cHsejUii/1g5sBNN0+TPz6/FDXhEVF2vYhYvQnpYERQHiURgvK7
3/3ubK111ilc3oen6vKCKZlTKrj28dRvLfBl57DTWREkV2fxPUpC8HBSOBu+
SljSg9ldMA43tK7BNypLoZO0I9K3P/wwJyzWAfyOd7zDAfyP//iP2Tpiq6PG
zmyedHy4arnNWPw0Cqx5ClyhRGNGVL4gynScqNixApdC/ClRtjG5XguxGund
PIXDbYgrEMv113b+g2nifhY+25jbedvXeHPx9re/PXvXu97loH3f+96Xrb3u
ug7emIk7JjRxbaZg9luW1FxKDZG9R8LhLJYLitexyH5aLtEii7nAw1nL3BdZ
ua0Q2e9Fyio65oboiXcav/G222LIrrLKKg7Z9773vQ7ZVSXlrbHGGtlC6Q/W
2bZTIrYtnILZd2C9XcVU3TGIXir25YQTThChEFyTN9Uii5tQZNUd7yqCV4fs
8QZZYk2RrZ2kIpqLLRJJmJRbHDntvPOSKrQrO6v2D//wDw7af/qnfyqg/dCH
PpRtuNFG2Y7S2hWr5vd5KdYqtxlBn1px1MW+x1UQPoHdGwD2jVFg0VwFNvTD
nLMb2wDYAksuDm3Js4EQ6LRCySRsjf7dCqa5KwPT97znPQ7T97///dnqq6/u
MF177bWz9dZbL9t8iy2y3cVC1Lmy6YyQxyqglDHuks9eJwIDgENNWGr+UssL
ltby7iX/1/OK22BpTzF72lRUtYQt6jZy1kUXVbFcfkxNgcVytdVWyxhIUSw3
3HDDbBPpbmy22WbZom23zfaXXPYpMQitpkq2KG4+4rsXt8lnLhSxBiqBLI/x
HpCpe/EN7tcWxTozu7e4Abuz+afMHqknmVCvnHYYji5KLhA6jLOS43tVCEu+
itxkIVxLHO26kqc22GCDbOONN3YQbiHU3GabbbLFixdnS5YsyXaXaz1Urv8Y
ucbzoKf4rHHJVTeIkrp5OkpNPJbkqS8xUU1oS8/0ElHfc8Q+EJ3gAS6wbAYg
xKhuKpe7jSQBDHixOXwEwvAovWIcBRLmw1ao5ILjRCUjEI6Ezokk9IEPfCD7
4Ac/WIFwU3YsEAi33nrrAsIdd9wx21k6wtQ/XD9GTCC5FHHiXhAq7otswD3i
ZrhfApB7B4NGCId74Ty/4pOarKjETcptJctmq4lEbbfTThUAyYzfC2xROMla
QmiU1W92Efy17ulbC1+k2VuBW3PNNR1wHFC0EcczM3C0+ebZVlttlS1atCjb
ThpWgSM17iGWjkvG3ilwmBKUiVtCpULgSLU1wPXHLeYvwY2yuFxklztKls7W
kHvZQa5P8UKaw26Q1gUfzmcCYCGfj0BVZ3SAah3pEjVBtcMOO2Sj0jkNocJZ
NEHF3SlUMGVgqJoMIxcg7TdE1KQOr3nZqFwckmtPWiyCMc8Ik2SEkyQYqyC9
pdGyWJBICYC05ZZbZgsXLoyChIj0A4n7CUHifg1ISS5cHWemBSZnAbttAAt9
IKogFzeLO0vmOrHZQO7lMyJsejh1aaPyxx8fE2f7QhUmV7To50Js5lSYtpUM
uv3222c7iRTg9TFPwATrgQkTQBRYmNAshYk7sjDBpxJMgeazuVFLL8ef53JE
QZJZBEjqYBp2EH1SYDdyNP65iYkXK7AMbig0G8ZgcV4ogCWU8iZY+mTDCDJ1
zgw95GrkLpI53JMYPASEO1xf7kacKpqTTFYRmbY/CJMbiEDjJkQGSm6hP5jX
6A/UqMJZkYNkNnRJUYnUAdMBmPG15Df8Zyniu5sL5L+xt771rS9bxp8mKFPA
xHomuWqBVRp4GDno8EykintDSAWhCSGNhUXLR29605sm5ZG9+c1v7pvTgcYm
KqAhUYXQ1OV0hWbAnD5NMyTs7pJKutxLh2cpGAk8xIPc46TAMyZ0sGkpH8db
aQxY7ONtb3vbjOfyfrbHpqmWtmepgWwPCUKwEbqJOqTuqUPMZRYBaFzu1HrA
fHlEx4WUB0YCkJ9vyTRB2TyuCSqWxwFoOnm8hdmZeh5XsKzxkYvscjezaPMO
z0SVUVUiBdCEVRNIku1yXN5DTKNNriBHDKV+uVJ6k/MJc1cFsTBxDeZ3duFw
BIFoLsrqniUON4eV4DQpxKpuqlOGaMj9fHOGbmt6D5PZoOk95noGSe9y76nD
qOPggFNB6WXpgawPgklgCEpD3Mww/+rwTCwQSQlp8bhNCm4jEox2HGC8h5uq
lHyQn8tnb3nLWyr5bhAToLgNYgJeGVuEPIiUCKUErbncSMqz1OHWdTcHZhKT
4GVHWS+N4DWrAa8/E38wXdMk4SGMlRsYIlq6gNflWcprwl4oSCjBNqEHqJXm
EV0SgW2O+9m/FtDWN0yliNIvKU7dUskVCzEEp1ncQIdnKYgJWNyUj1loNoLb
etqAdXFEy+Z6sOjoKli2o/tn7yBCjwVW6rG4YCzokOcZLY4g869Z/HQviS5x
d6g1CHq6gd63DHgXRcCb53Pliiuu+H/NXcxrbcXkouSDcvkdBGZe/gwEhx2e
Cp3c56SH7SkD24UR2Oa/TBZDYetnMfoWV8IkMK+1FZNWlNuTC54NWKmLVse+
Aiuh2KQEaGJBuqAH0oSq2FJTNBmANIjJGLC00sdk1CNlzRhISUPKPcoVD6Ep
nbw4LJjJtxEqCpnc3gRwPVmFy/aCPFzLZ7G+dFtvUVdyebm8xdxWjkz+copq
zONaOzzrcuUdYEuBTRDjbrzYgdgYtvabBrH8vMnOSBWxFZy7mOkKhKI28xWI
CGgxQyYXNEQoDKO17llawNcBPtF/boSo4aZ4QDmJUGxG8oQB77yIhOXgrViA
t/zyy1cK6q+k3xjYos2qNRwiCPIRgW1prtA96wCgJAGanSv3j9QBOVwCEhCF
gSw+e9xgeG5E4VwaSIFQgFQQyQl/Ci/SuuATAjm7FkhkRBDsoi9z0bsOz9IC
VQEUsQZU/3BxLuGMMHFzHtAJ7F0EzZIAzuuhuVIJTczJn7r80dLdzap1d9KM
knTkkoZp6SGEZ4hnKa+l4Cq/JqC4csiaup+zCsoCKQ/uUO50jA7ZYwbScyId
ibkFpCmICktDTGEqujlVB6O4tnUwrY1fqJrDUbsnzdcBxQ54LsVVuWcprwkN
uVJyIw+Prcd1uIQrdyd3Scw/WoV0wrJ0TgDpSlFIKWfSe3slPE/L2lMU1aFK
LhLNFogEwy4XM0QADSPw7lnKa+63on0IFgAryIa8IbgTEp4W2Pxs9s6oFsgB
dnYZ2BRchbAxZMlTkBZB+FNbJMEt6WMpuyWQ9+MMPEdUAbQLtPO5qA7P0gJk
+RBXqxir7CbDJYg9vCNCqW8YeM+K5PsovKvUwgt5gRjjHtqB6fipl2GYywPP
b+XbE4ehQ7MLrsN5YdnZKXnW4bWU3wqDSQ5EXIB0hckC86RIbgTiUgKb5Qv2
aqmQB4dzCswCdj+g4TO2ASEGbLUM0/FeMw827yZtCnpJmrPW8VfQHeJS5hJf
DvGU19xvE6chMcBzWncd3h7rMVGLrxusz4xktmasU6BO3tYXaHoLSDTsnkl/
Nu3CmgCCkNB44FYCOQXaLiAvw4WkPEsLuBOnJhW0Q2oDtdzdArnTR6pQj1th
Hur5sk7hy1CPHtQptBa822CNmqhoI9iDureZrs25ebJyk/yeNuNvgB6sTXPJ
EGw7oNzhQoYItdnkjy7P0nIbiIvlgm0TKNkt/HKT41SgLPZnRGjeGvv5JdvR
D3sRmJQGSP7O0b7J5L1M1b2eG5Eb43d8j8CZpLlAK8/TAvcOv+6C+3wupsOz
tGgBAYCsjhLy4KptCFj8uTu5ywj0JT/SbYReXlM1B/4U+MUb2gCoaQB5rzRB
8vdO5QkCvKF2Z0itU/GE052JxeuITV0LeJbLrzv5AKS0wKvINynP0qItpBkg
izaFDQVtBojlm2FUSPewaYbTIxFgmqFrm6HM/xz/4ToByidtLh/GQAl+Ei5N
oJPj0CSaop9xDMc7aYKWxtG9Rq6QgMpTaeI8i8ONRw38DvQu8A9xKbMITPcs
LTeJiBG2wLZI2BrcHYJEHSTSFNWIEEmyJSPfEknYFG8fKBc0tQWOkzxBblbn
iViRJ2iXQV2mtoeaIEKHcOI7nPtu0wxp0QwdPtgB/C7NMI/rcM/SokGSpZx6
QpywOVSnguYgMJKHTHOcFqk+dQMLFEsLqxRpQR/ad5qp5qA3SwonhxAyOkKF
dSLUuSuPobtzUNCCgeYToOd3vJe+Zd4Dcj1OTcXaHkmeZV06dp9B+4Mm8VEg
f6HDn+jSJEvxhzo8c68lS7sL4A/zCJsnbBqvWRPCuUirlIrSnbpWiWWMlCZJ
aZPkLaVAadsq9HqbWkVnjGurYLLosiFstBB5hkDCDpJvkALEGR4yvpEXUlxN
xQFReH5pnSBCaJEkiJDEJQqFOem1iW8JaZNXYehSnqW8lrrWWaponVjgaMuo
r5ULHmHc5cFq05SMbOrncET0q6xepllmRfWrnMr/ttQ0sWYhn8xgs7hGycsw
HW0W1yh5X2vINokGStLcKmkuWdoqHVplGD0dJjm5Z2m5pSTVE79hQ4Xh41Vt
XG7Jts+pkVQ/lfZZYUr5hfZB0F7G9tGQceWIpFPoWE/DulbDWjaOh18aokOT
dGmcuaS8IZ6l5WaSFiIpNrUSV6QCJzcSaaGSuKURB+BbJ4k1T0rriO8aVNY0
2WjbIGu2bUg2M9A2Rs46hZzRNC7bSwP5hnEPzS6Jy/gOUXkkvbZJXOS4/inF
ft8Y0ixdGmgpjOIQz9KiqSQL8W4+xcM2VthQqndyF2jdA5WGmm2lzj2CRspr
Ip2iAIVLcy0lNFGfpo9YPEX6jjFvoM1FONnmIpxmoLmKUkjSqSaepKstpTYj
91+dwm2QXPLG6trGKpoqzRvINZUr1IqTnMuzLq+lQfPNL5ovbDouQ1MVVy13
MS53aZvtlLzZrALWN1vXNls5vFJaK1mhtf6F+ck2GDFmG0yLjtNssKJDmXSK
tFSkpKRbeEIvfE7zEmeiHbBu3xgve/IyJp8KBA9trbRorXlUJYZ51uG1TtFu
Yir4BJ/u12pIAbfAcFG1yYatJNomy23eUKnM65srCdorpblEGAND0SpZ9XPe
M9BYUaed1wZIUV2boooElXS1pTS08ijpaEvRFIlrKXkrXTTqR3TT5NGhH5bS
YevyrMtrQ7yhm08fcc3L55d236Ttr62pLak5jpaEaT72FggG91cacs5YQ9xp
K/rSTqfoPOE6woYcjkZeoZQLahNbP9MxA+1Y9F7lKjWfGYXsG3CdIuDyoUEa
YZarvtompBdNb5u5F7Poc6c8dQ3qmnYob2R5exo06PyiQW1oamNqDvRGZTTa
kLPsCG3cmMjd2cGASDCuMC317OdOZqwRO7YRk9yRDBWOxOc4l+FyD7iM5jer
ma5oFTahbz5XMPFFLPmOQw89tEPtxD0TFCml8FveVWpmF7edopnlD/Pl/BEe
/MGwnW3Q0s4+YMeR3Uojp37YpyZMjZ3pWDuT9Fo4pYFFc20TD6K3/dzMNJvX
2JhOEaS0bu5hhor2NRGa1IfovEp4atvalWK+CCbtetRRRwm6FMR4jd9RMON9
vsXle7W9O0VYu/aWpubv8Pe0yeuaWzOthjQ1BtvUJ+fCXDJFM9faYUC3UeV+
Vmj6rd21rd2T46GwsXu9iuRVfQO5bkmgr0J3KUMnc4rZSTrzkLaPtnun3O6p
a/eli3aPtbmVce6QOxdEyMVfqzT5rKLSbAO8nIO7pZpySb3TvMovjZ28pTa4
22h3vwT8sjT1cNHUxjwVfRJp7VhLa8bVlratrANujDEcd9xxnWBmczirmY8F
ES8XLG0fNH3KH5VWh2R1LR9GOu5RABmNtvqcCeu+aiZS5d5ZAl17pvR36ls9
FuRNFnrQjP1Ktfpyta0eDvQxokFT0uI0L4slTjrppOyUU07JTj311DQ77bTT
pPXlaXbyySdnJ554omMC5IAFuvZEdZ88n8IBR4FOQQGX5aX1uYS2DPA+fEzA
i8T8hJX4uLx3S2NI1XDPR/beZD1363hvkva6RN6+1YfCVu+Vi6TpjaZbg5b3
VJdrDHZtdg10opnJIrSttHR25plnZuecc0527rnnptl5550nHV95mp199tnZ
GWz1JqyAAjAFxtSIQE6BTkEBUSF4x0XwaCKBFX/v68YFt0j49wv9XmdLwl+L
Upj1kABvrIR+WzfX1HNuk9tb9LRM+7dq/je20npCluYnjIl4wpump60vvPDC
7JJLLsnGx8ezyy67zP3/0ksvzS6++OLs/PPPd1w4nZPGRCWQAihkFyB4Hnj3
r1LQM4BCKSUBj5AEVgX82N4kI3qWAScF5a+IBPSq/N1SVbIqACnNLz24mALU
mbu2uj+FbN/c+p2IofurkqHrZ+qs6NvmP+uss7ILLrjANfUVV1yRXXPNNdl1
110nf+P6668Xl37ttddmV111laPERZx0xjZ6bNrNLpARGpiegFy1cCEtc0Fo
EGqCpYLVAk0G1NqrNJjbjwaaBfJiZ6coduLx4zSI6cCgiWCa6X9wGry2FQ00
/6PUNBMJHCUnCaDuSgOi/uqrr84++9nPZjfffHP2+c9/Ps2+8IUvCBM+97nP
ZTfddBPsyK5kz082UxQ2WFEIk4Nng1yq/OGADsIEyKlsCLODFQXNCpQYI4Iw
YlNChAV5NuiWhiiqWpDvnvWWYqLhVMSgXyaYIgOSsNpWKpau1JcBtitvrQBW
jpxOMJMH0HkYgAjQ1F/84hezW2+9Nbvjjjuyu+66K7vzzjuz22+/PfvKV77i
6ABLoALCgH3ASuATQpvoqZDyh3uVIUcFMYdaGooxwWoCN+67B3QI76tKgusQ
NhBBU0JevesU1Tt6AyER3hztEfSTg6YCzwCWIEaEWE2nLAUrtyJCOMGJxiFm
UXKyAo1IXGMGkIIbb7wx+9KXvuRI8NWvfjX72te+lj3wwAPZ/fffn913333Z
Pffck912222OEGgDmQIpgVAQC4mxWcITQq5ZKZEGlFiqlhKhMICFwDTCfPAq
H2aP2fQwSGqQ17RvSHroOEYsKCWIQaShqZcwQHLIx75mhbnBsqGhurdiUwG+
0jmktaw00KKXX365C3nJB44N9957b/bQQw9l3/jGN7LHHnsse/TRR7NHHnnE
sQNWIBMkEVgEm6xE8N22nqCs6ERYIYSwJWRLilAjfKYYZb1WRCDcgDeE6LOs
IuYVc1lYsbFQ0EYW+pWGpugQWrKgY1mQ5DW5V1dqvTrx0doE3CItSN6nRWlZ
ksPExIRjAQx48skn5Tu/9a1vSdfvm9/8pmMGOkHigDXiKZ0+kGisi7SrHj0b
UugQ04hkfoUNMXnwHYlRgbVKhFnjNksEJMgrwpJt7fB4lQr5RK63lgRBU8RU
BSGWHqbIg3wop1saytGh70AL6vTAlghthsDxnXfeec4q0D8Qk+j0gMxAiwsL
sm9/+9vZs88+m33nO9/Jnn766eyJJ57IHn74YccWdIGsgnWg24n5xITCMrUO
8vekHYQLaYQMYhq07miqzrXC4OeLjgmqVSrMaaKC6kFePJDg0aEBCgghFd4c
HSRoIwv9KsZNuaFvp2GoVDnwVEjyskHHugR5DU34ywoXdHQvzA+0Fc6fSCai
iWwinEjHLpIHUAXaX7iQZt/73vekIwElnnrqKUcVDATmATGhm4m4UGlAbKCa
Vpy8OBhKdFy6eFXR4YwMP1X0QQnhrUOcEMOOEKFjKNzCUCgLMS7k26auWOlJ
ttWFsBcZ6sI080NLJvxVLRNsjrAdCWWDdQt0Iu6+++7swQcfzB5//HHHhu9+
97vyN5577jlpQFRCMoZzDygIHYxbbrml1jUoHVAkoUQnIhJiGOrowJ3YVGGo
EHOQJS7UGQVRWaMLMSasUOlR2tpiG7cQ9iZjlnEaTMjHDzp2/CBxsy6Sjk0P
SV7Qf2tUFrSuEPYqlQxIA2Sw0kDDQwBRBkjh0gbp4+tf/3pJG0Iy2Cqk7h8j
hEi5gFjaENNgGRGKg2YLbyHHBNW6TKF7ddSsVYn2H0ySWL5x7sDLqQ3tfeOQ
NQwt6PCaijbEKEFz2UID2YL+onUPNDu+8ZlnnpHvFjJIuoAi6AYeU90DxQlN
Fw2UkO9QUjiZELXRckTDrIUKK0BWkI+zIreS1jtUfUO3NKUgog9viw5ANY09
9OtNTKHA0C9TWDbUk2GFKBnsSirtVNBY1j6onUT8bceCxAAp8AxoA2SAKBCG
jgWaQqKhfI2dxD9owlBC6OYfQgrHiU4hFC04YfMG2Pp9vyel+cakMe+tSRvK
iejiQkSiWxqArmNEaCb7ZY02/YoBjeT0GNGxjMjHCJM3VZac6mi0soJORqwM
RYuTGWAGLIAdOEkKD3Q1KTzAHlgEm2AV7KKTgau0Q9meFXJNwotOOYFIxjCl
yygnuHMQ9dt65xM3O44a0phjNPFE1V66ohTcqBQl+0iFcEJzR9Nwddv8MR21
aMmLfOLuUKzolOSDgn9VUgqrFuEMpJAbWoog6nEWlB9pd6wmhSnhgvwN8RnS
WdQyJdaSzskNHBXJqb6cscVZW2aM23AjhRydQjMMN5aq5Qa3AopEq9/TXPmR
xAhydzWhuCq29ZtVe9GkHO+qXfEX5pOZUI4ZyCV1Ncl8vHCFUh6x7LArc3X2
kjIE/ScPkA8wGnZEA0+JB4UR5Bj+z795nd/zPpSDz/F5mAbjMC/0SZUhPq/E
WJLMK4qalihKEoDQLcrZ/j71ZwR4orhHcfhGB66M0ur8d0c12ZT4ElmKk093
6JamOyhbckquUqJKLNEMIiZhxaJJTKZClf7Z5TUFTyxXwu1raL+QLzoUjrnE
U5BF/CiYfLfohxhSeIIJ5XX6JjogqmpCplFDGvBFvkMY4/ZOSAPGzLZl8EJW
CAdCtDgMYKg4DMCoS5IGJ5J4hRmh83F7tSPjBkwbGNMraeRDH0qZJGfku6MK
U9eHqXOsdYMgU/EmTZSJVTcr89UlPJQqni6pry+Fe8LQkhQqLWvwF7Q+LIAN
eBXykTAkxbRICoIs9HQgDOkKgmFNVGBsCtIDQ93Os8KaTiEzPdKIwphiecEZ
bhBgg83qk0HIIw1dkOdWQ558AtZQTT8HgRoK01KPNLnQvKvCmLAq1iYvNZVG
pyI0/RgT6czkZehOoSv5gCYT4pet7NqEzugcS3IIucRqDQ6GfIMrgR7CHPku
IYvYDPSHfIQW4YKpo+B6rM7oBE1ok2/Q0kic+SXicF/g43ezdlEbkGdA7kxI
+y+AE1+ucGe4IjqlFDUUpiinNsqcmN5YV2P7Q4N63kH0JpaiQuaEoyims5P6
YU51LthJ1xtN3hDd70W1xs7VY74F4qF6o8yBLeiOZQ3M4n0wDcap2PB9mqGY
6p1vSNgtnI1/BBQSSvq6a8EgMAj2+g6ZJF+OCM0qTE9LKo0plb5YodLsSaVS
zUL+fLi2UwzX9qj07lLXKbYQuW3qajLHg3SdbNqyLseKT2zbznxExJUzXAeW
vuwyxbZZaA7sQRtILbQ6rQ8LyFY63Q+WwBZhjXwb6rOMYxBZjFTFe9AdPmNn
gvKdhkG6VCDXny6XkBbkkUSqNXvlDzekGygHm59XOCQN055C3ZBCX6iwZ447
vK/PvjZJ3ut+X6XX3SaHKX0GzWExs9xGhTR/9dvGKLJ34yy3IekbdIe7Emc0
V6nDgQfKGZ+rXI8ae8P/dZIgv1fehDOII7zJ1afDhXQK4ki60NK+coc7cav5
BUpxQAPQZwAJqvDncxX+zB2lwNegPprFjPd5b6XiH9vupc7/zEQGq5OdOt7Y
Cn6wPEhP2BCBFark+08u5ViDGyG3oDaWOao25CrtVUkvSjCnb7VM0aOCQSgP
eYvPtFAduQhlTxrIzuyCOuiq3WLY79+eH78wp6CQPRTFnsPTo9DsJgqFdUDP
oOTmqhdynbBw479iRvIHSjOS6/Zxatr0pI0PqptzFCavpj6XTVzhZqYtlhq5
lUYpTZsvOlrWvcgv9eHfVCxSsYyCJbCFrhUMosJ31113yRfefffd0u2iWkx/
ncoxrNOul7ohXeGibsj76DRfAldlVfKXhSahqGAW27/aHg5gxSlkl3HaIblo
2j7k0hrijYZcfr+JGLF6ruj9pUls/TYIC12REqufK2pKazFz3SRNOkFNSaU1
P3XIupCJtqRfJDwRHRevnLzJcYZ2hj88eA//5324aeuH4JOtE2o1mbEmRhf4
P//mdX5PzoN/KJutFyqntG/Wc9lVYklS0uEpHsRXdfP5ZafLL1MGmNVEsGiV
+rNV/+2WX+gJIJGNmprMU1MCtN67n3kaJAH2ky67F2c4yYkWtP0vGEMfTFjT
QUqSNzsC8RIEQKDooPNW/s+/eV07+3TZME92VjUTIhjCYiiLIS2GthjignCQ
Tafc81m+Q9ficEm2COCJ1il4lgYC5tZm6a6qSX6KxGtK25dPRcwiZYOBak6e
bK7MfV2lYDm3suuKHnMXs1tJL1eGHb1Q0toQLua4BsmVMUmzeZJ+EC7Lks2W
o9V2k7ZEZgQ6ESlReCSHkhCde35PQUDem+K3xRvrWj6tEaBqOn6qE7fLU3aX
caPrvMZETcbMICdKGI6XaeXJeLEkjdBOGlgH33mASr5XZ7+jNgZXuxkioCt6
XmMIeIJ7Gjtfd9ipXwsS9surMds/iGHr113UvGq7iqp4mlN1srddBEIeQ2bI
axAN71SuEwwXlSYYAss8IVMYKSREqeCtEhAyYdEgICTT+YDPPvtskk8PXdZN
D2XOD0RkziDDc1/+8pfd5/l6VFQH9G2HwKbZmPz5kSK/vXeS9g59GS5tdW+k
0B2flbyqNRFnpoBa8PAqw8PjIzwc8jxkQUPtdu0b1W7JG4pgrNMwqLdrm3Wt
r0ME6diTcTFAutgAAYR/mjIhAH6LVIj3Qp0gk47H8Tv4qFxUgfRLWot+ArME
IBXk0unJzD184YUXpDkmJyelxZ9//nlHROYdkZZJ0XyOtM33KQnDXqknYSCG
Sacoq+YlOz23xe/FCpI9Yfwzo2NRz7/C0PG4Hh2DE6JnF7uxMFMysrtG/ifW
qBjBWF62lGzb3WiandAmL1sTiCTqLHc7lRU6QTV0CRpCJ+0mkDihC66N30FN
HfkTaqbUxpLXOzbqV+icJkwfOZgZsS+++GL2gx/8IPvRj36U/fCHP4SXbpYs
0sj7+HMwn++AkeR67dFGGNkpGJn20nM+39dvlW1p2bW0LI4cE2ZGWNk7w22p
vqycXmEuPjZwmaHlsbW0nFOipVZ/A2omys0mzxjbtq1NJ6WtZwy7wWG6tn6R
Spyuy8KcQQR4BqmY0gKpkDntWUAc8i69DTjKe5A18rIQKUVjk9c5TqGmOp+K
t9MpQSnh4Pe//33Hy5/85Cfu//w7xs0WaimQl/QyNXpJ1SjfVVLPBNKNd/WM
jiKRJ0Oxs8WS/MjBju3SJPkBjvNreTrz4w/jhqGfyRlaOgQqZ+iHSgzViaPU
l/GY09nNfSosbTKVto5sTaXWkG1Cx/frmjEoYNeQquzBSBKxJFuBkA7JrGKS
L+yFqbzXl4i9+XydU1W6NFCNiVw2oVua/vjHPy4klESPxGpSt7PJtdQccZY5
TTtFbVBHS6EogeoPkelMk6lDsc53kh94O7fE1IY69TSYeolh6jERxznsfq6Z
hUvm7Ol6uvFzvxMhYrk+HHSN9cP7dYGmaj8pKeLQNNdjPWEF7IAldp0rU9Gf
eeaZfInCm53uscARwuocZJwpMgzRISr/h6y8zu9VU/msd5+OsOR8iPrcc8/x
J1wg8F502M501+03tABkyJqWE34+POK6eflWUzvZw796bO2dJNifqLOaqkRJ
fgT47HZEndJ4ykWGqJ/qEVU3NPdEnVvaFVDnnWixsrLn7of6bijftOF1m+76
dLtKMV+KWumabBI3akgCRuH8WhpnKCEZ/+ffKCDkQzHhNT7Vk9VPPZpdbP6B
R8DX8n2QnM/Ld+nyPb6Wl/hTCDmiqr40nEVrq+I1XO06X6MnHLgzvPrS1Rx8
WZwQSFnzL6Zd1pzeGM0HVlttcv2NNhrbWhz1BYawn6x1qZtVXGqMtHaHGv60
Thtu6lGFfqDf+HJb5tbNSejHXCgwHeYiiZa5cDZ1panZTm55DanlPbwXaYa9
IrcpBkGYi4ijrvw5bIiuJYpVO7EDAXM7ZeMq7c29+qMfks40uTv9knz9+M/8
WvKuLq8vYktluYttR0cnF+6ww9iW2213niHvWE7ekaqB3TzaxTKz/ErkVbKq
FVAitzlnpR+B25YE2pTqYwRWmwAzrE2wq9ZgFrmdFa1Ukvi/+gQYpwM7uuqg
6H7N1o23iuoCX4mtQF6lF5cSAMnShT0mZOAu7oKr0GqAqm7gENKCvB1zFC6F
t3yffndinB5Q2fkTkbdtOX9EfredOxZiB7c50hJpUUPe0S3Fx5xj2PuJ2u7X
ktruV8zU6uGLsFTllWvn2vodvlC3cdhUilqDjJ9bo0u3jMqQLtbHUepifRI+
dFPJRCdhLv/n3xQStIAAPeGdztrhOxgn4P86C167aLCdz4jWSnsJ/4XDWihD
qnU9Ba4hnOcc6G9aFuDUWwdKI3pOgR622oLLL28VtobOKsVrya+244xIabFR
abmdpBWFy9n28gjYPLL14sVnGTIfVdtDW7ZkfJvIbPckULL6qqsAwZmC27nX
+22FHNsTtQ2h2wxcNRGaJrcDB7p7GSUnu5iYLhektmPsumzUkhnNhbSxQQS+
z2yM6N4LsSGvDkbwt2xA6DQ2OwmSoFNBNoaiGx5Pzj3lZzW8zGT+u+kOKWRb
SbPusd9+2e777JPtKs20i1jAEpulSQs277TT5MIlS0Y2X7z4DMPmI3tsnihL
819UNnhv6MoVjFYHrMOrZmg1nz+6aCBSD6LSbQpndRMwbYmX6pLupIEKktF1
vauOZDXNUIKQOvMNQutaANSVfhn/1yFaJbcf4XUE5m/wfwgPmXWE187qDR2G
J3QStxkMsOQHVMjPofxcYOV1p5nXUxuT+NuBxyS2kK/ZUxriI3KpH5ZG2UMa
Z7eA1jtGaL14p50mttl++wVCa3+UZM7rI2p7e9tMqbenhw3rwbbKa0tOfzzv
nx257dia2hA73QBSQVAIDgnVOqCuWFz+z799j8+RlfcqKZmL1XETYIaLCTC8
znfyHiF56rY3nu/4jqjDff9R5+VxHDpbkMvyriONW2cv0Y7T3TpOp21Lw92w
4pa6kls3nGOaD2G8vi+tN5TX9jvkkGwfSZR7CfQFrVHqkNbSbDW0Ht9myRJo
fYph9eE5q0uHPeesXtTYDbQHbcS6gcrQsKqmjNSaBLfcdG7gK8VsnfWs8+Z1
R1W7P5puZaHbFehiv1Bmw0U3vBcG8zlMushtkm/PP+Sk10xD5H3CExH1ZK7O
BHO/4z38bdKH+o4KpSvOQ2V61rQp3VRE7oZdwzwv/02F05vJr/fE9B1xRHaA
AOw4LXlyLzGByuk9Ak7vrJyWxitxWnpNi3fckaLcyYbPh9V2DDcu+NxmtKOu
Y6h8tqMZls86igF3mzgdbi78cnI6Nuna7vSm23DYua2ish03QXF2SV0tjVFY
+VgXTgpnEFs/U1Z4IW9I+UKhsad8MZVWVZk/a9xGQGNVZlKLnog7h1vull10
UJvr+ANCwQzs8mNeW42FNA3a/bVrrF0E5ENFED7+iU9kH5POSsFjSYWWx85u
WB5Lo9TxeFsOP895nJxoiHxIbadws0qnMFwg0KJTWJoZpkRW4tnhOB2K4/0h
mWPn8Lap3w1K5th6ytgu+HYXCIQSxul5GBAbcU2duZjtWKyTvC0rEVddxOKW
s4i86SoD3iOPFNqnPBNh5XX9nIqyZ3TSo/RQqMzkmPx8WvnZgtdthvfMHFxP
6QXRot1W0ixHSuwf8elPZ4eJDhxiKS36cIB0WyylCwcdofROcUpPekofbxj9
8VoDvXmpY9hkoOs6htZAw0RroC2rlX2WebBb+8T9Tph+JZgdLtuzi67sek6/
PqZ32M9sR2S7TMaTWUnZyXVWngnvdDkWFB/qrdvqVBncWxto7bLfjTc/gXKK
DK4rPL8pWnheKG/5GBOcpadxtMQQHD5cOSwgHSx57aMCWMjhPZs4THEj4LCW
6hbtsIOT5WMNiQ+uJfEW0+oF2tULodftR2JbZ+P5IES23z1dImsPsemwMt1F
Uhd8KaF1BWGnx8SuZSI8HMoHmqlKOCbrykJpAPmZFiaiG/C16xSXZOG7eLOA
a3bhiWdkrKRM2b0FgmPk6j4lVzkmtwhlj4Kyctsxyh4o8OwvMO0rcO0NZW3h
QilLD08pSw8vQlk/0Jd82lD2Y7WWuErZtl28mCWu6+JZJ2EpaydJQCNeH5S2
saHtNrRt2i4mtluDXXJvl0/nK2aUlp1iJkRqZpi5Z+41+e2sgqCzYkN3+fH0
LxNFX59tJ/AcJznhWMkJnxbtL1FUorGgqNxiI0VtEaKeok2jeZ8yDP1oLUO3
GmiKmnbaQq8Lm0KvW8dQOxoXjiUrW3i97qQYO629DUubRv9iLDU7p1WOeoic
9lrsIsI8cb87g5Btdj55XPnpxVJYOYdn3d5gnDvsqSiNDU2DmtEBjbc6bI7i
IDOxLMeLo2lLz0Nj9BQc9hU8ovTUGlm78bkxQ88Da7tiW9d2xXQ9Wb/RjFhX
LJbvQ3raqQ7hgjCliNYh+lE0nDc8yBSLcN+S2NGFdgclS1O7JZvfy8T192fl
Gxa5BV9KWEfJuZBzyE7VITr8KHFe5ArI2XpUYuXSqMQ+cvWnSOfxJPHTJ4qf
duQUPw05PwM5xZhAzk9KZxNyHu3JeYSSkx6VklMc64Fy17XkRFBaDLct7g23
JUcbdh5Q60i3Hrhb1TQuMWi3KlyyWNfdgR18Xx1LQ8GOzW5vM5MtrIzVHawW
MtVsOZnv8NgpCMtGWq4z1M23g3SLs5W2znUuY8kK33vzygSjFoyNFmhXKQq0
o/J1J7CK98ILs1PPPz87eVDSUgawpA0qW02kHXQw7UhD2v1rSbsw2o3S7Xnq
ulHhsENdNyqUubpuVDj9sW5TOIhDIPQjbtjF6kfcps0w647+sue+h+R1hygU
W9Tp/l1JWuw35veHUwZ3CgbPC5b0dB0WnsY8XK9/mKufPRUmHyXe5IyLL85O
v+iinMUXXJCdEjJZGA6Tj4XJ4gtKTKYYoEymZ1XD5GL8zIw1THH8zA+a5Uze
r9a7Lmo1E832rpoGHGBWG+9qe1d1Q7jhucK2p8Pz2IHIdqFRU8GgaY+8FrsB
R4+oiTA6yXfp7BS7dBZ76PktMquc7sLf4cJMDIXrfzQWHWFLxJ7Vv8TliJ28
0zXFrnLbZ4+PZ2ddeml25iWXTIne2F7o/QlP7yPb0NsOpYW1rnZDaYcZZu9T
a3sXt+6VNY1ATLdXFtsyz5ae6rbN43ex07pCOzyVusIA26I3MTzfXLRrNxfN
N60v8TstXEen0Oz54WJ1/oJcuS4XmhK5nWNO/iE7joHCyy/PzrnssvYEFxcC
wY+D4PL5KMF9MVcHJCoEDwckpjHGdohh+N61DF/YOE2tTcfO2uamjp3VzZht
jnXsmhhuz1jgc7Fzzdva6aa6RF2nrw/LU3+ieEXKa+1JjOpDRsqLVfBd91mu
0WPamRrlk/e6BtlHbuj8K6/MzpPHuVdcMRjxRdVP1IKGIf4xfYivBY2PRUYx
pjkS50cucuLvNQN9xqnMZWvbZ6zbkzC03/ZIIt1KjmKXPeeU72460b2fkZmm
Lc9PvxiKKX2SH2nWLYohXu7T/lo/v9h6zu/NRDz5DSD8Wvu+ARAr4SXvc+2x
h9zjSRwlf/XV2flXXZXHgcSAxsHZ042D6QyNxOJA2qHlaN5HTRjs2QuDwLtv
N1AvtO3kN6gXOpxYLzQcGanrhcZO7rM7KuqUTOZBMHuHaZZ151dP1fUMeBhM
PB8MlTqrPhyS5pTQKSJiiJsdznusxS5RriTjrsSjnPqZQRrfhSnqFAFSW5Rx
AeICSb7g43KZF117bXah28RNQiR5jwuS8yJBcla/IBGHdJLWakz1e9pBMr3x
wwNNkHyktoO77f+ZDm7dWYY6pUKXTzG/mNmbTLpnZmdT9+AVMk5JfhROZ6qJ
w4WJ28V9brAtd0cXC/ppnvnkfLtA2NVqnP+vhkltxUe+9yNyixdfdx0P+V6J
FekYS7S4dKIppYgWbNUA0XJiJFqmNFZEtDSMFQ0wlLm/iZY9arsU28zEWq4p
dZrrxooG6TRrl0JP/mROMjPx2Q6DNVfspsHabmb31zmtWNprs9NHw2lAQi+O
kBqecnoJQqZXC10q2IF82H0+clyvzpk2QZMMFDX5Wt1sTMh6yfXX80hd5Lzf
ZZmLJG6K2MGKhbGDFfOxc2Zd7NSMChwbGRX4RDiU9XKNsy5Zwjhrsq8Jnt17
wRPsALJkJpeNueDp1yWp64/HhrHsZKem/jjzlZiax3xU1mCx/IUdC1iNy0ZH
7BnDJkf4tTp/Fpuf23bRZcu0I/Ql8XRsfyXJT0rqhlFUG0RD3PUwQdQNjp6Z
7XAMz1wZLKLSupGHjo+oveR2xyWDX/rZz/JI24bVuTasSEc+rM4Iw2oGB9va
jBCHg239Roj3NmG1W21vf/HLunKt7ZzFmezts0AB58bqMtYDs9idTUDZN4zQ
Yksm9h8hDGJnuPTLUQOeWJe6JDVc1wPKz6wbKg1uVKtivfBy5wN1CaU55QMI
/aA0mTqPlny/PCMaxToeu3+hN3u6M5+GWKxk0AuxfB1zdoKwnAhzUXbDDUys
j8TZhW3jTFOXPE6XOJv2UGDDoHZ0Kd0UB7X3NHG2ax5nkS1VVp3WliqDlBNs
T2Smywn0lJhNbssJrORkPxP26nvxxRdTNupL3uh2QWOvCfY1YTXydLJZm7mb
jcW3jnWESW4Ju2G8BeHWKcJtXnEurDSmBpkenJYHj1uAn0ecSWk+4jo24hI/
9t0u3Ib9etS95U4vu/FGfaTEnHzvpb38ljQGXlHCawq8aQxSjg0ySDlDY/Af
NoG3S22JYpdXdNFf2/mjg5YoWNOkJQpW4rHIlBIFG1+wHxFJTfcXZr9BNt1i
/wD8JT6TOmDsdN+Z7JD1KWPkVYxueKBvXsjo2EJG3i/rFEE4Pzhgd7h05qXp
a5o47IbWUudF2/13+gaim+06BwTclGy5zBOlES4X1bvsppvkMiUU5SvHJShN
HuylQVawC/jObV57rbyfguF7owE5rUHVGZw1UBlbajdrwFc98mAcra2A7Bid
LTtoBaRp4eJUKyD9BlXDCohuGMbSWLY70goIO9yx+SdOk84c/+Z1fk+lhIoJ
iw75vB5kVnfk9lTqijXzG/MiSXeQmEzLOdGNrc4rgjCvzM+pHFkcGWzO06Mw
IBSeUmQOhZHZPIjVi0wJMgAhQ15+883yLwlPFtATpD5jjlcz5iWaMcWZmRjN
k6YpUs5YjLac+HBIv4kPDeO/fSY+7GZCdKfaDuEuM71Fz5+k1kKHMFZrISeS
G22thXBlXz9yKTmV8j8L4Mm1FDr1RDnkpOm82OmuPgryZ0o8JZ3GkYBeWaZ8
gLWbaexmxs0rgjWfLje/dCg93wOEdrJsEL158M6qC97oyIGP3hY1UJZWS/RI
4OqjKX5dZpXfXUIAX3+9jjDkAwz/FI/dmRyz1tj1w3GDrEAdeO6Gjln7/LqM
C9hXL3ifRNn7VlttdNXVVx9bdY01xlf94AcnPjAyMrm69BI/KME3IsH3Iekp
ril5cq311590jw02mFxngw3G19lww7G1119/dM311x9Zbe21kxEjCDvWCsJu
M1Yhms6q1rbTsTUybM9Vj0IikFkfbStEdE9thQgTzYEdVIjo1dK7ZScXNtmi
14sJD88pajLWsUleU5kcWxGGoVIlyWthkpeTOkU5qRgqdAbbycKc3FwjBssV
YqCCwOcQBL5P/sq4XN4YfaBwG/dggCf33MN1AjGlkcUhrw/7CApXiDb4R6eV
SPQ6w1YcoqOPg4jDn2qsvs/y9DkueLuIA8LgROH9q6+eZqIQyTLZB6Qzu5rE
4hoSix+UxkQjvD5ka0vDii5k60rjrifJej1p4PWlgTfgsdlm7By5+eaC9Eab
bz4pz8bkdyPrb7zxakY6dsilI7KBVHPRa6Y2kGq7uni6RS/2CcEXsIceg5zI
AzJRFL3muaIXakLdmS39KHyx7Qh1ab7C7BGZn0OR/K37k/16AaFVGrQOHShI
0ldCXInMOYtOoR6zc1OBv5hTEgx1EXyTfO+k/KUxuaIkdcQYWiApayxoyCTf
+KxjRaQ4kKBhYCgZfKy14zsJ+AyvIfIvVZIUJUkRkrw337G9+bCi3VdLXu6Z
DP20pN2i7MZ9A7reCHgtQUck/ONCYoxGtraIyDrSuOtaEZFoFdHINnKdwI2l
iedkmwjFN5UG1sdm0tCbbrPN5KZbbTWxydZbj/Gu9xt12b62srfutCp74YFk
f06VPba4pTdCrySs7DFSzIgxGyqy/Ry7GNHLMUfH9vYfEHmhYMH11dXe20pM
rNBQIzF+SsZQqdpQ6sL0NMbNA5+X1xtc5YEuzaySpPAN8q3j8hcXMP9uyDFi
FrIyYctBZopvku+GO7e444bey9RmcMibjTER6zMlQUne9YrO8PhUMMNjxmdH
zarMjpLwV0sihEBGXpOt6mVkdQnDqB/xMrK+NCg+ZENpVPEf2cZCYZGHQkKQ
js2kMTd3xx9vsWjRUMZkrM7kFosXj8mLC9YXJvyj0ZLtaguT6055R7WmZfzh
jmpTXcbfdrVHrDDJDsKcYKCFSbTEFiY5koBtK9EeLUya884rWoJm4Yq4j9j0
rhm2LdKwoipCHTuq4HUlcYN7aVHIdKrSBZ3h3Lk4D0OHaFbRqfEeha+blK93
PmVOa0EZjgqK28F4qkPrxcCCxOvlXk1m8zOt6+jIoxPp6Igvaa0lMz2tpW7j
A7SkaVpLi9liIiLZGmuuKdAjHn9d70FsR6bqPyrCIfqAZGSiFahGtpW03FbS
cls7k7n1kiXdbBuXE+TppPxydPNttkneY8Rk29qKyXpT3szuldp1oV8JVefU
aAmVPgx72XJ6mpZQMSN6rCkmhWFIDprg0Am6SHSV6DJRQo0fE5m8rqQo/FHC
026G2k9ZmibmBHPf5A8LDBJLgWPJJ+h0S0OWOnHAaYubBTcHHXHPRExUSHir
iol845j8tWQpR4vZoiUjk2FOiA9VxibpDDxlIN8zKh8FEa1wHkT0Y04/Jekz
k+A9g0/h8ZripvCgKQ0zCaa6L8VUpsptKyEiOpHLyOuzD3AShviPNUzNtFQP
Cf1HPwlBPuSxNRIi5NxG0uNCHkLSRWxKu4h2W7zjjmwNLqSV1ya3yWfqvcuI
yuIWojJIGbbtrhgvRxk2rKXYE+kpw1JSpQzL2QZ1ZVgmFXEGE+/RMiyfrT97
Nvn7kqhgjfjjdLm4ifB0tKauUL96bYN1kQvCvHRLEyK0dpsCUwcFmZt7F6Yo
DVs14WOT8lXYk2VzQRmj09pOUKY99yGfQttxE/wuy9Ukcf2apKMepZ1P6aMu
//CKzVOa8l4hgbrYaRG4FJEM70z+tllSfHnVSUoLV6KOJJSTRciJ0HIxj512
Ik/QZtLjYgBduMp4L7MT5Y1uktQ7jbgsqi2lrNd3HdcruQ1kbPfyukKt3U20
rlDLyUC+UFuUUhAaTiDkoBVcDe6GgeL6Su0C54jQFtUXBE31BZETBzXJ9dku
YGx28SC7rBnRTQGHuYBlqcmVplMoTVGA6QDanNzLUO7N5yB7deGTk/JNKMxr
jMJogqhTmH7TOOIiIy/rTfpHT2yEgjpVv1AO1RunLXMbVSYyt6NQmej8q5X/
/OZfBRMitWwrgjBtcdmU82NiXkWFRR4lYZHmwSpt647i245csITZNtu7Tqqv
7owtFB/zDqMs2zQUVv4ct+/sV6S1+xRrkZZ+DAUSCiUUTGJFWvpDTC2h4ELh
hQIMhRgKMvVF2r+vdIP4u/TDUBW5HlRlTBRhgUTnmF1nEdsMt42Ticwgk9YW
jZE2Nm5GXhO05DXtLhUFmS46MpSrTL6+ATh5i38r7mVU4H+tY8YcNwZEnmiY
aZLM3FSTxClLdqgkiFwMXLkkL8d6Q6OmZgr60ps7tsqf1dyxNgdT7CxtnGvK
G6akKZugKW3MijEqXk9cXZh5LaIidGl33dUVjTsMbUurM92bQW4z0D0pnxjZ
evvtk1WM1mw9hSLuK7Flz0wXcRnYYYCnrojL/1lvy/mHaBEDR2hTOG2trDVz
a7WG60BrRA8ZZsnHAV8zKtCNE7CxI2rabMYZ6ThJ4yM4Q6XOU0lynOLMdnIz
y4GIaAOovGtSPoVrGaEs+3p3lXMLeXmZ56nI77ivD8t1nyqB6joyrgjbpC9z
2k9bqZvbtsKfbG6bnZd6cOSEEMot6260UT60s7yrzq7uq7MjWp2NlVVCm9Ig
KWpRFlqLgpyopAjDGMmmYszINkLCjBmmwzI6xfS6XVxq20X885CrCvE6v5f3
j3Hq8NuMwGw1g4Xdl2M73dhiyXA73bCwq/uBh4slbWGXrlCssEvXiS4UXSm6
VCz8oosVTIVLalUGZUNlcFSojFzUpFzsAom6WbnKqLGZiO2aOqip8Uoj14PW
dAq8sDeuD+U2jR4Cu9QVhoecCMmvJ+UDTHkbpQT790ZawmlItdIyxckrEve0
9H7SghgJF/czLi7hPJa3VERlSnPivKicMAObPIkK+EHiFXvjPH6QuDLO4+eZ
uAJtUE0ZWEmMimA9sCDUjEdVPYQeVHwY86b6Q+dsD2eMpasmV+w28NZ5Nnvu
OcFQ+MpGUbasVZTqDLmp7DLVtNdxOAl1KjPkmqq6dpcprepSqdWqLmtAn3/+
+ZSqi58hp8tCmX9LAZj5uH2KunNqi7pciyjdGN5hvsN5uQWC1QiKImE62a/Q
GxZgjJqkfuaYwlSIyizvX+TppLw4Lu8dlc84R/JWdw3DdYPJ+Vm280oDXH0m
p3jZGLay4S75RA4SvuaaPJpnOcfgtw/JyyB+SZqIQNJCP6YwE+6NMzYTbjqz
aiUGVTTczBLfqwlnloSDw9FRnQbRWFQjGoVgeLuBvdjVCoUEE6Vj9uP9yAEH
0M+WDnPH7WK3V/4oXvMl5kl6aSsZAdmitnK76v+ZHbjaVm51By7GkU3lNheQ
+dHVrVq41fKKmZzfO4YnmV10ecKirVzemFx+PtIyhBkZlbAdEyTGBYkJEnt+
RPWcqHzYk7JGXd1MR2XTfLeESXk6Ia+Ny29H5d0j+Iu3tZ51MhRTiiQ/PqUT
UYo57qp2E8Wil0BYEp6EqjMXucHwFYxuKBVpPr+kZrBnClPc3jijU9ymMm2W
/op0OHKReFu7soefPeKmnYVjNKaM2uQq1FFYNxGKA2vfnTBIpqU8gyAwos2q
AMo2+xx8cIdhblF/qsSukpMPSU3Kx0cWj46uYGRisxkow/6pth6zZVhdvdJU
hmUhLWVY5q9RAgnLsJRKKJnowlstw1JaiZdh60sjWoZFJ+SeXuthFp0YEThG
XaSO0QcYJzA74xKY44LHuDvlyP0cGhdsxuTZqLxjRDDjg3460XTniswrzTo7
VK6VgCKwCP8LyuGf5EE5O3cK+WCJDX8df6lVgGkM975hSkpQmaDWMNk1NpkE
JaDimIf/KrUTyJpKFNEhWjOKov5AR0/wBtqZcKGPNyD0hfyl0Bfy27AnvpnU
QmWFkSEmuezvdiw5QH7OdhVdKi9MzuV3xfmWBx6IFixvtGDTnhYEO6mtO+M7
mzdVMJp2Nm+amtavTEpHwZZJmQ8fK5OiCXZ1L2VSLMZ0y6RynZRJRweenfGq
qM/nGB9MMN1tIqAhhPNg6tgITjTyxqcwgto/cF8/rVlgp9fNAqsJXCF3Hqvv
aPTzazf4eY3VwstbHx+maO/fozGae/ZojO6rMSqxSFwyKY0iBiMvH3V7s370
yCPZl1L+bSetyedHth8dfauJ1U1meNbXn2p7trYVR5bFsTyOiiOTMLTiyMSM
cPEtW0xRcYwsvm1fIKDiyDTy3QaZ6bBctGPOxugwGnbD9CJgJQrOU7vNXPp4
wF5qA3bmhiSDgP2bV2RilURaHqgr5J5a6/4NnnpDv4yjqNKFAWo89HY+QIsk
6v0zVbYwOIvANImTROmDMiUCUxeQHTeEcTCPo49mV362R+BpV8uQk5JVR0QV
3mIidOM8Qv+kG7u9EhU83dhNK3jMvQwqeMyciq1xra3gJfMaZ04RowiGFvH2
GHjGwKtLgXq0fD/MhcWVQJVbKwUqQWr7xtovblF5n+FpSX8xM9MGfJjufdBB
bWti6/0/7t4ETrKyuvu//1tVPT0ru7hnEn3jkmhcoyKJreKGGyEuuL3Ma1wT
jEZJVERslU1EMeIezbixqDGAG4JgIyACgiCbMKANiMgOsq/W/3zPPeepc5+6
t7q6pwdH+Xyq6Kn11r2/83t+Z3nOMa3rri5rp2pcj4Fl6+Yr47rpZmlr5hvM
LHW9jHo2mKOujwI/JpzsamZYVmb4zulpsSpSjcT1+D8lDe/6wAfoaKAdmN9l
ZQ4hczArth5N9fmtsbJnjRUrG7cV3PrGykY5wW2xsrZu9VmsTBdSr0WKG0YJ
lmUbRgsdSl2sVArATt1Wo/jFVvN6JKLhVe/LB4+bflc7fYXgicgNUAW2QNht
9eNz2Sp2OrDVxTXVPANvWfgq1L3lolX34JfKsliZ518NrZzuiiJt3Q19fsOK
qZEnizolOWtup8tZXS0xSwtBp5XSXMy35iZJSz2BGvu3sDAsjSg7ezB223NP
OonQzPk9e+1FvyHBBRs03qNjpbmf0Md2C9WOYqIz8gUPDeb5vHmU72xsMaqF
tsfPY1SYp5fv+B7MvDlc8x7M0X4pMleOj1zULvOwzJ0FNmg6HLEPNVgmSE6W
KShfqGV2o2VijcsXZJe1ypjN1rsyhkpXN0ZfK0k614wxytfMv8zXSI//qHSN
fmWQrW6ItbVRuP4dgzVxyACxLaLZbF147z77iM3tQWbjfSKwOrqv4X3VrdDH
ujwrhkUMnHf4Vm/51Gn5tocEi3xuQ6Soqd5lY+4FN060KPaCYzFkUYzRIqwy
38jY1gtuZL1Lk1lauKgaFPKAUUmf/pvl9xELISaiZinfi1l+uM0sBdyfCCGj
zCyLsfPDo7M+864vWbWg+hJxLCfC0hgtUdVqgyWiVqMT6ZHYV4YkDA4k2dmR
VshSaFaIBbIUJgu01Q5bojaOqDIGR4RZVnQ5gR/Yf/8O8Ss5gR+0SBb/KvV+
2aBTsrxBb2axvndavmhK5PJfBMN8zp9IWGjcrv2jwkLUjTRtBlyvsJAc2Aw1
pu8YLJZDVrmrHDTXjeuJVe4drVIYBav8iFsl7mawyjyQ25KKvZcysZVVrphX
zYaYVtX85zG6NrZZJEVY+I9eHZ6L1LguprxIJlAJ5RBjxWdEnLIm1qzR1sO0
FlbroFqiWaEamV8oMsJEqeyClcibksvW4S853bGsXt6kFiz25dX1fLbo2NXi
31otYGWVz76XQ0FtAvbe7vFfCwWJWVooKG6im7vd2ehQkNVjcHgaCvoPPdUP
rOVHieztYZc8XW67zPtEu/zUp9Tlwi4/5nYpxzaGXY6ZIs3yKwsojVg+XkJU
bgi+jhri45IhenVkozEGj9GTlTWRmtUnEMQh8TG0NLqX2LAsqiH6kmjLYW6E
e4Urs6/pGK7Ofp/4RImf0YU/RabuZ2XpWVlHyYeIqfriKV8z8+73vz+a47Na
wz3r1x9sY+z8H4cTolBjuAcF6+Ee8qDj9QcbFq4toZ5qLPwDyZwQH1dNhE+R
m+LQBR9hihtlrvPvRtokqz32JJZYs8NYT6ROo9tiFr2pOYwxchPyHO4s1hbF
KFGFIT1So/I0s0NfDGs2aMy4r9uf/A4uC/6EqBc5AXKBlnCFhJTygDJv2ju0
EuNayxdNvW333YvVwRSfOY/Qzrjttcbt+5+PkLk3+v63hXb4f9yZNV57rbl9
SNuZtbuZ4i50oREr5fojhpR/3RQbuHe/YIopOSKm+AfKYs5tits0lh3wkzG/
p3pewzcJzMP8XhrML9bxxqAp9TmjlkHiM7AgWrTR9OLpN7NTF55LgNkZI8ql
KLkWJRejh+8gGr2x6Ene8GEzx30sBStfNCsCOFrhM8bwGufbl6otnDOO13hv
tfb3MYoxnOPFBHH70hh9qZpNMW5fsnDOHnquV68Wmp5mVcRH2S2ao8mhJimE
Oe6fm+P8cpX9z/u00A2Yraxscdtki0CR5ES+9MXcosdMm6So29/Lg/25T6j2
F2Vo9Acblr7dzA+M8jM66h46i8vdR8P5pjyJc+7RbQ2lVeG0Ej4suQr6l9hk
U7SKD+ICpmVSvlQOYHq397//z4JNPv1eiORsjN31qRHwSA42STQHp3HRdwDJ
ga0lkvMBPdH3rwxSDtYN8r1zGWRMewSAzJGQrFL33WSPX2i2xwUmPhprBwbj
akiwbxtq2d0AY0GrZhE9ODOOEVrCwn3BqD/xvBsXQLQngZjs/DYZYFj01Phq
hueppcodKDnRcgrcQZcb/5L7lUO5Vw1ZUXJoJsllZL3l0oo5atvgBwd7nKrs
cVFb1rvTuLG1rJ8jhhP304zXCGn8GA79ivay2CoWSUgP1EDbIGY6o+xWi2xA
zB8sEfmUlIgEbU0rYNyq6ga4vUVHR6nQWjAGB9AN0HIUrkBrKyBqAz+c05mJ
/3gaG33wkDzKTqVcaqe3joaNOxqsHpQscb+8Vl2IB//JYIe+LMpRrBWJWrO/
p80RtFmMfkEbS9AmjmuMQRvWQtbEuFFlvH5B4wVtZG3f17KNAqKZfxObBDDv
cdvLowTjZhtH255BoxOXw8Iz+LUAanNuY3TD0rolPkktxTeIZ5OPUukpRTQp
W5iHQ0dZn4Vf3P/TfETQn9H3Iwfhrrf7fbXol53IxuhXE4GljTq9ehS6ikRb
CGxVlAepNMJ1Op/lNsmFCzI1muLfbYCgzcbeE92HNXrQBlNs2ieyvu10QtDm
w8EUEVBqioG35zLFjyw48b90VOK/IYCar4VPzy1Q3wsNtK15PgrEK0trefoR
lvf/guV55CV6fqNEp8eeR9YwZUJe482ZR52fo9r5ybiqTBkfWQq/aCeGN/NB
fCgXg4vj5id0sGZ6n32KBwX723YDhGs29jbiebjGbdCT/Pnej8XqNvNRyyfu
suuus+/gKQNSWz5x77nyiePl+ctBkn9ifZKJ26rVDA3eySZ4xZiLV8aQhyf1
N85a12hxrjLDiXIXry20XDs5DdbmlhasLFnXVw47rP+Vww8v+189/PBe/6tH
HKF/iZXxBC/4klGSWxsfzJeYpc2K+des7KmLHID5Y+irPSoA4xs4FjMAM03f
6497ckJMTJMTY+QJ50rZb7g84cDMir9TALKcTjUZWDbZavsYT/HSsyy3rgHN
zJWLBvYON7DoxkUDs7xd7gnX8jZBQPrpiMuYGpcbVmVUWFL/oCOO6B/0rW/J
+Tj429+Wc3SIqKJDyBh/5zsiueW+emI5L8L+1PD4EE4mH44Ff9oMbv9PfWpq
1913t2Z8lcFt0+rhzd1rerE7luQRlsXuWJIPBbQIS/Lw4i6MOVqWNIZY2tqW
eIjlk20JweCVrHdCcLTNNSQEm4MsanFibDzGajTUIDD0Ha3Veca4SZOhZUHL
mqF5wNINzTIGTbrRtfYBZmjg2zWj6+uhFUxsgt/jK9dXK+PCgpJhHfrd78qp
+tr3vjfR//qRR5b8JVdZHtVneeVBbmXySXwq38DZl6NYK1eqZl1PHuG0/aEa
fUTrGrfRx7j9lvP4CULRnbamTRTr2+jD4ief1tP8oA2T3mty/Yfc/3laV7GN
kjSL6dBAk7yhL46ZqJTomHlGgFLNVJESUnK1cEhYwd4VDOt9uWFli7s7Y3H1
cmnoTpivXMmoWLXEPA6Wy2vGVFlQB2PqfwMRc9RRcnr+R+47/f/Bdahu8hj3
q/Sx/6FuWG68nvfJJ6gFYn18PF/F13IJNKuwdq0Z3Zu4K5mJWXR9/HZ1m5oq
+aPoTG07NaUv4L8TFhBUuTd6FOeTphezR3EMqnh8k//n2ykWo/mGBVU+F3IL
90K2L0+/j5dbUKFZ/L2uVvmEoaZBZS4rk9+WRUooEaNG5fVZdsDjkyMNMvhr
kFOSk+6rucK2Vc6lpMtIN0bWqoNtZfuaWJBbIdallketBbdjjun0DzvmmG7/
sGOPLfmrWMmD+uQ3zSR5I6bIh/HB6FQYgDMuTDH1runp4gGVHf6T3m9ZG3RN
HRDnMrYeyH1jle8DCT8rf8885/nPn95u++2nt3vuc3+4CDGYcTZabGwdf8n5
5TEYT8+TKpxH/42xYzBf2PjygU15iJ5ZLZbS5gQ2NbFWjWrOIL3v2YOU4pte
WSaXjqS65/TenjuCo6w2OIGuTT9l2jRfQnF6vxQ0qS+fGBsW69aKMR5GyFtu
R1CvODPT7X9rZqbT/9Zxx5X8JQvoEcwJpc283HgxVoyZ8yF8GAspopcTCGXI
dVgrB2uGu7PebxoNVwv4tgnNuNrGwIbTXU2j71RnvDrr8i/uuzymE+q3f9GL
sOujWm36T7fnbhbxKfE+LcXv2zTG6tiRB3zydh2x5+6XFpJjXL+NxvPJMQ4C
Pl216L9Ta2Gj/NCUizhpmJaPWdZCxXFbeIeMRSiTebtl6d8ZHIY9miw6C+tE
i/6Mld+6pzm0BmPNsgYfauuvWjOWLIaJoX6LfDIbAY4/XrTnd084oex/9/jj
u/y75AkBBi/BrtWmsWchA1Zjt2UUzOcPOWRGroGvwDaOPRqynPrBePi/yypx
xxzLKp8h57pE+EzoPOcufzIUnoHwU9u94AXfbQ0ojdfW44+pBW5bQIlgEuu0
lwyM2OdhbT06sa1HMWYf3K825Srl5ePmKhe+SXm+ucrSbBrbms+YvX9o09YW
RSJcSwZSa0+t7M3tOUa057Tn6OQGTR0d3LQ6u56W1RkjxBjdlrFjseD+kULu
R510Uv/on/xELu3RJ59c9o/6yU/K/vdPOqnLk2X/eyeeWPJSEWRi6P1vu4Wz
YguaXGvzhRyAXA4z7FcODHtazHkWk64MewtdpSmzf1rWo2TURI+8ZaZ2zdWe
pTsyK+4fX/GKHkJJbJiQHs6OPDsrr8TgiyPm4UBvbF1CFtrJlq0iMcCFteNA
41DHrSTr0yUkdLKlS8ghlRi/txOi9Y3Po3OixZRqWD5tXpDLYsVt3rPHif/N
4sSpsiecBQ9lDWlwz0+1WHjS38Fjjqs1BsnSi5Fi3WLF/R8I3R/705/2Z04/
vX8cFH/GGSV/yILIQzx1jGDkB6ecUmL/wgJHyTuOYle8cIIyQbFCeUKYQD/V
aYBvcgqAZ3Cz5WhXH/DpT9+/ooCd6hSgxl9tOr1PTaR7aDGu601jONqG+tiY
depASi6QfIn3z36ZzorkvqePIbrkpbPyVuWF/x3wwry62i52n5IN2dWWVXxU
YA1egB98Y0vTwPX17Gr79Y0ti/vCyAu6bCJG5rP+xHCaS3gvOqo55SFp5EW2
UfzEuHbukOO38BP5eZ9tIIOadHdHnLBZWOq/I0s95ivG3f+hsP7xZ5zR/zHx
GHqinnde/xRBAf/n3zx+gjh2x8lrlB3k9cc4Q5x6qpw74YlipX6W0wQk49SA
rDjCaAFS4riEh9ewB8044WWtnHD/gd7PuminVMOIKRuxib7zwUvj7MDB/MDS
Jx3bXtlqNCn3S/QxBNxO1Uh13j4rFDPNJKFvLHLNx8bSVbepfcqoqB584TUf
bLpZ1PYpdNX93xH557wmfZz88wLYoiFDtpOu93OuTwNpmvTCTq4XQl7ZaxLx
CN6aR9qtCpjwJb815ZOzKPvHM3ogLKkH7549noDQQ4zTRU/gWyLkWc0xYUwc
fQAFQAk/oxWHXOyzLrmkf7bczpKLfqYsFqdfeKE+f9I55yhV/AiqkPf9UOgC
eoEyVFQMhEVFF0IV0JDTBOqB40C/iMeyVn6DMcRLBwwxW2eIrdOoDWeIvG+3
k7a3BG5UDIEdwpiNQmlBeUDnFE9qk/8JvXDKEmJxwggzIjJWTz33uYdWR/kH
beC7Pl1b5tPANx/BRexv3bp1JWxQLNdylHzHz/p0bckb+B6eZ83l+Q2WNa/v
Ubes+YsiJ6hXwWePooKmEdleppzUQpPrkAcHst/Jb0ylJZEKCPTZb2mlAncZ
cioQXx4q+G6gAswaRYC5Y/7nX355/6Krrur/6tpr+7Ny++XVV/fXXXFF/7zL
LuufKTRxmmAAFQF9HA8tCB6Ow9UQbighB7nmriacEviuRAdyDByPHN/s177z
HVcL/9igFrrGBdpXMQvz5wKuNm5n/CF+Jgc6aS9/mjDM1DTGgsZbNWO4wz+q
13T1PVxm+axp+c6D1zPWuNg9ZRa7hXBTT5m2WKOX1/j2pPZY48JaCH97EXL4
Q2XH88zhF69UogAFTbq1aVVy3Rr1gmcEaFAfc3xva4ktaPTQq6iNIPgptUxA
jCu0EUTIwEeCUK0ga3gkCHTCuUICEMKvb7yxf+Vtt/WvvvPO/jVyu+r22/u/
ufnm/sXXXde/4Le/VS1xurxe9YO890Qji+OFLCAMPvO4oCeUMOS7amQhsMG9
gMDkHBtP7NigGbrmVQzxhEV9xroyYSbPS189cmSw00Oc9xmmBvd0UvpkNShY
bjzFAsDLjS1mRF58ZQPHKZt2T/0huxl7nJJdUnmckkKffPfUInQznpLf9T09
zfdfnKKBcbf1vygl03m5twB+XoTfiFmzL/FaOisA0MBjllrIHYmYN83TCql2
rokYiDGMIgZPDZLgN2JA3LOy40TgHKAcUAcoht/eemv/ht//vn9rv9+/Q253
yu02uf1OblfdcUf/0t/9rn+BqIlEELJGnISakM8Rkij7J5x1VrEiCouKI0xQ
RH7Ar4C3vvTNbxo3/MOAG5QHBtzwkIVzQ8s8z53mGgIMITQPAWYu7FveUnI9
S/4SriCMxLP4i/AGl1w+cVY+eWpqu+2+OOCKmbaS+D/mPst5Y544lSuPX6Iw
fKdX3phn7CqjEY15quqPV0IYa9+eVyXkhLE4VQmq4fENao7tGBOpaxIii0im
9ERWUODqKIUbQjQyVdjGQoIYiRyTJdD5RAoJBWC6YtT9Uy+4QP0L5AMscaMw
wl39flf+15er83v53y1yQ1FccsMN/fNFRfxcLvdpRCGEJH4iJCFKooQpRC8i
KPjUSBQICScJOIoaBUSNHO3qT69dW9yvYokdTKKbelgQS7wwskR+YeYYE56P
CNepYfSWtikoNnJBwCsQ7MD4JRUi1aDfSfUfub68jGsNucjHKVW85NWv/u8/
otDlOP2C8tCl9wuKnZ/z0CVUgQNC9dKG2K6mnZ+P1RP98nul1OGj8po4SKA2
WHIEN7zMKvJrBQoejrTCXyrx3b2IxQm6STMPRVr1vW9pwSPKsxTjcIOnLKN7
cYboQYwe1+J6URDCDaKHIYf7KjnAF/DGL6+5Rt2QM4hFQA5ywU+W9UEJoiIJ
VxOJIZwdfiDfBycR/+B4DvnOd1Z/+pBDjBhe3EoM/6cxHLkYxFAjBR8D7nIh
jEWKowQp2xZ2F8iKEhQxwZV8S3UrqpG/S1Uj/ouP/JX38H4+i8+W75ra6dWv
Lj5f/d5FbWW0MbejHhHYhDXa9tktRiuj4/RUv2Th1RJ5F5CGagnWjzSRK1ey
c0TCPAYB/PicxiCl5ytyN8P3vsX4g+cqrAqxRhCWp2gkiKxiyVOZKiBEBZxl
AoLYg6iFSeWHrdXTuOauu5Jw4GU/Ez75qfADugMBcTI354nAEc4PhCDwavha
eEoObYq4sJHDi1rJ4RGt5FCLTzb4FumKGF27X+GKoY0YXj9QCTr+O84X3cXn
i9J31GeMvutdYthve/e7RWflM4Ahjn+p5oLr58r3QA6fa41j/un2xqYawuOY
SAckRKyi8m2Ci9hmqdrtteOiVkvAC9hjPnmo5ky0eLW+NLEsoVGTYPB4JIIh
xCN3D87Enk3ORAg5aLIiVCR/qaGkYah6kfomCzmwcKfcpRgviz9C4OLrr1fj
v3PAB/fI/66X22U33dS/8Kqr+udY7uJ04QTe9tN16ypecG4wXoicQNgBb4Kv
hZL+56ijIh+8sJUPHllVN1jRY9ylXBvMNp+ZiWEeuPPAOLPAh+YMM2N4MGc4
TTW10VFyK6rHllajh+WlOnpY3s5H8dF8lYCCkeHFp+cRwfxjadrd1v+pLYIJ
R3hFFRWYRDAXY6ti6P90UuW1whH9xBF5jURD//xajUTgCGRh1AnuSIyaTh8l
q+uE12U6AbjEcCSO0PtNJ3BcMZH5n8GRiEGGVNk8By/g2hOKJMigtY+ycGvJ
05lnqiGz+P/i8ss13HjdPff07+73lyo33EcjkZffckv/IvEjzpOXoBXOcG64
6KKKH9ANwhHqWwyCDypDiDbgSxwtX4lMkcOCF4wWbNovGxwSLVQj4h46tFup
1mYu21Ndo4MWWZBajmeDqRIN+KzG+kTjmvmXavVdvXD/zvzG6tYlXKSjVYUL
eA5+gPh5L5/F5/I9AgLlgk+OEXZYaOvwja0XVZwEFyOUzgdoh6Z9kOsdoWQf
pBDCyZW3mqokuD4LrZKQa9c6njCV0LSkxFwkvNZEQmPSMhyXRxxjXsIdBi1u
so2IebSRAugmIji8gQhwGFi1Wb2xVlb2M0TD4RU4GRBZcDYgqnA5UYVrr+3/
Ql5z9q9/3T/z4ouVEX5GEZRcU/IUMEP0JlwtqPeAUhDu5xj+95hjpoTEjA2e
38oGfznsNOQ9l611yQ7edNIacb28iQniIOUw+yONqGuZ2OozeXxqq7h4Jfzd
YVpyqYOTe3oJdws3+XdRPbc0DVTmQ/hApQf5EvSsHMhqqOHADRSR/EM00Grr
YO7bKfNZdHlEkgKqfD/lonUwP60Spguuh2Chbhp9MeQwtAS4UxFDzEBYAKEm
DEKEMRU7huxDk8PQFl2k/vl/W7iAumUifggDoowoe2wXT8D54Nq77yZ6UFSe
wyRCoX+D3H4jCgFOOP+KK9R7QCUIL5QQQ7EyUUOkhZMtlcnXIBKojeQwDj/2
WCjBHYftQ5KyzgkPqzkOrhCGrohfDe8bFoeRRGXQwAc+ECHnAueBpsGxhKl2
10HNwuM9wNThLzkJOhzWb9U452qMMyOc5RP4NCUFuf7CQjOkOj/eGlcYJoP5
tk/P92IuZvv0hezF9PbpWcwxxRWoj4p7Mefb3GuuoOMZ1Ro079IHEFRrfRyz
DDFo0MABviJ5tWMt0zCHJohBxOQckGWwAqYYNIgBxLghKnLAkXCAaDCcA6J7
aALWa2oWMFjnAaKGpB1vTTywpH+7/O9a0QqX3Xxz4oFzf/Mb9IFci59fckmx
KumEpBUiGYjucH2At8BxiOMStMHzBjww85RKHxQTpg3wFNAFaTafewgj2uHm
Lc3yAZnJI5hrXK3NBPMhmTogpRqSUuJvLtGhtZ04ibaaGy3o5HW8fo84OloQ
BxvwHUQV/pXI1y67FB+bI8K4GI3c16cR2XwjjE37NGMjd48wsu8qRhjxGrz+
Ke7TXKRGZGdVi85Y5Qw89kI5RfnYjzxW/bKw7MTsdhoB4lWMWQlCLTLQIgDy
7EF0Btjv7FGBmuFTtdi0+GP4tiOSFflEcQgQ7oT/qC1A8M9ef33/ittv93IE
zziiA26iZkl44dIbb9RogXLA5ZerHsBPOOvSS/s/51ZpgyEeOCUIArgH3+SI
mZnVaw87rM4BtSBiz5IKOQdERq6NgmjwCXwW4OviLECz/7c2zAL0zem1UdX1
MdUpzETZqQ3JFbsX7i7JAnX5q+j6RFx9tdxKJYtlGgfig/hArj7kojPlBREc
hBzUlJDCRxYQURy3+VlTRLHJTbg3O8r7GECPKFLbBCd4jZPv0VzkiOK5FfhG
li7wOO5o0xy8HTNHYKcwozkfR+lRQi9arJUbtIiAjwYR4GVIvs1hbXAE6GHi
QYE2HtCAAIFZBAA8II4AgQEWZxZpwn0YsHLBdddpicH1VrT4e6ECr0+CEChq
vO73v+9ffttt/YtFNFxopEAYEXEgxFCqQlhRcUPGCzgLRBVdG5B1hKJEt1gB
43Mr/NMnMEsq/FU1tLCFE4Yav7W0OY0D0moDs9tmg/qQNGuXX0tVB9WYZoRW
c0JRqwce2IXX9S+xYZ08KM/adF6fnl2NuJ8cjLg3foCEQAgH9Jb/+I/9FzG6
uCG6rC0kutjWZW2c6OIC9mOO3WXt/AqJqVThXaFUAYMmrTikRbNodZtX4HGq
mFLED031iSZMWC5GioMYKQwpA48MaJQwEEJMIboo+KG3SWA/mxEC4gD1Tvrg
bLFgjBtSIEKIN3CzVTQLMZTKC/dDMygv3GBiAYcBTXHh1Vf3z7/ySuWVxA8V
R/TPDgLCCeJ0K1cgivBjWQo4LDnUWfkJvkXqOQ0eQ8dSjtv4SFOLKCaGiFIu
28s+zhCNNL4mGx4VJwd7Iqqt4i1MDi7JAJVcTzlyH2UqN/4l95vrY1xtYtQs
BcSldLK3fI7yxoA79Lv4TpiJ4+CYdt1jj7XCbPu1Esb8WrjNt2k/zsWGbtqf
t3DzqYkx5nj++eeXxBhCaZPv2Zx3C7dRPfsvivULVteEQiBolYvVqBoavQdv
GWzCNYYQ01YHq48AcqNCB0k1xPCheQ+HmvdAGgGCiD1UjrYeKk4Oxxs5IOFJ
ALJ0QxBIfCwXq6bAgBDCb0UVoA4gidsrb0JVw12mJm60kAKvw6X4lRALLHEB
LCFEI0xRQhXFyjpZCFH83IjCVQR5yZOcJE49dYbuqHWSqKUcylCXsK3PPM5k
xNDcj9DQ2Xe0pw44oelF43jHSBCZdIhjxfdtmLEqV7HUYeLdwajV6jZBcFjn
HReb1iYb8zbliaAx9goDx/lqDgNwyiHiaOzbGnz402wJ51McYxiSECSiAnEx
1jbNhQwYmNUT/UwtXmAtek6mWGtT7V21BldC1yYre/HSt5o7EWKK2kghFhzk
hUhZWMHjie5KfF3YMZKC72DAffAQgioFIwPUghMCIQUlBVnKzxGLvcCUA3mE
q++6S43/tko9yMm8W12KO2zLA9KB16AyLvnd7/q/dGIQYhEJUcIOxapKScjt
3IG30T8LcggFDLgXHBZhRznstUIMxgvPbkg7VLzwqCoV6cUJlo7czsKOLh6c
F14aNqeNmqDwluBW/Hvof+expzhyPo189WSUVa6kJtth/51Vv8qxC8+X5IpE
O+jemupW/UuUhM5bzmYu60x0n4cuX6DKwmeiV/OXVVHsUbHFjGjTvUeEJP5U
5yXkYUqYgpBELHJa322aoZ0cYcpL9DQ/fS1LksMuehe1cEODcMgzXuhXr0Xw
4uWh0GNWhxALkqJwIOxIvoF25YQcqT2AH44UfviB91oSboAX6IxAoTJ8QGgB
TmDjNB4F3ICxYrjwAwIAd8H5AdFwjzBDJ4QcfO/k1Xff3f+N8YMKh2uu6a8T
fhCOKCEJ4QecFXTEecHjwNNwL0M9DPhBKMv4YfprRx5Z44fHaXvlEI6sORXa
wS2kJbfPHYumPrcWD45dcDQpnDXKir1u8zlhcRT0/m29A21Prm2zK8kgN82B
LvV+yzQH2mdBoxg/Gca0+zzojzZQhQsLwCTHPiWct+eYkcs8OvHHMrYBL8HH
NrRFLqEJr31q2p25CGMbLtXT/PhpVqnnmGqt0URePdsiI9J8ZPn5BMBS7aL7
FzEqmdUtpvKEJhkhvoVHI7/lFGFbpb3fEtul6a9En6WzL71UhK4IhmJSa5mp
WVwn/oBTA3XNN8XMxFKNP9yUuxLXX9+/6NprVTWsu/pqAXnihRWJE2LqAhrC
mSDi4Hxw1MknT4kMMj54lt4/IeqFxAc+vbM2rdrCQj6puuZDNPS91mJFC0G+
taFP7tCUzjCZ+kPzGcJR7wCm+/OXasOfzWozqD/jM+GZQy3v57P4TJUKFoSA
hzgGkCFcNcPksg8uQmhysfdbLsYAiFGt4tghlYcmMX6vbor7LRcUmvRQQxaa
/HW1Rq2ZkvWoZv0WXXhpS7FsLbJgvqsHuMCe5yR2y52IhvAj+PCihCGBYA4E
FcrfO+EEtfwfieV7eyUs/jxZlWmndNHVV3fYyygWLX9qEAHrZXcjGxrwG66R
Nf9m0wRen3Sb7Wy44o47+r8m1HjDDeovkJ8UTVCq+a9U14G4wvkWW1D7r8oX
6rYvckXcmllxdbxN+7PsJIcAQm1bdJwO5QmiF4xh9Hlrm7bxFXnr3LapO43b
4FomqArHxrZecutpb9At0xjs6CnwjWkMtnyiDXTSb2QR8HjDvkYHHK1oSyLm
7x+wwZxbKj3uuNi94u7N0RGNcUehg2J5qm7yLZUQx8gtlfMZHXG5nufHqgp1
FkgJcQNg0xbbNVkYwZNgXp7kSYi53ATA5uWJwIcERFz/cRHIQh79k5/o2u/9
k2iTQnO1S8VsLxfzveLWW+XHX3HbbfK7yTzSQ4kN0Czqv77pJn0s0sBS2+B0
l8UTrxJ9cJlQxcW4BSYCjApcDLibUPkHQQdo3CDwwHFnnDHz7eOPdx7YTu+f
FBstVTwg5FvjARuS9FwbHuyXIu+Ym/enyDvm5p1sYh+8OCx4/2waXBzNnRb7
ltHctYHB1TgAnwTQU1MnIsGqgNciakYeZWrMSiU19CMqxSmBLz4AhRDogD1w
cuBr//197yum/4RjjLHAqS3G6HXPXuA0xxbKsVvB5WMnaAX3Wz3Xj5l5FudE
QJhCi2G47k4jKhTemKW8PCmpgMzzDQ3+AMD7XPAHPNfgioCeavRTI1RA+SFc
8AtZj+mXJhyg2xJuIql4ixr5zWbepBNwAUgsUqF4neUgq/hhValIbwQeu0ae
0wiiUIepAjmlQgglbCB+wLpBSLHSBMYDxAeIH8IDhDWFr6YP+8EPajSwbZID
3rl5qBejtcj0mICffZ8d3ioF8qbZFiP0WpS0szSbsprPvYnz5+I0qzhp9YvZ
tFUfaaxTV+XG+1gBxNq7NjPqxS+eUApYrhSA+bP6oxbohQEPuemjV0Q8UlRT
vHcedUwb2wyK+fR2y4esetDQ0wtEA2Id0yIGDZlBcYWe5r9Zw/7atPRYaXzT
Vpm8DOZNsQwmbFSItUlx9+KcfoD8PE0kiCJyBUCA8IQzz+yfJmx4rqhvLJ5u
iebVW33REt2yfLuZ8o0W9LNyA7Hd6jXUGVxr9UeXijrAzFn1M1NfPjB1k/7k
EqOZU2Bw7Gmn4e7Xl/uneGFBrZDgmQ3TM/Dzibrkna9zH7/JxtumZPjOdm83
c0CYKv3JOCmjYeCrT8xIo8rNpg/2acqizHiPMLqcKxErHbr5Dsx8iZr5pMoW
3JH/DOaNHyg8tObtu+22+8Cy/6BTJDZ0F7Y4RSLG+bBoFnQsnCqkMfY4LmSK
xFV6mh+lESW3ai9s2ylEmJtKV97k63hwMptShKwoCMq2uoGo6w+10D+ePTE9
1nE0PX3T0fOs4TdbxeAStdauhu9vtxD+Hf3+Sn14YsiITbqXWLEaMWP3iO63
2DCuO2m+E885Z+bIk07y4d7P1Psnp3idlwpqLi92MTP7fYGppJTTC5NuYsy+
rRNtPsdq7481zLGKU25sM0fTsOYvfrNlAno1sFlVFBwr2qDDD+jU7bczWKYn
lPvhG7VdubriPsyInnjPGGG6jaUt2qiJDuO0RYthOrxvwnQIcGL02C7CnC7u
i70JUSc6XKMn+q9n0II1V9B04CtDWKimwC0mF0tSY1wu98i1TnhERB485Qqc
+WfE40jQsRbjhV8fuwN0dBm+y5ztlbbs3uLqOlisLb1FMNtlMWlfmax52Zgs
mwGO//nP1xx27LF1i1Vljar+e+sWkrcW824h8Wzm7WGH+rSMsNbkUIe+TbHx
oyvpfAzNHGPV02xY4h+8luOQ39DBLSgx2y4/p2wy22qSG6TNpZWDXE3LondX
NvtHO3hhPv3JPJhG2LwhmOY1Oou1VTAfvHCtnuq/WgPu3HurWW1eo5cVkr8l
qwLDi4pbfVOdnvvNoZB3KJJuCpocGo13qMkjvX66LHoMJ/iNmKCoZ/mFA5PF
Ce6nx5bo2ntjSJsHs5Xz48utmKxmzSyXnpstCfOfnHfe7Mzppz8omuyTVCRT
MIMT3NYJUGPiJpCjE+y7I98Qdke+NW+r1NSHsa3Nu++SHDXwNQyJPLRh6DrC
mYVTBL6cUDfawVqrRtvLtHKHCOoaNvXy3ztbo11/eg3DfMhqHu1icfU6mfXd
ztcy9OB6Pc2PnAVhO4Qoa6zljiVZb8hLskwQe6oVI82DW7hfuZur2298G17u
5oqRqpsrp4E0FwMAfnvLLaybao8lJlr5sFupIvYEFpHrS+KC6v5s5dMm40wy
WKzfG3SoG2sSuGadT9DF1F3X7dxtbWjxrSQXpG/sX5BqDEPx8VyW2TShpXWw
Yz66NRvE4IPV5fp0ia2V/Ao1zbJumo1ubIdx5mvkJXpG3jGPaBS6d7EmDaB7
N1Q0Kt9VFycNNEWjMM28NmWxdtXZpIEbKtPktFfEn62fyTQtAppXRA0lQkId
Sl7O+vGsVC35qphmloPKTZMck6yfy8xNvcf2tNxZqV4PK98ZVlCEL8lmQsti
q7KCirXqMioLbpOhkmKiNJV4E9WxJ5x11tQ3jjzSDfUZobaEOJP7qN7+JjdU
jzO9LKresM+4sdHIOIYap6o1LZ82Ve2goHLT0hmMlHahQgwlOqAkGdYZ02SD
BFaTneYv/nvbmFUlG3OoaT7ttEaFmlhZWWHjhjdCTfOqKhnR8P/Gym4VaTsG
sZZstiFxme968CpGrx2LJehkK2p544a6sUPzvLFp3p/KbydnjKdqrasmLY7k
AeNb7HZb5bl6ochdFj8m1ORrLSrYbDiY8LKBCZv/+gtrduEi+ORf/GJGjujB
0XqfqJtUaVSjAjhM5cs73XqEaUgAe3Qp5NtqZbotvQNr41JDRCn1FfVOAaFV
kO8S9o4BqdfwccepDwz7iFQQTdtiwuN4scmEV4t5VXU0JRZcubC02eZWdLkv
14gZV0/oS/jv/q1G31w8spAY1cbUKKshRlWin614ZENsWtM+WTdXzu5aUpUE
lmuDO0NAuVapEILJaR+k6cHWgHJbWMoCysngRT8fZYUi1I9TJkaTa4LKN1ks
asKcXd+GfqPuI7leV/AbzNStfrxrDOAEocWicrvyzjvVF7aVvGymAYs8uy9M
AbnKbdFQJ5x9Nqt4jQaeoL0r8IO3Mx+4rdn1P5qn8srQQpSNZKlDkMmfNKck
tBkfooAx5hAMTUu2hiG17oFMNJKzz9XAh98O4xcukBOtZS3VrdCFXU40LPfs
wS1jh7nc5ZnnwQy2wD91YOtODkW5VulBJ/xg69i83Er+UbLcl5h/l0W/hATK
Wbkrumvlflqe4DYlty2qj/6Dt/Wfb4utUWGzpr1tsa3/UNisohEvOxmxtW29
OmzdWgW7K0/cPUkTqMoioQHGP1tK6m2x7tGKnXfP01JebtZUXhK3sgYWYSlj
CyupKUrNU4mJONNXWoObO+Le9RUpQ3WTlZqwEeVK0QroBUpOCHrfYM/fyttu
1xDbrfbQ9RYX5+WBWPoXVxKjP+uugrznVy0u/bkhq3Xy+efPMHv8zyLB/O0M
gTZc+eQdZK1KfbZB1BgaEw/egbvxeeeR2gwDyCXbCjRyyEnWn9g9gsN90Ik1
HuB5wMHxwyDzJ5rO/J3/aXm20mlBhuD9p/lhHb3vJkowl0I5poRjOjBEh6jA
UuRG0Z2VP2fkr2l5HNJatYFCfrHK5d4M+Y3q4EWcwEN+5Lw95Ee4z6tc4tY4
4hDzrXJpmRFwm57mx68B93jBXtUSSSbO7MiLKmNxtZKMNdZwkkk1bFksPicZ
2mz6npZjTjlF/RP2s7CXhbi8NsqgbF1YxFnjRtveymYVxv9Rz3rZzTcL0H99
000CFva4ULQGhcA+4q3Ic9dpBALPhegDuoUIRPBgBLxtPsw631FvgXyLFc7+
+JxzEC81bnncrAoXdrOFBnup61mYmeKRBxUuobXhW6y7WR51aG11HPyWIV5p
G6yWCRafjwKvvK6a+VJW3KCa5FlGLSXM0urPzD8k8ZiBYkFazAysvVsLSdQ4
pNIpMEAHDunCA10cly5s0OEv+Rq5n5EnpmGZpfMMVo4zVGBUC7B8qMC92QLM
hwrkwUpIJS+w8Y10i9QC7A49zY+dAeT4P68IznlOKP+al2jaIKAmQvnoCEL5
Sk4obJJjGrmAmUJ59tifaJMC2SvLVhn2xtBcg0keEIUWyQsR8G/2woq6ETL4
1XXXCRZpu4PugCQgi8u1uP63t90mAIJA0Cg8jk4xIlEnqNgEqaIZCL/lcmVd
DGwO5Mr0kT/+cbE6Uso2Gsxk/X6e1cO3NVHE41SpYoFMihFjV4PoB8VmiftZ
SClmaNo6pw91S87CH3mzNL4H/41jR2oRyoYa8evIogQJ01H50o3yZWGxExMt
KW6iwbgGrpkYwTUCATgBjwaXaEA4JYTTSYSzArqQF8ufkM4aebLojRlqnc/k
go2xt1hbqBXl4qRD2MUrgxa8ga9tcoFItjurlWRKvODKBizM2jhSxMKCeWH4
exeBdcC+jjgPMwh/bF2B2RJD7y/finuR7cojMqI79a6+ugsfCCCJl8IQ7NaF
NSAkJZVLuZO/VKb0BjJl6ZBMiTGWU9etm/3RmWcWf14RytOrk6VZEiqcn9PQ
eC22ZSdu7Rolxld9f3P0faazGHU+r2mo+2qLPokdWNNwx0Ao8t5S7XuFHvqY
3DJwj8bnl7miL7WM6F8ObD6r4u3l/KL0kmmZEiLoQC0ldKB80oUUekiRJVBD
h7+KiVl5cFpesppPkf+cZSbWo/Rw3F5kGyKsO04vMp/IGksPcZEgGOqY8k2B
xHV9U+B6NSO7R6/qo1TTaKTRy1mbpiLn5ehh11kehRnFLAc3MYsYQRxeqL1B
2AUh7Oo9ghARbPgn/iE6R4BO56+l6raQfiH+us72BMMX8AaiZFZZhJjKylQu
URMrIYVzjqVw6Bh20rnnTn3jBz/IuEVzOKlN4Igur14iQVyF3LWXRxDMivuk
9hixTyqFw0POOucVLYPwWAo+Dw0cg8/DafU+bXIMJQddrNLySNzjBXHMYoVg
Wj2nP29QM0tGRF+a1EyZ1MyAcjrQhBJND7JYjg9U8lehD8I9gdm2mXPTYR78
nWvT4b09XwH7z+cr5MFfIZgSthEj8SqsuOdw7L5mc0V++3pNnzKDinHfCSVf
a1zYxDPW1iItwCFnNB8Fc7gNSs17lNHIw1sbe08yFI32HhKNwRwTuIcyqnOM
f3Bq4B0cHLgDbYLTo7xz7bVVjfPkoGpyaXO9h7lFp1xwwVo5muIvGpgmtAtI
fRt8lEkYZQBp/z8rkUwKJvZosNTQnlkka1QTp6HhMZFl3BUKLMNJZcQbERth
xZKDFhXDtgmIckzG0ZiMiAojnCrPbLnm7uLFZh48SPnMYuHJ6kuMXr7JBQ2m
77GZQgO8ygRyK5oYpkwM04VXutDESnii5C/jqXpA+Y97eAPmHruixdAvJWMe
+sVR8igNUZvF3uBooV9lmf+vohpSh2kdJkxDeaenp9uoJu6iRevn6WlNLI2I
+daaKHuPVBuncpyNU/HGyadY27PTrd0ZxV+4NT+PlIPciXSDzKmcKt26qDsp
OrBMJ9sUNdlYCaoFZpXb9JBhvon9C18cvKU4vAaPSc9mCMHkqiZ1g2rZBxoJ
O1X1hHbUbYOqcq7hebhPuLEckE4nkk6h7lRZeTfkeDqRcop5xYDnH5e530DJ
pDzSksxvClST+02FxmSUEIi8aFymrPNMp3KehCd68Mwq2EJeiDRxYisXaSDE
+rRVW6xosLdVa4sGe4opr4GL2y0Xoa2a8kyn4pmpHcRKaqtw1k5xFMfsFeIJ
qebNktdpekPgmK9buXPeqN2nNvwwm9jgPHOqt1eEZ5A3zjNB1ijPmCuVZE3k
GcHVL821QtYo7YgMdHFT45tYCnPhhbMnnnXW6rWHHFLUSOfRSjqogBdkLWny
tnSoRSr0YxrJQzRDMd85NrvV+t/nU7EaJuPFPvhMypTLUeLzlYl25Eywu/sF
1a1QJ2tAOyL/xnCvivnGh1vjN6VtNuELnslm9Oc8Rw6J+3pMZ6sGbpo0YRJi
OkU5pgBqJSZloy70sgnuUvE8VTZ85cYwimJUv7dR4eKmfm8+ioJwMSU0MVxM
RIdojlfpsZGUcLFvJF2MURRKS1V8fptpQhEagsDLIk5spfNxsty7mijJd7XY
ot1UhutVeYeE1vCHWejhO3F2hA2ScekT28KfYl2gibbgB7n8idIHP+m8EOHJ
aIkYc2/Qx2FpfQ84kscoSL5j9sRzztH+DQ/NdI+scLElW9OoyBglThUynnYa
sfOgyb/yKM64s7niUL5jrNM+l5Fotmi0ARV1kgIaENBCw8iLEOKpuK+jb6IF
1hNUl3g6m4jL4x43K0ZOtLfYvCGJPTnwx3q5P6Zs1KqTBnSkEZ8y0ZF6YV1o
pQMd9SCXVbBL8RzlnXGnXLRV+o2acoF5tkWWN0S3ubbIsnMRf7ftkB2r3dyo
yLIS0aRe1L9dixWp9Zj/FevL8iZmsZPxPrb/lQbk6jmYFaVFPPSQdY9B590b
CWlOJQywmWkYXnPyfLRR8MG0XaywzYQSz7JEPD6b4tyMfH587rnTclz/J3LP
o6ZoD6c9YL1ffN7Y3/b+/1+rziOKrCOAQt+dkdKnwdf6cjhraUC4846V9w4N
AzXeEV4SLIhI63C4Sj2duvO1oQLMY4R9qr0IyjXPE4kzCRX0BgUzKau0qiF/
PTkqutyN0eWG2PJA+JQNwkeZpgt19GCalRBI8Uylmz+FRnYtMWWlGKjG6/x8
a297I7tObGQnjwnPyHWZY16GEs0yvaJPnGGp3tm8hBTkCcVmcZZvapfuGfFg
Mrp/N9skeLCNznMv4YgQT05j83wQjpyDRrUj5ySqnTzQU1M7leKpOlN3tUvt
8tSZUjvVZl1qnWlOOu+8abFnS9ka1fyNJsVjU4ymadjeyiadPy8CDs0J2iRO
U4PPoQljphKPyBJU+ehRzh/XhFC3yLGKcgQfhL+hSbkVTeQjPDxmuHn+9X+D
2I/R09+ILqD+bjkmPFHxDEV5UzzIf02FeUvHiv0UWkSsCoQPa2WasoFpOrBH
F6bpwSEr8ZuKZyxom/KGbJoXY8pzbVP2pnlsP85jytAMsR4q/0ZtU17opA1+
E5dxhV7MJ8ywIrsXMNQHNxvT7X1jPhRiyJ9oiCE3pcUPt7120UQ0vpM5Uz+2
sTopxiP0cnoeSxZ2QIvUKKaiGW1534VP5Hycb6ziE/iyXpezQmXT3zzqqIdV
xFKV7z06dQ+tDcqL2sUKJImKofxirNgLImNeqk27xGh7zWcKZFwjFJ9hiuoz
QkZ1El4SnVVywE3E0qnHdoZCyiJvNmRsp1Ci0ZzXU7bdVqhCGGBFLmWcYiYa
pExOMUNlOa1RnCq+rDQht2IQyimT75TxTCfxTA8mWY5iKZ6uxHJvz+pYSA+/
uLE6zuqIQWWIBYKBaLzaz9v1+8bqhh5+c1f7NTTxU6ap5OkT1r6KiiO2+4WF
2DV/3Ksfe8l92BuRtIVsQrgzhWws1pCP+8y9pZPi8C4f1NMUtolMM2Cbrg7l
WlYbynVO1mCfxJR81bQc1sMjyTxqdvu8+V6mWna27i1DDlKIDRPX+lBTXCt3
KYPa+4YHZSwmHBNQNTq2E8VzkKCoK0GAUI0YPU4dx21qRjmnhGo6Y0aRN3wQ
R17KpvRniH8BtSxpJB3+GqQ96ruY5tQ1TaRThYOUc/jsJjdqQDplnXS6kE4H
VulAOl24ZRkxmeJpSjcby5SQUVu7Y/tBH2Aco8bQDi4UkRqvAfS93evdftCi
xlWkZrMqFjrNVkzWaVU2ocPAbiE6E3vP1gpxWhynQxboOA0pG4vQRM5hzKeq
m4p3SpyhYtWAeuwWBwCenQ0AFL+M5NSazx100CMi5/zVDC7Ei0PD3pfnosba
0pCP8oKb1CFqnlWRjcScxdJr6T0vI5CT9IVDD5XL/pJXvUrsz7hHj9mETqFK
R2yNwDaeH5KndKlDEFkgL7eiKYi8IUoFezkF9Z/81KcWg32TK4JDBemwRRuy
EU9r0Ulm4EGVDcqmA4WUiWRKSKYDnUzgL/UglZK/iscoz2xMM0ja9n+zOSGP
Cp977rklRCMn2EsA4/7vkW0T5zODRKmm2mz/2CnG4+JEsVq/vaGNeAoCWxui
2qodEuRN9X4jJ5m7S9AwqJgYTSvVWKzG6UYcKgaRyf3SNJqc1/jUYRsUNiuU
tvqwmRnboeOCRltp7NDQ88r3Yr/W9kwShtGJSwTXrV+Oe0w1xRfi4/Nh4Hxc
K6cj1ibxvZCfiK6KZEo4RozKWaaNYeaIEC+bV0FgU5BGvoFN7sIdauw97pdh
8ctjkgnbJ6MDcyy7d/ijbOCPMvFHCUV0YI0u/LEctig2bJh3VPwl8kbbdu44
r4RaGg/zejYJneI1fXE790I6ODbMKukPihUeNfUCOQ+IfBbcOH8ob37i+4g9
mqBtGaNt5LkjG1PqocmaOglCv8kjaqWNijoEM0IMXRiimEwcwQso+oMnMDYx
vLUzZ5zx17XgyprnGk3E2UBNTcc9sOIj5dnzlfs8CyovshLGH4Rq6ZNsZwY/
l3QZVdL4YxwfPo5au1h31zoVk9zCsXE/aF4R3V5TRLeYVzmfvATp9iRZnYmt
TiaiWGlBD/hg/QO0TdGTsiF6kjkypeaDOklAEEHJiKKEKDrQQ4/QyRLERclf
xZP/4ENOxo3XEjYhLQRfEEbx2rzF2KmdDTlRvthaDeivV++0Zs00fMEamqKO
YT5RmpRjE7QboyctRnJYVqnxfatKzb2ZIb4wj8bTQcoZFW/04AWBKBTCQwRZ
nCFEpVC2Oy02+aiKJbx/qzJEwyjh2Coel46C53/39vAhl5O7cZ/O3LivNOW/
gneCroId8EoQD6fJjyOEBMvASIgZ+ssyYoH0rI9N96loPhbJCv0rN2FJ5R4I
nr0qGXWAvNjBHZgNEap1v+VJYo+DDUVyvzQ5KEvN3DF/445KW8xZrLI4vFHO
zRtlnTeULbrwxnIYo3iSxkH+ED0t843WcXxKU+gVroAzvHLORzCs10br2N4h
hl6rfoKPmMJm/tUIw1fTFPrIxnakpE706jObiUmdRp8kEkYUGBYCiSLjpxVx
CMqEOoQpWIVhCMKyJ1cswftnjz311NWHHHnkoyNTPHQ2MkXsu/Va63ztZcta
W9sQy/DtiXk5TltNIDqCNJa7GsgomIP3CxuVTF4pNtEG1EoONic5zkrzWSzP
cjawmSw66UEEQGXck+pHbO8aQW74FL77WzlgPhHX5WOHO0RWCFXV+GEi8IPr
iuW2xaghKzN32rdqwKCVaLRjaGWHss4O6nkUGrrQ1IvciowdysQOHdihAztM
QA5dvJAOfxVP1CDGvTGnZVRJW1ug1Iv+IQmiF17SFjdLL8qcFmWIqh/zw1ev
edObpllRmxhi79AebWRwNBRh1VzzLM8QCz/dBUlB0owlYADRCl3oQmCJbOBh
lAcvZ3LxsaedNn3EscdaeyJjhj9fSxQw9nZvG5SSopwEIuTaeCAij898NovP
DO37Nv3AY7DMq1/7WqAqdLCpTk31cWqqETIq0NGJPprJBr5g8ogENWGxZg1k
dgem3qtaVcnt+eZTvdh9jsbA53gBCjlSLUCdTAywLKZTo0LIo5fDedlujD7U
S8zmzwBFN+U/TCIM1EGhboXmRORWZCRQQgLdRALL8C+Kv9RIxL0x8KVp83Ic
+DIUuRTrl5PrdWa+eXmxOlfWgper1VgewsjKtcxaGjL92DPdTH8o8uCmHwV1
EAexvZBHHzRoaQLBzd+Cl/JjhAQ6sIAsgiRN4ASMnRcJX6AE8BlWrz3ssMdG
m3/wmh2weYYjZaPM0rhRa47HT62Va4QdArn+aauZgweIRrxi5507tupvw6qf
mXpt1Q/6/7nRzFXXV1qf4AIlbXJzY64yGztUcUiLM3C/JEUbNOMh/+eNVnrb
GH2omGBJKxPgKZRVmzbngMlB+8dqNW8z//ULPlYNC7TIgvYFZYpADlig6KZN
w0YEGoSUd6IFyFPABE1SoExSoIQFOrBAFxZYgRIoHqPBhXtzY3EcIxODkCRF
CUKy/uMoeBEYG4sJPixkY3HLGBk1/2rz2kOZtTXzTgZC2Ro4ZPptQcfMLppK
r/Mtrmr+tvqTt1AKCDQg/kLJP0Rb8hQvEbaYFeag3nz1AWvXPr4y+mpe6QM0
cJ/PHk1tpGyyhmcbamHEUbneEE3FHeD9aPOuWvpm/ae6leP4N1h5XMy3t+lt
L7CW2GbhlYFWaYWQxiTxUJVYaMqzSn92YLVSizCWeJKiCj3K+zB+6wbVHHJs
2D5s21ie8MQnDhb2bn3d77XZ/NxBgW6U/YMlvxuX/PqCbxt8qa1iu++cq748
jMGz6NvC32TtnWTtHay9g7VPEFnsEiro8FfxNxplRPgvJJq40L6PbdFEDJ//
e1GW7/SFKBp2+s4vMhC3+lbF1Kux/GkMI29Z+uHYUGOMHH/TXtPYrsetn7g7
DID+FxYo+UOwxMNoA3np7HePP376G0cdVfxtNPP7rQXucU6Tdo/3CWqha+K7
whaSvSwW6APnnL/ikHbMnuAphdCVeT+w5r5P2QhVnSUVxiDHRdx0ejTv1PHR
122tmApmjU7BP3kpKciXvvrVYgLkTV9WJR74l9xP6mOWr9S38BE72FLfFjHs
xYihclTKHXarxmU1Sy8bLH3FOO59L7fzwaJedFNfVlvT57DziWTnFvzzVb0q
SOiouCehSHpxYOdlfVVXO+9i512su4edT2LhxaM1OojTv9jRv3zfbIz+IdzZ
KOLRP7dxr4CK0y2ogGqI/i1koI2aeJWgv9/0rnvsMfNeOba0qNtGhzzs1bbR
YahtKA4J5RTW6U/MXC6IKHxZmzB3tD43eXxWXrf2m8ccMyXGVjw52vPWa2gy
4D3ahpoqW5d87Nm3hKXYviVB/dA9qQErkQgRuxRgYscPGizTmRiv+dx1Id5o
w7o8W8WjN1s021XjdMN9uZhsCUtNUv+gfwmweYZX8S4+xT61PXb3XFUa2oKn
xWTlxdYMY95avClOn1zwopvqnK0fWO6Fd6KdVgF6+WJfjM0DHxhpoR64ZvWI
06ullslSy2SpE5hnD0tdRgi/+Gtdlgnib8hmhT4nOY+/ob0xU3xwnx7RtKW0
2UzHm0GjNlpFs+/DMrxmt732mmbR8uzd/mFSahTeXxjVLdxHeoqtir2WrMly
eQ475pjZbx599Kw8tVZequZYzR+xIUVYYbF53Q5tMJM3/GBd3aPJDkNyESkt
9lGZ3wMqf9hSZE8bsYwmlTyX+dnymcxvYHqV2ZWYXYeU4aT+oiWaEyCDSDkS
ToLb4g6jagbdHrcRVHsay3qWazNht8elGFXP7BF7c3tc0dZ1QtjAt1760mnL
ZrVq9vJVUxdNdYSLTtpKiTNcWeOStlVTF011g+UzWTbZooAlmjUGSyyTJaoi
LrHEbrLEFcTJRBKhjjdkFIwcGFEwzE3MrsQGqUQLZTgjd1suuIVf5U1uuvpd
09NrZJ2Z/uABB8zse+CBMx9mKRY8/2fW4imf44kZiptYzoojXHTWfvmb35wW
kTwlLy+eFkys2LzqX0GOyqzsDdmuTk/nN612HoX+53/7twlb3LZpEKmNPugY
i9vQwmaW9XLrkbVT1bZGTrUYk7JFh6T8JBE2Eals7SBHz1rODWvjbXycOqRe
Oleob6rGzprTrfrm1ixr4IZ6JwSspW5ZK9p0aZNlDWJMvWRZYYErdIUruqkv
iwWZqmRTLzeqQYC56OVGpdmlzKbKZFMlNtXBpnrY1FakqYu/VBk6bkxprkKV
tpgSeSR3LSlUweWMGwsXaU6J2tM2ivYeIWVsamr3D35wanqffab2OeCAopza
58ADiw6PUcgS9GDx7MoMB32n5JTE/tWjDIQ0DU6rfGVlHPdXD+7v3DisKsON
I1d+HpwZZRj/OLzkpAWn6KQyNhadElMo1TI6auuvqW5iJ//39a8v7c9XB5Ph
3ZiLR3R2sP001da9/pMFgVWIVO4HYzMyk1liGVesoObFxXhNZiYWlO1FU/EV
qKgayXZTY1hz2qpY7NI8FjuWnZgMHNhJoTJQ87FEYtVYqICTK4X+e55WrmxP
Bc3z2dkjFtPDh1uGMlzOX8VD1Ydb341ycXAwhkElFzEYD8byf6/WaNoot56z
ONRwPhQNYZO1Lxe0eU/ZuP//7WH/P+HMaAjkLqn5mQhxjEYryPyfFKIcY3lI
Pk99aUgLg0CDwwbfPu+Y+akUZZB+5eeseeMb5VKLhZesgx3KqfQvMQvMnowN
L+UtbiaYiEZKBmWWmGyFU+1O6rbR5Dh1G2xjpZU5ebPSsVaQiaYVZGAVk3NZ
RaXIujVF5gGMQrOTag9mE4O1Q44de6C4aXut6XJz6GAEHcyhRzXDBKkM/avQ
B7XCgX/1+FfxEK1ymG9gI27t8vkRHtggO8GKwsqC1+QVC97efcytXWPPj1BL
2a+ylOfo/QrVVGDldTZLMh/JtLsF/bGSXXbddYkaxyPmNg4L8M3lmewYlwfv
dePGYb22XmnrA1B+lVsGVuEWIbAH+hQWUrpEGfTr/uVf5BTJj5JLyTAeSEBu
/Evul+pj/GReS1EDkpLPwuL4nioYUdnL0wVYoBZ76cxtL169YxsNgvJaPq69
hJjCRDIYjMWXkhRR6OUR/kEer+ilsF+wlsp3kefcXGz50MVjILWqlUPT/Lgw
JeZSJnPpYBZdzGUlVQC9geH8uaYC57MXKR9p6+EE0vc4MG4c/O0p/Xwz0uJ0
qNo/WsbytS8X+AGHf7JdfXEnsbe2ZciywKaozOLh9dj3QswiOutRNQ2vF8kk
fKHwRULNoW4KbgIlqlAuLel8uvWK5pNzxX1HfyJNAQePLdXXoSOxHqyFj1xj
VsJhvHDHHQtrbT1sFgOJNZcvMqZFpKyXGEWmq9z/qOpgl7ZpqmgMhUa/C01z
uTEU6nUUGlRTHWVaqtSFo6PmQH3sC3RzwQtpAePWUGIDncoadtxxx2WUxXX5
q+QxXVrE7SQeN5+NNsikBgdfDcL9Ec9xt2y0WU8P/yOVUVQNjJfOAjh4Nm2t
p4g8GMRrRLj7GjHKxx4SUC3GsOMoY8jWh2QIGIGg1NcE+P11tgYQNgDRb0zo
F9yX6MMO22bkGpP1JiUm/y+qx5aqfHxzZRv6Tj4J03Jb2FbZdk47yAJdoUp8
xXxsYJAQmogLQvLBk//dHVZQuBQTNZciwL9Cfy9H/0A16TJQqGxSgfQirbit
ob8D5rugfxOKwzr8VVaPybNiApSL4KaP44577/jcHQf+eBV4GXHfSEufn/Ey
vU3++Ecj+iendhL0QbH5rnjQLwicVOA/WsuYamHbPLAUfef5rgCB/WvM74B3
1nfAD8CuEAbKVHKxR4yfwOxwDFl0X4mL1KPkQ4gCbwktyHNqDvJ63svn8Jn/
ZEvBthoq1UaaAsteHf8DVztj/6UD6K+q1UKMCf9U4VRsGuk/eRBj8L+DP3el
kw4qesltMBmU8X6hxK+A3kFrQxz+JaDvAP8ePsNyNFGXv0oeK9PSUDxAaygJ
VjXthJjLt3aXwXOhi7YTIm9tfkBlBc/T+4mZVwj0EBW6G9kSja/YeWdHf8wb
NiUtYli1MXJk6Hd/2V0CbSMVNkY3Un2GfERODfVG7qAahFPexGYw+Rkl1iyX
lBUNmSc3IVDul+tj2Dq/lpfzVj7GDQJ5xddvKyeg02YMvgkZWHsz/oEd6Jh6
8avnaQQhCLtFXADmawU1d2AsE8h8ZF0B1ATKZAJltQII8LuYwBIqheRteKLU
DPGvCe47PFvyuuLBWlHMlgK/sW+RV8cU5FwONdaBPEIqkZb0rrYjtgAsuMH2
xyrj2F7vu4pG+BaICHJrRhEcg1oyPda7Wa7BjSL6yT5NLF8K3AloWgZAZtMS
8C8NxmCGoEg3Kyip8C+xcLluu4qds9rJjX/J/Qp9DPunKJjNAFgOxQcYFksL
36XLhRzLNttu261GUwwrJa9rj4vEksw4Vi1klUhp+KIT7aOoFNLy1KZjDNsY
8g7MNlQaycN4BigjU0elRZJYH6D5f9BC5ZptKOYV/R0w3sM0lrOJpstfJY+V
PFuoEalpvESLH+UDBKYU4ng6MLrQxI7chT7rrLNKbEF+KjU0pAOxlLGK4sf1
oFNF/MejLXSmdhJwwsQC0mLSPORtxvCQnxccgrmMIF8RdrYVwVeD3AAc/C3A
LxPq5YIC6ncMQF/i6XTolC/PsR/unXaTv6uHl6kvxMt5G/aALaktyNfx9dip
ILLXYAe6qcPqSlpMoNRk+Mr54n9QLiaLxAIkUr44OPiLyi/uJb84oL/yC4pu
hH8D+MsEfl0XOoB/CflyORFsJCNzzr8muNdny2QahVqOWsZLtfoA29hSo7Kx
F3H0nT2g5M5DzOXF+vDGJhXzaUJ8YGUJz68sYRo3VvCvNlC5xw+rbXaIOgkr
YDmI+ii6w3Hcm+/xzi3AlwCN/YgFNqLf9Y8g30XP2yvEy7l0vJcAuwvMS9wc
OefUsry7usml5365PoYTpNYgzOBmoEsCJiDfxXe/TEs1/5aObU8UNHa0iPrx
gtDHq4x5PJNBHod8eqxmzx4jOAbXlqjuNVhDVRmyYr7mUFnDJmNbQ4MlWMKt
F5eCTCL1okRySwiLQKFOQkCw6qCaMXQAfg9bWEaBdZe/9DE5Pey2RIaYoKqW
ii3TUgFOc+8ZRYQBuN/A43PUSS+4S+4naqsBPadn6zbwyGFZ5CuBkIlOgDcP
eWhgczYRaGgFcPzD/oZ/lz4R+28z7L89MD3YBcPO8ILrUmHe0QaStEvYbc89
5Se8Z889OwS95AlqJ99T3eQqyhNyqnghb3Db4DPdJlhxsMOXQGryY5dh9RME
CCa8m5EwArlruQlMBd1xeRhsC+J+UwU6AAfN3t9wHjxe0Xi3RuNJwDQzeCty
jZ4ducriXZC7itrhDn/pYxWjK4Qdxqj85AhsqvyNu0vqGLi6oIfHY/PDFnd3
wS1XP1mD7VoEi8O2Sg0/qiZini7n05V8FC85badZwGGKTFTubZB1ulahMgKu
dGZ0agZ6bKMFkiTw3rv33nKJ3rvPPpPsVehQiljyV8lfQp7UhJAO57W8hx5K
fA6fSYsQvovvxoWW39Il8H9f2x5DMMtq/cQm5H4TlfKbKPOiuL3Z5hwgbKDP
gYeZ4iuFBk6Sc+gywqSAe5UDEJYJhAY9AeEEu1SWoJ57/KWPlTxL9n2gOXJc
KthFN8uni3wwPR0zUiMKXMfX07iXaYP5p2PgpbNmG1mU6gxqsUZgaDo6qQea
HdgctRebfk7MGZpyexxRIWi6OaoGh6BqZWdMUwoRfjBchB6MCKSAFvtj6BvB
7jh2jL4f63z/hz88Sf2FXDryy2TSpnXuA/cr9bW8h90lvJ/PUXg6NMV6+X4E
Nqz+Eu2xK+DcnEViqaVuKQq39G2xtaWOUACQY8RhSntORBimOLdHuGVBNxKM
CCzGgGAJssoEwQ7A6wHBFdSwdfhLHyt5VtZw9lKBRcdjjkXIz5M/I8o7a2Q4
R/oHBA7tcf5MDIDrGp6R4SPTxt1GFGbrd9Kv2ayJXLv+0xgIdAJU8hM01NCX
I88QJxeQkh92c3xQFA4lP3tSWsfWLaEWtjztPbiVPKDPlbxU1iTeyAekG8iV
G6iedrQaUiFRrAIL4XjlN23ND5/U9omCTUHSk0V2EsHbWu+1kWgTJ1Z5l17E
Y11NynMGRl+SVQsOVuRCxWRypwZwLBMcFYRd4LgpecoOf5U8VvJssZnu/Ym4
jJikupnarpiJaSiMHB2Djg5Vvtv2szUgzjwlUGFVMf/YWvK9BkSLq+VATCty
RoWviVRo4QN3nnwlbgShU2CgvwBABYqjD+SxXdARx76FfT7+cTk/+8p9RzfU
f6i6ye/jfkIfo1KTXsu8nvclbK5QQDs+HZN8NXbAos6hgUUYU36m1l0+kPgJ
IVmxw+cI1nCKttb7qjgejmwgxCHn3hixcsG7jj8nxDEQWFbkpzQouOuCwB7V
iZPsX9G/OjxW8qxgkdAXe025RVw6V4JJSrVireF67f+M7eQ+FwtF6stytQny
CRUWg3MzEo8e2jKnJs7L0KW5iRRx5M2ReWsDFn05jmQIOTXiMGAQfCn2ZA1h
8yeFkR/+5CdLdrIvYeebrE3srWFjO9tceZ7XfsiwubfjssKmfr6Dku/GHjge
HCPAuMs73vHn/FC0npwOy1wIBrlfomtzthBnxNeJxFf5IXIRuPzuGfsSbBEl
kILWa4JdCcS6gK0L7Fawb0r/6vBYoajUmnNuiRmXJwTGlZqy9HlN8pyrH9l/
Vah7doM7XaHucepOw4C+uz5HnU7z9smWJgg9lDS0FAcxmBgwLsPmh7QhjmXQ
mS9nvb0rthsgrUKZIkswVrJ7umTrxjLK04stdBcHLVTYVc32S+Cn0HNKHNBh
ghwwd/5zuFH89yB+WhepgWSTX+/dsJZyv0q35i1RTyVDnLOcRRonEs2Z5psH
2sqEtk5FbYKxLmhbxUqqf5U8VvKsvq5Y4aAb4jxHHBV3C9xUN+hp9YUayqYN
YYqv0lC2TcZtvkFUveCINPOAI9LyUR2vCZ7v6605pQq+hnWWC+hCL0fZ+x1l
jjDns4iwCl0KIgFUqdjq6i593atU7Vcq2RwrD7M178DBreSB6rktdFsTL+et
3NhD8dEITflGvnkfY0TYEFg6Cyok5VcQav0Lq0t9lZwR78G0td4vUZc5A19G
db0IPF9gq8W16KRuTK/RalYHX9FJDaIBVqfCmLKc8p0gcDO2qnX4q0xYFASy
AGYUqGiMqy/HAn0toOgseR3/XYHwWQ1eRwXCp6QQDFRX6zRgoRj3PproLuaN
3PeNC2wSe0Z1hFzekVGdjvdC5LUB0BZTGKoBfAqZhDyBEzuyFWpr12oHpU98
8YvyWz8p913dqf2pwa3DA9VzW+hreQ/v/XiAJd+hbGlwjEzJ8SlDBijKby3u
i6xYxk8HIqI6bHuW4JH7JeqSZDh0AqwcXgtKewTFJZ487BObuNUIsKzDrwR0
HeA3QVOBSdbRHn91EiSLlbqfmX3N3CIoIz06IDGQ3TWnMf8eP2sjEJ8WY4F6
e2q2Rze2sPV4oHedbGLCPADjIPT11t3et45gQbwMV3a+ztYAaOy3vzUgzMFX
A94Xv6jbNRVoX/6yzqZj6+ZnvvIVQcRnvvrVkvlIXf4qttLmHzzLq3gHMOUT
IhT5Jr41LtiwIozIkXLU8Di/Sn6pcIyw/n20Bk38BTlFeCAUaG2t91pHm0Mv
RVqEDX16hq27A+YrOqlvBR5EBr0yQa+sYPZGJIJAbyXb5fUvfUyf1dcV92kE
YQ5ArIG/obj57Gf6YgW8an/f30cGrAOvpUUqVYY+xtxdjBx4r8qA50IvxVts
+c1FnjNfWnpt7NievuwG1ssZLwIO5gJsn3SwVUDTrfrsh//cQQeVbBpexsZ9
cTvYP0wPaZ7jNbyW9ynsjAET5OJCzCIM3ISZidFgNGJMq/hhW8DrXt+yo5wo
gi9k9ba23B5sF2CmKKv0XS/hzFZYRVnTApvBrOikveBvUA2quFKECdY2ZS9r
l786PFbyrGCNV/Mubo67uTBHcfk4vU6+FLH2lOjONu5niDh7tuPMIs3uyiac
yaHV3FjvQW44S+EUcybmIjcfolnDWCC2Gqk5oUV8VdgqFFhy6mkJwZ70z+vU
pC987WvyGC0i/ru6yZIn99UTm+sLecN/GRD5MD70U8Z7KEZfegE+B4cK3Nu4
Dt9XftwElrSM9OKW/PN+FnfGzQ0u6zjrZ9FJk8hwTyuV1kl9t2ApIyyHWAmw
SiDWoQHBMvZ+TvBXl8fs2QS7zRPscsgBHYeciz5MoaVfh8LsKxXMqnaTT4n+
a2NRkMIstHhVr8LyarXp6OZRKJ15CDm0un+zR+1cyPka2iTijMr2sjkAXL39
bBbAEMQChYGAT0fqIhIvpFUqsJZo4y+F1De+oa2zmCFAC4QvfvObxSQ9g8TC
aRPOYzzHa3g9UOS9oI7P/GxAHPB2usvRhqnwm975vvct4Uc+UDPWHS2H9S1d
q7hfaoFlKC6AbuCyFj1HXFo+65TWireik7rNyK1Q0BWd1CBqF92a95a3vGWC
OF2v+kse1Fd09MXKgvoh3Hz1LVYlROZo9BAMZM1j2YYWReFXIwqnpp687baJ
7BrL0mKTYXcpzK+tzbiN7kQLAkn6u4qrLaYWJ24kOUOf95xKi2hEXyA3eOm/
rNEGyHEyA1GGOO1R9eWq+UZJL7qSjlU9elHqX6LsaFBHaw5exat5F7gEv3wq
n654lG9D/Sn7CeViG6r2DIvYEb9KfmWxCYJhK36oXPdXypXyDST30XvdPliT
bwPp1ovYc8orWlfUCn7dCL+K3QRZ8rD3iSA8LLeS7bwTFOF3+avLY11e0Elw
rLC7WQ7HGjvmWPSF2Lqik9NlV0nl3x4UQfiMlMzwLFojAL3dT+5O+Miw0LU3
Krq40jYCMKyyNSXn9BdWWHcbfHWN4IOajPYS+CLwAui0QRqdT2nAxIwAeiEe
/K1vLaUbU8m/RO3xHK/htbyHbjFfNGqMEEQFssIfaItvgp8YD7/FAt/348eV
5Os86cwoEt+6sbXed9WxcEWXoiW9hDxbaJX2Bh6DvM874FmLW11H2TZmbX6M
7xLqvEMJEzdL6hV7xO70r5IHyzoalSZLPqGCsErEhOxRYMRs4hItTtNafjOw
O7jCYDVb6mkDD0OW4rh3qa0x6/OD4ptrJuYbGjAYPYqk9BqWYO2ia55EXH7V
gwhLbyP+2rA3wByQk2tADyL6gAkuvsaogO99j5tcernv6BNbajtb2oXxLt7N
p3zFSFIJ0pDJEXA0WAZWoqi0BRpa5xcKC3bh+eXY2laafRb/VK4Y/gZpja0t
ueGyb2ftH4Tm6yUouu8JrQx816KXOi07AcJeFXQmG3HonXJ23XXXku2pPVZM
gTU7VdnCza0FoJ2KQusAXZUAOgqcvmLDkugPjG8YmGmFZnWugbKlDWHUhzV3
1/Iaa0KMJbkgOSjd/Qi60DNlcVV2UnSXQ1dkAEklpa/GDsgGMvyKdaE7qAKi
doEHZodWGJSL9vUjj+zQmK5HZzq5JIygpk+d3fQFxRYKWN7ETXHq+BS0O3PC
xopNOSjFpliQi0esjB9IOdim/MQtLQ+9q8gn33awtd5rWZ8vyFUcpeglPHKB
TQ9GLbhZvhgnXmzDou+S9m7g4rTKz9+N4nz+nNAHeZIXOVBrIO3weZ0E0kIX
9cTFaVlfoYcUQeqODrTvPjXLuPz61VRUhhW8AunTdQV/aqiBibXcOUDT6p3J
xwTQMMkvpUIygL47A2iUjfvaKOb9beyAAzQxJuCEMc1RcbasgTNnyjow6+0S
jz6alolyuf9X7rvayfiwwU3bKFbPdbS1or7+6KPl9UB6C/0cPs8xXMMvK78c
D0zOcTp2MTZWA4yQVcJaPwpLC8tuwoIhX8aTXqCqG2i2tL00LIU1T0YA7OD1
IMucQnJlDb5zNdEk7iLuiHzY+3SfCK4Jj/Ecr2E3dAOaO6C5kyhX0VwqmjdN
aMaSuDnn5lB2IeBcKydiDTUdQzB+hvIsCRUPJ7Y1/EqLfxiIHQWozqwlo2fJ
FMKJ2ofM/O8cwtMRwlF4hkU/ic7Ir7bgu9hsgi9QOsS6fDZBVzvz0j6BKrof
/pAOvT3675f8VdxXH6MxN89zo4svr+d9Duf/MVbmsx3CmI3T79oIXzn+/zT4
yjqi5WX34V8CzAPMwyMxuVzvRfsJqiwuJPD2bQHmEzXKAHnOBWlQAeaBbzqS
eb3tV1P/V0KIe+65Z5eYohxdXv3PS3G2G5AsXz2MZfW75HA4hIyYh6DssiEy
spjyWtRSgPHTqzimall8KeRCCiON2HufnPlsaqJqWDq6+kAEj4oHGOdSYRwY
IxOSbg0Oe/KXXB4EBm6CcA2+bOqjEJluu4Pm0v3vnXBC1V+6y5/6EE995/jj
S5pQl3SjFhect9Kb2pGuCJcbCHd0O0GzGHBYX86QjTvIT9zfSFlk/AS/dwnR
ii1Yf7pYsGB6j7328ipCURWv0mH1wLlRQYwUtJuOhLKzcN6UiywM+4j322+/
jvZIWeFFE5qr5umYFXSS5qMM1iWf30mwHqhiOSKOwoILNZIG1S6IXQxHchaN
sZbM6hCin6ki2Ik5bTYY0UkiRQZybeFRAeb52Awvz/GkNi4j0KyTDWy218c8
DBU0hQveGiE3CN1WJBsJf8tQ/D2ff0KTD6YgnHyyXPgfnHIKYw9OPlnHHjAd
gSkJ8rqignonwrxQnIvO4DOB+BEB4g5v1x+HNECb34V2UsKWc/CBj3xE8CK/
eBnr0CZY8UpYaYXFqiCpAOK5lcTmQxjOm8vBqXkfYPBLtQ+V3lQ2HnjggSWl
3+J9UXQbGyuCaRJBngSKeA5U3akcwBqmBc4YFAflsI6Qjj6e6w2PgMkqNYP8
GoLzM7SqiPo01Ri+A76tKYpV63rhRtIYyGQfR4cfZ3nylEay6GoMLCSJ7FDO
5LEHtFxb1KRxIOWDrHO4D+xLmiIQ8hEjJnjZ/PAOs3uKpTrHj4FePMx0H2b8
NSN7K0U2H4l1METAUQ2ilbDlEJysObyIZn6Syg/5uYhj4nwipwTN8kyHZWgr
TVt0+v8hJ9FT5VtXpRpzCYutWkNdo9DsXX+AKXtm2LvAZi5qxz//+c+TlPvC
F0Rrs6+Bzj5UVHodL3TtVN0Aa3nvf9DUpsbW6h4KqDkmgO3gbgO2qw/nafF9
Z73zQ52jZ8iVKj+72vDNYA1dfuDnOMXd1cZrrX98HL/kfp8Ot7d0QROg92sB
9KczQKvKCEKZKKsqjODfxVb4Lo5VXdhMqu8LJ4NQ0Ap6T2Dkztln939y7rn9
k887T079KdpyQP7WCfEnnnWWzrLltaAcI8hQLu8B51v4+AtFuSMcWRL5OnI1
6wtGSswNZcU5wAemgmoFv7aL+7g5FlDyw6mul1PmWdNV3C8NqSyDeKGJUIG8
RyxC1KLQiJcQdxvEXXREiLMFAlYGwsCZbg1skziIOoeDDz642ES3oFOtTo8S
0O47ebAOkJ4TOJY0jPYBjwvQOSqOzgGfgz1KbRjcZTaCpBHoz1AhkiqcbKPu
9k2trAJzD80YC0MFmzxDLTAJKYkU2AgCJAf5ZzOQ5+JjiLGjBxiFhzE2wASo
UDPD1QDyqeef3z/9wgv7Z/7qV53+WRdfXKzmz/7PmMzOzGXBO3ZQwzqMzoim
YVavYz0yecC5ym2xUX4O2oqfisxmAZOfvwJ6X44lL+OXdjSF1+kfKH6GqZAq
V3EfY3Bn7yBDTEs/LE+NNQbl3DVEGIPH2LMN5mYHJLBmNyS7L9gNRPcqWiyw
y5wtu+xUA+eYge+WjBiPotswLscoKM9AXmymhzUK41F4Y9keEcGNFMG9mn0G
MTE8pfdvUB/S1Xa+p7KpX9s/ZmzuIRCfo72LT+XJlDZVVG3TxBtB7iHloLCT
LMnU9RCLu48YJguiqp3FYWnhbUWzYLt/3m9+0193xRX9i66+uv9LufH/dVde
2f+FPH72pZf2z/jlLxX1P6mmjOskwhlDPZ9ZY3kGlMl3HSnId9Qru5vTCeK/
ERDPysTv4/fy+9Erci6W8yN7BHU252UdVoH7K133mkLMhWYlxL9tQnWcuOHt
m4nJeaepOGkDVMPOoBc0003qyCOPLGmeIMRNjxG2AAN2gO/gdgJHrON4esVz
ALcc4rvoPlZDtwoWYW9HtyPc0Z1Llcjepr2nPFRdB7a6koSom/arNzUhjLr7
NZ7UCwERJMrbM4miU3DNfdREnoekPRDSwNzJbbQwNKDOpclc7mICtUsTASR0
DGtD0+dddln/oquu6l9y/fX939x8c/+K227rX3n77fp//n3JDTcoyAH+z8UA
Tlu3Tin9RKd0AB6EeqT2o6oJfPr9TukuXRTcctz8Bn4PvgSrFGLcVrOm9KPm
dXhMfvbXq1uxTO87/X+TU++1NffT+4m2fHMVaduiNUYdhYrPYYOV6Q0Fk9NT
kH5R7O9kr/Fxxx0noD1eXOtNde87DXTYjwzDA34aMngXTlYGVgjX6NgX32fg
V+x36tiXT7Xo9xD0c+ESSR3RIup8ijq6Fti3bcDLOw96TYVXL0ZXM0VNomAJ
qvwDpsp9EJVPgNXYXw55mwn538G9jJB3oZJC1R6m9jhf5lomHg+Qh6t/de21
Cu9r7rqr/7t+v3+L3G61//NvHr9cnp+V153/299W0BeRw7B45kefIOLnRw5/
+F1M4NhM2RwVuD1BX46V4+Y38Hu+YpyON6JbZj772VX8uB6O8ya8VDNEgu53
yBm2vIb4nylX12uCd1Hhe8uE73x+hTdZdl6PDZbBKpiF08E3eKYnzsknn1zS
3EHASI8o2msCfTqrIWJoycmSgJZ3fuejI78bzMsGnFN+MkjyVDUgtJmUg3ft
krO7O6GvetWrpkjDDmP8mWu2EcYH4179XWtD0tBwv0brwfP0Oo1aVDAKcvM6
fcKxzzrV2HZDCCXh27zNgyO+R2mUhtAJ+ENrgE30B5QOvn97yy3963//+/5t
guff9/tyhuU/Uef3yP94jOd+e+ut/dnrruv/4vLL+2fOzvZ/Cr07xvFQR+E8
UHzCuBwnx+xKnbCQq3TOhSx3E7xgGQvVcsxhGb9Pjm1vOYvAFy9ya73vNPiX
j0xyJUqWUK0xFOB2QU5g0EdpIlvALNgFw4zGpSkmfXVoIUEfNFpB0RqQvjrQ
OXRPJ0F0DFSOueROqKcv30MFfQ3oAzEj0igAvVXG8NOjhBHnswXkT58msbNd
2ODV1CQwNk7eKZJ4CH3HuUiqWzwX6WLchvnWwiqevGkIqUTNEgHuIjzXKy7C
hwBu3iaiGhJGaF8omgUCB8R3CKyXKLj/jL/1MZ5Dt5wrxnCGkP6pAuyfGLBZ
DFrB7QQegS3HdUTQLIRZvmwhFoyb8yDAlysrv2KCdWgTDbB3+vvKWTONLaCG
k3u1ZGOdrx/RCOioxQGX90TOB0/SuxLOpncZoAW8AJoGUTT3o2EUzf4ANgRO
z0sMAI8UTeNN8jEU1yee7gnAll9VQ7Y4nB4wzzL1jTqFXx81ijidLbiemv77
7bZTcZITdxohlDUDx9GMIycTcZuTGSMpFHdGYeJaPDmYlpD8TMOYvlZMRw1u
U23zwdUx3v0j0+KnuDAREr5YdPjVd96JGFmqkH6Q6hIeQoqjRc665JL+6eKP
noqfKZA+SS5sG6ybIK1+ZtAiHD7BIOLhFkkR6SCv2sxSR/sJyiwyXExyv4nm
QXo5jBXEVcrvEY0wzmc85G6lyw94Fr5lhgPSg/5mcdxxbHYPzGlmjL+Jr4kO
geOR68j26GfC0QHO9KVrZupiVSOYc5JGiTiQxcec8uhghmM24iJAhrg5jsEK
DVwRIARLENhvdIGdzax7T8bNUXy4uE7+pCXVmzB8UAuGc1GdYxhAHVvlbFQM
/0Quh3KzgBNuvuymm/o3CHDvchw/mD/718vtMqHmC4WazzFq5m2nECkEy0QL
Bc8nBjz/KLiZfKVjmcOJmoPDJ05CFJ+lCL0hrykR4Ztz4F3CLSvQ5QLqj8hC
Zs5U1SHVkiGojIlaUCSQchVCfujIEVdxYAlCAcFAjIRgiIsNRlr5YOB1sjLF
YYr0T4O/0d74j0QGvYdaFNah0qQE0UU3aWy7DZAtmj1mNnNsR5KO4gOF3Yrr
p01P0a5ONMcQN8dW9aEzNznKNSFW4tz8dufm6DRanCTXG1FQfzak1td6ZHsc
TNP73IS0ptKrNHrCNFrgeEvfwM0/E1GNjvjlNdeoYL5J4LzMyFmEdf9GufH4
L0V0nyccjrN4OoFAubIObOyjiahzYHMsHBfHiPBHJ/FbcBQoJRCtJcQrR7sE
H3MVInwpbyxZVQTWH5V1zChXFMeuOrFlmJ4fWaPnJopuyq/HOSQR1dA0qI7t
hNtoGlQ7TUd3MWYuA1UrskuOJONqEVst5a5DTO1hEaT0zjvvDJob5EYFZ+Ig
jd3Zsu6qr7AZca+NMRBL2qh8DrHslJX0QdzIDDyIKDNMOntqHQ4jNoD/lPuF
40D5GIeyQAuZAdyAH5oBP49wHn4fob6bBcjLDc4C7f4V8hjPoTU0pg1Hk80R
OPN+TCKH9BCcRXMQA3G9AUdz3Ko1xEQxW5Yo8SPlu+XVKzncSWRRF9EiqP2Y
IIPLSvxrM+4n1H2ag5u3qiHZS6XzSWv5VJ0oOnD2CG7AwyBX9LP1t9yspp+J
ixDjw5HEoYwcnaMZnjZEFwrpToK0fKrndELusgZq19EeCHENPRegaZhLJjLv
OuOaOe+7ij9IFtJT7R7wSLq5gZu9ZiTXG5+LesMDHdl0+ZFgFuAomAVEEcwA
DKABOkCIeIBvfyFgRTtfeccdCuhlJjrgZwc1z19wxRX9c3796/6Z8p6fObDl
M051rhZwR1EdgY2YPibjaIQHv4U1x0uj5Dg3ZRGZQB2t4q2yNu8rJ83XXrlt
pTJTId0O5oc1gjmOicoLRjyIRybdHUIol9kHgBaKBtSoacQGYAboAB4ah84J
brtD2ARoEx4CZPn2soGlRW20QTrnaFccrqTXrFnTpqJBM+nGtJulqfF72HNK
Vub1lmr08LRHNpSaLXQXQ9PuAX48RDWiyqh5fw1IPqwlFD0KyagB0Aat4tbh
3p3vaBbU3lSF7yoV/YD+3SY4SNDMAugrr1Ql/XN52xnC7IgVB3XO2BHUP7J8
PIfjTM0hIzrIOla7wMR8V/DSDoJoK45XmBm9/37aeIv3v7Xe6/aohF/DcFXj
XKmQBOKclZvmnXnlE1lGIhtoBQ/XAVLUMWAmGF0CaQEc+gJXkagGrmCeefGu
m6hnb7gEkI2d27G8SV5W0krNjmOUs+B4dTMtT62hWARXMGmMhu7teQWUagwr
DEkTmz2U0UDJH42U3KYvGqQy8QAv1WsCMTFfYr8/NJnsIAZRIAtNAOJA4Vmi
HQAyKP2toPV30R18UP92cwcvJwRtQD5XZAlvg50VzMLQpwdAK0sHMJ8YwJyz
M5KDn8PPYxWi78BSXg2CxeZOrG7i/Ml9h4+SJ/gN/EYU5hbc97j8gm8ueMC2
JSnQ1w9vxDaAidsFmvAdM4poaToWe0YRjKOpaffO/yFoFAfRPVQKJO2qAztB
yRC5a8B3mQDeGTiLm9acxSaIR+cwSmmDdyyDMmRPEYjGGWxsphhbylpTCg8+
pyCdZQ81Ye7BjVw5ByfQqz9qgY1MNUdUH95QgNqE6h81oBrYAUHUMKr4fBES
qGTgS8BZ4DxpmgOKvpkk4t13a7DjV/IyR/fZoj2g6rkQ7hpE8+zoD6gaUW2B
D4yTFYcViGSSrEpLONYe4ZMteGuPYIpAGpvg+oLjldwvU16rIO3pZHcZq3Tz
wxKUczg7XXuwwyHtY4vJsFCoinuI/oC20RTAGuoGwmgR/g/MgTPP8zpez/t4
fxxh7PsPDNJyjA7qTp21i07MMhaVn7gs7lGoaY8A6NkM0FVd31TamJj6WjQM
2PBJBWlcuM2AjZE6tMYo1dzoAo7QGY1AJoIhQAYlPzR9AS8CYlDkQEbhgjK0
Bq4gavgCB/Mtt/SvveceTYPf0+8vMUCTLSSYh7i+9MYbNdABoAl2oD2g7BzU
rACn56AmupdR9g9MeyCmyeZjswBa7Hcpb1iKKWwK45ccOjsZ5JVGXOI7yv0K
DeZOJMbyDdrGy1VEd6uE44hl34iIjvatMDmekQ/oaWRIVuwkGDv66KOFTMFx
rHjCmYTWoWf0uE9Q8r0HseejYFoh3akLEflUT7sEVNdoOqqQDNEzlGbPhegG
avaW8yo6+DjygiHx7X4gtUwx7pxyJ23U7AGNKDg8yW2q2be35DHmSMmOZLgR
FXCKoRn+hJqBITxLUR6qAnoG0fDxnf3+hCJ6OX/qQzyFNrnkd7/rXxRRbVQt
yJZrLB9abF6nbEe2x60DVXO4LkQw0MMCqr9JVYcc80qczUneLoD+ipwfu8xy
aHK/XNmspw9mwbmq6FP8yQzNlVj9i7izVjWHbVFMugMQAkZAjbb2ulQIGP0B
sNHZRDb4P1oDLQ3wMQD0NAQd+zhjLFkj05Iv7tTVR4XqTi2ZqAE94ei4RTIi
2sMd4hu2IHoWwZF23Wb9dCM/azZFxAYVeklseHVeCNPtEyLOuYT28qS17geG
iMaQfM6q78IulwrJQVzUkCywOt3RLJCDn4lukM0GpsD1OhEchuheVtWByr76
rrv6vxHgXxxQzUeca3ytyK7QXedtFyI5XwcBwjJDFQpGC6pZpgTlKzn25bxz
BYZB/E6ok0sNlDfjvmfbvWGxENOossjdRMtGzeaCVVrV0eySg/wHNIo88D0y
EdFICRQyyBVUlzqkZpUCnId4ipcw3ssZmo/wETUZoMs2RNuR2a9spOlcSQdA
T1OWOgzotc8Xio7byPNhDHk7tzh2+51NgiOkBYk5E9jI6flLGT03iQ0H81EO
5hhbJhznKjmAGEQBZBBGYAMww6/rrrpKBQfy+Ko771TU3laJjp5VctxtDyE8
rsoAzdsR4OcBaqFqpWsHdgZqVdcZVXPI6CMNfgBo+WmHG6DFpoWWBMPLeNvW
GISgmR/Dlh4gfF+97yXCCgK5SimbEHX0m0KtAJPD2NUGuINQUb4QrO+F8U0D
4PZw+pEJiItN0t4BhIbzMgE7fME4rhF/MOuyWiieO0l3BDxvkld7DGHZRXQD
lothMD9tDYEOBXNoypUmOVhrj9gXQdVzQ4AjaY3MDSTe7DUarpwjM9dcQNuy
xaJ8ZL6bxfJ9J1sAA8QAXhTyzw28IAuEQaGgDkoFifh3v77pJpXH11shqQC5
mAg5wtudmsUnRJPA5L+U960TVj/f6BnDONfExzk5mk145PSM6HApTRjPkFxo
8XQJbB+IBUzwYwSWB8upQetyse+j95N6yT2RnetiB65pU0GLYARNEeELxsCa
awvolLgGzhzZa7QDWBX4FhUVb5KoGGgDcWIZQB4M+47GFgzLZzgpZyAW8/IS
jyYcR9mcY/j1r3/9FBu8hiD891onDYTzxoa6gzxrUa0OoMXoPKWtpf9i4anU
qMH583L/JqmcuDgIC92MJTI534zlQWTgQpSCtDWwAl7E4iBNnD0UAdC96Jpr
VCYDX1Ik1w3g69GMu1wqUy4qL7lUXvorecuF8tYLjIcVvSYwzs3Q28TDXonH
YbsT6ByM1crPXA3cuywebN0Si89h6xtGYirEyVVQ0asWbfhuE0Uq6MnRCsp8
8yEMCpPCqLhwIPTbGgQXHSyfgWvHY+7egVhn3SbEupu3l47DbEPsqrwoqca6
0ckLaJ2l4Ahw1hqDPU43qbS133ytde1IxZ7y0VoUZxLYM9UpRDFCMTSFJ2ok
i1qghEXUApcW2asIlaWX3VEognMEGhS8USxEYQVqACRefP31Hf4olmgGBJ5E
JCg4BYEWmUj1F7dZFPlKERG/pmCf/SooBOFVQK7odKXgjh0hixCHc149NRQ/
qyMXOJWfRVhRfkrxEPAs1/QHsn6AOK7j1no/MRRQgCf12gsUlui05E0UGdZr
YwiJvvR7sAGOBHn4Y9///veLanvVphpswFcjGIGc9f2D8G6uAbyJR+BQBWQn
6dqK2TvDeWo5z039mDI8zjTi8QlrCTTke7rbmiG5SxbTc6pgswBD06LfFPd1
9VpjTNvZx4IJW7KQ/tyqIcAhgKNwjWIeUm8s6LoZSm7idpWs3KL78MAQrdfZ
hpF7UgHFA5Utb7R1/jdhnYctIdxWTEa29AADeBRCpyDOAwuORxYDMbseUCyh
+wfxVrmEn5CVxUF5H72fTBTjgAQEDsIP0wRUUFKiQO0vf6xYoTkz3KIcn3Hn
H3ECAmDHHntsSWRX4EkajngvDwNTYJzHxHKPK0C0TBgt6xitSHNlI2m2AfTN
b37zNF0bhhH6N2t2EIQiTYdaIjZ0nAOhHtTNZSnlw00BXV/TY77Ng7lRkipb
2nqOp61b9IQpQScsyX4OkHkVElNoUCAmBkqhw1JNEN9ojhIUSUyL/99g8BRI
yoWs4Pl7e4zF/HKBMdFcFnMok5rMCyJEXZLagu6U6Ys58S/0xkkRnuJMIa8J
64n1PcRAibHVmXJpqsVxX57oFFAAEjhCH9dui8Jjcg/6eEyeI7Ig9yv0MSDU
hkoYEwhSdXbiiSeWpNKEfEmmkVwDoZ5MQ4RCuHyEZx/ikDIToEU5Epuylgf+
nBOaBGvf9KY3TXnqwZBZdUB+tHr/TY06Y68i9fwdlVlgtqY0vdJsxBrujpJ7
/JEzWb+JAaUdRraDjnTBdZYuuKsqUygVaF0FGh78HZWgrLDaUW1J7JUXrbSK
Bh6DSl1csoSTYVDKNEyqi9RAmSPxyPJteMTeSP1uBiCX9s+85JKlGtXt9P9b
IFOH5mTiSFgJAgQL3obls5/9bAeQyG8k4gSR8bCgsANu6IMkgORh72gBKOE+
QMmyTd6LdC6Dak877bSSIhyhTEpzeIgqBl4S94/65unY68WBabTZik3BfFaC
NgRNd+5xijyP8MY3vhGHqBjG5l/NULgeu8Llm6B9KJ5HpUga1Lwgr1KI+jI6
8SG8WlvP8YDcgTdt6WzJxmQ8HsKkvjHoduXHviLvbkOe/F/OCI/dX8WjI8/F
I4u1s6Eu2BF9xoZxsf6ZV7AH5OHSsLMfHSzH/UCgtgTQkY6VY67jbbPGlj/u
RIMgLj+xSlZP/s+/cT0Id/IagUZRgXJ5eo+jDggBJSAFtLys8eyzzxY+O/fc
c+VsUA0W97sxstaLDHzFbhGV8hnD4LOfBLuHGpv5wG+WzhwKvUMi9B65ZgeB
nm5EzhsSZn01gZ7nqzS6b9Bz12aUlHTnu3GhtvwUCzUykhgMlMgizQYdNg4L
rB6oCLtvjdtAGAHMXznC2vjN19sGhLkUJHCpexsOR3MJslaHldYkoMFrcz3/
sUAwerzAhFA4qyaXm6WQ/wMdHmdZBAJfYsia4EoQBvp4G8SEM4y+i0Wz1BVS
9r1u3TpBx4UXXihwoBScjWigjJKWuPmMrwDJMU/qCAsExx5RA9kgAGTRKEdY
RNkohO2yyy7TdDqKCKuG/TxCc0hNDajyztiKrpA78lD7/hFdLTKw5jRbBSwV
HfmCyyUn+nihwANS+515Gw+wpfOehtiMQkwkHUso4R0lsugNh0RQhBjLp3ob
cplANgjneNg9QZ3UXxjCDpXjdwJbyf0ya+Abd3IBMZgItgJGXGfWv28zzoB4
yhKFDSTDw94FxxAnsBGAiXcPNDwA7v0WKB9hnYTEgNlF4inNigS4RKTAxfJb
finWCNyAIYTG6yFAoIqX7FDL3Q+DWiC0TsIac85HEFqTzCODSdmUeB9J4tWQ
9vC1OB7eUKEJaW/NkBZDNNElbgoigrS5pB3iiKWKTCRhGZZPQjGUlt7iHHZ/
XTXdpVWfIYKsjctGgUxUJGFrEjCs4Kzmcmg9wxehyzOqm3x5FWlhgff439Z6
v7yxNwdw80XPvVLxAeSaCuEI5lgEoSpw5NETwx4R80MPFczxfoerV5z6JkTq
/9mvBd5+LSLgMvl5/J9/8zgLKRQI5nxDYhvmgn6rMJfxm1DbfDDn1Vzi8c7S
X1MBd2gNcGso+iAB45ot78YUm0W2Aa4Wtc59iSa9JoCjsMP1Gqqcq09wgxgg
fgQxFlkpI6vdYgsncb3LxM24RBxV5Nl8QYdj4Hu/+VqcVBgWGck+kwkQ1iHk
siUA7ViehLdBwPvut5+l+1bo2fdmGXEblDfLcG1vpZslNcriTLDcefUm2PMy
IcvglYBNfrQH+oAmqyNvY7Vk2zYUB70Bt9+IOgByUJ1DLtKc9+LIV9QAuWru
Zybcwpq6cizABT92sJYa4KrpoA+beSmdqc159TLmVI8fweYqrQ1smeOKc+DB
Pk+PHNbgHESwZexma+j9B0UTRm/ItIWgzd1QzW/IukSO2WQa6rEEWZvyii7B
veWWVybvuA8jud/73mLLVHperEppDRdvTnNocS+Ij7oeDJx++ukle/4Fdb6x
AxgRAYHFHHmaRha8iW/ktWwQJQClrD6iTlAmaBG8yQp4KdYqHM7iyuLrTQR4
P4QZy5GjjjPUDUA3IDr5VK+Cc65rgl0MP7uE++d//ue0rtZQJzTHrN3QC6CG
ujDvbiTqGsIlMcSsqLNqn281oY6VQJBA0zhCy4RKTL1VoeKehkjuMq/UoifF
pMXpYjXPNffc07/ijjuUBn3tHRecZ4edIaQ4TgkCj0PVLVc/+lGXJ3t4GUtZ
oicwmEl4UxB6nPyaA+TMhOq0+r4IrhJXj8XMt234hjoSZniTsSHFwPOcVJ8A
LNF9BajCYt48S7UiOeOlqTLNYcpLfQ81O01F88lHAtZNFKIQIx/Nmg33cgh8
BoeERmjK2YkGLKrx3N3aeO5hlhSCbEJrHF4RHQ5RgbO041Oofq2C6rONIInw
+bbofLNSbP45Nkw9E9LivkaYIv3UyZClkfYT5IcvFWyZC2spto7i1MJ4coJu
0cduM9zeo8G+ftpqd6ct3Tc4bmX5Jg3ipDoOdt0H9vherhsxL1xwyP7Ec84p
wekExtajqHICjHfwZCZ4R4eVXw6YtM+esnhTo7OiqoLXjg+UVK5K3Tu5rPgC
vncfrOANgz2INuLuF1QkC/iKLZJ3C7pBuffGcpkJ9GBaSymnTR68LrZpkc+R
M4zfvEnNY47bTV1S5rFq1ocajFsX+THhGwTlmrS+1+D78DUvZTihtfb0+vdd
Mvh6YLoNviSW2S2aAn8RvllS2eF7tCeVLQJDtozSMtZ3mPb6CrKTFoz2UrKb
KmSWPF9spiC90TzoW+0lt9v/b7HnrjNlAAEndTAgYTnVAmX5rEYwW8hwSI8K
Y9HogkAOXrZukD7uuEKxuoQfVPL8BPHEkpDPBJxddFJXjBOVQbnv9I+QBYjL
RRGl7nVYpgXCW9Sqtbjxb64t15pFN8c5Szj+jssAQIkMAOJVGGepci0+N741
lO077gLQi0paTCrY+Ty413vIoUgAtLy/1HVgE/0oTIqvhP2h+EjVMaEdXacx
cL6iFecNOnbWx6F+vYL4c6pw0Izv9P8n2xjtOZe8NbPGtj0EFB1zZ+cGeDfV
TKRmnd4giBbLZAIFPL4tFAnrhWZ3JwaeSEztDExY6Oq77irJVsuLqKJkTxIP
C647agbLq1fJw7haBJGcr1VrIIQHnC1nXIAuVy1B3fKFxC5H6Q2i9NSNUpq2
BOQu8Z14cvmPr25yhNX+Uqz6R9VN/sV9T0/FcXajdu//b+/M4yQrq7tfqeqe
FQZUYhRN6BeN8JLkDYq4sDYIMuygIyCRpBE1KoSIJjqJW0UlIGgM6yAwNCA4
CrKIMAKjNi6sohJeh2EvWUYwgCIgm2DlfM895/a5T91bVd1dM+YP5/Op6prq
6lv3+T2/33nOeZZzTjv7bPm8cHo2JJ9NLw7pobwNCvkfCFDoYE96iJEvIz9G
HrJCZveBzSJnBjnjPnrAXfEj0xhxvGrbJS/wXKD1i33/kPOfy/J5xg8x+Fke
xfXy5Z6yg32e8Nzte/Smi9xv6OzoUL7F07Z5ZrHc/AL/ffY98t9clEkbXxDA
FqOL3vEOdVHeafvn08N6WrXKlsPTGfaO2K1f+x4T6VtqQ2w8MRzb1xABdp6N
7o8mFvzJSUOvS+H/bbRm70YDcsszlpz3xKrL/4T44nK7hYf+6mq7pY9uyxRc
l5vcdWH2weJBDhnSxiuuvXZI8wI0skoX2UP6lOehLKHu5KPOWFfHIqgfU+cy
mu+lnmV+ofhLQydaTha8PyqR5CxEMAv2z8qLpNVeXEgWy09XSBweUm8+5uTy
ZC9wFvOP7V7JGCW+UG1jVQfTEW7OiTthv8+0McIwy8ulwp5QvSwqwvFHKQwD
/C0/+b8HBCgKecSlerz4ODTo/hXRRyqP9VN59Aw4gw/UYocoajg/k8ZCfX51
k7k0dooQYOoepiRhxkct0ZyuxycLT+n8mU5p9PDaS9Pv22lrKIfDwbQ/Xjzy
YP/SQ2b0sfBI4cFMCrqpTiy8EEf8cnlmJwgWXyy/8FAEIDx0KfCQ9+uTf6CK
kId8FC/ohZkqypQRlk7jTEkcHKA/Dv2FK1Z4JSOvDOAPGTvkflQ2mshL0Ggw
hz2E8yS/ASFG0y+KsfkIfr0XCR7qqKAeq6nJQysQ1TbT/3pqxljDwrXhqdA9
fUycj8EfZ/4OEnt4GvOJIgqGDYSBzfdsG05q3wTNdSA3P/l/KhIZThp67HBB
fjYr7kb1/dPuLsWwwIaNxrRkEUMDd5nErIxzFDzIYtfMZWodRM0yEvVaTtGY
sMCT5rK1z7eosA3AV8tYw6ia5UslsdwksSLkU8Q9xtpidf2o9io7cII0fiYW
XKjOpJZweVgpHwNTdp42YHNG7GH9BR+4x/Rxj0ugrvxv5O7RZDTwJ92nZXx8
YEnEZqc9GiAsZxxkVimWNGJtkPfJMqpVGOuaNXfdYvnFtASjlWH0n1YoVy5w
tjgpQ+3/FNib0h1Wrcpq04oboBVsG2R+GyLvrHzUC9BbJfCsBv3LNA2Al5n3
Ihox43qVjjyNaUwqhjHHE4PzENuneiz1dC3zmeZpvIy+mFFy9ytqCCHIdepM
zcs4yCV5C0mhE8YPkVQD4YiMfEji13wUr4s7QUIs1rjnZUNLp4ySwEO6pExE
qd9lC4QtMVAj+dbEgoo2Gz2Acqx0DbkXys6U25SQn4phoxebaXRHg68EJgsz
cdbS58p9zVnPjofziZ5hyZMe6PEtseBwGKvOuvKdDz9cR1Z12F7P/iuvhDFo
DRUwLriaVExDvIpRs65Th3Di1qpwIkwBfcemgKRNQoyvLl9ux11IWvPmltiM
1jkXX9wST7MlNmSCx5lf+9qEoDE+ft5546cvWzZ+qjwEpeYJ4+PN45YuHRP7
M3GIoH0AZ5QOOqi991ve0n7Tm97U3mmnnfKfb6ZGxM47t3fZZZf2woUL27vu
umubsrHk199rr73a1JGn/iYVCynzRoVkkhlRHRoFhcrlhYrlUUJpMehUQl5v
JlYoiJmAvSqHVyhAHpZ4oY5TJQpytwrXjBHIt5Cz+M5WD7w9uUxdq43N0isy
svC2qykv0LSujlemOf0Y8bqXJfNBKFFQbdJDa5RpaJ0ODZX5Zha354PQ1zL5
7JbJp3mggOt+me6RtL3lMam1hithOsr3oaWL6MtsET0uM/kiOjT0tAt6UF3G
+ZjSSQ+S2QlIBqOfxhM5Dz5YR0t1BggRDfRnuEBadwQtTeqIx7CNTB6M+IPI
PPuT9bu6Xz4NRboz9hMRUot/NS7GYfSoE04YPeoLX6iPyNMLsrXj0de+9rXt
17/+9e03vvGN7a222qq9zTbbtLenstvoaHvHHXdUafSSxb777pvLgsr2ZbKw
+tMqi1ApsqcsiPfLChvERKyeSso3CMdjFUiECSx+RrfKj7x7+TEruFcnJBJd
QHKGCt6G9OhEPlbXXVLr6F/wFr/yEQV/sUIT9XxYSSQhEuvlmsVRRWwEo0o2
olyQSWJ3fX7tBEv+TGEdHsKUWA8yDVM8ei/sjQt7StIjFpeF3A3fsiwkfkA4
T6MjpGNEgYBYdax7PFMJUYmiIS3hDKMB3lMuDSE2u5qE5g0YPzsbXeRVRv0F
nTOwqc9l2eDDDGxLXKg/UZBePw7T3/CGN+RM32677Xoyfffdd2/vueee7b33
3nuNMT0t4puWjGTJCj7hSxGzwz1ssh/A/JqW+cPrmZt7PW7xo902nnKS5MQT
a7qnWW25vF9T6tcnRTBHfxNZTRhOyJGH4hXUrq3XM/Aoi8UFhFHKt0V275EF
4xNM0GLs8x1TScZKPaaRRhvp6m6cmO129B0/Kcnfh2/iJ4ed3XrsPTk17MZ/
VSe7mWc3sz8np7S+J7yu4nRcIgvzTC2JHUbGly17icKzg/IZC55yGuemynp3
4/Tb3/72SqemF6d97qmqkJ4nBIQWkdd+1APbilWGu+aO6E/bqNrBZzx5jpPU
4Wh2gETZyv/q/KYOgTPGDyuXw4ETLHVNT0fVGnkMkHsxPUy2E7uHyZ6gqo+S
+sJI6teMEAQQABBGp6fjPGFJ6sGc4h5MifNfNavkzr97MGnmM0+x8+PpEVs5
PJSxGTdlg9zrv9N3qZrVjgsKZSwvRAE33tiSBoyKel+aWe+x17zmNWq9t956
6/a2227bwXJc+F4sX7RoUV8s7+W6R5ZH992td1qCPSY0gYN+jsScjFrmkM9V
h4P3+B2fMXY7V7G/GV8bvKzz3rCemRr2X6ugzETX1EY34PLQjG20DE4tbHQe
0xqd97S1BOisDrnvzo+J/uwoHQdDdJI09T7C3uluzviVnsyvJMeq5tlxDwQ6
C6PcC6mic6kXIra6AWcb6nQ0cgpjqutqyhd0nBz5aUpluQE2XNu2RKWy6PZl
itXrJtzlhsa42zvssEPfNCYKLaMx8zczpXF0Qtzl9iyXaQo1r8aOKYXSQtU6
/kJWln1WbmYjL4WTw/kJ1NnFU6lDJTSdjsmVNjTzTbIXZRzdKzO5ylHmW9Tc
WpmvmGKV/Qs+13KizbWUTeJX+RAduaCqzK35ER48duNobnIneaosHIKpGR/X
z08zlR0ESE3s9UVeNpeef/7LM15SHlZNrDsSzkufISnjZZwdcV4yOzJTXuIc
V9W4i3nfyw4/++l7OCfca0DCuhrPRudkhXFOXs3lzeH8vaFJc7mgq7lMpzBs
6bVFEwD24oyFe2ferLKQ5aT0lIkXEiiN0ZIpi56zfUxZWIxWaiVt0I/ebE8W
TjJRcLxNecgTExzrZ9SLJ+Dj8eKKYwJQUO66+aWLLvozBWfL5ute9zr1Z+MI
7/TDj+1FP5+cg37EZpF+xGZl9EvntkNRjdIadLE0TEwC7An5PB2JncOvDedz
YnOy5Rl5NY/3ZhVpNpVJAQubWnJ/k9mojWj76PPmoyRhYjhmMgDP8pNJqlKK
sZaauiRcyg+XdDF1qWepqUhLhuNuRNPJgUmyzYJPwixnVHpoPT0k7GcBuA3x
EFrLxbhJFDiSGf8JN2w+4MaIP432YVUaHcUpX1ss6WAV0VE/rIrRUWrYyphl
iW+yvR9Z1hknWbZBRJ51l8hQtglbGLVed271Gb1Muntfz7i1rz7/9cjYe987
wbKFZkyw87/q5lk+Zw/FWQv3LYDd3Lw83a2n069w8+Iw+sMwjFZxC88MwjAa
GsdEj0IlIdYtITFXgVTxdCaL2bbtX8//SmBy2fe+xyTqxkYsPLk4WsaQ20nl
E6ZVwUjVNJKTCnMVa9lXkSodLcty8juxkqxK9Tyr0mxYMpQdk1NiCYnmQafh
nnTqNiTKPTVZp1c6XZLR6a36/CqlUroZ2o+S+1hYmL6Pwa/tNLo42WlUGAuD
icqpFDJzVpipumaJHVJWsGBljJoFXSSGKmRzC8SJaQuus8Pjui3/hht07mZx
s1l7hU0DeEiLWYqDnftaKXv68bXKJiEje9wsVbGnqmpUSQo5Z5GlcHEeDWVJ
iPTUuPNo/XxvQlgQmt9v8DnBPielzjcy6izKqNNk0xpWiEXTNKuQzptMY3S7
Ik1R3IM67koF+tQtCQXGCG4IRyQqkueMU/MnE1lamvgfWq28a2yijyFMKNy8
4Ioraq+yER2y4Bm5qYlekRPFg8V0babKKypzylOipLPVVUQpyymf5hu0XFR0
NZlVLPmq5k/z4a2RD2XrlnGmcxGxyjuSex3xmjNGm7dltBl912GHtSJtYrZr
X2v3HSueOaCwOpLkAo4VQCtpY45R7oGHVKpGnTqcmK3cWTe3JZ6a2isJ+IDk
GSLFwukUg0QGtU21fZs1oUq0KXFESp3nqoWNKjdnqrFbF5pkWaIbkSk1zybt
A1RWkahgX+pF+zIMQ9S5HspPoUnQVjU6VTg86kz7wbNLM7rsr8+vaH6YxJPm
P8dkpTlVbB94P1QptTBpEnTp3tzKGF3M0ggWYi8aMKKO9dBXYlC81sSNJWn5
89Ql11zTpOj8X2iz/nKCkYcwy41JHHWiI5yOOmUTqKnPEh3hfnyWPoxJdoJy
qDD4aPrxzhFokiHqySwoO0Uwv59TBC25txE2EiotLstocYA+//nIBxYvnvAT
MPlunZQWJRbk/JCAuUCL4LNUVXpwarglgR46EGUUqelhv9o6lWWi8ryyWYbk
lvhMo3Jvf6VN+r8TxEjRaKRr/tMZW+Kq0XSdkEAHyy0/XBhfjBO17oNMQot5
eeSU7vGaMjOWZ8w4UJ//rEnyzbJzUbqMk7gjXy5xR9IaIGnpRw2MUmawYfta
LQ1znRNE62rwvI7+X6s7xmq8XoSGlNlZERpc1Oa5X//65tqSV07gcEAI4poY
06QjSGofYkzTLVCe4giSHewbSs1D3UrfRN/UTEStzD6otzFEpy8oOyg/r+d2
DLnNPK3wN7O+f4c+/yl93/p0kgyLYHiJzeblG5DKzrmXWITY91gFHzBQsRUz
yg6NDetpsnl5GVotcRjqhXMRIROSZ9JtC73fTbWHfQQok7v3bir3qcQcM7D+
qdpDF3ulwooIRPt3buZNlpyR7LWPk/sUNo8J+2uxn/9Wn1+GU9A6MhwMQ9/R
6o8nGafioTBf26Kf0zo/2tdetCrrb2modKIemdJXtTnKAi8C72X+5EotsR50
7utMvjiB0ZbHHS3Rjvcr3X53tFR0bFbkpFGSWX8oNeVlfTsZKaw7mZOsv3Qq
fnCbG6RB0thxAaLQs2P6/JKRxUcd1WQ6S9Msxp4NEUF6GFtrUYdSZLF3qXnK
1NYV2aEHPQsRjvjM0Q5E6taJmH7tyK9edtnoCePjb7RgF18t2uF+VBoH5ZnO
K1WoNKvHNVyI+QrefGVXDtOBs7Lx2PMWh8xfZUcVQoCn90YbaBvElfYX+vMQ
fX7RSFP6E6VWTQqcFesKmFK9triqdbJPpUHSOdnplNk6RNPRWqn+299uiRkf
F5M+duq559a21S/feIxOc+e6bODstjNhqqFXlw7LBs5GiSM1lHZaWZ9pevMh
+mduWYbp9TryAMbc/PSVpczSJtAkeCnNnrSu5kG9R5/Xp8/GPnXMMc3PnnTS
hOovZFyLqaG93/Ji2qJF6b86Q2qdXhRiysvWeZdfzmP8nEsuGVsi3ZMlCn7l
KA4vmkqNY9RTahyn4uROUU91K7uaFM3RyKde0jlauGaIjphXzEJfm5t3SVWi
n6zUpdxYbVZeAJKm0Dwzj7FnDtXnuVjH0U8fe2xT/NqmWMfmcaedNi7WcVz8
m/FTzzmHHfi1Onvx6yzA1Bpj8gus2OgXliyxw6evZOJzohvs6WpembMx1TWX
nrAPFaau8oizEV3K2mTZjCFwnp+XD6q9qAPxMiF4pULPYs2dcue0pMOQGfQ/
MNeSkRzEynZglyE2ABtixX6HeiHWUd1pkqhD4DI/r4RX++Mcn5g0tKw0Qqwa
5qVKuxoRC9CvzsKwEbG5Eyleqaj7xWsKs6JZ/dhGhKvWEy+t4ToENPOSymrD
HfUCM+PNZRfkiztpIR+vstZN2QbXtfr88ibDFGIsO/NS5RzOYAI5Y1aj7yp4
ipWKcQhc5mRCzIuEvri0thGvvUYvdEtT68V6MRVSjFBdp88bKrPcbk0Vqm7z
IQlUde5N4OgRBcdQqZFDNZwXZ2tkBMOYvaQDIVBhiyGbb/nJ2jKIgWZa7awP
Icb50xsyHY5h6dFg2QJomf76RaqHhc+K3jZi0dtMh/UiWvPyquCZR/TSQjFO
9rGxCZnTVhypYvM9WzM5nYWHijinIcBaBOpGiynFq295aDYdIzWFYbDDsMcQ
TVFqTNbJbuSsyTxGlSRW6GU5THwASICK85sc9PdswJxHYM82W69mIMQCZD/O
lKiQle0BSp21XsFPD8jqitlQWodWlahetdoste9DGcVg2+x8BZVms2WdYxsc
a12xYgVR/VVX1TbQQ0oc3RikAm3B6yZ9/uOcWFWLx9MglfmOwwViFchVz0Wo
GV3UXjUyjiHMjbRRNNIzt3heCiTGSS2A4awwXCJZxMDlZyjdbIGi8Kgpj1YZ
SnE5rI/zEIKA4FRrRC7Je27T6/kAOFedhVfk56j9fATbe7y8FW1lGy27wjkD
wRkfdBV1RjKOgerMsFlp2MiI1wSXbsuEVVs8E411YAOP6iCkAM3WQW9OLjUQ
ofWeDsRqh2e7UP40317PrzkcEhSWlySHSByF5fDUABRW2MVyqz6/QMkjAE1U
RYtlBigBSEBgj0wjl1kO07BpjZ6jJ5kiMcXU9JBLbeO8sgls8R2rsfqAK4vM
E64sz8s4QGVFbO7U53UUG8GlKR9ple0NTlYH6oAjDQ/wSCt53ly7xDIb5NAB
F3fE3dGddK3n8vByMp4S0mvAdtOWpwUEHX4OUFsRnZ/p87yR0dFREJpgY4dv
6sAHT0xQnWvUeSWhphttR86HMzoF5jpR6ESaym17uZNESLVeSuJAeTclEc7N
SEm2vfBefd5ubNNNN21zONmPa/r+Op/IxvFmMMNDAh83zzDJzbKbY7oBwtI9
dFcQjp9cmJJwOEzsuYzWhHAMivv0eaPWFlts0Y4HRuJyPVPA0MStMgyDFrDN
DY17zt0U4jC4Qmh2XhWp9vJKheAQR4VAF6AahEKKMIxvvvnmbTaHx228cVXS
wzAUg1pg2FTV4YaiXB2zu6mjlpVH20DZMUB1xH3dGRQbri1x1O2YsFclytKL
Z3Yi1hyp0gY2g8P4A3XXDIr7pyAOws3piMMrELg4PPF1L3GQiyYVBwkJBimO
Agwbri1xOCPo9X5GDiyj5wiFFQPWRuGM1/0DEAes6CYOzyGci2PjXByxrnwU
h2ehjOIADhcHZ5oHNXAYEqvXkja8JrQnCZiqNoCBn4PWRhGGntpgVmo62uAW
0YafYAcGdyXKxMHnUnF4Jqw1Jo4LIxYzc6v6FYe7mOAxVXVgKteUOgyKn69F
dTgM7k/Q7ElavLyQ3cnVgRrwKteUOoow/F7UYY52wa2qUIeV99lAs/ngdaIO
IJuBOkZhO62/IEKRjRxbbrmlsmK64oAVPcShp6Rl5KC1/WrDq4F4NuGoDdBL
tRFJ0Y82DIkH9HnbtaoNr5tk2ijUcl+L2qh14pC5VTBiTYpDaFC3rDyd2ug+
cjBqeDnRAWqjFnOuGRSj/YoDMzMdcRjrozjiVE2VOJgzd3F42V+mjREH1xiE
OAyJB9eyODz/RwhEcxiApUocnlaZXGdkz+lXHLCiqzgKOGxUEEc8wDYIcdBO
Z73noWIU6aUO2lulDn4/MHWcH7HYbtT9qjWsjjxj11TlgbFcU/IwKH5h8iBN
T5U82IhRJQ9g7kceXkT3f508Cjhs+vuUR06JKnlczu440Yb4VawhDVAdscpA
hsSGI2tDHDo5IVCEocNC0RyIbtrwij6D1oYh8d9rQRue1N9NhBeX6FcbXsti
kNr4u4MPrnXisOFYv9rA056ONnCrNR9RxogwgZkzgtepNPCqvX4TrEAbwDNT
bfz9oYeOckqZxluVpYf0+aWVuvB9WAPQRc1hwFr2KwyvjhqFQZbg6QrjEIHj
yP/4j3HO93fAsOaEwW1GYXim1n6FgRAQBjB4oTmYwnWAbSrCOEyYcQy26dRT
ORRW68Rho7UlDL1/9yMsBs0K1YpPNR1lEMz0o4wjBJfPy/ezfZuUDkcffzzK
KBQYfTjjxBqRBvcXpOHZT0uD0G7SwEi6NIjPpyKND8t755LG6dJLdQs7KZ4+
d/LJSKMEh40K2iAIXVvayPxsOPHygWvjYzJgUQCBA29s2WcbP4emTBslMPwv
kMbsSmlQt6Ou1ag36EsanxToTxEYOfDDCSFOl3DihIoYiTRicfFH1uCg4cqw
lR5pDlmBN56WMrwgbTdlLBXoLqfEHIeQr79ezzxxwIbjcSXK6IRho4lXv/rV
OnVZJQycMISBhz0dYdA8NxBeUXQyAC0XBmUqvMRFFAZbIqMwjpbrX0oJDDuL
PTF5OLOnMAowTN+Z8tXgvp0pCNHoOmRAlkQXSgZIwaqP6+KLp53WXi6d7Wky
PUMBicQ4zdiHLjJT+eUMil+uYWGwGc/WNk0YC9RURmF4wjffZVMhjLoaixe2
/+uOO9r3/PrXmn+K1B6a+WXlSj2xy9HeqeiigMLa04UnqZ2qLqgl9sgjj1DY
UKu5Uc6K7IFkO/GKatPRRRGGsc0222yN6wISAIP7EDYn0zFguDAuknH/llWr
2k9qqToqO75IC9tRvYu0ySSSmrEozs1w+JU+v6odazx47qABi0LbDw4uCvet
oyhOW7q0fYO06ddZTewhaz7lsX/5u99lYli9eiZiKGv+jNUADaaphvZxAs2F
wtYfS5fe/ctftlcL02mrdPmwNv+FKoDVAxJAoeVrVgB0LGSPAlgqOr+MEoI/
+YkIYOX999dmac5GEihTgo5ydU9kxdCH1hT3z8kgeLQP7jNX79zHd54q90+S
Jp8r9/AtIeVNWPNHH9UixaSr9GyCt1h5MkqTUZ1vTXO/2PxK7vuxy6lwn7Dl
Y+K8nSC9vVyISNHa261e530UUJM23C3deDu1Mq35wEBNz7XA/ULLNxxbKJ27
s7TQuY830A/338MhB2ntx0TdX5AOPk38NvIKQj5u5Wq5NdRM3bm7SXl/rxaK
A4Q7pJ/JK5lS/74u1H/mGaUMxYNmTP0vZQj82qj/NunL/YTOi4TW+3AoRn4u
kpbux350KC59eyiKFjV/imUEMdsk6iQ3Cbmuv2xZhslowAF3cpCQSuSHwk/q
cd/50EPte4XWNK9f6j9bQn359UCoX2z+xD6c/5FmanlbUXBeao1klKT7EANG
ihbPVRrT8pCaBZjhGt/J2f7Lr75a+XgdJbKhvnC2QH2huFKfXKK9qf/YAKlf
aPlGYzsL9el4irdrBVMx3XmlLE4jS0CqJRotA7AnpuFYPakQvmRzE5Ctivot
Efp90mpar9wXMvTi/vNF7v9ikNw/O4PgscD9A8WGHSQmXKtVsvZvlZHIMtqU
sflIq0cQc7Z0cF989pT7K6lFD/et+c7924z7K9cO94+N3C82f7wX94kbSG5C
Wiq4f0IZ9yVk6cb9ewL3W/1x35tPKfMB8b+k+Rt2CODdJoB/DAIgMxc1Sl0A
J/crgLvuat+KAKjgc59W14X/GMNb++f/k4Pm/1kZAo8b/xcJ/9/ei/+sBEyX
/3h00vH3P/64/sR9o8Nv6Y//z8L/558fHP+LzS/l/2FWZvPDU+T/1xP+3yxk
vQP+y73TfHpY+c/ob/y/ZS3zv9D84gDwd2X8F+fV+f+56fNfm36/WcAggNWr
owAEorUhgDMzCJ7oUwCfHIAA7gsCuHvqAnhkkAIoNr+7AMik1EUAZ5oAvjJF
AdyRCkA+00sATzwxGAEUmr9mBfATBCDk/pk0DfIDQZkAbu1PAHcOSgDjGQS/
KRHAIS4AquPMVADSTfTw3Ta4FQRgkR+/hwkw4p7uAvjZoARQbH4mAAlk15gA
pGn3BgHk8V//Avi1C0DMxowFUGh+5gG9bU0LgNqc92cV0z38+z3y/4wMgSed
/xLlrg3+04P8zGc+rJTE2uZ/sfkF/h/cL/+/9KWp8V9kT/PRQIH/VHMJ/P95
J/+f78H/702V/4XmbzK248KFGf8PPrj9d+95j/L//TPk/7cD/2/L+K9Npw3M
3/n8xy1WcAQB3NUpgJpj8BsUIMwYmAKWZhg81YcCFgcFHDNFBdzoChDG3x8U
UAgCeyvgmUEroNj8cgVQVnwQCrjnnvadZQrIZkHyekYooNVdAfcPSgGF5k8q
4MA+FXDcNBTAFMBqU8C9ZQqQ12tVAadnGDydUaD11mkqYKkr4JJLKhVwiyvA
2l+pAKEE1qFKAc89pwpYOQMFfNQVUGz++N5kQSpRgFcEozR4QQECZ1TAOaaA
r6UKWLUqV8B9QQHuBf++FFBo/obdFUCWuCoFfPnLU1FAnfaLDxSmQcQHuiXz
gUoE8NwkAvD/wZT/Au60+X9ahsAz/fCfGk0z5H/L+E/n8tP5704ARFib/C82
v2/+Hz0N/v9/+C9NQ/Y0X52AyShQTWCB/08+mfL/uUHzv9D8jcr5z1ZM4T/1
T/91JvyXruKeaTJNB4J7zQvuEABLBWtJAKdmEDxbIYD3sjEZAbAzc0ACWB0F
IAOizwPe0p8AHp6OAMQzUwGcdVZRAMXmrzEBXD8FAWAPgKVCAI8OUgCF5tsA
wEJQvwI4/fS83OoUBFCn/bX5eRR4m9U+vcU9oE7+5x7QE4MWwBczCH47UwHI
tXsKQNqHaXP9p2FgKoBfmACemWTA0y4A+bOBCKDY/FwAf+MC4PhvvwKQ6/cS
AMuAhEAPuACkmXdm8yBTFcCtgxBAofklAjjssFIB/HuVAOQ7qgRwk3QVuz/u
LRGAucC/FwGckkHwnAngLW9/+6QA3v/+rgIAyhOnKYAHpHf5OVMBiF85LQEc
eWRZ88f3ZncLAnjnO9sHv/e97ff0IYAlXQTwzTIBSNfSfPUBkiiwXwHIJQYi
gELzNxod3WknXQdAAH8bBUDm+yoBUK+2RAAXRQEIO3MBSJNpOhDAcma8KJBd
p/HBBbq/3AVSATz1lI6bAxHAkgyC57sI4B+iAI4+uv2ZCgGcZQIA7jIBrJIe
Zhnk52UCMBO4tgVQaP4mXQXwzxzKiAI45ZRqAVxxRacApLsge6UAKJ1eLgAW
APL9v78dtAoKGGzYWwVUgZ6GCq4pqqAOCDIMpJGghkHlIjAINtD1kKiEm2em
BEXh5AyF37kQqKuyJoVADwsDHjQh4Az7fGCHEJ55plQIgkxrUEIoNH+T8T0R
wkEHlQuBwiAihE8NQAg0HzEQDfquqFwIYheiEJ6sEMJ9gxJCAYNMCB4R/+27
391+V5kQjjkmE8LJJ09dCML4+/oUgjCkUwh/nAvhgWkK4fRJIeD8N3fabbcM
ihMzKNqJGt6RqOGIVA2caShRw7lVarjjjqIapB38dDXcahXXdXXQNtF1qOHF
aiIfmrkadM1zr0WLWsL+5m577aWtPz4isUlzL9Iv9BIGpxnYLTlFYfzUhMEc
AUioj4AwQpjYWxgvUWH8agDCoHfp+X157L9/S+Kj5m777KNQ/GeA5Y8ylvQn
Fk57TF8signYoIhuanl4Ui1uLxDL4wMQi5Bf3DWJlGrDum+CqFn8ptY+++8/
useiRRkm/9GJT08VUS/4MxyViyo655yeKvoRKpL2o6IHEhXd2a+KXjBjFUlE
IIGauE+CCxLZTx5QYtGBB04IfTIsPt+ByyZj+xB3r0FNsfjOGBs1dXeJpn5W
qakX6Ap8QVOt1pQ09b4jjhDvXnpfwGGrFWuNAlBLaIRNyQA5NoBT15cv7Smq
ZoWoznBRSe9UiYp9WWxKrQONDEGAVJiUNFHd3SmqHJjng6rumIKq2DhJOP03
Bx9cm03XCzC0E4EAkPBo4q2iMQXjmA5gTE2+aS1R00cGoCaWK2ELYYiqidma
MjUJmzrUtGBaapLbrdMeARcbcVD2EFHxPFvfo7XoxKBqCYdGFu6zTwbN0R0w
bTK2J0f1TFxjJq5D14C4fiH9j8CiuIARR9bF9UCpuNadkriYW/ig1gAFlIbq
gtkqech7Y3//9w2aqa9EcPyGTyhsBx/cEmaNcroFbI4KaDX6HMKmrTZpkalN
UQKtNP5dZQtAudok0EVtv/UhbIO+xYbA0APxGxu62NaOZWVvG1ph9Dnk0EPr
bHat09DaHN33yqQvv2f2k7+DgQLH6CKrW/zvnZBN7LsGdPh90yFbhxnFXIca
KpTp0I4MloxqT3bRIbrjlmBJDlEGjcJB6PtuLVsjqpnFgoioEAGxNgA9wBFR
yQVGD3jHOzJgjuwAqQ8V2iGbvlRI8t9UhcIZ5lUASd0jppZscrU/FdoQJ++n
KqRDGI7HjEA0WtEREGgH0+SsFWV+0fuoVPN+KtW8/0Mfqs1Tn5p1dJT0Ph5H
HKGf5i/BWagGdIrWZwJyQ65Im5HuUCTVpYIij52OIgURJuRRI8ix9bJUkWze
LVNk5/CHaWeeMAcLKmU0ysDKgFIYaMqhWlHzMIoe/cM//7PYQqRzeHjwfw7j
sB2PXuCPuAAXlIuPHiAuhQL26U7wyrUZT7Wl2hwfr9YmKfrRptiYqM0HU23a
fBbg8bNSmxsoA9kXMX7eeZn+nF0GGMxKwFIMaILiJDyAC6xQfIACWiKnBlu2
xJyhLI6w8bvDDUP+XjqgBRTlkHVRKsU4S5R6vCmVnVBVSr0qVarwrKDUbBK4
qFTMnvw+KrVukcxDQrQjjz1WTbTbrKjIDswiXhlWurHtCB1HP0gRuw9RJ/Gf
qGknr8TKsemDuS5gBGLgk8tNHPK+92V4fSpgN+y+aqLV9w1Iq//lWn38cblf
Qa62kWIIRn1otf2QUPAioXIUJbbdBVnFL+49YKWgfEjL6v4T1UqFDrNYFxG2
MTkMO9grh6/Ap/lruWLT2fZvHYhtqQI9YA0KlE3nsIyTw3GerUyg/H+ZXO+D
0tqcVVUoyT0eniD0wQyhWkahWYoFmPBg9Yj2fIRa3hLrzmJXteBG2Mv7HLPi
c2AH5aQXRuktUGp24ja2cM89J1XKoVVUaodWZ6zS++7TrRowDNxQajo5h2e6
QrBm7hPvAbwOCXipAsuwKjIpxwgW1UGCSveCCfsNQaiuz8OqHoaVj/rjyCPl
d9LKur6cq2/ygX+RD/LHHzFA+TK5gREBM0Pwkx1ovmHkDaOjuXYPCtrNj0CV
aPck167Y7j61q0iCqE9OcDwKNqO5iOK7A4rKONPk4c42QzCgpw0GOXbrF9AC
Iwly6qxeDrGPVyDmNDfS+oQm1+d5rr7HLl8CIo58chEuyMXly8blRioRbG61
3Xbt3ffdty8tfzZo+RTXMluI+9Qyr88UiwnH+S6sLRp4Z8K/HLnAPeddATW4
5ojJNQHg4wYQE7sSpTfo/iGWfQQ8pvGa2UOYyfMcjeT5vAJo4HFt+b5R7gmU
PtEx2m6pzAO7bXfYYWZ6vvjiUj2DIb+DFfQNDOc7CGwYPRkNGDk59O6YHRYw
O8Iwc6blLJP2wS7uK8dKMGhqMp8MJ+6XxUJ5yP+k53kmw1v2yN5r6K/n6WIK
f8CD1TUA5oJcnC+SL27RgeVAvn7ijdtuq0Dy2GnhwkzKnGZEyvE0Yw8pM1el
m7oFVD5HBMffsiLIyijTMwCYE88li7tmgwQdB/FTAJ1wLlHIxpaCAJ623YFD
LABV524FLnZekYXgaM03dzQpfI8mGz7/H9Lf8AmWY46k4I78aV1hn61X46p8
A9/GN8udjOWa/nhHzNbIuSkP+XKeX9fe7k1vavsSADx9v3GUpulFBS70QzPx
XuETHGNr0b77799+K1k1yLQhf698NDiVj1hA52PQ8GFu+SIXI5SBh+g1h3ES
Qu3uHL4TTtBN3Nghli+PPemkBlxoMKtR55WgyUEnfsmHFGT5a9E51+F6XBdQ
+R66jrZzTxVYRnrKxXl+TXur7bdvby0YbyPa33bHHRXb7Xfaqb3jLru0d9p1
1/ab99ijvetee6ldZT0yYshotb9jKFSHjgcFO8gIktPR9Wwjh9u/FD8GAKdh
TsGAHbYH3PDFgAf5fG7JkjoGqc7s92zMur6SOA4rxfI4nzomA1GvoBSVK4Ig
38I3yh2MEf0pZB8L8NVLqJjB9+r21gLfNvJ+hG50553bO7z5zd3hO/BAneZS
NQf4ULMOwBZIdKPfh23YQMU59ai5Y+rNaRdhm4RMwQGmOoiJuNhMiCWSBwXk
li4dwsLXeVXXN9fRj3zhi1/McQ3kVEz5OnpM5N1aLLdXAeU4rCuqeouchduV
QPkmMaZv3n339kKg3GefaiiDYUyVnBtFYyGeMmcKsBqMJrkxdBiNgQpjZJ8x
L0ConoTDJ3BR2vWMM6RleBdMtZ105pnynpj4IcKt2gvU2rNxk1/yIU4ycaCN
C3AhLqrEdYDli7kJbkjAHfuHxYszRD8a0P2jSpu5laLL+J4ii85Bd2fQFX9+
tz7QdTup43aicXzsSFLXN8OnDzO5to2giqxr2siJT5+gqvNxgAVwRK3seyQJ
Dj4IW0DFj6vjyjZYPBWQ8Wrx7fgdn+GzJxvwDngONhZCwHagRUTjYhEqQR59
wzbb5CDX9fn1BUuQAow14Iivg7zHW95SNKZdQHZD6o7R4Tam50bUnaHECiDF
aAEcYBKo5LStABewAA4QgbOOd1LHLZnFhKi+qi3Qkwe4LSxXgzV/Brm5FP3G
V3zeiEwfczv0fzmsbyy4UDwc0u27QLqLGNnd9t67E1LGp34gdTcJi2AukloE
xqSEs1gDRo7UEjicOVdTKDMYwaqWYdfQeWXiDnnIe+L4zWYVXl8JsvyGT+AI
KsKgKx2i7KXivDAX++PISmePfUBaAI7/GpCt7RANgj62dlDdECSAYmrjyIWz
tU8y6BdA9QHfRyz3PTGzYbTKDUEJRzECPkJFA+CA5tw0wQMHsACPA4nvzDQW
exkISDgQQVB31oUXiv95tjyvrxM2vMfv8a/5vEPN9egovsMJDMTck3T6OI5d
J7zRFKhDEKFNuQq08DWOZPvst59u8XCfFIegwNcUWmysQZv7UOYE4D+VcTWX
frCrBZ663DOOKqwOqcNpUGp4wmwDhy2I6875+tdrs9idUdeX6+mb/JIP8gf0
AxfhYo4zfcjo5zRGTMQJnQBv38y5C7gyiHWAS+JA4+wuYl8BVwcyMwgKrgxk
+yXOajQG3cB1D6tgCNyuRs6KEdABy+xpGbCRq+MGKrvWARTc2OTCJARHuZd9
4xtiGJZdeqkYi69ceqkG1/KQ93h+kb63zB+UVZMHf8s1cvwNe75T+Q3u0umQ
gHuWNoywaKRY/0vEfdvcGG9jjkPEvEBmwRxb4UYYe+HOAzEr+yxyD7fEAGMr
CpibO4bxRXMddiIhs9oIG7/U4Ab7cHogspP47IC14mzYfnX5ckH6vG9+c5hZ
NHHyz7v8cj1KYI+6fmKBfpa/cbzPMay5Pt+DeMAZDsAJEd+Y5302iLP9jdup
ad7aHni+lRALvLsKvNDagwnsRuo65EFE8M3KIF5cBXGwF/hEmOFSSgOvUPq0
bvAKNNASuECQmUnmhi648so6E2wN8lQ2eCVQX7BihW5kskedTwrU51sPMCfH
dRxy6M13OdyMsdgzofS451gsQp2baTfPHTCb5Ygw7xEtSMnIR6yWwvyPVTDb
iFcwy4nl8JEuZzEQm9VwU9wBMUnaDWLgZeqSoz9sFPnGVVc1WNAX+8xsJvtb
SA7Ir5ihu/g736nzWXGWmTJmrxSpQy+0vuBqdEAE/5wAPPrC2UOD4obUSlAf
20psCIMi9sNDuZ0C4m43djefeM8y++E2WxBncuGQENIdliDutuPjZYibrcYh
dbuhfm8kdRj8dOBz+xzsxVci2oIXULJrYvn3v6/nza645pp6+8prr61tqLut
2IrGXCg7HZiVv/R739OPV/RI3hVIgq84z7qAjmbNBPg57srtcvs0qRP5pk/p
uknR+YiIeuA45kS9PFyR4DoXRkpzQxR1iUKiy5yPkhWo46RGa+2mBNnmlto5
bmZER0QQd44LBLDR+Q18QCpA60IHWzG++5Of1NmpJO4ee7t4iz1vK66/PuuJ
rBdkAJV+qNMR4hHGrqAbtAuAXxRwvsCfQ2/MZ0SBLdKekaPM1CwuQK/zG9sb
4dXzMyteBbtHLe6kuIlxS+4OCvMXh9u2njy6Tqx4V9jx9qJpcettHl5O9MRy
w0IgAZ7LhL1CcIUcjDlZeP0tt7COVOdkhUB/w623tq9dubL9g7DFjm1jV153
nUAvcqi9MBdEFMWl1hPaC9LDF5oA6AF0x62hSW5dmjP66VL0JxhLIb0bdx8/
1cyUIB/HUTc1GHem1Zk9yo27zW18yGaNCGfcLdTxswp597MF+VMS5AsGvYTs
kBDksRGYF8g+IXACLTCT1YIdDatWr66zKFWbr7kOWfBjyYrMN3xUN3/Kn62g
FxDDddchCOuNBUXzJL2AFlwHsQcgCDqVMWqMaewO9P9mApMTpz/VOUyRN9QJ
Kvc159yH1mhu3Mi798IeBo3OCSQj8uK5VCHvwynId5gZc7xTw54jLyQEihx5
sSfwnQNEnKXUXOqWVJCdX6tDShWSDbC/l166OuSHwx4hBu+KK7OuKIwSPkIg
hAu9C+TeYAiMEf02jzzuuFoJ/i0G2h2d+Y69D642swf22BvcmpT5HTbHTH10
aTyIJxgqeI1V2CcmvsPWmAOeujBgDyXBByNytVBZc1kJxdnzCuakI3nMjuCw
CexXzz+v26HoF1Zp2WN2g2cokj5ACt+hH+R62heMD6EvvB/43rwP5H7gBDYR
tUpbxsVtK8F/W3Ut49T/bj2wjzYf7ruD41Yntffu3JAPmEBUg6LgSrqt74V9
wX00a1OGPXiAE6vg4OhniMH4sWxvj+1efJkeDqYP2GMA/hwrIu3C9SFDFAMC
fTCR9oObJunriD9mCC1yj/BFrOb4f55+egn226jdcd67tY+uTYp7gfcemLqL
4zYnsfaMsz4BQDCqkZK58D7GltmbiHuZlUfntBXc0T8Y4LeAFYOp5i8Se4ON
YQvf856YfsM8Nyubi/JDyVh/25HMfkiFHvo7/AL9dwz6FTYifFO6Gti5BSw/
t8atyq2PHy9N60B8a3Us48qMh/97l6Ht81vO9BA8qWeDlRGmRyvziejVWOiv
camjjSNZhbaPqWbZvxotewnaqB9IgEsrJgiM7EF66Nln2TApjg1wvzRPgoSl
X+UWRj7PfiTgZre8Q47F+W5idbA2Crd8J9/tFoZ7lBFp/Pjx8RJ2b61WPc51
5xalDGebE3CL3jGaih9TsCjBmucjaYj/j3eHHZzFf+lgdTqCZnF+5jUGnBnd
UDhqh4rsTtICBWIpOFr2qO2ydKxj1lX2fZHE7EfyeSwKeLODPMc84M61J4LT
w3fy3WpRxLrBBRn5x08sxXor9R3jelhuQUr47Gvgbr3fFbx1HzkLFqTEcvuo
qRMAHhiZn9gNZ51PEe7gqaQ4Y7mRNpwGE8zBTZYEBzzFZMy104pYj5+b9WDr
HVld2HYOzPxZDjVePRaFAyFmUXKY5asuNwsCpZGa3O74SdKUEoQZIxeWLI2/
pYTFvktDmSw2Wpnss1qByWoxhMms3RYsRjouWtiZe+HRNlehm02nFNDFYuA/
oG73yL3YAvvrHu9EmI2fpOLEaEBkRVmMRwfSwZDkKMtX8ZV+VIljOHK7TQxg
p71oMRLuGqZkfZ2BaZVFjq5x1yNO5a9lHSrlrwX4yt9oJ5jAivbYvI48xjFv
j+GEaetSdEWbl6Xoinaxm0AAJNhlbAAIw+FfJ/bC05NwioA9tZw2oUcgNId0
fijD4g0C+Q0lkP/ASI3t4DtX+DFCuSezz80Tym3zBHWLOtbObZ/R2xxnm6P1
+PJg9zaMyUc4k0vGPvU0zE74RGFuj33cs1jyS6lnV4aziDTFGRHDZDw9PA48
bceanaOcS3k2YM3pOtLB8juw5iAQn/+JUJsTPtC7DPNrBfMC3snJRO5TsB6t
wHocXuNrpJwGZ7XHvqkGTtuSA9vj3M8o43Qc+1iGjD5GbjFSe2yRY8GTK8GZ
cf5yaVvEGTnjG4ABHMRdAzt2z3OAg1OeTwrKsxTreZOe9TPP6CFIjrko3uKj
cLRcMb/77nr7R3fdJfF8hN0hv9oPPcrXQm899Ci3xnAoTRj9gtCq06cmHUG+
CFzYPRdsc5wSjyPgYW6fxYfO7XNkdRj9YHW0Hqe59UhGvsLMSAnSsIihCLv8
HWM0TabpsA44BCR1km+zmgigioHOE/3N1TNFHPng6Ad224/kAjpV7/7rnntq
daCvre/g62V/lCJvTiFEp9MxKtwmzqc0Z4SCZZ1RpGaD30NQV1sS+B3tdZyc
xZa8x5LlecSIHx1tdoHfNiLm/kbw68aDHclHwwRxJok67LTxmgiP5sJtEIff
DHNEglQZA8aYUuWpLJqxkzXrKPRPm99HoUFOktxt5VqAn2vQBXBfuiHrhXUL
vYCcMDfXmamh8zHrkIJbFlepxbpq56rnNsU1H1uBiPv0fGJWA/VoVjxYDC51
N6J7cB5Nik5GmenWIdJdaCAnTDH3GYK7GVFyG9wwDcaRkhnIMcOYFcKUmNX2
MYNYzEpdx8/5ekbnSTsDTM94Yqzb7WyP14gT5KWnBHsxM4J+tD45+a+3aMjr
InCrBvsErOpAfesWJsYnYuPmXDUtCdGjefFBUwPG4FxHQ95BdAZMc0zctCwz
05Kv6TjiFhh+29w8N9rXONLCMHQO22AdiAMLcOWp1J96SmF9snBsPzPqT5nD
8gsh+n0Q3XKSezaqlUzsCu619SLnC6hj7DE38QAyWmTMkWY02W3UCflW48SR
HWvIyf78uLU8z0UcbMvHbews81Gc5F+MJHe7gh8odsUXdIhd4qwHAxRQM3PK
JLbDC8OAmHZjT8ABS066por0ET5L8qwNoRxKW20H13Bb9NAfaENyS4OsRJfH
zVj6MMRiW5Tg0uPYFYVabhVyyzg6ukRchQ6k/0pPSpWt1nfsVbWTI/HEu5oT
j2vEnBA1Rq9bPZRA7KUpsc2UYL112Uwsd5xbIm5xD4ToEHMhIaCQlLJoc/LS
EBzxviMiLJ6fIDzH4punzHQ88PTT2QE3TAc8DugqnzHghvDN2Tiq6CqRzWpf
Ix3uyMqtttAjQMZtQdmGwb/OYE3WiaMrckjYPOVHSCvtRQgVj4+uSEpebIUd
dNHFGVuJdEivsUCFGI9Y73bLKc6xUw6wYVbveuQRMaPybm1Y/8+ACKyPZLDW
PG58zub2/lus9v2WGgTWQnaw1UOEYGvsBVtlrhkKWOsGAnvFSAiucr8T0KIc
179o7e24JnumfIf6u5I1+CPsEH3BoU6NQuJMu7NRRlUMAsFgvuwimMIPxO51
PO2wveD40LPPCmIMWxzXXW25XflJplIw/Y0FivMU1z/R/z8s769mqcDywGN3
bxNcb3Ncg1VQXI2vbglyTIWrDHGC6ajIsHMPWwbqlmNEiNiA/W2XX69NUXhx
RCkFdwL9izvh+vdI8JSgf3clcitrRGX+Au0zmKF7XARmOZn2YV75ESHZ4zYo
PWMuwpNGwF9ZtIf5/JWttzynnkNb83/x2V8yySEdcA/5R4TUStQIajS1gagY
gAgo4hdXrXWp3C/IxZ3C2RmCTRXH/So2ovpJMt/v79Hev1r84bMX0ROOoxVL
/GfYrAVzQsusroraUCemOAXfFbF7gU1sI4R8VEaeZ3zUmZU7s7+x0ec3GbTr
JKi52WT4vxMqpsiZzFea/5ui5iZT7mqCMbUctU30rDOmshCx2YETn1XzLeag
5lGbr3pgJlnxyMf4VM4eFyfjO+vXOK/ECTDPk84R6zKSMK+QDSVDavKescfz
k1DpdAPRmBDsXsvcfpeRLMKVk8xUyyijI4xDJeM2sYBANXqaiKYcqleNLhSx
vi2BqrDfK+xyZqDWY2c2ohBqueWrGqRVpOYKued5kRVuxp/AhcuTREm78CKF
PZkBayixQCqLmdqaivAJM2quwRZFvoDIGIWBU5iMUa5Dh+hHlpcFYyuDxMSl
3/9+53mo7DjZn08wQXtA2KocPXPfqOLbJRbbkbzcVSwzYGGkJfx04Sk25rzg
IhL/XGXCo64VC8Es0TybG6MMHPtnFn+W+n/uad/P4ecMoDoISSyTqq6Aj6vN
qt0w/S3dM3qRMLsCnrHdJIw8wNLYxtk+d0QO9+1TJfBg3/PAJdqlMGCeWzVg
il1SeKzkC04Hs0m/zaFo6KrKb81+zzN5PW82HYlhjQhGGBjh0N0utRQj0oYL
Rj81jNTZEGUz3SRxXwsag0Y8jZgdln3lhCebK8yE+tYyP59ljhpRRj72uc32
CKMP66P7ltjD4dgYdXDKOAv/tMtqSGF52obAZ929nafo/MZsNQTCbcAIJQjV
gUhYeEcKkJlsAMIGITAZhMeWXXZZ59lXQ0gTPnn6WwxPujIdd2Q4QkcGhNw+
L7H88KWeAQjZ/qKIkK44W6LgwkrGHDU67hQ8ZqPaU0ao33lSnvnKsWeMUxE1
eKXSm0SulmlwfsavqD8m2wQ6nC5sk2rv5psn2LTUcQp72IiVL8WVQKYnpux4
T4TsswGyE1PIotcf7LRDpptTfGOQkB+Pn80P2CTBKZstn6vwPGF+1MPmR+FP
/cpgfEJnwDLX352FR+2zD4Ided3ALmOdfFbQE7vl2nR9ujZXWW1zt+2ErTL0
teRWc7sV4ZulL7eYrMBth9bTfRCLzcGP0H0+QudDXDDj3aDzvSVk/SBgus0S
tHuew2czWum/39mY95RhBn7u9BM88fNB+T/BkuAmlk6smVD2IT4nGGLXcg6C
I2VAyf4LlOuWmjn1JkzB0NDrXcgQ0LzMh8dPduD4qrEDbL3SSxlX7SfB5pdS
kMwKlhAgHw7jtGCyR+dbth/zGg+UbOVGC9kILuxYeJTpvsfUYXjU4RNYfm6Q
4IAiTQwb/2eU5HfiTtTBTkYJPAtHkI/xcUNxUtElI0ZB0cbIG42R3DmYNQOK
s/XlX04w9ffOWAenAsHPJHYvMrFfBAnfCTW/bzMijPa6SmDZN7104M8tXzY/
V1sVJSaTWlQWk7BHRhGaDxTAIhANg1WdV3XV7vo5VvnYEZxZ99BQMCOr0w7r
Jz7+6EWinnK8/mIE1jGb5Lk7/jHiZceYcFBzLyOOE13wuiDBi61CV9regu/a
PJ2urAhmN9v0J7hhzRllCa9t2sM5IRZMfiuOGfzgPdqvwGXgzVaoGhEq+ROG
i/ml1CI0wtiFMbYpwW6tI+/THHPwwSrNspPu9FJH3pxVjxLzwaEXTiXTx1i6
fBVKsMLi4Rj81AqQi6mp05o6hqc2W3lAA5nuAcuAVQbGnMyH7YTFjRfuB2Oo
Kk6+UXyziRU33NCZQGyuvty8eaAMADF/ZD6rYxtuNQyU2OZYi22ONycsjpcx
aM6llsyosxYzYUv7zKgT+F/vs+g2tQs0mAvg8fqENAhp0OfAk0BTz/wwABlW
U9QKj7tzDq1Tbemj5Fatak38+Mcjy2ymLOI1L8NrAj+DCZsPJCsRvtB5pOVk
ZyuVxjo485aXPY8BkwEyrj74dil8DOJWzBP+IyYqrjrAe+67gFnEy6nkWAW8
ZoFJwQuLdihEQT/OdnO2vnfTTaPnr1jRmfVwvr78fxN4XkTHH4pLv2FFzN0G
j4xPieGNOahl6zG+gWxF2LCQLzbayhfqv9EWCjpQMRbRqMggQ0Ud+NmTrvy8
rkgI/K0f3HwzSHTkzlzHgEBKHwiTo3GnHVMEuWXxMd/mns62zHLpKsk3wspr
ugwYV1yREj7fj2y1BDkBREFOZdTIgGho8xtqsO/K56stujFIbg8RToTlh7ff
rrBwfrUjG+u62Ug1gU/kVS0/muyKYyLepwY8P6Fn6Cpd0wijeGpaXC5qXiI5
WEHqQQ7DRRouzW3ooLVePt90R5h3uj1M090SpuiUJIIGw3aORkzgu0BfbjaO
VDAejNFRJl7ozn2aXCYex5V41rnhCOvyV5Wsyd/QD0OKaNSBYxZNFhqUzU3G
aA07IT0wsuyii2odyZ7Xy2hAJpMscROTjHGTglMgjC7qmNjUR6UsfHUcCoSt
H6UUMPtQNdKsCiPNrVofiipRC/KG+5R2vgaTTM5acWS0MLJw4cKO9ODrZ50/
uuiAA3SZz8OqOEOWdvyZoePLHNl8dA0jRtrxuWmokoFhsNLSz6uZeOCBIcAQ
i+hNXRmW8XwJ74fZBGsTE03jYtL4F+jLTThuPvERK+cdZ+J9OIgDZFR8fvgv
sYJXdunu62xpPm2ucz02WdQvXSytklDQF4L9kew50bkR716Bt8kZW21kLB/w
In35iuaHxfR/IkygfzZ4A0usgHc0+b62WDrupTs/Khqb89uEfZPcdLZnSZow
rLs45hZ2E/gCrJ7VWLlyXOznyLgr93OhVRvoy43pRkoX5f7gMUGx3qp8NO9m
psJonrbqGt9hIa1S1aZbAFqtWbr9Z07HHpTrsiX6lgigeYF8LTcdC4K8WF/+
n9F/+tjHJpqU0rKVjWk3IemYKLprk2ZoB1knyf3Wsm17c/Mdk/zONwYzlyrX
wQ2dnHCIlV9eoi//bKR51FHjnwkTCZ7c9zRL7ps2ImdXIiXdOIflCH3he4ti
YwBYyFLnLgV/3U1rO2rz3Z0336z3jVq5yVjHZ0N9+dKRxc1mkzHf/SDPrnu6
hxIl4308tQH2V4b9fuCP0fM+kNuXQEDuRiLNeBBGPteSEXLMF8FjtaWX68sX
67392+c/3/wstVbNUcUynWHFhqN/dkE4NxX3iOf7EaF4do918BXI9AyOHQr5
VnYEqiUfb4o9H8XGcxMnh9sa0ZfrjRy1ZAm3NKG1Tw2qs5JZysJm1MmDAX70
mVPQw37esCUUGJd7Hzvb9X5q+NZX6sv5nHUePVa++bilS5tLzjprXMLfCRmN
2NDFXrqWADFx3vLlE19ZvrxWHydDSWNs2SWXjAlIoyKi7GJnhAvr081/eOMP
b/zhjT+8sdbfqP3R/wBNFZuy\
\>"]], 66->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA5ltyqhqs4r+nzDYXZz+6P84LlNEG
H96/QPY5GYQ54j+5bXNeU9K4vyyo5e55Rd8/fHOWTWQg7r/DdI4xJnfrv4pn
BJR7Seu/hdY9BJs/0L9Xp24iDt3lP3UDX5QUa/W/cT8i4AmC9r+4dfft4oXk
P/iJZ57DwXk/jmAcql229D8DLblqSvfmP1awGQCyitk/fM8ZqnDdyz/9YZP/
ynrFvwH5SsrGV/g/8fNgRmKp8T9NAM9aAlnwvyzmZ3MDkM8/sWcEfD9m6L8u
m6dOOS/Yv7g2Z35/LOW/KEeRLOjL2r/sgFUF+yTZP2gGxEjW8uy/ZG1bNRfY
779NT97Qz83XP6ZtGsP/t82/rlu5th/T7T9Mv+r+/9zTP0Gsf/cVaNw/H2rA
Q+Aw2T9tjGZX+vHAv4YxAqOSFPA/Ee/9UiTG6j8pN7aQJ+bhv6HNTNS9htc/
6Eu0/A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8620063386076958, 
                 3.2508408174898213`, -0.3367180594240052}], 67->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAifVlLxSs4r/NaTZMaue5P/Owh0WL
IN6/MEPY7Rw54j9HO3scJ3m4v+VDprmfR98/1Cn5Ks/87r/lYk/3XZvrv8od
VQMmJuq/EVSsLKg1z79A8YdYs5TkPwknjnTzwPW/JxNCkA879r8HeJceParl
P+Ax+kcAuH+/Z9EOMSBU9D8SGaGWk8HnP4lhGiKgets/kFVvaZleyz9FBufL
dLzKvzqxd11OQ/g/b7wFY7QZ8j+iW0j+0OPvv+vXVcYWQMw/ro8vrXHU6L+s
lcitcF7YvyJ7DNM1m+S/jQqROn552r95vg6ioNHXP0YT8EUWSe2/7A31pxmR
779ARR5oKufYP7qZp0Zrn86///L6p65w7T+psRGzbrLUP7dS4O0fYd0/lBg0
SMMQ2T/0URIthHzDvxqh8CWbCvA/B97x2UI26z+F4evwennhv+2XaI7Vs9Y/
tZyy8g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8561107099923615, 
                 3.2518503448217984`, -0.341970447727183}], 68->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAn1o8kVKt4r+uvUa8Nhi6P5i4kj2H
F96/+mxsLg5C4j+dxmrS0ry4v6lPS8Y3LN8/s4Jylbn/77/HQ3eusZHrv52J
rOiL8Oi/BTVyBGw3zr+/UoVeyFfjPx1gvCerD/a/EWN8wy3m9b/M3oFeg+Pm
P795txxhDZS/hpPhCncB9D9Vku+UVVPoPwtdDVwcNt0/aVyTD6tUyz9YKYIR
qbLPv+mz2umqJvg/vU9/yI128j+tDDSRsTvvvwRZShZD9sg/qW5XE4ZW6b8S
bO7Wqk7Yv/TyusMn/uO/4OdYki072r90Kg42z5rWP0MOIfeMle2/YJAaDNc8
77+Ctgo2iibaPzQwXk9dWM+/A8oXIn4i7T+COaI6uzvVP1pWLBEqMd4/FERR
8jgX2T9Uxls9iQjGv9SHbdu48e8/Ooa135SX6z/AssD1pSnhvxY+uKis09U/
j4Ovkg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8627315647954185, 
                 3.249147591359287, -0.35090479715984535`}], 69->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAl/mIGPyo4r9UaRSR7o+5P1a3EnmE
Jt6/WXZAr2NL4j+EiPKc4WC4vxTSdXPdF98/iJvp1Wpo8L8dvNBQyJ3rv9+A
K0GvzOe/7CmTa6SEzb/QliiaIRviPzihKgAdWva/8alwcCmd9b+F0VuIMNHn
PyZEBhq6d6G/drfRIeKb8z+n9DzRcwbpPx6i5hMsF98/EK8nQTw+yz8/A0BU
6SfSv1qARjK6Bfg/DKyhU0vh8j90cy5M6mbuv8HrPAi3IsY/VBgu4ui86b/z
Lq5+ymvYv0Vu2r74b+O/EsRtMyUK2r/6I0tsH03VPw5Pbx6+4+2/vCa1fKfx
7r+vXn5aLgPbP+6/Kd69KtC/ovJx+ZPB7D+Xo56dV/rVPxk6rsOEF98/HWKK
v/Ia2T9gpXy7IUDIv9/0I4+xy+8/OOdBK/0G7D9CYuY/g7ngv/ojynucFNU/
oc6z/Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8543751323953123, 
                 3.2506085930163584`, -0.35775257951928957`}], 70->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/VAPTpKd4r8TasXr9KC5P03Tg0wq
P96/9FrM2NhS4j+y46OuLK+4vxnz6fHZ/94/LAVxOqbV8L9bOm8oz3jrvx4R
l4zCwOa/2DqQPPCxzL+7pfzG1QHhP4Vcf928m/a/ffGOwctK9b9AJNyytcno
P7iBslrDzKi/ld9wAZ078z/2i3hGL4jpP0CiSqmUkeA/fcfcAy0Pyz9o2BuI
H5rUvyRfDh7E3fc/qW1uEYo+8z9j+FGQFKztv6zRGT9OXsM/qq14YW8k6r8Y
jfaKsETYv2J9bNkr8OK/s18zXQ7K2b/9UnVk9DXUP1hRoHCHK+6//JmW6JSZ
7r+D0VRQ1P3bP8IR7VthrNC/Dw3XbQll7D+AD6SwSXLWP+bNH9HACOA/04zD
GaQW2T9U0cSz6sXKv+rbiJq6ne8/I5vUffZn7D9tOhMT/WDgv/htu4iAV9Q/
Zna/GA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8545639675230023, 
                 3.2506529836807347`, -0.35689719121741786`}], 71->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAALCahbC904r9FRkUOwgW5P8vCgn37
qd6/2b+7WZY/4j98o2wibV+4v9AtIv4iL98/WnyvMZkb8b9W/sj4rGrrv9lY
N/1U/uW/m25SLnzSyr/35Vke6MffP6Tim5H+4Pa/3q5fiBMC9b/sCZOqt4bp
P1bZrxn98LK/JvouxZK58j/I83YNZiPqP9Vj6CRV5uE/eDbTGVKjyT8yuMmV
GufWv69MYdgIuPc/cjgKtkuk8z+8wt3VocTsvyRmKeHbFcI/cA8A6LBV6r+O
VQC39EnYvx9d/F2pqeK/08E1eM4o2b/Em/VQrATTP1aT/HB9i+6/9EGwPis8
7r+0slvsb6fcP5Bc92Eds9G/EtoM8l3Z6z9ZXylpeBfXP169/FHzvuA/d40w
4Gqo2D8R4WTe9f7MvyPY6ZfRg+8/Xhjo4hbE7D8rVyt6j9Dfv3FwW3cIHdQ/
0N2+Hw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8441854156182759, 
                 3.2541894864267378`, -0.3492875183671529}], 72->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAARnOd5vV44r832CvwHVm5P9yG+B7w
mN6/mYZoGCFe4j+OUR17Ewa5v7BzQ+SE3d4/nyvfrw+J8b9EKeVbIiHrv5CE
8ycZ++S/D8OZh4E7y7+s4e/OWCHeP++8OaeODPe/ix4moie29L/KneDl+k7q
Pw1jQ1psNbS/apzCawpX8j/ZGVOOwoHqPzXbTRSY7OI/pgxPmu2kyj/oJ4pd
YrjZv9S8vOIOevc/VugtwGkI9D841HxUd+7rvw+iFH8cv7w/QuUto4rF6r89
rt+d/vXXv//jt5vII+K/CuSDSNZH2b/da30l0DvSP6be967Ksu6/Lth0laLy
7b/RGOajHnrdP9CvxJol09G/tt/29xqG6z+ob+8eAGHXP4bKN0OtLeE/wkn8
flwH2T9LfFE85/nPv8CZzRtwMe8/oitiTHo37T9qfuDDOQ/fvxpOBAKmBtM/
mSG6hA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8352358537043255, 
                 3.2582084115098247`, -0.3329549757150812}], 73->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIGZjtOF/nfVo/9/F+cVTA3baz+JTW7531739WRUl
TEBx+6/GwflA8f0dJw9NAorbF8+/XT3j08f9TJZlgpWXXu2PLqt+xP718X7+
kM9SDTdO7a/VWKW54cdte+8g29/tLt/3t0pLeSXEfdmfkdJS9UT9tb2LnOfp
WK8d+5la38cBzbHfo3PMCGiO/cVnyquB5tgnci+qBppj/+yHMxfQnP3t8/f8
A5pjf3NCdRjQHHuDaU8SgObsd2ic+wVojv23+ZXMfBqv9ze7cCSnrbi+/4od
e7Txyof7ua79EOVWvLl/H4fz4Sy1i/afrrKlmn9+t59DZsfFq5Pf7n8e8Unj
e+A9ezHtPz2r0i7tNz+o+YBX47W93bHbLUBz7E8tdbICmmPv9DtGEWiO/ack
ns1Ac/a/DMxNBppjz3d263WgOfbr/pzjA5qz/43I13agOfYAm7a2CA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{10, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{11, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{12, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{13, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{14, 8}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.018782305109029, 
                 1.7668172111438032`, -2.05603379033145}]}, 
               Dynamic[$CellContext`i11825$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.920893944355275*^9}},
 CellLabel->
  "Out[2546]=",ExpressionUUID->"573f3d9e-dbae-463f-89da-740453ff21c5"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          NCache[
           Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[2], 
         LineBox[CompressedData["
1:eJxNVG1Ik1EYfZmGSoRiFJbm5zAEUSLBEnWPZctShw51uvkxp1sWlYkgEiMv
WD/CH6n1Qy1qaeJIM5FUthAf8KP8UVqmlAQNAstItMz50dL23vvunRfGODu7
957nPOe5YbpKpV7Ccdw554f/posYkNu9bHokNzb6T0SbZRSDHvHgl+LBhVcM
m8px5ZCkz6GdZ5hz4uzquzi1wLC2DH+svyw9GvOLYdRh+9K3oNr76wyH6rBG
3TKqUmwzTEpxb7g9Iv+SBNj9WjSqMzqnVXsYBi2uXFxrD+z1EnAJBvg3WJ8e
82GYK8aAweRR+5CAsRDXHAeqv7t4osFm6b2A4eeu/WoMsZoO+xQK53MF6Fup
XtJXCfejCiN9o3eKtC59eWhMqwjT9wr6IRfnl78WbCQL9XE5iLO32r0XhfpR
ibYj9RZ/IvhDshHaWi9vSV4L+7OQDFkccNYsYz1QMP9rB5LY/9ORi/A/Xy0z
y7Z3+JWGpmfNW/ZVwX8iR78XGTUXKuZlnvSHVNQGDU1ZnP5TTFLw1JOm2MdR
Ln3J6GfsmMhtFPRzJ9G6rXhfkSjUx8Xh3EPpekGJBLwpjsEHC9OrNzNd/kix
59NsRnmXF6xQPfsx4ffgQF2sy39nSRPMfxvjwZjasIuXwlh8L93PcAzcjg/9
4z4/DuTmLHq/oA/CW7tneH0b9LwkmD8+OibqJykQwKXS+hyUPw3XyhrfWlz5
I3KAmb/VvD+MTwNS32d3+5cOBDapv5TeyWT3Rj1Kon7LsoC8W1jj+yP0DyBe
UcX3j/IjSiAJHlaxv1wOtCy3dfL9p8fJcsGg1rjzQfIgOWo7WMwPqiBYaaL5
+kc35INx3PJTzB+oYXLai+aT8nUauDrX7c4vFoJS40nzzfQXgXl3/qEEJHcK
3PMBWlD6enSI82PTwvXEfe75IqXwcXGSzh+tL0QH3pFnxsX5RB181n0I5OeX
8iVlYKyx6cT55sohf7OrSZx/UzmY3oz0iO8D6IGTyQ3i+2Fz4sl+i/i+EAPT
Yb4y/B8oCLJe
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxNVG1Ik1EYfZmGSoRiFJbm5zAEUSLBEnWPZctShw51uvkxp1sWlYkgEiMv
WD/CH6n1Qy1qaeJIM5FUthAf8KP8UVqmlAQNAstItMz50dL23vvunRfGODu7
957nPOe5YbpKpV7Ccdw554f/posYkNu9bHokNzb6T0SbZRSDHvHgl+LBhVcM
m8px5ZCkz6GdZ5hz4uzquzi1wLC2DH+svyw9GvOLYdRh+9K3oNr76wyH6rBG
3TKqUmwzTEpxb7g9Iv+SBNj9WjSqMzqnVXsYBi2uXFxrD+z1EnAJBvg3WJ8e
82GYK8aAweRR+5CAsRDXHAeqv7t4osFm6b2A4eeu/WoMsZoO+xQK53MF6Fup
XtJXCfejCiN9o3eKtC59eWhMqwjT9wr6IRfnl78WbCQL9XE5iLO32r0XhfpR
ibYj9RZ/IvhDshHaWi9vSV4L+7OQDFkccNYsYz1QMP9rB5LY/9ORi/A/Xy0z
y7Z3+JWGpmfNW/ZVwX8iR78XGTUXKuZlnvSHVNQGDU1ZnP5TTFLw1JOm2MdR
Ln3J6GfsmMhtFPRzJ9G6rXhfkSjUx8Xh3EPpekGJBLwpjsEHC9OrNzNd/kix
59NsRnmXF6xQPfsx4ffgQF2sy39nSRPMfxvjwZjasIuXwlh8L93PcAzcjg/9
4z4/DuTmLHq/oA/CW7tneH0b9LwkmD8+OibqJykQwKXS+hyUPw3XyhrfWlz5
I3KAmb/VvD+MTwNS32d3+5cOBDapv5TeyWT3Rj1Kon7LsoC8W1jj+yP0DyBe
UcX3j/IjSiAJHlaxv1wOtCy3dfL9p8fJcsGg1rjzQfIgOWo7WMwPqiBYaaL5
+kc35INx3PJTzB+oYXLai+aT8nUauDrX7c4vFoJS40nzzfQXgXl3/qEEJHcK
3PMBWlD6enSI82PTwvXEfe75IqXwcXGSzh+tL0QH3pFnxsX5RB181n0I5OeX
8iVlYKyx6cT55sohf7OrSZx/UzmY3oz0iO8D6IGTyQ3i+2Fz4sl+i/i+EAPT
Yb4y/B8oCLJe
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-180., 180.}, {-8.428813202954188*^-13, 
             3.214826131203864}}, "Frame" -> {{True, True}, {True, True}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
            "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
            GoldenRatio^(-1), "DefaultStyle" -> {
              Directive[
               PointSize[
                Rational[1, 60]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-180., 180.}, {-8.428813202954188*^-13, 
            3.214826131203864}}, "Frame" -> {{True, True}, {True, True}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 60]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxNVG1Ik1EYfZmGSoRiFJbm5zAEUSLBEnWPZctShw51uvkxp1sWlYkgEiMv
WD/CH6n1Qy1qaeJIM5FUthAf8KP8UVqmlAQNAstItMz50dL23vvunRfGODu7
957nPOe5YbpKpV7Ccdw554f/posYkNu9bHokNzb6T0SbZRSDHvHgl+LBhVcM
m8px5ZCkz6GdZ5hz4uzquzi1wLC2DH+svyw9GvOLYdRh+9K3oNr76wyH6rBG
3TKqUmwzTEpxb7g9Iv+SBNj9WjSqMzqnVXsYBi2uXFxrD+z1EnAJBvg3WJ8e
82GYK8aAweRR+5CAsRDXHAeqv7t4osFm6b2A4eeu/WoMsZoO+xQK53MF6Fup
XtJXCfejCiN9o3eKtC59eWhMqwjT9wr6IRfnl78WbCQL9XE5iLO32r0XhfpR
ibYj9RZ/IvhDshHaWi9vSV4L+7OQDFkccNYsYz1QMP9rB5LY/9ORi/A/Xy0z
y7Z3+JWGpmfNW/ZVwX8iR78XGTUXKuZlnvSHVNQGDU1ZnP5TTFLw1JOm2MdR
Ln3J6GfsmMhtFPRzJ9G6rXhfkSjUx8Xh3EPpekGJBLwpjsEHC9OrNzNd/kix
59NsRnmXF6xQPfsx4ffgQF2sy39nSRPMfxvjwZjasIuXwlh8L93PcAzcjg/9
4z4/DuTmLHq/oA/CW7tneH0b9LwkmD8+OibqJykQwKXS+hyUPw3XyhrfWlz5
I3KAmb/VvD+MTwNS32d3+5cOBDapv5TeyWT3Rj1Kon7LsoC8W1jj+yP0DyBe
UcX3j/IjSiAJHlaxv1wOtCy3dfL9p8fJcsGg1rjzQfIgOWo7WMwPqiBYaaL5
+kc35INx3PJTzB+oYXLai+aT8nUauDrX7c4vFoJS40nzzfQXgXl3/qEEJHcK
3PMBWlD6enSI82PTwvXEfe75IqXwcXGSzh+tL0QH3pFnxsX5RB181n0I5OeX
8iVlYKyx6cT55sohf7OrSZx/UzmY3oz0iO8D6IGTyQ3i+2Fz4sl+i/i+EAPT
Yb4y/B8oCLJe
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-180., 180.}, {-8.428813202954188*^-13, 
         3.214826131203864}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[
            Rational[1, 60]], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->15,
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       TemplateBox[{"\"Energy\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{
             SubscriptBox["\"kcal\"", "\"th\""], "\[InvisibleSpace]", "\"/\"",
              "\[InvisibleSpace]", "\"mol\""}], 
           "thermochemical kilocalories per mole", 
           FractionBox["\"ThermochemicalKilocalories\"", "\"Moles\""]}, 
          "QuantityTF", SyntaxForm -> Mod], "\")\""}, "RowDefault"], 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
       TemplateBox[{"\"Torsion angle\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{"\[InvisibleSpace]", "\"\[Degree]\""}], "degrees", 
           "\"AngularDegrees\""}, "QuantityPostfixTF", SyntaxForm -> Mod], 
         "\")\""}, "RowDefault"], HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-180., 180.}, {-8.428813202954188*^-13, 3.214826131203864}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.92089394768528*^9}},
 CellLabel->
  "Out[2547]=",ExpressionUUID->"5938e6e9-d249-46c1-b94b-d196c5c49521"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIGZjtOF/nfVo/9/F+cVTA3baz+JTW7531739WRUl
TEBx+6/GwflA8f0dJw9NAorbF8+/XT3j08f9TJZlgpWXXu2PLqt+xP718X7+
kM9SDTdO7a/VWKW54cdte+8g29/tLt/3t0pLeSXEfdmfkdJS9UT9tb2LnOfp
WK8d+5la38cBzbHfo3PMCGiO/cVnyquB5tgnci+qBppj/+yHMxfQnP3t8/f8
A5pjf3NCdRjQHHuDaU8SgObsd2ic+wVojv23+ZXMfBqv9ze7cCSnrbi+/4od
e7Txyof7ua79EOVWvLl/H4fz4Sy1i/afrrKlmn9+t59DZsfFq5Pf7n8e8Unj
e+A9ezHtPz2r0i7tNz+o+YBX47W93bHbLUBz7E8tdbICmmPv9DtGEWiO/ack
ns1Ac/a/DMxNBppjz3d263WgOfbr/pzjA5qz/43I13agOfYAm7a2CA==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{
   1.9965046645570634`, -2.7223749112523414`, -0.16445050010777468`},
  ViewVertical->{0.17841268648404823`, 
   0.9730894560342437, -0.1458280626509336}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484202`*^9, 3.9198503896300073`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919871395648071*^9, {3.9208939187450314`*^9, 
   3.9208939477951403`*^9}},
 CellLabel->
  "Out[2548]=",ExpressionUUID->"d199b256-534e-4a4e-8610-3549b640cc9a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"ethane", ",", 
   RowBox[{"Background", "->", "LightBlue"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.920893975685869*^9, 3.920893979629177*^9}},
 CellLabel->
  "In[2549]:=",ExpressionUUID->"f4c47ce5-00d4-42fc-a4ec-f418d9527eb0"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIGZjtOF/nfVo/9/F+cVTA3baz+JTW7531739WRUl
TEBx+6/GwflA8f0dJw9NAorbF8+/XT3j08f9TJZlgpWXXu2PLqt+xP718X7+
kM9SDTdO7a/VWKW54cdte+8g29/tLt/3t0pLeSXEfdmfkdJS9UT9tb2LnOfp
WK8d+5la38cBzbHfo3PMCGiO/cVnyquB5tgnci+qBppj/+yHMxfQnP3t8/f8
A5pjf3NCdRjQHHuDaU8SgObsd2ic+wVojv23+ZXMfBqv9ze7cCSnrbi+/4od
e7Txyof7ua79EOVWvLl/H4fz4Sy1i/afrrKlmn9+t59DZsfFq5Pf7n8e8Unj
e+A9ezHtPz2r0i7tNz+o+YBX47W93bHbLUBz7E8tdbICmmPv9DtGEWiO/ack
ns1Ac/a/DMxNBppjz3d263WgOfbr/pzjA5qz/43I13agOfYAm7a2CA==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Background->RGBColor[0.87, 0.94, 1],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{3.2823012066538646`, -0.3541794876577038, -0.7248832177124216},
  ViewVertical->{-0.37647710741913326`, 0.912137945696835, 
   0.16207823916022837`}]], "Output",
 CellChangeTimes->{3.9208939804443827`*^9},
 CellLabel->"Out[2549]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"70416196-2aac-4b80-aa1d-37fab140d160"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["torsionList"], "Input",
 CellChangeTimes->{{3.919799366343082*^9, 3.919799368657453*^9}, {
  3.919847337711438*^9, 3.919847338687681*^9}},
 CellLabel->
  "In[1512]:=",ExpressionUUID->"67d45785-9647-4b4e-9cfe-f9034cd885c1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIH718PStGb3P9sc2Sp7SVTq8X6W8Zrlw6Fl7f6fl
d4Di9so/dxjpKR22zxNL7QGK72fR7V3gWfNtf8fdPwdT9j+y58yxKj2099j+
qxbtCQ0zXuw3lfD8UJK1b/+p7YdFZyt9tT9xsKP4gd2H/ZZGPve3eX/a/+Vs
+P+lprv3l976sBRojr3tzs2rgebsf1B9YCrQHPsjl1fEAc2x7/1k8bs4a599
jvB8XqA5++c0cSUDzbGXVmD+AzTH/vC3jYmLTXfb/+n7ydb98MP+xF9v5m16
e9q+QIfjpEvsLPuE3pVzeSY/37+HTV5xi/bB/evdNnfZnn1hv3fTuwdrWl/v
T03qn/Fn/ZP9IQoL/RtL1tufs1XiAppj//Irlx3QnP0WWZNuOcfO2s/FvQJk
jr3pTi0JoDn2Vtu064Hm7D+iHHcRaI69vX3UIaA59hJmEtubS9bvBwCxd7gd

      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    ImageSize->{180., 172.81871673421526`},
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.9555392341665696`, -1.6249852912505585`, 
     0.22047820418677544`},
    ViewVertical->{0.2608698643397846, -0.02810633580301755, 
     0.9649647391314723}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAve1yWsqU5r8BRGzQmanCvyT4R6X8
S80/teYVOuia5j+gW1YzfRHDP3O+0Q08vMy/xpITvWiL9r/RreVVUwDiPyWx
CGFaBsy/lqdmVSYa6b9xj+NU3Lmzv7qRIc2VFfU/KzHHcXsH8L+x54S31Hjy
v9dxXxanKrO/zuIKq3Jc9j+ZUGwzGI/jv58clmYrZ8M/IdDBl+F56D/Sk6L+
OwHDP2mHhU1NE/W/Jru054SD8D85SQMlsQ7yP2heOx99ksE/0oQm9ebq8L+h
OZXD2avKPwBw9EMkWnQ/qsrsV3jX57+6C976h4a8v7+QymEVv+g/CqgAn+BR
678xcJLxB87kvzg/GBqptrM/FOsKZPPU8D9icy3NcZXNv6hDd04hqqK/a9vr
6GSK5z+5d/yYXAnDPzi/P8/Uqui/gK6/BPnQ6z+tFG7L4HDkPxTALN19U6a/
5xW28g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1174457795537698`, -2.6730343751746757`, 
     1.7408624755827204`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAE/27GroB5r98RtesK129v8W9pu/V
uNI/QHA1on0R5j/IUlfaNjm/P1dmDVPePNK//07IFdvt9r+mYzmjQJ3fP4a6
2KiTMM2/lYdpZCq25r9t5HijkZXAP5x7HFYHvPU/9dVrmGQt778YsSPYGKHy
v3RRp/wHR8Y//tZUCslx9j9jPxOMTXfjv6zqy4Kc47s/Q9oYMtxp5T/LlMLb
FMGJP8K4HlT4+vW/7Rb5oQmx8D+/lf6JehHyP4m0lsGqIqi/xCaTEVz38L8G
kgO49UXIPwiC6WwwgqA/VMKSP/Jb5r/wEtTQvG9+Pw4rBtI8auo/hOmTWY+X
6r+AJfGS63bkv39m+u1Z3M0/j8e37UO98D8UqpBhTSDPv1jXtGTuh7a/QiUn
6qy95T+w0ue6rDixP1gS4ugviuq/Dc8Tc8i56z/rCqT3DQXkP+g8QKszQcW/
AUm68g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2563129404704885`, -2.417097845570353, 
     2.0009287344994457`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvW2tFYH45b/HnorlAX29v0eOjAsX
5NI/iGHXXy0P5j+uiBjd+RPAP+gbADR1MdK/EBYWuu0M978gSxi6TmrdP5Rz
vByzDNC/yVFVd8kA57/baY7xl2zEP9+GtoalpvU/lcvHtoSL7r+0tt6f/cPy
v8pNUn34bso/UPMFa6NS9j+vUmp7+y/kv1+cXnwqVbI/Te8PUBoL5T+l7HP+
URisP1iqfMneBPa/o9blDY7v8D//OTwpY+jxPxKcDdAeOo+/d2Z2IpcE8b9u
o7VADgvGP5DVgHYfu5Y/w1+BRqV85r/caST7W7iWP3CqmUmrX+o/qZw65gJC
6r+hYDe+zZvkv5baGqXJDdA/CtJ4DR2t8D+DMCQE/SrQv6Dp0ClVOLu/aqjz
1yON5T/Xg7VcDhq3P1KxfBY8keq/Z4fRvST36z8US99k4urjP8mIgCpGK8O/
BIOyWg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2664590684090196`, -2.419751180777233, 
     1.9913025011714682`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA2rJbLvUZ5r/wISH9fSi5v1Rfjygg
sNI/RY81vfc15j+vohJLiJu8Px0slpf41tG/sGjnfXQH979tmTr8ambbP86u
QikQsNO/sLw9WX3U579dnOVennPPP/4HeFq6QfU/k122Pitn7r/+dEwhU5by
v/hua7/aQdE/5CvlszYS9j/opTgMDUDlv2/iQ5QSVrM/Fky3y5tP5T9ZJr0/
0YelPzlctv2h7/W/N8yX3UJd8T8mrz4T3IrxP68vOwgVG4G/DqGKijcK8b/w
UPJ8SxzFP0DvaRYA/n+/xbfMQzn35r9kC1VgX9+yP9Pfm2TC7ek/NgiJNpBA
6r8dhx4B2yjkvyZn/XP9+NE/w/k/SZmW8D+SUdYCnKzRvwJnCuXnArq/rm12
xMnC5T/umnh1uK+zP0DnmyNgZeq/2pMyvD547D9R2e+XlFTjP5oF2D/RX8K/
wCa0BA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2248564693583337`, -2.3616303978813065`, 
     2.0849049122859333`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGZS5Ewkg5r8Z157Vi5S4v9Jnq92X
pNI/uHTG4KdA5j9PoG7TFX+8P47b9KR+qdG//NPMFdgR978q6Dop28LZP8yx
z/KQF9W/uQ6Bf5g56L+o+P4XKJHRPyibBfApFvU/kasNSzMU7r+/088UNpny
v434Qpep79I/3Tfn9fPZ9T9k80OCyT3mvzkF+ql1r6I/opHido4l5T+xG3/y
Tg+3PwxrQzBX7PW/s1YZWLO78T//qDycfDPxP4doLyygfKE/BM/UT+4Q8b9k
MtMzuJ3DP9BPIqnIl5O/aVGdydAs57/DhS5FCti2Px11cOdPv+k/1Z9jLx4a
6r8wwSnSfiLkvzAwd7ogytI/HDkl8yN98D9aH9bH5q3Sv841a98fp76/LYPU
Kxuz5T8A3vZiMse5P++hgNm2Vuq/D5F8SAfc7D8Ek3P5bfviP/rc3T7V876/
l9i50A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2121188292765186`, -2.385013887859852, 
     2.0656419579464766`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAwnOeUn4l5r//yG7orBW4v20VBaVV
mtI/wtc+GldI5j/xouy340O8P+EcH5M5jtG/BmEHjW4f97+1+Ymc64nXP7bB
wCeDtta/5eLsdKyu6L+Nl9g4eQrUP2mpaxQf1vQ/p8CyWuui7b9+3D4Qmpvy
v5lMmVBGW9U/KhrWGUWo9T+qVoAHcAXnv46BN/iTx2Q/mflmblUH5T+Hu3f4
uq7APxhOPl5j5fW/g4DhNN4K8j930D04fuDwP6SCTW6JirE/dE0r2xYZ8b92
R25igITBPyix7gq2cKC/VKvFYxVq57+bynn9Gwq8P8TurH20fOk/NJqo1jTk
6b8OycXe9BzkvwMxz/rN+tM/BsN6Uzhm8D9MwoKQ83zTv96tLmuqZMG/ruhS
RNan5T8ADW7UrNC+P1AVBsPxSOq/ZOwAwgkv7T+mmrxzvKTiP3B4F28uV7q/
hG63Og==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.206512472523818, -2.3861714637707556`, 
     2.0675863704161404`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAOeKeseAw5r9pTHC3Fm+3v9EYfSGX
dtI/+YDtXaVT5j99YUtlaJq7P80o67Ila9G/hMcbQhIm97/2KFBPoVnVP+cO
EKCAbNi/rey0IG806b/uljmZQrPWP5Midub+g/Q/wfMV0VdG7b9t0B2QXJLy
v4IFcvti3Nc/nZvx4T9v9T9oTWiGR9Tnv4Mk6dg6Hp+/G9ILXYQF5T9lRs9j
uefFP9qafgzK1fW/73lGSRFg8j+hLnY3m3nwP4490Urw9ro/UJx1TUEf8b+3
K+hCt/u+P1jYS/ql16e/c+cp6aey57/Ug13rfNfAP8ho1a6kIek//WpaQZy7
6b8z1ZT7TQnkvyqPdw59KdU/DS50SIlM8D854b55+mDUvxW7eWAJXcO/iql8
3ZSs5T+SezrLdtrBPw5lOXmTMOq/bDo9+OOJ7T+55Mq9QTPiP9SybUDTWrW/
LMK47w==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1936184260474716`, -2.388363187615591, 2.072533796357167}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAtYJOxMIu5r9er4yVJm24v5/icYk8
cdI/e8AIl1FN5j/C8DP2GVm8P2U7EsXDfdG/rQiQ2oI9978wL4gD5FvRP90z
80QIMdq/8IKIuPrc6b/Zi3ppPN/ZP7rmrnJEEPQ/R4B8nQVf7L+sO+nt/Z3y
vx2GItXFsNs/Z2RKkmVf9T/AIfWV9ATovzURjEOtjqy/Wif/xtjk5D+KcuH2
sBvKP90eb3sK0fW/SYpPm2l68j8cvVruek/wP1NLthtuQ8A/BKVbHnIq8b+y
Bkq8NIG2P/hEBe4u/66/0oJrvt4F6L8BYBfE8sPDP2JfC5WTrOg/foHlMORG
6b+iBkJX0CTkv140Si8BEdc/UmLnLgdD8D+ooy5X0XnUv4y9g22ZD8W/6vMD
LxWZ5T92tf34HiTEP7ats2x7MOq/hurTZhKh7T8o/L2NDBXiP3grbm4ZuLK/
4cKylg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2169658692823662`, -2.343261476884767, 
     2.1100994583075066`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJ5axwD1B5r9VYJ3Pt863vyNnsab+
KNI/V7e+xdBa5j+gD3jvtRa7Pyf50wlSXdG/su6VxqE497/2IrrItCrOPxQ6
5JCk59u/oAYl2RJ76r/ibTmUgsvcP6BJqfnnlPM/lSn0mQ4d7L9TRJmHHXzy
vxtUq9omed4/HzPAMTMd9T/7JLyDF9jov8gr14TEoba/xvWB5lwK5T8haVbh
xLjPP03WRoBis/W/zt9+TYfV8j8aAY9ls4jvP+Vi/tdXisU/41x3U6As8b/L
cuvgWEOyP+SlZdRLfbO/ZE7rTChe6L/OFVKg1NfGP2ijVaMnH+g/3t9SLSYv
6b9ZGpMECfnjv59drsASUdg/ZcdPyk0l8D8HI83FQHXVvxnECSvDBce/jlYg
1pay5T94OInsD6LGP5bUuwK3Cuq/ejtesO8C7j+HAb8RxXXhP9AeU3eYYKq/
NnO2Mw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1948199591560291`, -2.346426047116679, 
     2.1192192124966174`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAN6WnhERL5r8gXwQuIvu3v4gl0Mxs
99E/Kk0ZNZBd5j8qJipBQlW6Pyb1zaF1ZdG/kekTPwo597+RzWSpkODIP2OH
ES6pRt2/o0INsjMN67+GW/z7y4zfP/6ehmLgEfM/tHS4za+0679Fy08RDF3y
v6HoIEU7wuA/ZJgOFm3h9D8zyvfcjH3pv0WpwkHiMcC/mv+7084W5T8z/VFW
jwPTP3bAi0Odk/W/unC1mwEk8z+Oy+50D2zuPz44dmk/oMo/Ft6zQFYv8b8A
PMUk/8WpP7jDgsJ4nra/7XNaGzys6L++Q3twA47JP2CoupW7j+c/9gwwKfr/
6L83ETA0vtzjv2X7iKvxvdk/fJ9NmBoI8D9uhdKU5DLWv8hJr8Jmfsm/YqZq
hC+65T++hpzm35jJP789/6v67Om/TxdCtslS7j8qCIreW9vgPxxkS7RXVaC/
Jxu14Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1846080806912167`, -2.3474090207781524`, 2.12385841908787}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0p2IsRVd5r9p21sL0jm4v5ekAQoB
m9E/i7U2HFJm5j9P+/IoJXK5P9Y/6InfT9G/b6Jf8acv9787DlSnUfLCP/Te
vaW29N6/2d+uy+TN67/Lo8RmAUXhP1n9DQX0ZvI/OAeV4p5U678huDvC/Szy
vzP1vKv9YeI/xduzlPyp9D/tutUGyw7qvz8ticfTJsS/+U3SbLlU5T/fLmEI
JfzVP6IEVuZaZPW/25/xPPJn8z+MiQweFELtP8frDZw93c8/rPgRZRkv8b8c
gpiGolWbP7x0eDdrs7q/1r6bPn0V6b+8ULJKjnvMP35mjke0zeY/hdIOStrY
6L/XdfHimrDjv37HvTB+L9s/ijbPoiXd7z+DW7dhhuDWv3bWrG1JY8u/woGE
xIXd5T+y7Z1SrljMP5cU0MhSuOm/oPoMSxub7j97dJVhLDjgPyCfFL4LFIa/
kLu86A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    ImageSize->{180., 160.11822278860402`},
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     3.0807994202941056`, -1.3903269628337491`, -0.008115930814439176},
    ViewVertical->{0.6051765441208867, -0.15807100266258575`, 
     0.7802402889899657}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAy0C7PUCC5r90dEzB1BW3v6bUD4TP
89A/YkSnRECC5j9ozkyj1RW3P8w4sJ7P89C/FQsKUMER978kqbCzomq+P1yF
dN3QfOC/GT/SNWGP7L8vAdw5jMziP/Tbn3Q6pvE/wMiaLWd2679yUFQ/Ytnx
vxgTHWD4qOM/Se1FCZBS9D8LsWfUgffqv5nTI/YU88e/F9vYpQT45T9EpiX+
LRHZP626A0tHEfW/oUr8FhPG8z9936fyzofrP2xf6IBuTdM/vdVzt3Ap8b/A
0pDJN1ONPxI22TbSBcC/8r/GudCI6b9C5WRDo9PPPx7Ro1Uu4+U/xgSrtVP8
6L+6F2mLv0rjv2v9JCLgItw/eo+ZK7CT7z8+F/4fxxTYv5giwhla7cy/vA9A
dSI95j/e2fhmo9bOP+DIrzI7Tum/0uxPOTMH7z9KeRGniWrePwA1wRH3zJI/
B6O2jw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.9195192477567636, -2.9110401561774895`, 
     1.4507686108153055`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvZY/uP565r+B8/At0Wa4v1E2roHm
+9A/U6MdI1Ry5j/tO3P+y0K3P9qLuhzIQtG/uXBaCwsX978mXKeQEqSxP5kP
cKkpv+C/4g0z43oI7b8xLX0uBuDjP5FjW7pEE/E/0zxSWNbQ6r/F+T3gC6rx
vwBQmctoVuU/tW7zSmYe9D9+Xm9eSzzrv78Y8BN1OM6/jxtIyS7V5T9j6wqi
3K3cPy8uBbmW2/S/fKv6OAv/8z/E/H8+bUnqPz6+UHLlVdU/DB69M0Uq8b9o
XSZ1+gqLv+LoMdFsgsC/UFK5zbzB6b/BDr8ILNPQPybxxlo+UuU/yOlIiOql
6L/9CB3zeDDjvyhrcAxc1N0/XkCCXJBX7z8B96De8VPYvx1MWVOBL9C/cd8y
dsEj5j8v3dPQRz/RPyXRM8BILOm/Jn2JSjU47z9BZE6+xjHdP5DJWFZ1TKA/
SdiwhQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5675621371263786, 2.3906199476485357`, 
     2.3210362957966537`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAfKihuxJ35r/t0JLbNGO5v7We8KzS
9tA/ISdynlFn5j9P0BN4CE+3P0T8m4X6d9G/WgAT8egT978G36YjG4OUP4T3
LqOfBeG/evV7nXGO7b916B7Ax+bkP0t+7W5wdvA/SG6E3Uo/6r/scngFZGrx
v7i9o/U+7eY/WkZwlnHm8z8Ujr4Sx3nrv+kAIy2IDtK/t8DA4jDL5T91CjFm
uwbgP5PTtTdLl/S/RGQ+qp029D9NrO71eP/oP4/Z/RrcQ9c/TOpxJ7kn8b8s
GakSbkKkv1JQbZlsFMG/+86OLMIC6r9YjqwkYbrRP/ilKRoltOQ/YguTzC5b
6L/7nzFTlwDjvxINHEyoaN8/6lmpZRoa7z8KFLwD5o/Yv5Z+X1lBw9G/7HOZ
QEEZ5j9/hDN1nPDSP6TSHNlJ9ei/1Hd3eUZq7z9XJvEEWunbPzB1h1WGL6c/
RLqzCw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5662382878987149, -2.390926961998522, \
-2.3210433997894246`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKCM8r/h15r9oW3v62eG5v6IRc0Bp
7NA/RGcsnDdh5j/xDwlp8iS3P8BqQDiCltG/+w5XEdcJ979PyRnPi8qav/8m
fT4HSOG/+UpwtzwU7r8z06RU/9/lP0pYUxRxru8/mxw+1yjI6b8X4xwPVBvx
v/LsYL3GZug/SMirwiOo8z8jgXeSi7brv74+CHPQ3dS/zqg6CqLW5T9iL5MW
E5HhP0LGdzfPR/S/+htRj/Vu9D/R3lzhEqrnP64mPrnEDNk/SJB6tGki8b/e
5iB3Pkqwv1w8hzylo8G/EDdWsxpF6r/GZ1UVxKPSP45wRtpSEuQ/4h89wxAf
6L/OmMSucbniv+I6za59buA/6vvBkL/Y7j8lX1ZF7dHYv79UpFUpOtO/CYgz
0+wb5j9gUbRjsXXUP/Lgh8Vvrei/nE9nXZGf7z/PAH4usY7aP7jv9gMK2a0/
B/61UA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5663998131127178, -2.390947054432604, -2.320983290462457}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAISMafXxu5r+RfuysxZm6vw1eMpPY
/NA/75VHGAdX5j9Whyq1voC3P/e5M5xUvdG/oocoZPH+9r/dDbxIIw6zv/mU
BiqUZOG/Rete0i2W7r9uxxMreKjmP6E9JBu0i+4/K1bOg2c56b/3tvcpYs7w
v2GjrEW4y+k/ZSbOzvhs8z+mnteIi8rrv4MvAZ+jzde/EmT7+R3I5T/8rR0q
uRDjP+zoDu+p9fO/Ya7A6m6h9D+y2eEaBHPmP3dKoY0Wf9o/mcxa0Rcb8b83
RtR69NO2v+bL2sBPzMG/M4e8J1WC6r+cN3Z1P1XTP1S2XjIQheM/pjx0APLT
57/gfsaE/nfivzTpokcSJeE/XPHxWnyY7j+8TTKyc9rYv710mh18xdS/AH0h
iZIP5j/m/sIA0QDWP2rXGxb/ZOi/WHnkdvLM7z+cKofxG2PZPwAh2+KDg7E/
+Da76w==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5657891454180122, 2.390849609974954, 2.321232600453855}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAU3IO4DBx5r/m+Q+YNZu6vzqbFwdZ
6NA/MsEAKAhZ5j+5+GL72nC3P/jh/ArCrtG/2NuCaOHp9r+Nx9jS5DS9vzur
5zvFmuG/QbUbQE0X778Eev4mb1/nP5KkbDIocO0/26r9vwzr6L+yjpybBHvw
v8rzieoy5Oo/rmNRwSMm8z8q+Uc+/Orrvwj9NGZGoNq/Xd8U0tbx5T+xKUU7
aX7kP2vhZiv/jPO/1KgejxPY9D+jrWpMFQ/lP5qij+x/J9w/gQpF7DwR8b+6
YHQ1Dei7vzy7t3AxTcK/yhMVED/E6r/IevxzCAzUPxg5/Foq8uI/lw4G0B6u
579Qjh31tyTiv7TgCrcvrOE/R8RR1adS7j8Tmtve4PzYv4DvmDiEJ9a/SNAK
fW8l5j/IiLGahGzXP+kZJq6v+Oe/toSP0UsC8D+6DNerMP3XP0SBJcN78bQ/
x+257g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.567752570592848, -2.380481711754108, \
-2.3313866771922327`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABcVr3xKI5r+2zY2kdzy5vyA1TRsD
idA/uNZZoElx5j+r7QqBTDm2P2IcEg7sRdG/+f4JQLHC9r8KkzZe0CPDv9l6
ypUlF+K/BThSrDaw779qIh7T0lDoPz/4ayE3AOw/ZGnODD0B6b/FwhlM5QLw
v7hMtt9Y4us/VqnFtfHb8j+FD3JE8zjsv7Z2PFCCgdy/t5x7AjyE5j9pP+V4
JH/lP0qaQ+5jGfO/LucD+r8I9T8QstxXIJjjP4bhV7wlDd4/vvDfV10D8b/l
eX0wDMK/v5LARxBIpcO/hf7exSQc67+0aIzeQynVP2hJiVdcIuI/NBcd9qfE
57+gn2LGrJbhv6RzrjZtE+I/spTyhZYU7j/PsVC0yXHZv4xJJy+349a/uLlq
0cJ65j8fnQYJTkbYP2IhyPHeaue/RWkYZbIg8D/GD/7nSV/WP0iKi1xzjrk/
OU+wpA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5627327340278557, -2.38048703635731, -2.332597980747717}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0RCY5M7B5r+z1aCxsji1v9WhNWCj
NM8/jiq4EDat5j9Rf2DCE5WyP63X1k6DRNC/eNf0smaK9r/RZhvTxrHDvya7
bpkZE+O/BBNwMb0N8L/8YjqhInnpP55CmuK3fOo/qC9TdYL86b+QRvlWGOnu
v7ZZa0P6Luw/8wBEKPVo8j897k9o2fLsv45jjmBqHN6/wZ2JAtTn5z+pcBN6
CWHmPxjZmOjUY/K/oL1ZVNJD9T8BxOaBq0LhPxjeuw9fkuA/8G+gEqf18L+q
0esrIE6+v2GlwoLhi8a/bBu8o6Ru679FSAZLDNLWP4rVU13wJOE/PKD1rChf
6L+jsJZWF8jgvxZhvI0R/uE/OhagMJC/7T9T3gPwNqDav56dstd2MNe/KOSg
CYVK5z+TgF/yq7PYPwSPTrz1dOa/dOlarjZN8D/r0zL6TZXTP4LkoNA64MA/
/Hq73A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5723108334790381, 2.3465719455767338`, 
     2.3644154487134346`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAWKEWHEsj57+qIdnIlLGjv8HLSF7U
7Ms/7/68VG4R5z9yuYy+/YCeP/n0MYFuAM2/3D/XCyYy9r+JVCWkC5jCv7JZ
DVVEoeS/KFgMcoIR8L8Cv8AyR2rsP2cQiqMRVuc/YIRqelxG7L/OFnM+Iurr
v7gJjWR6B+0/RVkjLfmz8T9Rn5vEUxrvv3N+dBmyD9y/97HYIoSM6j8caLM6
LQzlP3p4JtDm1/G/NxEa1Yl19T/vHPNQLPbcPwqSM05FQOI/REjxzOXh8L/0
nFvWcIS3v4NN9noeTMu/1KgXACij67/oLDPmLS/bP1hDHLtGUd4/3JJAy9O0
6b/oqACLOyXdv1SeD75XAeI/vNiBV7A87T+FOafWSybev3i8Bq30R9W/c9jK
O/nO6D/nzacoNQDWPxm3TKD0d+W/V0i8fyB/8D+G6NssPN7OP5cpzltTAMY/
neiwIw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6002455638212141, 2.3881787992922727`, 2.315320125970462}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKMzEDV0l578zO5lJ1Fagv+SHhJT4
6cs/m0k/bRwX5z92PlyT4iaaPwTTbHYpv8y/FuXQLhEr9r8rnk2dqY/Dv7hG
ZqoGn+S/4Acg21YN8L+c7GvZc9TsP8vrV9+t9+Y/5kQj20hc7L9ZbFGc73Hr
v15rq7kLU+0/zsfRDQND8T9fcsfB3Q7vv5NYFfwYE+C/FzB6lm8B6z+gBfhU
TXvmPzJggJoMMvG/aoia4/Gp9T8QB4ckWpLYP4H8bkbLAOM/laXZ2t/e8L/4
7LOvXqW3v35JigoRScu/9G0CYgWg67/pWNKUBs/bP8QNeQQs8t0/hwh09NLA
6b8MAOvgXHfcv6xGZu/EJuI/nGxxRJHO7D9skCytpj3ev1SNsFnjQte/2bzc
AUYM6T+T55JphEzXP5L6TcnxyeS/nBYdDcCa8D/4yrxNyDTKP4CPp9EBosc/
k3a2bw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6341980435021852, 2.323292359624117, 2.3716039832421867`}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJUO+CdLI57/xNHbNQWu7P5Ah7WVd
h7Y/BXxJgoC/5z/6XSBeEKi8v/xu97Cfbbe/Bp1DbuyL9L9Slpx9UyvEv1BJ
+zMCauq/+/bwxatc7r+/XViDn5DyP/smRU4kadM/FmFVnqkM8r/FvARCBKff
v1B/xtwRU+0/J3nFqRcE7z8nBHHAQ+Tyv24EW9Vs2cK/5VVFc0ia8T9Sk2Kl
qQ7YP31wnw7VCvC/suQHYECv9D9jm3aKyUvTP6gIhZcrS+g/TF+RuSo48L9k
74VbytaZvx6lPYcWmde/EJ3X574S678OwS+gU0fkP19vwKf7Csk/qII0oxLx
7b+KL6fOM8zIv8ERwsT+EeA/lnoHFsxh6z8GClPGxK7kv+y71q08kL6/6BNq
tAh67T/Te9qNpeTAP2znrgmvgeG/WlGWUIBH8D/KB93likO4P8kaZqF3XdU/
oDGzVA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6320101800727966, 2.685898531783721, 1.9521557850864262`}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvv920tDS57/Uc8pBOE+2PyUaJxVp
Rrk/2PLvMaTO5z/5GlMqfOG2v/GoCNhEvrm/FDXDa6ec9L+Y+wnoOG7Gv+TX
cOebCeq/P+2n3Zw+778PJZu72AzyP+WNv7VW/tU/qQTgqCen8b+ZU5HDA37h
vzCcauBVR+0/MwZMsKaX7z8xhrzV9knyv8EnKQIqENG/qgtELT1y8T80fGlv
9FzfP3h9KA4vw+6/TsY0QyOn9D/A3r0Jc97PPwKjO/9ZHek/elp/6gdD8L9c
g0mOOY2mv6D0y8TO4Na/fnYP2LaI679MzLc/zHHjP25UCfvwT8w/iIQbEpCQ
7b8+CrB2OWjNv7q/h4EROOA/hvwdcSWz6z/gt2GYDrjjv/5RKzi7f8e/FgU8
Ro9Z7T92tdRklaTJP0vJlNR7/eC/3V8WrjpH8D9DUZT0tG20P+SNOmSR5dU/
A3C2yA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5877920305185216, 2.5745166101246175`, 2.10968356704302}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIPYVeSwT8e35fl3X7/Un7261T189PcK5aZ39248O
5kBxe/Pd51Yev7t1f4DAOUeHpnX7pWUE1rw7/Hm/opPk/e7K3fvVXosve3bt
zX6WuXklMXff77f92ChlsPqjfUNl/0v769ft61hPK3G0ftqv9uQy8/GOx/vP
cpRXW/a8tNctUwgCqrc/9CpYDKh+/7EMjutA9ft5Zf6KANXbt9o67TzW8dh+
u/Rmdquel/tXWu3aBLTXPjK6raSvcre9k4nCYaC99k7LGndJ7X+//8Ln9hrO
/Lb9+QV9BYfe3dq/4sYKj1svX++fkNq4iYfzsf3bvEUhHctP2y/ptzE0aXi3
v/H3lcu8Zy/sb2lm2Bhbctued8sGF6B6+7JrHyYA1e+/oOV0v3356f0sU+ca
ANXby6VxHAGqt9/z5zx3XMnt/Qs2R50D2mvf0XBPSzq/zd42mHk/0F57AKdj
tnA=
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.36390375882917525`, 
     3.352315980148783, -0.23227488790031783`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/qEMakXZ578ytZA8Tda4PyH6sU8+
CrU/03SIJrPc5z+pv3xJdke4vwD6X8CFt7S/h0JDtZyY9L+wTYVEyAPZvzwl
haCAeOe/W0XGe0EB8L8XFsoijJLyP3CHumO5zLU/W40nxjJg8b+P8vdtbt7V
v6pUbbJHZvA/z0jZEFSs7z+EPYhEyYfyvy/z9hwD8sS/TNI34uSR8T9UxjLr
ienZP/SBzsXSoO+/c2MyI0uQ9D/Wqfkn7KnUP8HU0FVWxeg/w8kktZ9C8L9j
IGH1NM7Cv/jljtY419S/WpbMMOTt679qIZP28B/kP8hAttl7a7U/Wt4te9VM
7b+Giqc9tlG/v0x0aJfrtuE/0d6wm4PE6z9+CSCpQAzkvy/wJv3FTb+/tgx8
dT6A7T9qltNYrNfDP5pA7b7hG+G/7k47W1I/8D/X8zQrHTC9P4HVxJ1lLtY/
pbW+DA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.1073138557885786, -1.7084774888329732`, 
     2.9144447852904616`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAAPk2zNzY579mJPrbl+e9P3hGfptP
XKo/ABwNyhff5z8F9uMnTuS8vyZwv0byNqm/fZXnpfVU9L/KeU6XjDXav1FE
7HTEB+i/4NVLye1Z77/m//vzHO/yP6Q+odLXr4O/lshMClf/8b/2a6Nqtf3Q
v3KUXanoEPA/r1ILrHHi7j9LdGN7IuLyv8LmTkG4/sK/kePT14lj8j+ZPmbp
oiLZP7kiMUMS1O2/q1j5XGMp9D+If59f45vRP/03MMsctuo//ogBBrIg8L+x
8E+gprvCv+lfNHv/Yda/cGfBSmWZ678tortxls3kP8/21aZZcJU/FkVocMXr
7b+6xUnnngezv6aGOSbL4+A/WDcMu8Rg6z+ss+FdZ7Dkv8zC/tJ0TLm/kXHa
vBVT7j8YQW1fj+nBP7wZnWeBZ9+/VvP/oHcM8D8NBE2rn8W0P/pAxKatItk/
0qPCdA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.03977244140280435, -1.6583709165937601`, 
     2.9449319272100047`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHoNGZzTN57/XoEdMfgLBPwm0z12q
vZ0/si+tQZjV5z8+0GwbA1fAv5nzvFj1v5q/NaSx+HQy9L/MVMPNDVnbv8vu
Fv6bJ+i/B8lPRGiy7r+TkNlzIi7zP1qy3NcfQ7a/j7loSM5l8r+WNVLazFfJ
v+IXVfKlr+8//HXlPzE67j+UbLfLNyPzvydUG2rPXcO/wHKkts//8j9RCGU/
jffYPyfg9E0wQey/qmxbFF3Q8z8bBRqy/hfNPxc0jFIQQew/4nIqlocM8L9h
hJ+nztfCvypxKKuuOde/EibLVc4/67+uhGI9ck7lP6+K0YBqp52/HvsLfGhM
7r98KRUcnaqgv8HKoaLJTuA/11LJwOQH6z+cBiUvGC7lv5ryMhXOtba/mQp7
15vq7j8yoK6xC8zAP8THuvgvF92/gwQyNSm77z+4aVot94GpP3pMxqcQa9s/
Rs+z+g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.14957163507466617`, -1.623380344457142, 
     2.960855380326993}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAZsQByUuk579Xs3AZjI3EP0MJlBbU
z4+/FRXdkfWt5z+Gp4n3BszDv/cAjid7Y5M/ZBmac8DM879TfTzAKHfav2MG
uBkjrOm/2Hsaxf8e7b+zM5fSeabzP2gwGD2558a/U+GPF65K87/nHHi3Kxm/
v3NLPiVy4O0/T/rIApMi7T942DVHBJTzv/lmrx05/sG/o4DlDOYb9D+G2ICz
9SPYP/rdZkMKKum/0j/j7+n08j97nTily93CP8kFLBFbE+8/l/saWOae77+n
I4SzYjDAv4hWEmpiK9q/HyAOx6Vh6r8eSsVVKzjmP/xwgX625Li/hsMQ/NMc
77+Qk9L22AOUP07749QyYd0/sgdTSkRo6j9oDScmhQ3mv7RNe3GTI6+/LgvU
1eDy7z+ECXhv5Hu8P/NtKmrujti/XMrRuOTL7j+AQSFKasdtv9B1aOp2rt8/
7lm1hA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.3812366236282519, -1.6185284782456857`, 
     2.9426899602085563`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAnDgEas1x5r90NHAKsPjRPwHB+++F
vKG/jzt2Au155j8X5NzIGcLRv5AGjMra6KQ/AIfsXMRw8b8sjhq02DrLPxDw
Fus24vC/Adpqrkpt579H5sN2jSH1P0Vres9qUtM/o1CXzH/39b+U6ERXXpTT
v8eu1E6ROOM/jP4EekIx6j8wlQFdfP/xv/LJSlrQh+S/X0KNq2TP9j9e9K95
euneP08WrH5bXNG/CRWkgadl7j/WJGJHsdjiv7DMf9vv8vA/TqPuEaup7L+K
e31kHJbPPxjOlhobcOG/Tok3DIzv5r9k8195uZ/pPyXzehHaGsE/eLbMQDOY
8L8AQkvN5LqJv7fy1O/IHNI/Dp09vpdV6D82zjjPAnDmv4kJoq1COdO/EzBk
li0G8T+MIKZhwU66P/oqtUqAfr2/TCgNQspv6j/iltArvrnbv+Us1LE2muE/
6e24Mg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1321505430373722`, 
     2.726056777995848, -1.6465872558243244`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATVhE+3Vo4r/AzkWqGGvTP7hqFnJv
uNi/9f4kTBRS4j8kwZFcy0fTv0b/KQfhFdk//w9VhEEk1b8YrxFXjHbXP5Im
6n2sNve/QuvVJyim6r9v4YV2Trz0Px+XGeBJy3u/voY+kU9f97+lRHus2HjV
v04/mE6MfNO/Xi15I5kt8j/hfexKhgjwvxFUGHnonM2/KXQUsm1f9D80U8AA
Iu/eP0f/1XtgROY/SHBB6u/Myz+tyHuIoe/pv6ifIS2rq/Q/TOBuvZb63L/s
vquA0nDVP0DBb1rIZO2/yCGNEU+H5r8fVRehFJfpPxTRlpmcJ8m/cllwR8VJ
8L8gr6sRAG6QvwNVV+B9Gta/2KyLSaNW6z8q7hAiedrkv3yqO5XZjrQ/pPMm
2HeI7T8gJF1IrU63P3V/tX+oZ+E/B1u1RlBF2T+gVGKbw8nhv3of7G4j8eo/
Z0ix3A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.6822183917042866`, 2.916663387316241, -0.2959999454405246}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/Xn3UtW44L8zd81Jd5DYP39hGLPl
8ti/MGG1aRas4D9UK0W4LGPYv96a3+j4QNk/CDNL85Wp178A3FdeYl3QP6If
MWy2c/e/ihy2xwFE4L9d+8+xWCr3P6cQFYHbuMG/cw9KHjxU+L9ZX9wWf85+
v3yuM8FYRsW/Amw0wLMo7T9NgVMtF3zzvyDlUJN2rMi/FrHie0D49T8zpE+1
uD/RP+3k/A5oxeM/6tg2ynimvT8wvyaSGATovwBDstfycvU/gROdTKCN3L+a
qRLU7HbUPwI499hvsO2/RMtWjWt+4L8qWUOEdk7tP+l00bmp59C/OebiY1NY
8L+2BXJNPRXIP14c2QkJy9G/meb0FGXq5j8izGRb4pTpv5xQbj571bk/rmG9
sEtO7j+AHNYL0I2svy5ZtkHyMuA/TTz8guVg1D9tqiR31xriv7gp6hExw+s/
y121BQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.238332650245279, 2.4385790057092698`, -0.6838123863750435}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAqlh78u944L/+2+iP/QjZP8lDYyj3
KNm/OHhSxQZv4D8aYVE9nebYv1yjdqW5ZNk/nWODU0tF2L+M5XQVHwbOP08U
G61ge/e/7GuNdQCc3b+41XZIe1v3P1XH+q7LbsW/7zg/bulb+L+pTWoVkfGj
P5vSqWw4DcO/hqHoL3nq7T/cMysxzCvzvwPT19poksq/5RDDNhiS9T+fw0m7
l9nQP3KKVmZ/k+U/7YV+1sEdtT/0Xf/A+p3pv8mJON99BPU/eAo9nJWb3L9i
p1GNBgbUP0LlM3eexe2/oA5CLfBG37+3DHGsup3tP7pT8H8u8NG/onK+szBM
8L+zJZayL4fLP4sWXK/JV9G/34yd+r8s5z8ijH+Ac2Xpv7RzFXAKN7g/AU1s
mZvJ7T/4Og8ECxqwvxDuiBzuIuE/9kgiAL8S0z9AB9SvpAjjv6AylkisXes/
RzO07g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.268477816287621, 2.422308536287064, -0.6409600237470113}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzky4yR4g4L8CtL+PcrfZP6E9zDng
Ytm/U81FGq0Z4D+EWWeRCKHZvzWYaybJidk/+8+vHaTx2L81SSkyym7LP753
dSnVf/e/QuWaLX6y2b8/Ma1GMJH3P+x0d1xVw8m/YobSO1hb+L+7vx/zLQ+6
P3UbCFGVdcC/q1J5VkBb7j/5+RQD8/ryv1/Z//Dz+8u/MOlnxOUp9T/RmpXA
LWXPP46MZRtGZec/gsEpeHUCpj9B6TP2ki7rvx3NKJoTivQ/zDSQ2PCY3L9O
LGrUa7fTPyaH6DeN2O2/b7+F4F353L8/Hp3qDP/tPwz8A3RFItO/ZFZX0LM1
8L/40UMGnx3QP64lKHHVztC//49fuHY65z9a0G4nNWPpvwxX11ueF7c/2s+K
Ubw27T84GDli49yzv1SsTVcVFeI/a2nIcdR50T8Cy3Ofi//jvyqzw+OF7Oo/
RUC2ow==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.320003137206787, 2.38267231651475, -0.6040348296786365}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAFTbyaS0P4L+oKMXtes7ZP4rAfXrj
edm/1sWQfhMM4D+f5QIvIcPZv6mUMu4pjdk/AGuhHDMr27+W2iOoGivGP6UE
PtYmcfe/AamJA6KK1r/Iw0aA1KD3P0GjAf2EFtC/Hb5Xmgda+L+8Y6ehIOrD
Px1mrItzUba/h8ideEsA7z/8ImrvA7Xyvzz69OI4+cy/4UjWQNjX9D9W3yKJ
DHPPP6l3U9bjmOg/lKxe/fNCnD+0iZmqXz/sv5HnPsjCKfQ/letC+Mak3b/6
iusgBHLSP8d03bSfz+2/lgq3a35U27/yDbg7cxTuP+axvzs0yNS/lGyoJ88w
8L9DbUyfxeHRPxHaaF1ADs+/LkeXey+G5z9k3Co7zCXpvxQvcPkaIbY/zKse
AOLd7D/o6+LUNRO0v/9gtma8r+I/Ort7Hivu0D9Cfg0heJDkv7yMy0MNjeo/
plK3VA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.345903034788885, 2.3505784331770303`, -0.6292217263026727}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAR+vXuXxb3b8uelLWYnLRP4aI28GH
LuG/CXZZT1hY3T+vRBQsLG/Rv4YUrPivMOE/DvN9LjlIw78JLt/woGy0v1UV
t9Pmavi/1Mdcj6MS3b+i4RnWxN31PypBGYWEOOG/MJxxkwnL97+/C1VMLk6w
v/XTwt0rv9e/6pwtNTfq8j/Ht+M2Kynvv+Dl1YfPU7w/UO9YfjRa8D+qvOPj
wDzhP1qZu5SKJfA/ByD6apCuvL+0AKp7YDnpv+/JeEoYC/U/Z3KLqMx/079Y
XTU0da64P8xsUloVgfC/jlmaJBA33b8tgK6LXTrqP9hkeiOGM+G/Apfnwegh
7798bnqGrr26P4DyvLAdDt2/bPoDSU1A6j8Q7XamYPDjv0LRpukpu9Q/0kwv
kkqw5z+mNLObVQrBP52jEZHiveg/CO6aNLQsxj+GEdpIe/jgvzLUzkZwo+0/
Dz+1kg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.0697684925130178`, 
     2.6336182666891386`, -0.45223137082878667`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAB04WrM4l3b/bOzNP4MDRP5nB4w+b
MeG/r4u+lc4l3T/vpe864MDRv5ELgPSaMeE/fmB6ePJMx7//OjLNdkG+v2KT
l1s5U/i/p0/LfGDL2L+eCfQGuOb1P1e2TIZMg+K/RHqE+1D297+WJO/2WS6B
P4d860Dkv9W/fu2usOYi8z+znF9JK6Tuv5s3MMAdALs/5Rl5rFmz7z/FaoSz
c/HgP7XAc86UwfA/TPYCJ8Kcvr81xmHFQpfqvzqBmfdBk/Q/I78p9CNm1L82
Ws03BWG0Pxe6xHEDdvC/185wlJf42r+U2MAa8FbqP/g7GMtz2uG/xg2KpsQ/
778AteoeU0rCP9x/WTCNEdy/apAeVlps6j/Wt2uzTcLjv4QShqyekdQ/3i+s
eyAj5z+aLxksByLAP37Gs0hiWuk/HM79C55+xT+WzGxx2bvhvwKH2XEPLO0/
zH+4ww==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.6674233470295085, 2.6795414804749638`, 1.949103263106899}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAavT96pKw3b/sa+bjZxHRP1L6F4NQ
IuG/Mm8SH4Ct3T/27W8+HA7RvyF//Al3JOE/jT4uS9HPzL/dG1cvYvnFv+Hx
tB75Jfi/qQZ3k2Ae17+TXxD3SKT1P0oIN2z/D+S/684vjxkg+L8nfcGbKKOl
PwmfffnrBNO/ZMtmOTu88z8T1x049RntvwLj6RF5D7k/5gV5SEuJ7j+jsGXB
yqPhP+d5KlLsJvE/oFplgQXnt7/uygf95q/rv6Qe2pE8NvQ/2IlKyD0M1r/4
d+sw21KoP4V3ILCQW/C/in06v3ln2r+O+gnwoujpP06Bp/cnmeK/BUzvST6M
77+Rm173zMXDP9bJ1n/GpNq/MGcrQZsn6z8H56qrgdDiv4G7OSxmRtQ/wB4B
rAWw5j9Qc1tEeTnCP3i5KNcnuek/ihi5vr6zxz/04B+OehvivzRe2BZ4yOw/
S/q2PQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.0960075536491747`, 
     2.6045330798082444`, -0.4975537872734799}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAIzi2PkG83r/FJpU4rz3QP6CBdwBV
3uC/kzspbDmv3j8H3WYR6jPQvyCbZUWa5uA/bp6NuWPSyb+A8yrKDMq+vyE5
6TMZRvi/Up/A8T7Y3L/AeFKq8o31PyhBdWPkY+K/wgtZF1Ae+L/UpaF/Ooyp
vyZxdPxUjdO/ylMG18mF9T/YELKnypTnv8m+EhP5xLA/OfqUgQlq6j+FuHw0
zvThP/hdV7d6vfI/tXrziTFwhL8KbWL0Ygfwv+UAJ59zjfI/rYO+jbnS1b/K
0xQMWBaxP/h8EtqhWvC/ums7GEDK3b9ywnd4Xp3pP2Rh9rEcoeG/ypkGZ2DN
778U5EHRTxi6PzO6sX7/pNq/rqIQMpgx7T9cf2Wwv67fv/nyx2c5/9I/AczU
G9Pg5D8ClJJXsrXDP4grCtrHMOs/vZ/Z37cLzj9MJLx4XRTkv3XO2cHAAOs/
3gS5SQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8156403561119783`, 
     2.8402183067071003`, -0.24700216092864502`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAaL+hWzKs3r9ppMb7fGTQP67u+yfz
2uC/fXrvhPeR3j9gF6n+1lDQv6sVILeY6+A/aEQD9Bf9zL+YvJAB+27Dv9gX
tPOjKfi/GllXs8QB2r/6uo0AL4j1P2ZHBaVpauO/VAqnPjI5+L/w8dVNHzFK
P5jvNzI6A9K/R44zyLDS9T+iaOXpm2fmv3YDi7qM/7A/MGLTi8QY6T/Z2M5w
wHbhP7fNPKJ2UvM/s/3Ra9VAKD+cQ4BhEarwv4fHsgLl9PE/zrDRKl+V1r90
GPnr/bOqP5gH2cOOS/C/QYx8h/tW3L8UZH8/TqHpPwqbgGauIuK/LnqP1T7k
779ij22LlXHAP3rmF0GQ3Nm/5mxvqS537T9S9DlpB5Devxp2cU6KC9M/t48l
J+Aw5D9SmvTiqZzCP4zYzP1CyOs/vfScn/+Uzj90iSohR77kv1zSQl6xauo/
JoC9Kw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.827785325827179, 
     2.8336739761174465`, -0.23214779724471674`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGLGh1IXO3r9F8ChVlEDQPzqOOfx/
0uC/CZQVIlWm3j8raKmQTSLQv3eX2yQQ7OA/gSaxI7Z80L8rgQeS3HzIv5yY
qVe0//e/vitmlzvn178YThDrtWX1P/uk3iMOlOS/MrxvOpFN+L/5SeDxd1ul
P5wtwAgTOtC/K0tvBdwl9j+DK+65XQnlvz4Zw7zeFLE/r9+2PJDw5z8fAybA
Hj/hP0XgtvTxvvM/GCsoy2mdlD+o+BgnaCPxv6mBWhw4e/E/zGsp/J2l17/A
vpQwmAigP9wv4yp6NPC/a+4DtuBa278qiloA23XpP5oZDBBHs+K/PBTMV5kA
8L+E+WRTA+zCPwilmYCJ79i/LrD0TXHP7T+Y30KChBrdv5/6c/yrDtM/2tTg
Zt2h4z8SnqLv71vCPwCsJAf6NOw/uhbIvivwzz+yUkOL+yvlv2RNyC5A8ek/
YD+zTA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.826095351531008, 
     2.8338825902130154`, -0.24266279484999417`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATFV84Mzd3r9bbk5uhS/QP/HxzyAZ
zuC/znBvADGp3j/Z/ACd/wfQv6CnV/OD7+A/JwcDWXdJ0r8o3DkLDu3MvwGx
BzPd0/e/Uyyx1PL91b9ddNWIU0L1P3k7c0muneW/V2w4/qBW+L9xQAgL1W+0
P96kKMa3m82/o7phMdtz9j+wbU7oXqLjv5cLfwIEyLE/SkGQKKDB5j+Bg+Ue
AuvgP3BM9l6BKvQ/PmWzI+YepD+ebjwC4pnxv+rsiS10/vA/Oq6/HKKT2L9w
BBiL5o+LP/3Ut+F0HfC/0MCW2t9t2r/0D2nkNE7pP7WWIbXjNeO/1cArGwoH
8L93fhCxekvFPygbWhIHNdi/1pZ9cSce7j8c7M62XqbbvxOJp3OEKNM/2Pxj
VBwL4z8qCsqgBM7BP0AgolhDouw/u+5y4oaW0D/UrXzp4Zvlv7rANSc2duk/
1X60GQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8213127223170156`, 
     2.8368523025521375`, -0.2439036306224676}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHfRSlcsc37+ZDMqXR4bPPyhyGfRf
yeC/H0XeJXLf3j8bt+sOlynPvxmZudZU8OA/y+PNA1tr1L+X7dJwo1nRv659
VRM7lve/tCRwHa7M1L/UuMJtSwD1P1DKVdX53ea/XVp43ppd+L9fcufwcaW7
P+ACSWCAWcq/bB0olWvG9j83ckpVkgXiv7NzbAJLVLI/VDvmGpS75T8+AJjJ
ffDgP3XQeYcVcPQ/LA+JUt1rsT9i0V1WReXxv0x4fkaTp/A/9GuQTBPE2b+w
dN5O+meJv8I2Yg3r+u+/aIxh2bz02b9n+rtgFPHoPzyet+Ss0+O/sovm4WYS
8L/k4h5IgKzGP+CyKwzAX9e/tK6fHkh+7j/+XwUZ+M/Zv5AnBzfeOtM/8q7q
lqaV4j/vJLoLMEzCPwKd1vI/6Ow/dURAvTSd0T9FSDs4eMrlv9hE27G9H+k/
KPe5tw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8023645037145133`, 
     2.8462118013761573`, -0.2737892939050491}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAS6N/2lFV378qkbYJBNbOP57/lwBA
wuC/tDTHZi0U3z9AqHYmG3POv8y0CWat6+A/bVdqRGmU1r9WGAIUsADUv7AH
tYaTUve/sSJi7PK107+EOLrAlL70PyOMIsNDBei/l5tFR0de+L9lfByJiG7B
P8E1CS/cUse/+MgAzd0P9z8Lp382WHHgv9MyFXbNtrI/uGxyO7jK5D9v4zfK
KNvgP5uk90fhr/Q/A6K5rNe+uD8zKKANfy3yv7ZCewGMT/A/XP10j9302r8I
P5s8uFaiv38HAYezs++//uJwY6KF2b+qCvFBVZnoP+BF3eHBY+S/NcLy3s0Z
8L/IhmlJRiLIPw5NWgz3lta/JZayJunU7j8bUR0AHw7YvyZbzBSHQtM/iQNr
d2cq4j++cjQBxHzCPwF//Pq3Je0/ms76qPGh0j87/W5y4vvlvxwdgLRixeg/
c4WySg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.7845630313499794`, 2.854689789140926, -0.3008005899487306}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAyOB9lzqx3786ELwZPK3NP+biDC9l
t+C/glA4Bqlx3z/n+hmOpk3Nv/zPJE/B3+A/JLBqXqCu2L+8ryhTR7/Wv3PY
G4R2Bve/VZg2chxy07+O4ZMEfG/0P/VMWgXmIOm/raJLfFtf+L/VFMtMAWfD
P3Xkl6KUTcS/gqoHoEBh9z9hcV0lbwHdv6lyI6bJwrI/p6Q2qJPT4z/rtJ6t
A+TgP5P4GawA5vQ/b/0IriRjwT9+I87yImryv+3r8lOB9O8/dkj0eu0v3L94
nioZpaKvv+ZJohspYu+/jjzahKuR2b+WY8uHIyXoP+6XM5ol7OS/cI0VEdUl
8L+IkkOzHorIPwPcslfKytW/or6V4ao97z9qNzU2IdTVv1E+6YMaONM/dGap
FTTG4T9jbDAUNCHDP5FgrFPhVe0/nWeerp0R1D/bYpHE1xPmv/Tdi1Ehaug/
Xou1Eg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.7435135179845498`, 
     2.876726345905426, -0.33016078413214167`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAmY23v9Iu4b95vFgRwWTNPwRgLyUD
vd6/3X3r0qQQ4T88GQArBzzNvz5r+D2ZCd8/Da8LKPM92L9sm5De0h3Lv0rO
ULFUgPe/tI33vTju379ukzxTRhP1P6SQ/5PWJOO/pQ1Jgn2F+L8Od7S6cdul
v1GPPPgQdb6/FL50xINY+D9DqHhzrDvGv9Xp3DZBL5M/KG2bfQfr4D9ksE4O
SGjYP7P4vvjbSPY/LW4okF9G1z86fv31Y1j0v/+XlNikoug/IGW9U8xN3b9w
CEGWcTeCP0umnHqVL++/OqpZj/eS4L/9qmd13r/oP1OgSxOsQeG/OWoScXOO
8L+2nqui5O23P+xBn7EjLdO/gT71Fmtw8D/AYDzP2bvJv+4cs6hGHtA/gnVD
KNb94D+MR53xiJSzP4ITPUhCC+4/9LT/mtSz3D9hgV3b5P/nv89myLu4E+Q/
ZmW3fQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.245328058769693, 3.1387849531603607`, 0.1469253002549984}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAegeWUkk24b/Vg028xvjMP5KnZatx
xN6//Aa0Ndwg4T9ApMvhSMzMvyq+ni2A/t4/InwaYkXB3b9eQOGSH9DUv0cR
CIf/w/a/1GmAzw3s2r8nn2XZYKX0P7y8/KUrrOa/j7YTrLaJ+L+B54A/PKuy
P3K5X83GK6y/+GLdy/1A+D/QGHq23jTMv6zyFVa5MFC/LbXx1qk44j9x8OzE
/l3bP2v+07kOyPU/w3DHEr2J1T8wjdoogPLzvxiCTpPaUeo/xqLRAXYL4L/M
+enS8E6pvyx74fEbde6/ZDxWOlCs3r+hT++weUToP0LI1z0yB+O/Jl2vqm2S
8L/L+wZuMifDP2DPiEL1JNG/O7Nb87Vo8D+I3iLMk4DMvzeoSHRP7s4/FN5S
BsOs4T+gPA6otO+5P/atO8Wuh+0/Xr8Xv7rl2z+4ARRFCYznv5bwDlWN6OQ/
Hdy/2Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.4227949974249705`, 
     3.0634569121063864`, -0.12363714235649467`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAdbknwWJN4b8MaJCY3vjLP8/z1EHk
yt6/23m1mINB4T+mtu3hPeDLv2rmPTsO694/3hl1TxqT379huYcvlpvXv1Yb
JZuIcva/X38PXh2A2r8WQDwTDF70P8YZuR/Y1ee/MlBZ1TyB+L9vFJINgGq3
P6G+sMvYHaK/zFEfWWBf+D8jCSS5DCfFv4tXR7P6tH8/MQ8k7ENx4T+dhrZP
QOPaP11cZw+i8vU/rJh769/P1z8q5En20AT0vya/WZwDqOk/MiNx9HeL4L+4
Cn/GTT6zv0pYmqtBJe6/JHkvcHGN3r8XTU7mJ93nP9fJUSClneO/dpb2GveT
8L8iuaxPD9fDP9KFpa1Ph9C/XQe9EhGA8D/k34hNpYPIv8gDCybiac8/hsRs
wmNZ4T+UVn+9Qua5P/jVNp5lre0/MUZzjnMp3T/+moey2IDnvy5Z/FzFjuQ/
oe6z+Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.390202550062198, 3.077125614920644, -0.15177226294620422`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmII6UuLflZMGj/Xpaky0W/zlgH74tsWyG6r39Nj9W
bAWK2/d23WMDiu/vnlxpDxS3j3p661u/2aP95qFlFyeufLRfqH5LssCxL/vn
VZxwd7d+sL8wrOfZc5dP9vHb5q/Mzn6zf9sib7/Uhh/7tXVletPLltpLmOyx
eCy5xp7r5PN4oLj9+YSzqUDx/TvYBHY/kVyz/+aN9G1A8+1nsbXITVr5yJ6r
Py4UaL69+OZCP6D59k+s/74Dmr8/iyvrCNB8+1t1d66uCX60P0x0MdulK2f2
r3jj01jm/2Z/jUdwHUfYw/3bds/zrUl5Yn/UI+OT9P6n+wvDY0VS73zYX2l6
S9o2apv9FX0v/phFp/ZPUYqTBYrbH3wU+MAmatv+LZPEV0QvOmXflcGxDWi+
/dvjM3YCzbd/89kmFWi+/apQ3iag+famvDf9gebvl8gSBplvDwCFobPC
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.8969838528865911, 2.680938979738597, 1.85267000693024}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAjAqZC5HY4b8ItJgJZJXDPwDBwScl
K9+/jgyzFIjm4T8FVVq4K7HDv+vftkWnBt8/P5SEgU7X4L9PSZ1hHxXhv8C7
hfKwaPW/FzNOLddi3r9Xl5GARNjyPxulICn1ieu/Ss5Qgcx8+L9QfJ9+762l
P8perWMVjVw/iTPTHQ6I+D+PB14aU+qgP2D+P0GN/5Y/kaWAYYuh3j9sxNBx
R8XePzXS5Ff69fU/q+yaD3qT4D9cFJWlTzDzv3rWTCVeu+k/Zs+Oxu9X4b+a
OG6+jF/IvwAsdjx6M+2/DBIgUf6E4L/YrcQB8UrlP87CgN7Dj+W/yKmOg4q0
8L8ck0Dp3wC5P6ETXhKYDs+/6FwWFKm98D9CpoXjLe2uv+hv5QxQO9A/q6+5
4qab4D/pmaOVsezEPzCKUimkt+0/nPwmEgE94T/8XqAcdablvzgjFORYn+Q/
/h2zxA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9664480244747824`, -0.9779941318188181, -2.5692430101427113`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA+qwIc8WF4b9ETdZrOa7HPylRj6EM
Mt+/sME/jc2i4T81EEU8+uTHvwAZVMrO5d4/zrP0JIir4b8DT3FKFNDfv/7x
iWJTfPW/ieTBmaOz2r9fg4fLf1fzP8QN9iWYLuu/bPwHKzRm+L9grN6+0UO9
PzFaMWpp+Ne+/IgIRICI+D8b0NmYWaWhPzcG6fTQ7as/vF96clwC3T8z9Bms
8AXZP00faULog/Y/tXyvVosi4D/ixQaNhv/zvxuZXAm8huc/ZLD+y6aY4b9g
KIaU9/jDv0jG7YrWSO2/Pp/pP5ff3r8HTQL5Rk3mPyzbXjvPY+W/dClGcouU
8L+60aIlESjDP1q7+JkkMs+/6jRUhfOs8D8unA7Wo3uzv+SceHTEMdE/x3g+
4/0R4D8y2O4b5ya6P40l/vRbPe4/Mp/3cazi4D/oZ4/UJfzmv85SQ7fRfOM/
7VW79A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9690884101162824`, -0.9284328550772332, -2.585556664774312}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkeNIktNi4b/d2ygyT3/IP5Oq1hBv
Wd+/3Np4LhuP4T8PORmuS9PIv7zPEQZc5d4/KfYAOHeN4r9ZrvLgpmngv/pr
Mm2IOPW/x8ome16f2L9K2qC5ETzzPxXmkxk1Cey/4uXgFWRN+L8o9WRWnb/E
P2MMLOnHmHc/CenAuhCF+D9IaY7NqkyvPxO686us3LM/AI6f4Ht42z+SY1o5
3rHWP9UzxpJbwvY/WtSjiUeF4D9nXacjjzv0v3YcH/nQhOY/3ewkZSX44b/D
7tAoppPEv54WaDHkDu2/9Ejcz4Ky3b/F9eWf+0vmP6+d/1D22uW/1auC72Z/
8L+C6EZEdp/GP2H6MfEL+86/PKv+KE+m8D++nrX6IACxvyBfh5hD7tE/3KHI
HllL3z8WjpvEcJC0P8SnSpSye+4/m1cOXDEK4T+JhGqZ+FXnvyoCFH6/++I/
hRu8Dw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9703328171418877`, -0.9343041568932107, -2.5824918842284443`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAt1uda7I34r+8vu6wJD2+P3w3WgC6
8t6/Z34e9ZRy4j8TQC3evxG/v05+BQeKWN4/XGMqc8Tw4r/aFkbKx/Dkv1S5
973UIPS/ltFbUcdl37+OVwiMdaTxP1ia16mXfu6/tQP2NSth+L92I4Jq/F+x
P/gwyZDsz6k/ZGUMnQVI+D/g8AMjM0nOP9IAww0Gl6c/5ibVGzNv2j+w2m1c
4bzbPyZRkGOndfY/TnuNIHdj5T8kvaJQJu3yv5kXCfyaC+c/it9jbzuU4r8D
Pyg0IynRvzNHDj6D3eu/QaIlCkv14L96QxfXR4jjPwtbAlX6++a/yFjiNYK+
8L8ZcbiNkM63P1wRQW68uMu/TNLNC6jA8D+uodpnpoCtPzTvXmS1pdA/2hEJ
gy6q3z+qiuJkcfjDP7qwUeXJC+4/2vzVCgbr4z8lkYVOQt7kv2Drxf/vG+M/
IJ6yyw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.978752901382878, 0.8930537541357196, 2.5906354331501253`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzLdYMocl4r+++W1h6LW/P2gHJaGd
CN+/U4DaPrFs4j9uKP/qYFvAv1yh70IJTt4/+pYTAind478bAc1H1mPlv5yb
Gi4FzfO/oNe08WeS3b/zt1w6Nn/xP/s9PdC0Ve+/68pTPx9Q+L9kHiZMSKi9
P/kzaGVUNaw/UbaDz/wz+D+qSRUDnwbRP0sGqaMqfLE/HAjYm8M72T+OMS5g
zRPZP/cW2rCEuPY/QAdu6pX55T/ktC33XB7zv6dprikl6eU/Yyc2GlgB47/k
QZ87GW3Rv3bdY5Ysj+u/zpGZlV134L+Pl3PAlHrjP9jgZ9ABbee/aBNAbHGx
8L8RDMpWGK++P+gAeBTzgcu/PXt4tyq18D/maisb3bGxP3jx7PWJVtE/YYTG
DJMK3z9Wna7qHObAP07/lQEHTO4/ykOklCMz5D/ymY0UySnlvyodk+UUiOI/
YuWvSw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.977315781861854, 0.8920812559872141, 2.5920673856048415`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKQGnIEw24r9hGjqk+oy9P/0kN8OY
Bt+/rSx5pluG4j8rv2noOK6+v7wnQc+tNN4/GXp9Yjqr5L9Yren6FI7mv8fR
qzLiRvO/NYhP7OkI3b/PK8objgTxP/wwP7h9RfC/S0oL10FC+L/ZZTpt5nLC
P/4M/IZzbrA/MEwUxZ0K+D932uHTXlnUP6sPK0S36bQ/SgChGNwY2D800J/s
E7fXP3TqWOzd4PY/wja+1HlC5z91VEcS6f3yvwtfW+jzFOU/oT2SQcNw478M
amKmddzSvwabeWOICOu/omJni2Bd4L91zQ3GXd3iPzz6DOkjB+i/cGWv87Ou
8L+FuavfsZzAP74heOH76sq/Q3EozOWm8D9Z1Y4zoVu5P9T1JdCNt9E/0qzJ
ssmS3j9qYIWyhQvAP2M0KWAJbu4/uLGbvWrk5D9n8M2gzOjkv3T5/WelF+I/
yVe5hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9770970439290763`, 0.8928765902800303, 
     2.5919603919459906`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA08w+9M084r8Temr245+8P0dYluyN
CN+/HzC7bPiQ4j9ioehof8+9v9tPkb/+K94/WnxC3QWC5b+NmTS9rGfnv7Pm
xLOAy/K/7HKIBYn9279dMVsZspnwP/QdDMw70/C/SQzQNdUw+L93Y4/epUjH
P+2T3xTkr7E/Ay7EEore9z/tsSQnlifXP0GGMQFDxLk/w2+qAwDt1j8940lT
6qbVPxMKOVTAFPc/EX8aFrZa6D8v1nO4lu/yvzlqkdW6E+Q/lqTA6Gnf479K
Smc+sNPTv8R86i6kjeq/JIOBO8kd4L/+2MFYsGPiPwa0MUdflei/Wbn3F56n
8L9AUOLsS8zCP0xzXueUnMq/CeOQJIOT8D8qE9WZbGe/P7bY7r+HTtI/AGiQ
bngH3j/KdR/yFGa8PwpeHQTAn+4/mNdqQdd15T9FYAKvjszkvxMJrRrdlOE/
PVC2Hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9779606819850422`, 0.8918818119571635, 
     2.5916439520160313`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQWfGy0Q44r+lZQx8CFy9PwxcbY2G
C9+/5KR+U0eK4j/DKR9GeYO+v1MezWmYNN4/DscPLA9z5r+N1yckl9vnvw/e
klF2X/K/MBfy0lpP2r/UKHqgfUXwP3hqWkXoUPG/VX/5FmgX+L9keVIK0L/N
P6K8Rg9LBLI/36tjGNm09z9hY1VodDvZP2SGdIdxI8A/AKsYbDK61T9B96Se
orzSP3zPURomU/c/HZA9v74w6T8LOjufOvvyv0gr4hGC3OI/KBfr+6lV5L/Z
SqYUFjDUvxI17vRXIuq/2XI/NfJf378u7zooPhviP3vBtejJE+m/e1luPsWZ
8L8bViwk6jbGP+Ssm8lzisq/KH8RYf588D/wmM0WlprBP8Kww5YoI9M/ZPqK
iWBn3T+hWTqaiDe2PxAXxTRM4O4/gBpeCYPd5T+nLJ0zcuPkvzldZCNn++A/
Qc+pJA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9780309537088736`, 0.8908182918033151, 2.591956079326613}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQgQFdyI84r89W6aDWC6+P2MdpD/F
+N6/wbrEwuCE4j/O9sbr7yi/v7GTICRTOt4/u46t81E9579DgSIy8Bvov/tU
E0AOCfK/PvUtygj82L+tISAR7/3vP+G5EHOVr/G/9aWXBBUA+L/wM9e3/J7R
P8GAZN5YZrI/Bmt8Mtx49z+uDhTyoM3bP0Fkiq7VKcQ/w0RJXHFh1D/jKlJc
WuLNP/UNCzrkmPc/EVZk7VBQ6j+UIW+JyPjyv6WrJUN3R+E/fklZNbq85L/c
ta0hJVbUv1Rc/I8/x+m/4f4b3Ca63r+KdsoQ3eHhPzrB+cLGbem/CxQNIBOP
8L/AysDYkirJPzL9CggvX8q/M2TvSaZd8D/7UCL3ZAPEP+nisv2eJ9Q/Il3p
cJm13D/4Xt3MxJusP+IyEwN5J+8/aYgU2Jhq5j8BkSuIV+vkv7/6mmpQMuA/
PBq1Cw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9851613028017856`, -0.8548328303463973, -2.598614137193186}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkfeIFqxc4r+bGhK/b/G7P9ALzXe1
z96/2/c4otmT4j9/ix/FmbC8v8swricZP94/Vk6HrQsb6L9mXZiAvh3pv1L7
UxrjYfG/czzSdHpI2L81OCpvZJjuP6AREKoJVfK/ZIhIunLp979XtT6dPi7U
PxNKFH677bI/eOFFFZwu9z8+XF8mIPTePyOJ24hrY8Y/iwZ0o+WA0z8KqHvx
55bJP4wew0sKw/c/82bZvlW96z/jVGzg1Kzyv9Ts+JGAOeA/9CII4ts75b8S
GraIkJ/Vv0Y+R3jQFem/yhXyUOmA3r/EPYYzSQvhP5RUAwj3COq/FoLGYuSL
8L/+OwONmirLP0z5R5hGFMq/sy4xc0Q88D9eeRe1+cfHP676DXZnuNQ/IPvy
c0xU3D+WxNcdNn2mP76qrpXQUu8/Zy+JsJco5z+bTb583nfkvzoF0CUNWd8/
C/uxkw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9831952277478089`, -0.8588529176922721, -2.598789786498667}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABDvAp0JW4r9F/9JFff26P55E4c0C
7t6/W/Qw6hh14j8Pz3Kb0167v0Sff57mnt4/dRkmk/xa6L+xNd7gQJfpv5HT
Vgf2GfG/uzvO1L4U1780BTgS07ftP73ABSfMv/K/bLSYytTd9793R9BEWBTW
P/2OYIORhK8/aPlj7hnA9j+gc/+STT/hP6xXVahrUcw/nAnFDdx40T+u+sMN
E2TBP2+cMbaiBvg/mUnyVo1F7T/gASzKclvyvxKutqBRgt0/PCpznZ9Y5b/J
1SM4kTfWv7gkz7p21ei/4lgnEqLg3b+OMnldwYvgP+QRftpMe+q/92g8D3uE
8L9IB0WWt9PMP74ydZ1w/cq/lnN8Y6b67z98MyI/5qbLP40lVTnOY9Y/KXkT
8YYx2z84mVQASqWNP0CE0V1cru8/+p6RIFPd5z/RLuMDYBHkv6smmx+cEN4/
kXC05g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-2.0195637418032493`, 0.7968861559336123, 
     2.5905085885352714`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA7JcadUdq4r8AF9EVVL+6P8+ffnIx
wt6/hPSRdEdq4j9FD64rU7+6v+G2u1Ixwt4/Kq02LwJW6b8zBtr8sRTqv1p6
HZOph/C/XwlrcsCp1b/MSBytb3bsP80ojUXwSPO/Z2tkcPm097/vFNHIDpbZ
P83U/V2iPK0/gX7fAddx9j9PTDH5lljiP30rPNVB3M8/fQkrpjad0D968nkc
dmm1P+bU/ZNdLvg/HgQ43Yti7j9hqMRRRRnyv6I2WJE789o/i6Io0iTg5b9T
4x96x7zWv04ive81OOi/nBxQric/3b+sa9YvWs7fP8DQLKJ8+eq/rtt4lQ51
8L9YrSLn8SLQPzblviadGsu/w3govPqm7z/OFHcnWQHOP1DmrB4pWNc/Qnmn
x+K42j8oc9A8dFeFv57CrOjp3u8/UfzkqGlm6D9WiX+EOsXjv8L2CXK22tw/
Ic62cg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.6069546013452312`, 1.8516290067288985`, 2.32670731521082}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA4djBez2B4r9hhhAZafe5P19jw54q
ld6/MVoWnWhg4j+1yw7dOo+5v+ep9YNi6d4//cUroqlE6r8H9Y2YNqDqv3ox
uLKm1e+/77kwANl11L+SQZwWkwjrP2ayI4El0fO/QZdHYUKI97+fI2C1L93c
P9/TuGVRZ6k/D0WA4GQZ9j85cvjWlIPjP6098NDGrNE/MtXKPTa/zz/llcYO
KWehPyR9vpt0TPg/dGpaXViO7z+8hH6eAL/xv9p+a60nkNg/b8/2jvNi5r87
5Gt1SWHXv5TxDAEekOe/2DXa+ym83L9eUr45gEfePz6L1Chwduu/2UGUj3Bk
8L+cItL9hK3RP+RIDHJAaMu/KHILL5lJ7z/DmFZ7rVHQP8rzcqoUS9g/fg+J
LDZQ2j/CgKtVptugv8/zXZ5mA/A/UmI4fWD36D94cU9M9Ffjv2CUsBjFvNs/
CPa2yA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8578347510111645, 3.25193264328275, -0.3368287747649862}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAANB4Z+p+S4r+nlZQhSL+5PxOdiDmA
bN6/cejIfQhT4j+7mb50gvW4v/GPHByMD98/hneafQY567/qdj/Hxvzqv87u
p8fvq+6/HqEK2SU707/k7Hdg86zpPzYwhpGCSPS/Ikb9VIxR978lCyOEzRTg
P/F/hIsIh6Q/tSp0B6LA9T/O0vHVkIfkP1XKlbWqmNM/DdbrG6drzj+6oEBR
NDaTvzhbOaGrYPg/WQxr0o1O8D8505vdCGbxv3nJKDyjKtY/3crZO9Pl5r81
5AzD3cTXv6weNvIX8ea/w26e5jIw3L+Zf6pk3OTcP3pX6J+i4+u/nuoEKW5N
8L/anVWItkzTPxQNGCif28u/7p5YRibq7j+W/1mH4GjRPyMt2WgbVNk/9N3D
RPLt2T/qwQ6JD8Otv5o/IFRHEvA/koBPERJ46T/VvOcEYfXiv7WsIqwXndo/
6ey5rA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8563633964399463, 3.252180336897317, -0.3381786355408894}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA6fyktVGh4r82+jCAhq+5P3VE6b0x
R96/7LXo0KdI4j+x1cJA8JS4vwR8tQK1Kt8/gfGkFfk07L/NVZzKlkLrvw92
J2Sgfe2/282N1DQh0r/slriK1FHoPy74p6LUtfS/C5aA5j8S978W4sxxtqvh
Pzz//TaxNp4/tmPJAqZo9T/Uk7VreXDlP3BvX5iBfdU/kxHUH09tzT9iFAja
E8Cxv/64pHDCaPg/tyw4pw7L8D9xiJLPXgvxv/JGADUZ69M/NfekZSVr57+G
Npb6pQzYvyUMjqGcUOa/1uPrH+yx278ytr5axYfbP0xJIhKhR+y/QIqpYHQx
8L9cAdNBp+HUP4JkearGY8y/rL496/mM7j8eOZ1j213SP7p1ik0bVNo/Ubrd
mPuj2T8KdWUNgiq1vwAMqdi3GfA/rYesj2Lv6T/MtZ7TrZTiv3vh2hvnitk/
WMu8sw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8573893152780458, 
     3.2515740099543757`, -0.34139422935407027`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQxD4ITCv4r/TOs6YPFi5P0Cg+1bZ
Jt6/55waO0VF4j91o1VhHAe4v40PGH/vNt8/XSGcmiEh7b/28Viq9IXrvw9D
enlMTuy/SVF47whT0b8uVshwv/nmP8+Jra95GPW/dbm5EuXS9r+AvJyYOAnj
P1sPuTGXCJM/W8x1A8cJ9T/q04VzRl/mPxSbSBVRWtc/pclNX/nJzD8CD42K
oue9vwn43MteZfg/h38cVSdK8T/MfoSevKTwv9IW9mYTztE/0BhK3ijo57+b
Kj8X7VrYv5gJfJLcsOW/6Di0mbRY27+JHeIDxyTaP99xbAUwouy/y+DakT4V
8L/ag7YrQDTWP0oP4ONP9sy/zhoDoWks7j98H1vnYl7TP1BVMEqgSNs/UA/u
ksN32T88WfF1X/e6v/Z90VWNGfA/+s2p8sls6j8D2ZlkLiXivzATB3OBgtg/
MAaxKg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8506908284373658, 
     3.2529201527482576`, -0.34530507418338874`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA5ltyqhqs4r+nzDYXZz+6P84LlNEG
H96/QPY5GYQ54j+5bXNeU9K4vyyo5e55Rd8/fHOWTWQg7r/DdI4xJnfrv4pn
BJR7Seu/hdY9BJs/0L9Xp24iDt3lP3UDX5QUa/W/cT8i4AmC9r+4dfft4oXk
P/iJZ57DwXk/jmAcql229D8DLblqSvfmP1awGQCyitk/fM8ZqnDdyz/9YZP/
ynrFvwH5SsrGV/g/8fNgRmKp8T9NAM9aAlnwvyzmZ3MDkM8/sWcEfD9m6L8u
m6dOOS/Yv7g2Z35/LOW/KEeRLOjL2r/sgFUF+yTZP2gGxEjW8uy/ZG1bNRfY
779NT97Qz83XP6ZtGsP/t82/rlu5th/T7T9Mv+r+/9zTP0Gsf/cVaNw/H2rA
Q+Aw2T9tjGZX+vHAv4YxAqOSFPA/Ee/9UiTG6j8pN7aQJ+bhv6HNTNS9htc/
6Eu0/A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8620063386076958, 
     3.2508408174898213`, -0.3367180594240052}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAifVlLxSs4r/NaTZMaue5P/Owh0WL
IN6/MEPY7Rw54j9HO3scJ3m4v+VDprmfR98/1Cn5Ks/87r/lYk/3XZvrv8od
VQMmJuq/EVSsLKg1z79A8YdYs5TkPwknjnTzwPW/JxNCkA879r8HeJceParl
P+Ax+kcAuH+/Z9EOMSBU9D8SGaGWk8HnP4lhGiKgets/kFVvaZleyz9FBufL
dLzKvzqxd11OQ/g/b7wFY7QZ8j+iW0j+0OPvv+vXVcYWQMw/ro8vrXHU6L+s
lcitcF7YvyJ7DNM1m+S/jQqROn552r95vg6ioNHXP0YT8EUWSe2/7A31pxmR
779ARR5oKufYP7qZp0Zrn86///L6p65w7T+psRGzbrLUP7dS4O0fYd0/lBg0
SMMQ2T/0URIthHzDvxqh8CWbCvA/B97x2UI26z+F4evwennhv+2XaI7Vs9Y/
tZyy8g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8561107099923615, 3.2518503448217984`, -0.341970447727183}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAn1o8kVKt4r+uvUa8Nhi6P5i4kj2H
F96/+mxsLg5C4j+dxmrS0ry4v6lPS8Y3LN8/s4Jylbn/77/HQ3eusZHrv52J
rOiL8Oi/BTVyBGw3zr+/UoVeyFfjPx1gvCerD/a/EWN8wy3m9b/M3oFeg+Pm
P795txxhDZS/hpPhCncB9D9Vku+UVVPoPwtdDVwcNt0/aVyTD6tUyz9YKYIR
qbLPv+mz2umqJvg/vU9/yI128j+tDDSRsTvvvwRZShZD9sg/qW5XE4ZW6b8S
bO7Wqk7Yv/TyusMn/uO/4OdYki072r90Kg42z5rWP0MOIfeMle2/YJAaDNc8
77+Ctgo2iibaPzQwXk9dWM+/A8oXIn4i7T+COaI6uzvVP1pWLBEqMd4/FERR
8jgX2T9Uxls9iQjGv9SHbdu48e8/Ooa135SX6z/AssD1pSnhvxY+uKis09U/
j4Ovkg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8627315647954185, 
     3.249147591359287, -0.35090479715984535`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAl/mIGPyo4r9UaRSR7o+5P1a3EnmE
Jt6/WXZAr2NL4j+EiPKc4WC4vxTSdXPdF98/iJvp1Wpo8L8dvNBQyJ3rv9+A
K0GvzOe/7CmTa6SEzb/QliiaIRviPzihKgAdWva/8alwcCmd9b+F0VuIMNHn
PyZEBhq6d6G/drfRIeKb8z+n9DzRcwbpPx6i5hMsF98/EK8nQTw+yz8/A0BU
6SfSv1qARjK6Bfg/DKyhU0vh8j90cy5M6mbuv8HrPAi3IsY/VBgu4ui86b/z
Lq5+ymvYv0Vu2r74b+O/EsRtMyUK2r/6I0tsH03VPw5Pbx6+4+2/vCa1fKfx
7r+vXn5aLgPbP+6/Kd69KtC/ovJx+ZPB7D+Xo56dV/rVPxk6rsOEF98/HWKK
v/Ia2T9gpXy7IUDIv9/0I4+xy+8/OOdBK/0G7D9CYuY/g7ngv/ojynucFNU/
oc6z/Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8543751323953123, 
     3.2506085930163584`, -0.35775257951928957`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/VAPTpKd4r8TasXr9KC5P03Tg0wq
P96/9FrM2NhS4j+y46OuLK+4vxnz6fHZ/94/LAVxOqbV8L9bOm8oz3jrvx4R
l4zCwOa/2DqQPPCxzL+7pfzG1QHhP4Vcf928m/a/ffGOwctK9b9AJNyytcno
P7iBslrDzKi/ld9wAZ078z/2i3hGL4jpP0CiSqmUkeA/fcfcAy0Pyz9o2BuI
H5rUvyRfDh7E3fc/qW1uEYo+8z9j+FGQFKztv6zRGT9OXsM/qq14YW8k6r8Y
jfaKsETYv2J9bNkr8OK/s18zXQ7K2b/9UnVk9DXUP1hRoHCHK+6//JmW6JSZ
7r+D0VRQ1P3bP8IR7VthrNC/Dw3XbQll7D+AD6SwSXLWP+bNH9HACOA/04zD
GaQW2T9U0cSz6sXKv+rbiJq6ne8/I5vUffZn7D9tOhMT/WDgv/htu4iAV9Q/
Zna/GA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8545639675230023, 
     3.2506529836807347`, -0.35689719121741786`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAALCahbC904r9FRkUOwgW5P8vCgn37
qd6/2b+7WZY/4j98o2wibV+4v9AtIv4iL98/WnyvMZkb8b9W/sj4rGrrv9lY
N/1U/uW/m25SLnzSyr/35Vke6MffP6Tim5H+4Pa/3q5fiBMC9b/sCZOqt4bp
P1bZrxn98LK/JvouxZK58j/I83YNZiPqP9Vj6CRV5uE/eDbTGVKjyT8yuMmV
GufWv69MYdgIuPc/cjgKtkuk8z+8wt3VocTsvyRmKeHbFcI/cA8A6LBV6r+O
VQC39EnYvx9d/F2pqeK/08E1eM4o2b/Em/VQrATTP1aT/HB9i+6/9EGwPis8
7r+0slvsb6fcP5Bc92Eds9G/EtoM8l3Z6z9ZXylpeBfXP169/FHzvuA/d40w
4Gqo2D8R4WTe9f7MvyPY6ZfRg+8/Xhjo4hbE7D8rVyt6j9Dfv3FwW3cIHdQ/
0N2+Hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8441854156182759, 
     3.2541894864267378`, -0.3492875183671529}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAARnOd5vV44r832CvwHVm5P9yG+B7w
mN6/mYZoGCFe4j+OUR17Ewa5v7BzQ+SE3d4/nyvfrw+J8b9EKeVbIiHrv5CE
8ycZ++S/D8OZh4E7y7+s4e/OWCHeP++8OaeODPe/ix4moie29L/KneDl+k7q
Pw1jQ1psNbS/apzCawpX8j/ZGVOOwoHqPzXbTRSY7OI/pgxPmu2kyj/oJ4pd
YrjZv9S8vOIOevc/VugtwGkI9D841HxUd+7rvw+iFH8cv7w/QuUto4rF6r89
rt+d/vXXv//jt5vII+K/CuSDSNZH2b/da30l0DvSP6be967Ksu6/Lth0laLy
7b/RGOajHnrdP9CvxJol09G/tt/29xqG6z+ob+8eAGHXP4bKN0OtLeE/wkn8
flwH2T9LfFE85/nPv8CZzRtwMe8/oitiTHo37T9qfuDDOQ/fvxpOBAKmBtM/
mSG6hA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8352358537043255, 
     3.2582084115098247`, -0.3329549757150812}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIGZjtOF/nfVo/9/F+cVTA3baz+JTW7531739WRUl
TEBx+6/GwflA8f0dJw9NAorbF8+/XT3j08f9TJZlgpWXXu2PLqt+xP718X7+
kM9SDTdO7a/VWKW54cdte+8g29/tLt/3t0pLeSXEfdmfkdJS9UT9tb2LnOfp
WK8d+5la38cBzbHfo3PMCGiO/cVnyquB5tgnci+qBppj/+yHMxfQnP3t8/f8
A5pjf3NCdRjQHHuDaU8SgObsd2ic+wVojv23+ZXMfBqv9ze7cCSnrbi+/4od
e7Txyof7ua79EOVWvLl/H4fz4Sy1i/afrrKlmn9+t59DZsfFq5Pf7n8e8Unj
e+A9ezHtPz2r0i7tNz+o+YBX47W93bHbLUBz7E8tdbICmmPv9DtGEWiO/ack
ns1Ac/a/DMxNBppjz3d263WgOfbr/pzjA5qz/43I13agOfYAm7a2CA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.018782305109029, 1.7668172111438032`, -2.05603379033145}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.919851379301186*^9},
 CellLabel->
  "Out[1512]=",ExpressionUUID->"9a803fcd-64e0-4cb9-912b-749cba6fc545"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Butane", "Section",
 CellChangeTimes->{{3.919851602382831*^9, 
  3.919851603416019*^9}},ExpressionUUID->"0a688b36-aa4f-4c67-a23a-\
0f25a1681984"],

Cell["This is an example from Mathematica\[CloseCurlyQuote]s documentation", \
"Text",
 CellChangeTimes->{{3.9204029497217407`*^9, 
  3.9204029591340647`*^9}},ExpressionUUID->"faf8c150-80fb-4e9e-926d-\
355c02e58f3d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"butane0", "=", 
   RowBox[{"Molecule", "[", "\"\<butane\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"butane", "=", "butane0"}]}], "Input",
 CellChangeTimes->{{3.9197970788059187`*^9, 3.9197970788107023`*^9}, {
   3.919801030684396*^9, 3.91980103982067*^9}, 3.919801282179001*^9, {
   3.919847939045866*^9, 3.919847947877406*^9}, {3.91985012173764*^9, 
   3.919850130970047*^9}, {3.91985024721163*^9, 3.9198502480154877`*^9}, {
   3.919851625458147*^9, 3.919851625914761*^9}},
 CellLabel->
  "In[1513]:=",ExpressionUUID->"fcd742e9-eeee-41ef-b469-ac4fbbb7cbd2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-1.299038105676658, -0.24999999999999978`}, \
{-0.4330127018922193, 0.2500000000000001}}], 
                  
                  LineBox[{{-0.4330127018922193, 0.2500000000000001}, {
                   0.4330127018922192, -0.2500000000000001}}], 
                  
                  LineBox[{{0.4330127018922192, -0.2500000000000001}, {
                   1.299038105676658, 0.24999999999999978`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1.299038105676658, -0.24999999999999978`}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4330127018922193, 0.2500000000000001}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.4330127018922192, -0.2500000000000001}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.299038105676658, 0.24999999999999978`}, 0.2]}, 
                 "4"], Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "4"], 
                    SubscriptBox["\"H\"", "10"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["14", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["13", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-1.299038105676658, -0.24999999999999978`}, \
{-0.4330127018922193, 0.2500000000000001}}], 
                  
                  LineBox[{{-0.4330127018922193, 0.2500000000000001}, {
                   0.4330127018922192, -0.2500000000000001}}], 
                  
                  LineBox[{{0.4330127018922192, -0.2500000000000001}, {
                   1.299038105676658, 0.24999999999999978`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1.299038105676658, -0.24999999999999978`}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4330127018922193, 0.2500000000000001}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.4330127018922192, -0.2500000000000001}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.299038105676658, 0.24999999999999978`}, 0.2]}, 
                 "4"], Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "4"], 
                    SubscriptBox["\"H\"", "10"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["14", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["13", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C(C(C(C([H])([H])[H])([H])[H])([H])[H])([H])([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"IJDNQMDRQITEOD-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{
   "C", "C", "C", "C", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{2, 3}, "Single"], 
    Bond[{3, 4}, "Single"], 
    Bond[{1, 5}, "Single"], 
    Bond[{1, 6}, "Single"], 
    Bond[{1, 7}, "Single"], 
    Bond[{2, 8}, "Single"], 
    Bond[{2, 9}, "Single"], 
    Bond[{3, 10}, "Single"], 
    Bond[{3, 11}, "Single"], 
    Bond[{4, 12}, "Single"], 
    Bond[{4, 13}, "Single"], 
    Bond[{4, 14}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.919801282729629*^9, 3.919801299105283*^9}, 
   3.919847949213829*^9, 3.91985013192519*^9, 3.919851626836689*^9},
 CellLabel->
  "Out[1514]=",ExpressionUUID->"8c63a574-2fa9-4264-a851-5eb5c349d8b6"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"carbonIndices", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"relaxedScan", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"butane", "=", 
      RowBox[{"MoleculeModify", "[", 
       RowBox[{"butane", ",", 
        RowBox[{"{", 
         RowBox[{"\"\<EnergyMinimizeAtomCoordinates\>\"", ",", 
          RowBox[{"carbonIndices", "->", "ang"}]}], "}"}]}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"ang", ",", 
       RowBox[{"-", "180"}], ",", "180", ",", "5"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.919797122067869*^9, 3.9197971220725927`*^9}, {
  3.919799589782131*^9, 3.919799595053973*^9}, {3.9197996560921164`*^9, 
  3.919799658975943*^9}, {3.9198501966808987`*^9, 
  3.919850198963031*^9}},ExpressionUUID->"ee30b9fa-1f82-4294-a86a-\
e850b8564759"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"carbonIndices", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"relaxedScan", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"butane", "=", 
        RowBox[{"MoleculeModify", "[", 
         RowBox[{"butane0", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<SetTorsionAngle\>\"", ",", 
            RowBox[{"carbonIndices", "->", "ang"}]}], "}"}]}], "]"}]}], ";", 
       RowBox[{"MoleculeAlign", "[", 
        RowBox[{"butane0", ",", "butane", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"2", "->", "2"}], ",", 
           RowBox[{"3", "->", "3"}]}], "}"}]}], "]"}]}], ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"ang", ",", 
       RowBox[{"-", "180"}], ",", "180", ",", "1"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.919799131970634*^9, 3.919799133354535*^9}, {
   3.919799233373477*^9, 3.919799242778784*^9}, {3.919799323900893*^9, 
   3.919799327536851*^9}, {3.91979966444763*^9, 3.919799665951273*^9}, {
   3.919799897895506*^9, 3.9197999525094557`*^9}, {3.919800516234479*^9, 
   3.919800516411214*^9}, {3.919800623180562*^9, 3.919800670849657*^9}, {
   3.9198010243907537`*^9, 3.919801073603569*^9}, {3.919801111616724*^9, 
   3.919801119385726*^9}, {3.919801317340496*^9, 3.919801341043055*^9}, {
   3.919801452819283*^9, 3.9198014563309727`*^9}, {3.9198017714504833`*^9, 
   3.919801773762993*^9}, {3.9198018383728247`*^9, 3.919801841100336*^9}, {
   3.919801905272937*^9, 3.9198019061744823`*^9}, 3.9198019792747307`*^9},
 CellLabel->
  "In[1462]:=",ExpressionUUID->"1126995e-03e0-4d8a-8020-87486757ae1a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{
   RowBox[{"MoleculeValue", "[", 
    RowBox[{"relaxedScan", ",", "\"\<MMFFEnergy\>\""}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Axes", "->", "False"}], ",", 
     RowBox[{"Frame", "->", "True"}], ",", 
     RowBox[{"PlotTheme", "->", "\"\<Marketing\>\""}], ",", 
     RowBox[{"BaseStyle", "->", "15"}], ",", 
     RowBox[{"FrameLabel", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Torsion angle\[ThinSpace](\>\"", ",", 
           RowBox[{"Quantity", "[", 
            RowBox[{"\"\<\>\"", ",", "\"\<Degrees\>\""}], "]"}], ",", 
           "\"\<)\>\""}], "}"}], "]"}], ",", 
        RowBox[{"Row", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Energy\[ThinSpace](\>\"", ",", 
           RowBox[{"Quantity", "[", 
            RowBox[{"\"\<\>\"", ",", 
             RowBox[{
             "\"\<KilocaloriesThermochemical\>\"", "/", "\"\<Moles\>\""}]}], 
            "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "}"}]}], ",", 
     RowBox[{"DataRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "180"}], ",", "180"}], "}"}]}]}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.919797146167304*^9, 3.9197971461730947`*^9}, {
  3.919799644000936*^9, 
  3.9197996455573473`*^9}},ExpressionUUID->"3aeeea50-2aa6-4dc4-bab6-\
fd8134858906"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{{}, {}, 
        TagBox[
         {RGBColor[1., 0.4, 0.], PointSize[
           NCache[
            Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[3], 
          CapForm["Butt"], LineBox[CompressedData["
1:eJxNVFlIVGEUvqnjjMuY20OguZS9mNiCFFo6R1xztEzGMR2X6zgzpEaKlYWa
cwOJIXqIMh+scBRyN7WybEFPgaYmBGai5MMoFoWWS1ph2tT8929uP1wu3/3u
Of8531n81UUpWhuGYY78fSxvcjgd6h81rL5O8kSCTVpsuXCuvsmRYtCib7ei
FWI8eGzUoF693Fbp4M5jRoPSianwzgJXHrN5WFErbrkkkvIY1Sja+NRaPCvh
sZ8aA+sTHToe2PGYy0XXkiy2eoCh97N4wNP2yfjQej9/P4tJI0M+CW1rFOfg
4dAzIWV1KzxmsnGQHZ33nVvmMWaiTaLZaKP/xmNOhe5qadn6oR/UPgPtOtpv
JPZsUPt0rLDf9+5i1xYabxoGluhHjcdEND4lPr7cq9j9gcYPqTh/cur95wBn
mr8C2e6i4pq3LtQ+BbflV9wW66ge3HH8YmiNfblJMSTjed98uTHIDfkaHMXo
g23lY0v//pdj9pQ+2V7uir/NlhOPE6evucxVUv9cLJpl0zuaO5zQjnyIxknJ
V/df4RIec5HoNKC8NZZK9WUicO/DEXvxLqovE4pxFW4i8TDVgwnB68rFTpVi
sV9CcDA29Az73VwzUT4AIypXvfsyB/uXSDweuKDbs7I62SZj6OmTyrw57xcy
E8/DjFK5IfAB8Fwu9bHY8zgYqur8twv+Q6AvtZrcT+OD2nSNvSW+n8RfODwN
CxPi5yKhuVBF8tsgfBTM3t1J8qf6wLhnOdGH5+OhuXRGKugnh4k3ZURfQpuT
QI7tRH+itywZ2Ho/Uh9aP7jz6h6pH+H7U2B4rUWoL6OA4MKaIkv9iTtZKmwV
4bS1PzglFHT2CP2DaTDfOEz6a5MYnICPjoYJa/9BBpyyvUL6k/B6FRRKDUL/
Yib0PIsk/c3HnwUJnkNC/0MO2E7/Nx/AwvelBWF+TCzEdTT3WueLy4X7Q/tz
LfNH8vNVQ61+XZhPVEPjQlWTZX4Jn5MHaolNq3W+GQ04B8UI82/UQFdpabt1
P4AWcua8hP1h0kJIlEHYL5wOvK6eJfvnD1HTzYw=
           "]]},
         Annotation[#, "Charting`Private`Tag#1"]& ]}, 
       TagBox[
        {RGBColor[1., 0.4, 0.], PointSize[
          NCache[
           Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[3], 
         CapForm["Butt"], GeometricTransformationBox[InsetBox[
           FormBox[
            StyleBox[
             GraphicsBox[{
               {GrayLevel[1], DiskBox[{0, 0}, Offset[{3., 3.}, {0., 0.}]]}, 
               {AbsoluteThickness[1.5], Dashing[{}], 
                CircleBox[{0, 0}, Offset[{3., 3.}, {0., 0.}]]}}],
             StripOnInput->False,
             GraphicsBoxOptions->{DefaultBaseStyle->Directive[
               PointSize[
                Rational[1, 60]], 
               RGBColor[1., 0.4, 0.], 
               CapForm["Butt"], 
               AbsoluteThickness[3]]}],
            TraditionalForm], {0., 0.}, Automatic, Scaled[
           9.75]], CompressedData["
1:eJxNVFlIVGEUvi6j4zLmMg+B5lL2YmILUmjpHHHN0TKZGXOd6zgjqZFiZaHm
3EBCooco88EKRyF3UyvLFvQUaI4JgZko+TCKRaHlklaYZs5//+b2w//w3e+e
85/zncVPU5iss2EY5ujWtdq61gw9XC7qHzesvEmUIsEmHbZcPF/f5Egx6NCn
W9EK0R48NmhRr1lqq3Bw5zGjRcn4ZFhnviuP2Rwsr7VvuSyS8Bg1KFr/3Fo0
I+axrwYD6hMcOh7a8pjLRtfiTLZ6gKHvs3hQavN0bGitn3+fxcThIe/4tlWK
1Xgk5Gxwad0yj5ksHGRH5nxml3iMGWidsGmw1n/nMZeO7hpJ6drhn9Q+DW07
2m8m9KxT+1Qst9v//lKXFY03BQOK9SOG4yIanwqfXOlV7PlI4wclzp2a/PDF
35nmr0C2u7Co5p0LtU/G7Xnld+xzqR7cCfxa1RrzaoNiSMILPnlyQ6Ab8jU4
hlGH2spGF//9L8esSX2SndwV/2yaTxyOn7nuMltB/XMxuCmb2tnc4YS25EMU
Toi/uf8OE/OYi0CnAdXtUSXVlwnHfY+G7ex3U32ZEIwtdxPZG6keTDDeUC10
pisW+sUEB2FDj9H31qqJ8v4YXrHi1Zcx2L9I4vHA+dy9yysTbTKGnj6JzIvz
eikz8TxMq1TrAu8PL+QSb7M9j4Ogss5vh+A/GPqU1eR9Gh/UpmrtzPH9Iv7C
4FloqBA/FwHNBekkv3XCR8LMvV0kf6oPjEnLiD48HwfNJdMSQT85jL8tJfoS
ejMR5NhO9Cd6y5KArfcl9aH1g7uv75P6Eb4/GYyrLUJ9GQUEFdQUmutP3MmU
sE2EU5b+4FSQ39kj9A+mwFyjkfTXBjE4CZ8cq8Yt/QdpcNrmKulPwuvToUBS
JfQvZkDP8wjS33z8mRAvHRL6H9RgM/XffAALPxbnhfkxsRDb0dxrmS8uGx4M
Hcg2zx/Jz0cDtfo1YT5RA43zlU3m+SW8Ogc0YutWy3wzWnAOjBbm36CFrpKS
dst+AB2oZz2F/WHSQXBklbBfuFzwvHaO7J+/Yt/Njg==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[1., 0.4, 0.], 
              CapForm["Butt"], 
              AbsoluteThickness[3]], 
             Line[CompressedData["
1:eJxNVFlIVGEUvqnjjMuY20OguZS9mNiCFFo6R1xztEzGMR2X6zgzpEaKlYWa
cwOJIXqIMh+scBRyN7WybEFPgaYmBGai5MMoFoWWS1ph2tT8929uP1wu3/3u
Of8531n81UUpWhuGYY78fSxvcjgd6h81rL5O8kSCTVpsuXCuvsmRYtCib7ei
FWI8eGzUoF693Fbp4M5jRoPSianwzgJXHrN5WFErbrkkkvIY1Sja+NRaPCvh
sZ8aA+sTHToe2PGYy0XXkiy2eoCh97N4wNP2yfjQej9/P4tJI0M+CW1rFOfg
4dAzIWV1KzxmsnGQHZ33nVvmMWaiTaLZaKP/xmNOhe5qadn6oR/UPgPtOtpv
JPZsUPt0rLDf9+5i1xYabxoGluhHjcdEND4lPr7cq9j9gcYPqTh/cur95wBn
mr8C2e6i4pq3LtQ+BbflV9wW66ge3HH8YmiNfblJMSTjed98uTHIDfkaHMXo
g23lY0v//pdj9pQ+2V7uir/NlhOPE6evucxVUv9cLJpl0zuaO5zQjnyIxknJ
V/df4RIec5HoNKC8NZZK9WUicO/DEXvxLqovE4pxFW4i8TDVgwnB68rFTpVi
sV9CcDA29Az73VwzUT4AIypXvfsyB/uXSDweuKDbs7I62SZj6OmTyrw57xcy
E8/DjFK5IfAB8Fwu9bHY8zgYqur8twv+Q6AvtZrcT+OD2nSNvSW+n8RfODwN
CxPi5yKhuVBF8tsgfBTM3t1J8qf6wLhnOdGH5+OhuXRGKugnh4k3ZURfQpuT
QI7tRH+itywZ2Ho/Uh9aP7jz6h6pH+H7U2B4rUWoL6OA4MKaIkv9iTtZKmwV
4bS1PzglFHT2CP2DaTDfOEz6a5MYnICPjoYJa/9BBpyyvUL6k/B6FRRKDUL/
Yib0PIsk/c3HnwUJnkNC/0MO2E7/Nx/AwvelBWF+TCzEdTT3WueLy4X7Q/tz
LfNH8vNVQ61+XZhPVEPjQlWTZX4Jn5MHaolNq3W+GQ04B8UI82/UQFdpabt1
P4AWcua8hP1h0kJIlEHYL5wOvK6eJfvnD1HTzYw=
              "]]}, "Charting`Private`Tag#1"]}, {
           Annotation[{
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[1., 0.4, 0.], 
              CapForm["Butt"], 
              AbsoluteThickness[3]], 
             GeometricTransformation[
              Inset[
               Style[
                Graphics[{{
                   GrayLevel[1], 
                   Disk[{0, 0}, 
                    Offset[{3, 3}]]}, 
                  AbsoluteThickness[1.5], 
                  Dashing[{}], 
                  Circle[{0, 0}, 
                   Offset[{3, 3}]]}], 
                GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                    PointSize[
                    Rational[1, 60]], 
                    RGBColor[1., 0.4, 0.], 
                    CapForm["Butt"], 
                    AbsoluteThickness[3]]}], {0., 0.}, Automatic, 
               Scaled[9.75]], CompressedData["
1:eJxNVFlIVGEUvi6j4zLmMg+B5lL2YmILUmjpHHHN0TKZGXOd6zgjqZFiZaHm
3EBCooco88EKRyF3UyvLFvQUaI4JgZko+TCKRaHlklaYZs5//+b2w//w3e+e
85/zncVPU5iss2EY5ujWtdq61gw9XC7qHzesvEmUIsEmHbZcPF/f5Egx6NCn
W9EK0R48NmhRr1lqq3Bw5zGjRcn4ZFhnviuP2Rwsr7VvuSyS8Bg1KFr/3Fo0
I+axrwYD6hMcOh7a8pjLRtfiTLZ6gKHvs3hQavN0bGitn3+fxcThIe/4tlWK
1Xgk5Gxwad0yj5ksHGRH5nxml3iMGWidsGmw1n/nMZeO7hpJ6drhn9Q+DW07
2m8m9KxT+1Qst9v//lKXFY03BQOK9SOG4yIanwqfXOlV7PlI4wclzp2a/PDF
35nmr0C2u7Co5p0LtU/G7Xnld+xzqR7cCfxa1RrzaoNiSMILPnlyQ6Ab8jU4
hlGH2spGF//9L8esSX2SndwV/2yaTxyOn7nuMltB/XMxuCmb2tnc4YS25EMU
Toi/uf8OE/OYi0CnAdXtUSXVlwnHfY+G7ex3U32ZEIwtdxPZG6keTDDeUC10
pisW+sUEB2FDj9H31qqJ8v4YXrHi1Zcx2L9I4vHA+dy9yysTbTKGnj6JzIvz
eikz8TxMq1TrAu8PL+QSb7M9j4Ogss5vh+A/GPqU1eR9Gh/UpmrtzPH9Iv7C
4FloqBA/FwHNBekkv3XCR8LMvV0kf6oPjEnLiD48HwfNJdMSQT85jL8tJfoS
ejMR5NhO9Cd6y5KArfcl9aH1g7uv75P6Eb4/GYyrLUJ9GQUEFdQUmutP3MmU
sE2EU5b+4FSQ39kj9A+mwFyjkfTXBjE4CZ8cq8Yt/QdpcNrmKulPwuvToUBS
JfQvZkDP8wjS33z8mRAvHRL6H9RgM/XffAALPxbnhfkxsRDb0dxrmS8uGx4M
Hcg2zx/Jz0cDtfo1YT5RA43zlU3m+SW8Ogc0YutWy3wzWnAOjBbm36CFrpKS
dst+AB2oZz2F/WHSQXBklbBfuFzwvHaO7J+/Yt/Njg==
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-180., 180.}, {-5.075973341399389, 
             0.13368226412977252`}}, "Frame" -> {{True, True}, {True, True}}, 
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
            "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
            GoldenRatio^(-1), "DefaultStyle" -> {
              Directive[
               PointSize[
                Rational[1, 60]], 
               RGBColor[1., 0.4, 0.], 
               CapForm["Butt"], 
               AbsoluteThickness[3]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-180., 180.}, {-5.075973341399389, 
            0.13368226412977252`}}, "Frame" -> {{True, True}, {True, True}}, 
           "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[1., 0.4, 0.], 
              CapForm["Butt"], 
              AbsoluteThickness[3]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 60]], 
          RGBColor[1., 0.4, 0.], 
          CapForm["Butt"], 
          AbsoluteThickness[3]], 
         Line[CompressedData["
1:eJxNVFlIVGEUvqnjjMuY20OguZS9mNiCFFo6R1xztEzGMR2X6zgzpEaKlYWa
cwOJIXqIMh+scBRyN7WybEFPgaYmBGai5MMoFoWWS1ph2tT8929uP1wu3/3u
Of8531n81UUpWhuGYY78fSxvcjgd6h81rL5O8kSCTVpsuXCuvsmRYtCib7ei
FWI8eGzUoF693Fbp4M5jRoPSianwzgJXHrN5WFErbrkkkvIY1Sja+NRaPCvh
sZ8aA+sTHToe2PGYy0XXkiy2eoCh97N4wNP2yfjQej9/P4tJI0M+CW1rFOfg
4dAzIWV1KzxmsnGQHZ33nVvmMWaiTaLZaKP/xmNOhe5qadn6oR/UPgPtOtpv
JPZsUPt0rLDf9+5i1xYabxoGluhHjcdEND4lPr7cq9j9gcYPqTh/cur95wBn
mr8C2e6i4pq3LtQ+BbflV9wW66ge3HH8YmiNfblJMSTjed98uTHIDfkaHMXo
g23lY0v//pdj9pQ+2V7uir/NlhOPE6evucxVUv9cLJpl0zuaO5zQjnyIxknJ
V/df4RIec5HoNKC8NZZK9WUicO/DEXvxLqovE4pxFW4i8TDVgwnB68rFTpVi
sV9CcDA29Az73VwzUT4AIypXvfsyB/uXSDweuKDbs7I62SZj6OmTyrw57xcy
E8/DjFK5IfAB8Fwu9bHY8zgYqur8twv+Q6AvtZrcT+OD2nSNvSW+n8RfODwN
CxPi5yKhuVBF8tsgfBTM3t1J8qf6wLhnOdGH5+OhuXRGKugnh4k3ZURfQpuT
QI7tRH+itywZ2Ho/Uh9aP7jz6h6pH+H7U2B4rUWoL6OA4MKaIkv9iTtZKmwV
4bS1PzglFHT2CP2DaTDfOEz6a5MYnICPjoYJa/9BBpyyvUL6k/B6FRRKDUL/
Yib0PIsk/c3HnwUJnkNC/0MO2E7/Nx/AwvelBWF+TCzEdTT3WueLy4X7Q/tz
LfNH8vNVQ61+XZhPVEPjQlWTZX4Jn5MHaolNq3W+GQ04B8UI82/UQFdpabt1
P4AWcua8hP1h0kJIlEHYL5wOvK6eJfvnD1HTzYw=
          "]]}, "Charting`Private`Tag#1"]}, {
       Annotation[{
         Directive[
          PointSize[
           Rational[1, 60]], 
          RGBColor[1., 0.4, 0.], 
          CapForm["Butt"], 
          AbsoluteThickness[3]], 
         GeometricTransformation[
          Inset[
           Style[
            Graphics[{{
               GrayLevel[1], 
               Disk[{0, 0}, 
                Offset[{3, 3}]]}, 
              AbsoluteThickness[1.5], 
              Dashing[{}], 
              Circle[{0, 0}, 
               Offset[{3, 3}]]}], 
            GraphicsBoxOptions -> {DefaultBaseStyle -> Directive[
                PointSize[
                 Rational[1, 60]], 
                RGBColor[1., 0.4, 0.], 
                CapForm["Butt"], 
                AbsoluteThickness[3]]}], {0., 0.}, Automatic, 
           Scaled[9.75]], CompressedData["
1:eJxNVFlIVGEUvi6j4zLmMg+B5lL2YmILUmjpHHHN0TKZGXOd6zgjqZFiZaHm
3EBCooco88EKRyF3UyvLFvQUaI4JgZko+TCKRaHlklaYZs5//+b2w//w3e+e
85/zncVPU5iss2EY5ujWtdq61gw9XC7qHzesvEmUIsEmHbZcPF/f5Egx6NCn
W9EK0R48NmhRr1lqq3Bw5zGjRcn4ZFhnviuP2Rwsr7VvuSyS8Bg1KFr/3Fo0
I+axrwYD6hMcOh7a8pjLRtfiTLZ6gKHvs3hQavN0bGitn3+fxcThIe/4tlWK
1Xgk5Gxwad0yj5ksHGRH5nxml3iMGWidsGmw1n/nMZeO7hpJ6drhn9Q+DW07
2m8m9KxT+1Qst9v//lKXFY03BQOK9SOG4yIanwqfXOlV7PlI4wclzp2a/PDF
35nmr0C2u7Co5p0LtU/G7Xnld+xzqR7cCfxa1RrzaoNiSMILPnlyQ6Ab8jU4
hlGH2spGF//9L8esSX2SndwV/2yaTxyOn7nuMltB/XMxuCmb2tnc4YS25EMU
Toi/uf8OE/OYi0CnAdXtUSXVlwnHfY+G7ex3U32ZEIwtdxPZG6keTDDeUC10
pisW+sUEB2FDj9H31qqJ8v4YXrHi1Zcx2L9I4vHA+dy9yysTbTKGnj6JzIvz
eikz8TxMq1TrAu8PL+QSb7M9j4Ogss5vh+A/GPqU1eR9Gh/UpmrtzPH9Iv7C
4FloqBA/FwHNBekkv3XCR8LMvV0kf6oPjEnLiD48HwfNJdMSQT85jL8tJfoS
ejMR5NhO9Cd6y5KArfcl9aH1g7uv75P6Eb4/GYyrLUJ9GQUEFdQUmutP3MmU
sE2EU5b+4FSQ39kj9A+mwFyjkfTXBjE4CZ8cq8Yt/QdpcNrmKulPwuvToUBS
JfQvZkDP8wjS33z8mRAvHRL6H9RgM/XffAALPxbnhfkxsRDb0dxrmS8uGx4M
Hcg2zx/Jz0cDtfo1YT5RA43zlU3m+SW8Ogc0YutWy3wzWnAOjBbm36CFrpKS
dst+AB2oZz2F/WHSQXBklbBfuFzwvHaO7J+/Yt/Njg==
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-180., 180.}, {-5.075973341399389, 
         0.13368226412977252`}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[
            Rational[1, 60]], 
           RGBColor[1., 0.4, 0.], 
           CapForm["Butt"], 
           AbsoluteThickness[3]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->15,
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       TemplateBox[{"\"Energy\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{
             SubscriptBox["\"kcal\"", "\"th\""], "\[InvisibleSpace]", "\"/\"",
              "\[InvisibleSpace]", "\"mol\""}], 
           "thermochemical kilocalories per mole", 
           FractionBox["\"ThermochemicalKilocalories\"", "\"Moles\""]}, 
          "QuantityTF", SyntaxForm -> Mod], "\")\""}, "RowDefault"], 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
       TemplateBox[{"\"Torsion angle\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{"\[InvisibleSpace]", "\"\[Degree]\""}], "degrees", 
           "\"AngularDegrees\""}, "QuantityPostfixTF", SyntaxForm -> Mod], 
         "\")\""}, "RowDefault"], HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Charting`FindScaledTicks[
       (Charting`SimpleTicks[#, #2, 6]& )[
        SlotSequence[1]], {Identity, Identity}]& , None}, {
     Charting`FindScaledTicks[
       (Charting`SimpleTicks[#, #2, 6]& )[
        SlotSequence[1]], {Identity, Identity}]& , None}}, {{{{-5., 
        FormBox[
         RowBox[{"-", "5"}], TraditionalForm], {0.01, 0.}}, {-4., 
        FormBox[
         RowBox[{"-", "4"}], TraditionalForm], {0.01, 0.}}, {-3., 
        FormBox[
         RowBox[{"-", "3"}], TraditionalForm], {0.01, 0.}}, {-2., 
        FormBox[
         RowBox[{"-", "2"}], TraditionalForm], {0.01, 0.}}, {-1., 
        FormBox[
         RowBox[{"-", "1"}], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox["0", TraditionalForm], {0.01, 0.}}}, None}, {{{-150., 
        FormBox[
         RowBox[{"-", "150"}], TraditionalForm], {0.01, 0.}}, {-100., 
        FormBox[
         RowBox[{"-", "100"}], TraditionalForm], {0.01, 0.}}, {-50., 
        FormBox[
         RowBox[{"-", "50"}], TraditionalForm], {0.01, 0.}}, {0., 
        FormBox["0", TraditionalForm], {0.01, 0.}}, {50., 
        FormBox["50", TraditionalForm], {0.01, 0.}}, {100., 
        FormBox["100", TraditionalForm], {0.01, 0.}}, {150., 
        FormBox["150", TraditionalForm], {0.01, 0.}}}, None}}],
  FrameTicksStyle->Directive[
    StrokeForm[
     Opacity[0]], FontOpacity -> 1],
  GridLines->{Automatic, Automatic},
  GridLinesStyle->Directive[
    AbsoluteThickness[1], 
    GrayLevel[0, 0.2]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[1., 0.4, 0.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.655728, 0.8, 0.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0., 0.742291, 0.873126], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[1., 0.656408, 0.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.893126, 0.4, 0.767184], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.295048, 0.8, 0.286932], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.238758, 0.610466, 1.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[1., 0.325204, 0.406504], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0., 0.786874, 0.739379], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[1., 0.520437, 0.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.7529330319872088, 0.4176501130047967, 1.], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0.5572809000084149, 0.8, 0], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[1., 0.06811595600706821, 0.0851449450088353], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[0, 0.7226017980018511, 0.9321946059944466], 
       CapForm["Butt"], 
       AbsoluteThickness[3]], 
      Directive[
       RGBColor[1., 0.7154761789941944, 0], 
       CapForm["Butt"], 
       AbsoluteThickness[3]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-180., 180.}, {-5.075973341399389, 0.13368226412977252`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Prolog->{
    GrayLevel[0, 0.7], 
    RectangleBox[
     Scaled[{0, 0}], 
     Scaled[{1, 1}]]},
  Ticks->{Charting`FindScaledTicks[
     (Charting`SimpleTicks[#, #2, 6]& )[
      SlotSequence[1]], {Identity, Identity}, RotateLabel -> 0]& , 
    Charting`FindScaledTicks[
     (Charting`SimpleTicks[#, #2, 6]& )[
      SlotSequence[1]], {Identity, Identity}, RotateLabel -> 0]& }]], "Output",\

 CellChangeTimes->{3.919797149905439*^9},
 CellLabel->
  "Out[1377]=",ExpressionUUID->"9f870602-ab6e-4a80-bce0-488b266e3248"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "hexane", "]"}]], "Input",
 CellChangeTimes->{{3.919847960630517*^9, 3.919847965878662*^9}},
 CellLabel->
  "In[1470]:=",ExpressionUUID->"db825385-1a91-45d1-8842-59ff7699f445"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBQQO+/CFib1JlAgAAACIAAAADAAAArzne/NqOB8Aoz8jwcFLhv7gWKpdV
Or4/9c7pumsU/b8kjJ7+eOPZP1ZQG9JH7tC/ovChjQGC3b+kFh/EEpq+v6eV
tj7+xMo/dl/d2vtm5T/vAXOX9rzqP5CZlGNPTMe/zHskXGlJAEAdnmQUIVra
PxoU80pj/9Y/u9XF7CddBECIWiDPqJbsv9ltPiMquM2/IOsqbQ4DCMChyfLo
b0blv1iQpUzBRPM/Pa6i5uVkBsCuubYGuHL4v96DmHo/UtW/8BT0Gu08D8BO
j1Rw/tLCv3b5ESvNY82/v7tO8yAWAMC2klOe1zz2Pyxuoku0bsY/FHyHrYbt
/L8ZleTBbf7gP6yMd8aPp/W/YFTnjoZN0r+fOUhOkrvxv1QC6LLwYs2/Uljg
Myx73r+a+AT7IVfPvyRl2kHUxvQ/jts2jZ9T3D+i5amINWL9P8i2EVEmY8o/
l4CaiVr05j9qI4xQtJLtP52+Gt4nY/S/gpmAiQcUBkB0Qy7+BkDzP1RggJNC
xMA/mPOlfmXq/z+Ib32Vh9vUP0Vu+SXqOPc/0QzBS1GCDEC7hYmKtXfxv9gt
lc8MNL4/bny/5e3A/j/eV3H2tNn7v2ikB/F1YLE/VDpoxvuHBECOQx/iHSLr
vyIUDnGTNfW/aJIEtfTIB8BkzN1scEzjv8MxGKZmKOU/9nPAceD5BsChkI0/
+I3wv2D8mylUh7u/UCfpC+RlC8D88t2MMAfWvzTc+b5Ejay/OqPD0Fag/r+/
NfvdtbXsPwBlKLG226a/hKU4NPkA/b8r2zNBKvDdP8Fg/roh4+m/gaJEDsTn
178KK4p6M6Xjv3Bli6GT74S/eiTB4Jb+3b/2QYquFVLHv9k3sQl0H+g/nma8
0GXI4T9MszFqWGD1P8Dp6Gu3tog/BvA7Mqst5j+skv9z1SfsP89RjcqxTOe/
p4rScrguA0D8akdDj9bpP0REs5SEYc8/zLq7DU4fAEDSBvFU1JrXP0sztvjC
+Ow/RnFDnLxvCED/shnyCcPvv9yt53ZHPK2/+cnSb8/eAUCRwgCvhBL1v6ab
uirvB7W/CAiX2ZFyBEALz59YY9zrv93hdbWY7Oi/tuK/Eg==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2, 3, 4, 5, 6}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], 
       SphereBox[{7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20}, 
        0.24]}}, {
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 5}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 6}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 21}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 22}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 8}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 23}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 9}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 24}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 10}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 25}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{25, 11}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 26}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{26, 12}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 27}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{27, 13}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 28}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{28, 14}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 29}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{29, 15}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 30}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{30, 16}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 31}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{31, 17}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 32}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{32, 18}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 33}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{33, 19}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 34}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{34, 20}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{-0.6778648506334365, 1.2751767026121066`, 3.0559488905070094`},
  ViewVertical->{-0.09056242859787879, 0.3113544022003616, 
   0.9459687535838113}]], "Output",
 CellChangeTimes->{3.9198479666313677`*^9},
 CellLabel->
  "Out[1470]=",ExpressionUUID->"7792faf2-7a66-4a62-b9d5-dd41fa311533"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "/@", 
  RowBox[{"Part", "[", 
   RowBox[{
    RowBox[{"SortBy", "[", 
     RowBox[{"relaxedScan", ",", 
      RowBox[{"MoleculeProperty", "[", "\"\<MMFFEnergy\>\"", "]"}]}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.91979728496559*^9, 3.919797284969697*^9}},
 CellLabel->
  "In[1379]:=",ExpressionUUID->"0792312f-3d72-4e95-ab3f-a294946a8468"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAA+Le3X/nA+r/EIPSs48XrP3PFdwgC
ZeG/uCDPH9qA4L9ST95DTSTfP+3d8HDoedc/oVwZB9qA4D8We3/Rw5DXvxte
zjToede/FJRZXfnA+j8YLI8hH/znvzMho70BZeE/Ty1Be1Ue9b8hFbpW2SD3
P64y5aiWd/a/2ANQQuGCAcD2X3LkgC+XvwLHuk1bSu2/cLdFaFMvA8AmKtcC
oKr3P97GlJHERFo/U+pFzgL47L9gIksbBkOvv4oGkij9ufM/2pst1wYUpb/y
OXeDoWH2P3+Q9B+35ec/Z/w9XwL47D+eEjxT0/fGPyzATEH9ufO/V0eN9QQU
pT/e8fE3v3z0vzxDBqG25ee/udnrhFUe9T8kvNIo9zv1v93CpJqWd/Y/CCO/
Y+GCAUAGoY3aAA3CP/9CP/5aSu0/4wEnTlMvA0CbxBfcvcX1v12Pv0qtRlq/
pHJ8bafv97/CEpqW5YHyP2gVIa0XKu+/1N8r8l3j/r/EjdClZwzbPzpGGauu
V+e/tskQDOhHAMBEnajsyMbyPxD7LqbfV9G/hoUKd2685r8G63SA7DvLPwY+
zkR3mOk/dvpBjRrS0b/GzW7UtCruP7t/NqxV0eE/hKwrM2685j+Q48JPtCm4
v7JXgE53mOm/FjFyVhrS0T+k0FEs8GDqvyW5tl1V0eG/5rYicafv9z8YKc1c
A53wv3ZTdnkXKu8/Eu1rEl7j/j/Ww+vq3njTvxky8V2uV+c/9uVp/udHAEBU
rW+25uHwv2vB/WbeV9E/EQ43/w==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2, 3, 4}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], 
         SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{15, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{16, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{17, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{18, 8}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{19, 9}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.6550272455183235`, 2.796142050594323, -0.9310609268410969},
    ImageCache->GraphicsData["CompressedBitmap", "\<\
eJy1nQeYnVW1/s89kxCQANIEFHWUjohXRDo6SpeulNAnASKE3kMIcOgIUqUL
HgFReq8RPCBKBymGDgcpisi9WLh4BeX7v7/17fdkn2/ODIHrP88zmclk5vv2
Xnutd71r7b3X2nD8/rvsvMf4/XfdcXz/OvuO33uXXXfcr3/tvfbVt/r+o1b7
j11qtdqN/bVR+rrQl9W/PsdftbH9Kw0MDK6y+uqtlb/+9eLra65ZrLHuusU6
G2xQfGuTTYoNv/OdYpMttmhvuuWWrU3HjRvc8NvfXi1+rXzEZ+PLj/OIxipf
+1rBx6oDA8XAWmsVa33rW8V6G29c6Fd4RPGdrbYqNt9222LL7bcvthocLLYe
P7699eBgY7Ott14le+Rn4su5Oo/r+UiNSiMq9KvFltttF4/bdscdi8HvfreY
MGlSrV7stNtutb72jrvt1r/JuHHxxBWzdywcX/blw9bv8PfcIYE111uvWHej
jYoN0tA322abYtwOO8Q7xu+yS7HzHnsUu+y9d7H7/vsXex54YLHX5MnFXgcd
1N7tgAMGtt1ppx7vmrtrPnys/s1vFt9cZ51iPb1n4803j7nwju122qnQuItd
99knnr3vIYcUBxx2WHHQEUfU+oqDjzxSf08+4ojiwMMPH9AYaitk7/pUfLnQ
kHchP1aVFWU+W0hm20yYUEzYdddiF71HYy/2P/TQ4uCjjioOPe644ogTTyyO
Pvnk4phTTy2O1QefjzrppKJxwgn8f/+6m2xS+2r23k/Gl/MNrLTaakPm6Pey
Xiw989tp991DdvtNncqMisOPPz7ed/zppxcnnnVWcfK55xan/vCH9eK0Cy6o
jeLL4vtnn81QWvrRHm9urbz66uVMkw4j2W9JU/K3Ttxzz5CoJFdMPfbYmNHx
P/hBcdI55/Ci4swLLyzO+clPivN++tN6cf6ll9ZGFz/82c+Kc/WtM5rN4oQz
zxyYfNRRteWz1y8QX37GJtRcRa/PFTYUacMNQ+goqoeBwA9qNIrDNPFjTjkl
Jn3a+ecXZ2kIen3xo8svLy68+uriJ9deW1xy/fXFT2+4ofipPl+sfzevuKI4
5+KLW/qdfCjzx5efG2KKq+mDYdl+0GvsZ3PpNPqMLu+ZhsM6sN4nSdg/+NGP
QhoM5aJrrokhXH7LLcWVt91WXP3znxfX3H57cbU+rpo2Lb7PUDWsganHHVf7
SjmuY+Lv0QwJ1RjQUPjg37Xvxf99nq/bneGmYfI1i5gjyLfHjQMxih0nTSr2
OOCAWMTDPFwtICuE5H585ZUhMYbEEG+4667ill//urj1nnvi882/+lVx0913
F9ffeWdxlabxk+uua55y3nlpxEdUIJERfWPttYs1k+DW33TTYqPNNrMRAYsN
gUQ50UX4lS79tyZiB6jCekn2VocdhFeT9t037ACNRBU8GVTvwquuCrkj8+tb
rWLaffcVv3r88eLBZ54p7n/qqeKXjz1W/OLhh4s7HnywmHb//TExrUf7gssu
8xocXkFoZvS1NdYIs0QzmRHwg3xRCYYFDBmhtyoR+sh4zKJDZhgWrpkxSwTF
I2OGCZ1ZMjRs74MPLqYIXbA5lB3tYrmY4c9uvDG0iCVhhvc//XTx0ltvFX9+
//3i9b//vfjtK68U9z75ZPGrJ54o7nr00ZgtM7385pvTJA+Lv+ftUqava5JV
mef+AvzbYeLEYrwwEKUCc+U72tvvvPPAZttumwS3MM/smjH2hDrgG2xTCDF/
/qB8xG7CN5T08O99L1AG88aeUFDW1DO+9d57i7u1js+8/nrxflHUC/2pzVr8
QRN/9KWXige01Ez+bi377Zq4dLp/78mTlysnfmj8PX8X4HdW1w6MpcCBCQbt
wABgHNhu++0X1gQAgEl7CB71vcGtJ0xIQv1UB1r9bITKc5lsAIqWHJvAvzN5
lnxiWvJDjj66ODopNdgGmFxy3XXFFUmhb5FV/uKhh2LJX/7LX+Taytn/WZ+e
/P3vi9+028VDzz9f3Kf/Z+lv/OUv+zXuNPuppW53KeVq3/hGt1vVzFluLWvM
eleZW7jVKVNKt9po1PGnAvvJ8kTJs+J1B7WK6RULdzxbDuys+neSjqNh9nKQ
HF6JdmHdvAYt+J604HT5GfQeRAWirvvFLwKW0Gms+aHnnite+vOfLYc/vfde
8fQf/1g8IRN47He/Kx6WLO6ZPh00y+RwSOn2h6gqWrC+Xa9WhtVHzRkUq3OA
JopRHpZcPsbJagFDuOMjv/99u3wEMyD5pXctHlphdFxr/fUDp3kPE4dW8DVa
glagedukdyN7XP5Ren5oxUUXFT+SR/uZTAK8BqfvfOSR4te//W3o/uOa9ct/
/Wvx96L88z/6eOVvfyueeeON4qk//KH47auvhp1Ig9qCwAQIU+LvT3YBApoR
EtGygXagHEv03b32Cv1nmdBXZowEWC5YRyIjYcB8lrco2chpp4XEJKUp2QLY
ia0toaARmIaxHnPD/PgeYLt10hKGsI8UEh9wnB7La8695JLQErAfodyrZRcS
iqcKKWpj0ZIQhv+8rY+XJZjn3nyzI5zHpTYPPvts+46HHuoSzLyN3KCDK2mk
CIXlg0XDPhlRsDPpLgIRAYrJg90Y87klV9KI5Ktqs4ReiwGE92Jp5ZqbU44+
+uDShMJKeR2YYcFgPmglAoDoYqF8fwuZUBBUAbMdJOTke2ecEa8XOws+BIbc
I00RdhT/kAD+qY+/6OOdorAJCVOL1955p3jhv/+7lI3MCaWRXBryIkku5SA/
HSv4Nfm0HERRZZQFVGcwDFTzCpOBsaIgwZY0dwYGQbvI5E1gBx0RzYjV5P9Y
WVZYK40R1ybHuxcM8sg7MSWE8G0AVaaDd0JBw2ykcAjH5ryzBAaAo7yM5/vy
rfBY3nPpTTcVt4juPC7zkGDGJIH8KwmkLQVCKCjLExLI/c88M3DxDTd0CWS+
WDXTF4RhdQZPURKEgdUwsBO0OkwMm4a+4OqYOA4+qOO0aXW4Y21MUC80+7Kb
b44fQW761cGG2GOSR2t1GezaikPBVnSTeTNnXtvBVL0SQt1FrhWNwWaBL/Tw
bA2HoTCEW4W1QMq7VpDZi/eK7j9vJUPK5fP4yy+3Bc/m/klbAgRzV2t1ZhT7
wHgsGFkOEYb59MXSBISCBK694w7c2hCSyveuk3rDE+ALEmhbzKkjHTDG8dzm
yclhLrhx3ovF8jU4hOSQDmYG8OPpOtKR1sLCkA6sCpz53Vtv1QEXwcwb775b
/F5c5L8llb/q481//at45e23i5dkcS+KpD3/X/8VUPPwCy8MyhqTgMpBfjbM
iYGuI45gLoIphUrLE+BuUVuW0QQJ1UUlGNDVicFDC3GPD4gH4BWggi0R39sf
eKC4TQSKgeM9MLUzf/zjflz3QTGG2VpraoE2zDyRBRGYIhWSt0rB/5yR9gB3
DMgExIyvKqgbRNxw2YxHoFxHBCIvYAsqI9XRI/l7dAipY2avvNKW+3bsnEup
SiMZJYpOWE6cA9BgW4AMEmKmV9x6a3GtCASz/7noP0v3rIbwX2INb+qDr5EW
3PHO3/wm+CPqRfimZzT2nzo1SWnWJmoMX4K8QGigxbgrVkgg1RcCmjec6Hdk
i+AOmmQBwenxCdgZNo3msjB36bX3KlKBuEBgfvvaa8XTYrrP/ulPkpCURxJ6
PnksoXIbEMKbdEmoTCzAMxkhRhawKDaBqaPsR5tNaAgKfkJ/LB2MCelAsgkl
3jbJ/lj4T2gmQoJWoWIsK7aHfYoKkGM5MEYxZhBNjtAtMWmHzvsdckhtVAho
oQ5BhANZw2EUhAA/kGPE/Hn0NTJ71gL2izZr4sUjL74I0hTTNaSnJCTUKVy5
vkZ1HpDLQjgr5MKZd3AVvdKkxpkdyD2qY4w8Xf4JSMYHsT6gjgWDatynNXpe
azIqJDNb8aI0Flr1oPjofSnSxAhBIz2vefgJJyTVmaXjH3EJvBfD0RhKiczT
ST7gQTwsR+7QCWgDeQ3AEMEzJLj+PYp6eD0xgKRSRz80PqiwRtZWSNCQEFfs
VhSis43kL0z7YV34R3wnSoKvPjuZEMuAKdh8kAO0k4ADnfyHFWX24BaIxGyT
HyEqI/hGx07RY08880wis1qpLbO00NWgUwSDsiRZG8s0GrHUSQ3U5gvXhrM4
OAEyjgL69KM0vGvSMt2ewgOUFGXl/ULc+CzNaf/y0UcHxKBXGmo1jMJKsZMs
BqM9VDQTPCEYQSmQPtYCqtlSiMgw2iekj4lqWhi4AGD/ScH+E0kgDIpFA6xR
cQF5U2pvYQxivOgIsLJ74itrrLNOEobYlsDXAkMghySjhmgbV+AzCMTrhQPQ
xOvgm8BXr28LcuKFK+d+ep5i00T30dAc+rVkuIsY8U9TAAJqIebpmtkL0oIX
NFME8OcZjOHNf/4ztAHbDCFIJVkJcBYBXKaBysWTV0pGMroFrkKsmfyBIifS
hFrMXloAvzK2gL2OSNAKrAStADtyZEMQvCuogzSkRcw0fXrr5w88sEo++bnb
+D3rocPRqvMHEniaxFk8K7RxYPFeyaUTLMweDADPD5F+OhHpR6SHIBjJDHQV
O77g8ss98wH8L94MGyC0lmnOmHmK1lkgNBSPZ+oGNkR0qMVBS5m5gyEWCd8f
EaBcimyhdfPdd3fNfA42Kzrx6O4pZwgdw1odXiFLRk067U/vvit+XATvIYr4
neJOlp91nq63MFOsEOemkCokJqLfP25wsJzsqIHNNBGWD5DTpD1PJ41YCzyH
PStRMLwHOPJIiH6BXLwB5oWGOdIlaBF1TvMsg7mxxVZS7QmJUSG9mGOOrAJt
fA1PfeMf/ygDgTkiWHpd9I4FNUPhJagy6oSgUenbhPtSkP6BdddN0NI3ME7q
jIqyz+JJEvnChE1fyPDDD2Ci+B9s2EOBFwAxgPtvs0liSvr+4M9uuqlrknM1
4bjjk1M9SKKzijBJIi08E+IDvJ7Wk1hAYr+/a6714k///Gedb0lar//jH8Hv
X5RRA2PoMV6X4eDiWGUkhWfWQ6ekGWtl23gS5lqyofmL5ZZfvlhq6aVj1oxv
e8XyjA/0wnCBciJBvAx5PpQHRw9iorbMmJnzermTARl5rWvan0Xo4cTQX9YW
LnGyLJfg++KUHgAD0EdGjTCfT7AVn7WwLDC6zGdHNSJgwTPwIiwy4A1Bk4ax
OG0x7zL5VVLjBYoVV121+NKXv1wsuuiiMWdijy1SrhMa5twFaI3SgaWIk4eL
uMScp3vOejEvk7cd2ElUPc25zC19JpQLpoC9NgTT4B9IkLNv0t2/TH7qN1iK
FIfHspqgEysbMtAHc0XMDAFoR26QUGT1cGnTLVlfmevr6ySMNFvNXvMV72XG
BDBQP0wNjkNaDFoHiBLnQwTwS4AhxIUZ5jPm9dLO2qrlbFP2srGtTIUoGq+M
0uCVQXr8P4/EDFvOiEmQmExntq+/XsduBc1MfHp6C4wba8PyEA7fR621yA0J
Mb26LzIOy6+4YszRM11m2WUjyMdfko5haKReWARAEz9J2gX4NVvqkFbNdHqZ
tm3LO3umZZZ64SaM3ehOwEAsk+uwmd+93cwv1glz4TP/Zs1YRzyOd9AAFYSt
4bTveOABtqHyWbJ++Sy/yCwzvgFeY1rwjR8KURA+8I5Z8aqH0yyf9CxLd9Ca
JsKRZnlY8jpEBQYAAArfRbRmqonggt/qsfeXXE7D0py0iKbbd0mz8XEMwZuj
GFOCx5b0Ikm1b3C5r341jDKf3uKLL97FJsj0EqZBf0m14O+ROPwVaSNR65R9
qsbV1M94euV+yOyE1sGosfXO9KT94C+PZNhAp6ZYK6nZ2DBU2BpTQIV5JaI4
OiWaUXG5u7YYeP/kRqOc2YKDX11pJc+sWGyxxeLzEkssEbFyF1uQvyM2hik4
jYHF3GsvysxyL/rcc40TTzstTawRfy8QPIl9i6nHHNMJZ5syIm9P4fXNuIKT
ax1ZP56MqbNHAcijQkwKrdYIGtLwpBt9/fozZK2WWmqp4itf+UqE1eYFR2e8
gOeg3RGmDeMyb7rzztaGG25Y65rSJ1rBuLVeaDekIPYWxXexY3wmRJXpMJXp
JZwEjjyVfBLTwyj5HYZ06Y03EnOl2TS8NjNm84lYp2WWWSZmtLpAdIJePyWR
AJKkYDjSZMmxgo471IzsDu+TekwRwK699trt1VdffWD55ZdfOZ/Y/M31BcWQ
ecAJvWb1Wat4cnK0D6QnBwRnE3uiTIqHaQOSEkxLHrU2/KwWjFmheV/84hcL
jaZYZZVVijXXXLPYUbPDzgkiYJNXpwAi3p85vYdl11dJ2EdobQ9WBLaOOC+/
rxkOrKQ/XbMbXFf6DUvErRKmsGxi1LFrFuQJuWWa0JkdeYKMwGHlml3zuNNP
N1p0za4v/p4v0MKz+6rQZFW5+rUUj2ywwQbFVqI1B8vGjhY4skeD3w2+IG28
Q19fKes4meMhWuOGfm6fffapF+utt54evq6oS5qgT8R4hkQ7YBNAghslEANI
bL3mwJ0Zat08Q3ttpABnloRihgnuBxdZZJHKDEutXHLJJcPWlhX0r7DCCsVq
io41vEJ2U2wmh7e9XPtEEbg9hAH7yQ5Zp0NlOKwZszuaZK4+Hy4s3VvsZKON
Nqrzy3oJgtKc+5npCl0zjdwe/JzI6xAhC4QB87s0mZ4R2DjlmWKK4WT0feRN
vDflyCNbgszEk7rRpJzpwp2ZfuELX4iPL33pSzHbr8kW0bqNoKpyfDtoTN8V
r9wT5wdR12wPYxOhMlu+N0mEBwl9h0Q8WVxRv4033ri1/vrrp9mmcxORhsff
ELniIKBGQRjIl9qV2tf84Q91plqbxZwh+AQ/On6nnVpSiykz5tnqnuc8obOe
J3NEd//zP/+zWFF05usEIuQzN9642HLLLYtBOfldoKl4Qmkc2MK8jjzyyDoT
1UOZKoutH5PRb7XVVopqxpFP4+Aapwc22aShRzovmeYbPgOShBcC4cAB4lS2
dasESb7V8zUbtB+cOGlSe4fx46ckv5dpcMf3YZ+eLxq83HLLha1+WZRcalcM
SM+YM2vDwKtzPgQaJ83N5qwvi6lTpxY77rij5iz118i2I1VE7ozDeiRbv/Od
fol1+Xza87WcySGVgF8B2IE/lHRalQFnfqXjKmXaOIAdJ05sS6HKeH2hfJ27
5o3Vet7MFwRmnZk/c//GN76B+cXcGfh4IcuuGh5WeiDh2Iy51/LJTxa+Tpgw
Qf/i79Hxe9gFAtDCN2Qrta6ZJ8cjkMgdD04EcgfwO9ox9+/lUVEOVFNOZEBL
mmLqhQbyqVu9lxZvZeqodz51HBAmzedvfvObxbfkMjbddNNia8XemkyY7D7Q
I8XorDHQLB3vTB8z31eQJMDT9wQEWnvAb2c51R05JCJRoAsSQ5cE5h1cXYqG
c9o7OScoJcTLqZncqQ/nes+VmUjQerPmoohLANWPJPhzQPw9RytXAksCYmFD
h2AAbCuvvHJIQlLQ8+RUax8rBEwBVCwks9lNgQezrUjDwsDwEdikODqqH66N
iX+jQ9gQgkGo22677aB0zEerSoifD7Vtsl7kwTsOTQQSoo1Di6ROJd9Rddm3
6mcwU72ujv+ts7Jy15phzX/2jb8X7sB+L8kAhYYGTEP0KcwDd46J4OxwAWCa
plPsRJ6GKE/SwRxyh8dnfW8UGFLHUUhHcI78POLBfUgsTUFs12GzTzHCtkGM
NSLxifPjSAX5GpyfSXqe6srd/E2i24A0a8YiAOrMBKDja615C3+7X7yzv2M9
AIYlAmAgkdxyIDc8A/oFYOK7AQ4kgrOwzuQ0wA4DCWFVrBRf838AjBxoHRFK
QPw3uINfRe3QHUFr10G1BboExAfLxaAmSFD4TfZBYVvEGwRT7IU8MsNvFo/I
p1wNu0t8hMGwLKh/H4utv5mgjKItQVl1GlabHFEtINSGxTK0rLHGGsEYMCbg
CgHhDoEYoAEPg6CADBYIlWDWCA3ElW3VixNOOEFhLcPE7lhLZAfh4McQFg6K
X5Um9mNcXSfb+nJJJTY+NkbKCFHocRrNwVqaM+WCCGe8h3EbW+gC2osvu6xe
HHPMMbVRHYrKqmmgfUFTRwd08qREV9tSsto+8falAoTsdW1elpUVCh6JYsIl
eRbmBfggK7xRL1mhGcgKs0O5jleMf66A9BICM6392YohjxOMYI4MF8GhaAiP
3+F3ZX6Dek+t6zBcN1kqBTZHLDl4yVCZJp4CPbf1V+kusFhKbXQQQaTGMFkr
/a7+T5PsS+QX/ZD8WtKX2t6lnsUA0DGMsCozdB0dw4jRUcMSg4JywF6AJjwx
qJvLDKO0W8ODnyWYvfbaa+vFL3/5S+nZVQouzzjjjI6+MWaLD9Hxq3rMoF7R
LbZ58rioC1yxEEaLJZhf5C6lApq51PgWhsBbpQySmki0XItpNBPmkSiMhNgQ
ANT2KgXYxp/YQPF2ufBQOnAdv4/S5QZqBCOY6SU8oInVttI1m83iF7/4Rb2Y
Pn26BHi74tcLLrgg/gtcYWYWJDPFcKV7DWFArevw4bx5MNLFYIzDeCO8ECNl
iUdmKd1S5P8QtmYmhYOdj+mwcwITByXC8uARe5bm2/b7rYLYgCUIb6iqoM3W
EAcLwkbwdIzVEmQsmCPjEsIVF154IVIsfiu6/4S478/FBn8kQOL/GD+ixH9Y
lPyuniNUGKyIsTWcCJkCYmToIDPDZaggi7nuSGLEWlhNxA316gvCPyamibUx
ZZQHcUoxm1Iqi7HFGHLahQjxFCwp7tToZ0XkGbkVYy/4waoI7UYRzfdEJX8o
Mn399dcXd4sayKCLaxRSnHPOOfF/JiTMzaLkd/WcXIzp4OfAcCFEzo+YAjYE
A3BIjK30CBtChBJmlyg1ldEROYzpRA7M2KGTpNiPSe8RQ1q6aTQxGeH1pvKY
M6sKOBsLrYiYMs/HlFlpYyC2yIoDcAwVyaBwSOxSUc/rFIdeffXVxY9Ftk8T
p8CmHdUzBX6eaaCQQIKMALr55VyQ87dyWlWNw0wyMSXYC+sPCDFiTKZH7Jm5
llHxb/6Pn5V+9EUcMmsnDsHyQAkEiyAk1KbUq5TnMg3kmS8nsmQ0ODkbtv1x
Do3WSN5apb7IBC1jZMcee2xx6qmnhiFfccUVoY0/4z6Q/PRJCnrxz1YJayez
ZEasExYB/5KFDMhyvlTKtYx1P9GBy1yutrEqVWU2zAR4QsMQkPM2WS6jZFyl
aJmIebo++iKqmXVIVIMcQBDEK6vdPQa3bEQ0eSLX4rWq5gYP7qLupjpWVWM7
4kCUp5AA5h6EVPHkk08uTj/99PA+qCnYeccdd4S6AgL8P+rK7+VWZ/EiBJYV
c8GnSEjEAsvmIv7UgCHURMQEjhl5NlYUnuQYGiVhBhhaNTVmj4ThmcRJzaXS
Qo16fDlbfDMPlJA2yozmSQsHSSRNikF+GVF3cQ/WP8dWBghIwT8AqioyYCDO
4zFQsPL8888vLldIjjhBAhAAF4Wo77vvvuJpBaKPP/54uCn+Dy3n99Boi9xk
GQEgEKwH/WMMjAW0EgdvSFdry+RyX7IxHGlGixyt9woucBloDyIDkDBK1BtZ
82/L2xGYIzNHYfwMxpyHYCyBxS/tbEpbd41hLj8kBkNNnC1lmOBIHiiaIOQ4
wmOxJ16JtODteLB77rmneOCBB4qWgthrOZwgYoqCP6k47lUFus8880wovaUP
bqPwXgGnI3m2UzH2KxgcqooByhCNL0t3LUIL8yUMzhfAij+zEYsJpOkPwgTT
HS5gkowcNER/MAzTm2qI54VICYNdYpgrdKU6PWSG6gQ9C1HNYRjQTTEYqhGH
VyI8SCxkFjb21FNPhdrfxPkxgThq/5vf/CbM4CGO8SjQPu+88wJ1mE5uCjzL
GQgDph0974fqGIlQFJlrU6a7VNdiDMtDe3FQh0EsRK8wyCQqXwgM9swzz4zQ
8bLLLgtjR61YIFuQFwUL4XexJj2zrcWeGMNcZQgWAZ4MGw8LHjFUG21KuYUO
VRel6gZ4JboBM0HYLAbWgUVcyX1NRb142FtvvTUWB5zCMnAR3+dUZLYoTBVL
w8DzRBTvQkxgYsrfVvGKvUTwaolyccq061Lhib0vlIdaVkGjr52d2a0xoFeY
hYCdcMRpsRggMXhw7733FtOmTSsuuuii4sQTT+w4tTxQdYyf7L+2c4x19XDM
ucnAHhg340WZ8ky4gyNDrS2d7+XO2swciTIOpI35sCLgFquDU0bB4D7wIRw3
JlNdIWMYbhKFQw65N2Q+vA/cxGxHwrW11llnYAMFzIsNXa6cyTsqtoLalgxq
wHWVRud2lAcj2ApDB8ZvvPHGQIlnn322ePDBB0MUcBdDM6JyWJzlFphabacY
6xLDuhhvsrI0Zh2oFGNENCydVa66ZKibl8wEG3aC6FEzloTPXhY+g2zwL4Aa
lSMrV2fBFByaZ3lHQPKolURmrs7SMS9kZiPLERCjNwJywHgi6QEFRYsOXbZq
DGmOOxKdREuqIbityxEQsSBTQDtZtkceeaQD+iwbtNO4kYfhJhYpm1bbMcb6
2UY1D4S6AdtOvHhvnKkzTsRhrGNsqJ2XroqJLJ2juB5bEorLyz0J5sPS6EP/
0lLV48sxXQSNSSCExHi61i0HRwTIy9EvbAH9GqeBk5PnLPTu++/fnjBpEhe9
a5/PXddSQyJWbyo4Ws3NLEdEz9OcwSbGfB2zMBVQBaSBDf36178ubrvttuLi
iy8OdWWa1ZgflOQ5PFPvC/45WLrZmfZf3gNnvF4TxokYQS3MGzHlc0Pdq1E4
0GEdBA74PdDcEaSTBsxTqFiu4MIdbuHA0VaZ9ls6tInHDwegDtxQq6Ow6DPO
iP1IDg9x82zSvvu2d5g4cWDdDTbozxf0C+1qyOwoCKUGi/IETp4Ds3sz70BQ
LAaL4ugIhSX/isuABmOM8BEMExyy3uaLiuAQILNjcaRcbS3WoMCitt2Mhf1Q
bs84yZhtaEiWxQEL4UcsroMpFMFAw+8wFmdKPU/GyXidIvAhCc0prLU2tjM9
foxXog94RYez/JvHJZgdCWUn6WvOIXKggB1WNoU46siOO+eud91778bWg4Op
AI9va7Yc3tpSHcOArsNFj3Ym3rthsgiqk81eIAaPQRJYYqysK+vLOpOCR3tz
jXYqxEk65Mv6oGOslda4Jd3jZEFt6xlrPMRX4ixyXwmoVn0lFpEPHcNDBwGS
drsdY+R30GlP2+mffBsmByfrNGvN8zSnEpdn7WTPUAd+3a9nXeNshaxZXhVV
mBl0PpvT0opJ2EHnSDcnKbjDy2k7DpHup9fsfsAB7fG77tr49rhxtU/nXjWy
SBFcOLLLwyWMqRqzVpWcoZn0sMAspshPHQlq3VlvHOidd94ZzpTPrD9EHnuu
psCcUmTWqBlyNwGHl6GKWsvY1R6XZQtm1tmyfnm0h406wcg4GO+vfvWr4hXu
iD36aDgSHJLTf8OBuO0cXTWQp/UfhTLXPt+ZGq+tbgvwCKSIOLD1DwLzw/R/
HBjhcACno6j0w2EBLipzoOR7Ccy55sB9rV332ae9/cSJ/fK3ZYWndLdmuQif
fTLWQjOg5x66V2SWay6Lhycmv0mEhnED3ASULDgLD6N68cUXQ7AAAMKuJups
/AiPd+T5cMAZAwaLUvaoLX1tyBltFtNZelgHjnqP5MCdys0dOMCL7cPh0QfI
BWEMi8P/5XF2Lyh0it16YVzQs/uYX23RDo9kCKbo1Y03b68Ch7waK+vhC4rJ
WucrpA8cf+NyJidZfTmeA0bnVZ2BdI1jvTiDXeQMxg0OlrWw0gGaFYYI06mV
6iEIgNlOv5cwrN2MHn0ghkWopE6I4InW0QcAAsAlv0V2ET1C4M4O5bQHHcFw
8xQ/i+mUCuNxLEj8nUgBea5NZ+hKFyfw9spH4QQsCpkh0nIvvfRSJCIwB6fl
GDa/A5RaZ/JtBOuMscS+RM/vwykJ9PVlW98e1Os5z9zOUz1GZu+T2TJ5RLlf
IjurfaLLqZwhybpMAKdEOJ3OlRvOCHNi3U6FkyRcvuJAErfNuC3N4TUo//hd
dhn89tZbL1jqzf7x98pdgq0yaLI+1h2n41grZtHLuXoDAJwAR9ARAmqwBIM0
kQBfwBX05i7NhlwJvggnU9UdsAUkdUquGtw4U42EvUFQJR0bzYhKO6TD52JM
OuBOJh08rxfp8A4MjACFIa+DAqFIZN+dWUeJtHpteZGGEKHhoN/nHXKbc9SU
FErRHyeL+lCsluY9yI7jqBj/og1sI9/fqm5a52vgBEEkBvTBuSKOLHKinMNY
oUlaB44ndryT1oYT+3ins+ydFE1zVYYzr3gnoU9ru5135qbaJ0pN+lj5t+u+
UWym+fU11mitse667bXXX7+17oYbttbbeOOGgpOBgTXX3KEMu7sWo3rY3mcc
Ubg8F5wrX26RnjiLgxXDBMgHA1qkHlkoHBwe4sorr5SJSRVrnwzFI7EFIgyX
C65u7VTjsWwDuIv94L00F0LWDWLKnxmR/GBrTBM9rpIfppeTH4ZHzg6bwtmB
z+QXc+yV7bTldfr1jL54/RwQiobwsZX7QauPZtXW7NpSxyZHjaR2/HxtTPzu
4px1bxlfR3J+mAjk6ayzzy5+pWH9huvCFDPTKnBe1AX5bpTZdzm/m24K59dM
zo87KCeXVYXihGU4PznQ7+61F86PQaFwdSrW1EY3Vx0YaA6stRZ1LRprfutb
3DiojS3Vc9b4e85OSTwuI+TVRbnn55J4FJuglsDm22zT1teNjTbbbNv49U92
ztLZ+TixB26w3HmGyDiUB9i9VNanOPCPJPKktnWARAQU10scDSzCv6FfuFf+
jbaa1zgFmyfK8yyCg5Y8aV7d0RiBqq1bam5PqobBmqrhIWaWqmFoP9US4wHQ
Xs5/YISeUtLelnxoCS19aGKcFoyVjL/HjuhWcy99nmKuB55+ul5Mf+WVWn8U
U+Q2C5fT8uI7XV5VhMBe9QJ7VdlbeFXZGDec8Kq7yatuo1m63lhUR0OtUoEg
1Ipjwt/eaivuDgxuuPnms5VKWZrV2E5hLpdOXdeVc1IFXUr5cPye2zPbTJhQ
5yy2nIO+jFKN+rEUWX2+a4nyvTWDC6vba3lMvvLMc9Wxo1F2fuAiToU0K5G3
nQzLp88le/lM51usqBXVPt1nUKqREpqSK2zu670r7QS0EwwVvrjWDIVtD8cX
7WGMZ3alzLjKF7Ep7I1tXdw8lPcWuUpmnvNFUYKGJFSWM162ASL0isSY0d56
NJB3k7TurkceCYh86rXXiid+97uyykjy1B2o7OGpLxnBU1NvYluZuUsO56Xp
XEZ5i1T3M+lVW5+58l6qZW10/D1XV3HZjoamApubpjqTXJHmKdzP45II92Mm
7rkn1wz22kuqynXbCbvu2pK61raYsThDOGeOJL7N04vIoyPVHcj8ZITV1Yf2
fFZKejcqEnd9ATCsGzsi9RnJ9oW7gDTPPlePGfSiBL2S7jkvdUJE/qIlTo0M
vtlDV3Na6i1JfnVmaSn+wbSUHW82XKu0VDFQQ0Pvj9d/YYhrZ/QTJUnua3dq
68pN476pvvfbl18OfZ1Z187x/5+kSsbh2mcUDAysAzVDR1MhvKpmbYdmcahj
t920XDvvsUetr7H9TuWmG39G5Z/mRmk7RUyjPGiCVZcV3iIVLaXMggujTqIw
Kqc0OfE/ZYpeI3iXpvBvhU4tCoyVWYtFh/DWKqr02uHLs5bpGGNn9z/PVFUz
Ej4ymWejU4YygFT6XJ+x1zBL15Eefi79fp0H1BbonOl1FqK63WB99rWgkSgu
RCGjuLWBHhzXx5r/LxyXszWwBHb5SOQPw3EXidd/kdunbWyFiwIHSWLwSECS
uhy4dJeivUNK+xChqRT5SS7RloUwZtACA28PWsDdN0o2QAu4Pu4a8p3aw9US
vFp9ygRQjJYbQ1z0JZTS59buBxyQ4DYpcFYKP9VbhaRGBepUJZPHceuSR+2T
6tqyETQldhIPiTPADIuEMt/f75BDWljNt0sq35PJ5lDTK/3q1cmhhu1xVirH
jfyUVJ5u9cnVHqn27m2Vz3WdAORV3lL02Twe4V2kLN/+kVivk05mvdKehuy5
ttowtNdxapX2Oi7tRXsZp2kvCdfHHnuseFkQypHnKu2VOKC95ZGVJRpbS4G4
dOfiC9yvJcsDmoKqV6UaE9RxekzE5Onf/z5YxH0fkkWgrK6i7DqtIzUnoIBy
PTUngAtPFvmhFlpC4jLeXGhGoWYONXK+gap1lGXMS/FyTolrL1ptFyamTgRT
pmgZpIbPx6aeBBQTYWfsoEZjcNx229U2LkX1kdlvHpygWWgfPpR0JmG184Am
cTnNyPeSnDP2pnCm4LVRkdZbpJMu5+cMtfm5FENffm/g30WTU0qsLXnELdSV
/z/wZHgG6WFSfmwdcAJvGJ5cnphbhvIirYNTofi8YHZe1x8egSbfR5k2eQK0
/FE9fma4BzyjqxWGMVTDx/Hv6VYYHPLv1QpDqpjqYg/sPXVqqdm1evw9T6fe
tKuQR4lwKTj0gipkLh/ssso82XWmYezM9gfNZh1KVBsTu4F8mzAT/efFEk70
NNkwXrnksNTZOXBfCjd1rq4VaOQLGOQUOIBHGpZ9NNwrKFkF81575GYlBvSk
83HVuDY21MFbwqhqfpQJtc3NR0Oq84MiKFXCPRxBqebgqoS71w7kisOwbZBi
Ztl2NQ4GKZAgbJskN0lvosUebLs8Nb00BUY7VYzQgzMrBCWaP0iDwW/qiKDt
kJSRCAp5CrS703gllYvmgBaNCayDh7nxCjpIIkk+hboz6CEFi/n3CWec0T7q
5JO7Nb1TFxoyDU+3luMdXODRTVbYz3SRbPY4z7vkkpihPFedUpfSdNgTBUAI
MSKxcuaZDKy5r7j3BjMQfViePdxJuurpANQQwkg+mDSTj8Hb74LG1fzRSLvF
rDtUug7O15YIzQfxfUKQbR/9fJvnVZN+1SNS+S1Mn5wYjpxjLjNDztHbRM41
RtFzhUqQc/9ZbgSSzqZP7i1dKMU0kPHnJN3H8DggapJOvh0UyTdyMpJeXopZ
Cq4QmYrj5Ng7vIY60BQpuvnm4Ccu7gefoUYlUWcvXsOhtmDISe/hLJBtwrnQ
SkIhDQcSgTdA3VzOHhVEM8/P1JGy5EeedFLS/FptPv4KpF89dRQgmHTvg579
aWTV7MGdnQrE48sokcfuiiy8DnWTDWDsuDhHEwwKQJAJ1dZPgsqpep4VGOmk
RL5GximoOth0//33B6vBS1c9M/prW/DzcvTPj2FiD2nHEyJ48MHiOOivvt/W
z4B3pfwWGxCctn3KMz+Tkt8yyIdrc/i/0vvqnnKi93HQ7D8/BL13LorxO0yv
0ntgADjJ6T17nCTwK/S+OdndXD4f5McF8ly1OcgPfYAy8hNdcuRdcAPPUNgw
Iz+Xy1xcKpvMxrZJ/d35Ck59dKXlFCfNOl0LrruuzqkULSDKeHFSRv2oDSBS
mlFcGIrj9B/JGWrD7Z71vTkudUfApeUNAQhVcGskkYi9CUOuT6FIvolNKILR
nHDmmYMTJk0q9x6WHpHaz+wREYMVR72h9mQTMAY2ACvpMZxGW6s0IDLQwMCs
VSPs2pZ1sMqNW33Z5tI0tVZmKY2ggRL6yk1+KimPAPKh2p/MTARQTT5+UASg
j9gU/+L/pwiADX4igBdeeCE2/NknyHCmLZ/b0O+UpZWWoO1OVP2EcQcfSjXd
L8qaJsBxKChIxhFfACeCDxFAbpjKf0fFa9pjWPErzc3OzZoxXJqe68ZmKOY1
qbkZyqqfG5iqwO0/chNoUNV3ndSgwpV985r9jtLJxzODeFNSfVQdxka5ebwa
5usSibA5mBymfplMHvPXiJvybOv0WKNerP+D1idn/STV4EBsv5GD4OpNJanG
Wjakb2U8P9Ybx01ZQUvq1RaGt2UJbS4UydLaUsGmvuZm9oB+Zrb0a2RT7KF6
GVAeBESWElK1QHgBBwEjZSmHCwJGOob4hY8QBPj4D0bmM/95EACmcNiAIGC6
YlTuYg4TBJQxyOKxsUJLKpOgaPWQNcMwCaLU96+feKKYLodyiSiEe6N0ylxr
GJAcUH5Ia7ysmxxh8c+lamQ9UTl3HoFAkd3U+xoKALr0PXpEbCBZuqki0QSH
zWFcWCtQb12HueU9+KIqohSMevKvvf128fv/+Z9Is1IRjjJAuC66gV1fvpw0
bWuvgw5au8fy5Nw/Pxlcjc+8NFXuz0463B9955RwD6cMP23oGWXzzsXQ99Zw
+/Y5hc9vZLt2y8xS+JyzDHdmUt7NG/G1Jf8/UHfudXE/Db7CpSegYBjqXtZs
XjQ4S5QyT4Fe3tkPbSNHDtgBpd7MIelCFTXAMnofokAp/O30Pkzhb9TOpni5
qD5ch6YmdElDmVqp9yHKJcVpSsOtsfPyVwt0dhc416A3wYpWSZpfrq3XpvYC
mASx9aPtdvHf//pXrZ7Vv3c7QjdfpN4oh1XwWWL/bfkdjonU1uixPjND2atr
g9sHVTgPYsr+sN7LgcUeybS2dI71+WxiGnjrakTbq6aJt0bz4hq96HavXOOH
PMKZ7oaNTLddVKJKt51v7UW3IW9E9L9TiMgxVc7J9KDbX4vXL9QIpsHVhQSU
7h6Dnz5fKght9t6jG1myVeNuHV2NLLlrnzUUAaRf+ctfkuaMCcxz9z7KI1IQ
7rb77mtdOW1arVtn16MVW+pVRKnxvGPHaVn7wF5tXNBLSg6+p3f2pU4GVIF/
OPVQ5M3oLK4Fw4vTw1rYQfnsrXbYgetCX4+hfHYIyc637T4qyUZtgRfComFI
djDRzyfdZe3zo40jlYPymX3vBFVZssnCcCw5Pzqa15aoHh393Ags2UfAqju/
VRaW7/zilYjGzZKf11IhqypLTgxsIF6/YIcwuAmdCQOVvvP9crcddMM0tyI9
N7UijerW0lkIAT6YKnN/c6+XMTT/KJ4si4GXXZKkYHc+8kj7ujvvrKgtxMDN
o6LkeNZmBFLgUtoQgujgQhl0d9wRnj/7xhvRaqR885zR8BHVjbaXGhTVE2+S
qkOqmQiXI9jshPFgmCLf9IhY/d9EkF2XiCUgoeWiAUTxeMlhCPJiM5hu05va
+fmpKtNN3KQeNwo+OtOdiSOn6arYv5/pcgcApkvxKwC4B9Md1O+W7vATXXwB
BXbvc5SVkC06i7GXUGnrFT16ZCPwCBNK9OcxvfrPMxQWD03fLNSGYpuUoRXq
0R2mW2GbTlpARMiJu9sO1hH9ZlJPKl7281T1Orp0SRkp5UoHoLc7CvvxaItE
5wlq5z+WTm6RvDgtnRMk6QKOYxhMkL0gGg7LYOghvcpHYLq9lgbKSRabI/cw
XSI6khucUevhD9vCS5jukjOYbntmmG5e1wk7mRmm+xGPnNbmYmhR2fBj/2bO
ixDguOa8cCusO+e8SUhwqjIa+XQLgGVrb9Ps9JC7pna6rqXNSzfYyptc2FVD
Jf/4j39EJx5ajL2moCj6eHD4jztsUuD7nnqqpaivo7zz8FdXayMye2y18MYz
UjeraB6Sjmjh9Am72lLY3/3lL9FO9y13s5onei3TpDA6oujF1LD3ySxyL2Qw
IPaAOXv7wRvKg9fBG8aJNwysueaKM0l3q0d9etFdABX/5ysjhCJcp6j4xKC7
cAY95wuJMoBeprtOrDlpnSfWTBlc5fDD0t1qYg2bGeYEajpwPgcKzI09tmtb
Nm9XpUeDU6nEtj4a+rohZE5HJz4cVXZScSSqzOUHqDLIDYKD5BVoaEgmZcr1
01GwP9Jc6SBIbCam3rOTU1/ajqfXqkFOSW+R1oJ8osnoII16/zc1F3sntXKm
PY+rg9OxmDaH17Va1vgy7Tw2jIxX0tSU7BqYenalKxB7QewPdRxCH51e/SdB
9bzBLWiIxJuxQ1/EvCi/iZsOJXb4Bs0NzDc0DEkg6iUsPwJfNiRV+XKvxfFh
eITvQjnsnnGlg1sqFbcafFkLmmVuF+frhgvFDceZs/xaZ5/e2yvDceaPeqxV
H8ilzBrO3vPOQLXIeapIrKVSsNGHBGt9Tf3NGRX8Yqpp+8mZ5tvVk5bm28gX
vv2cCAK7X4TXPfj2eiVjiO2OTtvuBPfs3BOdkb5w2263IyOPdT/VvqTg4tNk
EYo//u//0n05RWZjij/o35221G6+9txz0QC1S/ln57B0sFzSbTQEIlNyTtYC
LA59PfYYHQtTC7v547VoOXaFLQLs/CwpaDr2+Lh4kBSRnhPTvXN8CV6MUBeP
Jh9jklL78jD0Ooeikeh1rn2+Emt6TXRIGRD+XaXXpEu1Gl+eQa9bI9HrSj6u
zu9LZ3yG6t9x3LVKr/XHCl72qJi9q7ZjtRw50IDAUvmi2iicZG3hUOsqK8d1
+hxmzsrzmjM5Kwc+ECRXEyiARrgNHayyck213Feeow22u00oW9iEjDj6w7Km
66RGSHFME1l6/o03khr35Q20E8LOEk328lZz9PYVk6l3aTWXTwPSwdXDcq3O
+vlFS8o//jG1oPxU8CT/wZNgRLwJTwO/isNe5BulUZ1rO9lhc1J+QWnEJQie
D65Qmh0mToTSROnWZUfg5NW6FCOFS+bkYDhYDicH2zkPZ05uTmNOLtwuXcui
GsnATO2YO+Xi0ir54al/14FY6eOoVFW8Wro0L6CWqXan0C3V+keBELJEV6Gx
d/ywhB1WSJaPz+BFL8KuaZRHh+aI9rNbpDNQ3gwnDmO7BdiD56IgEIHbRdBf
FIy62+vfK/3h6Y1KB3SUDt6MeisebN56770+I9KXUJvkyz7JQXCiKRreZbrN
xgfs6OVIFBJMfrr403vvFa+9805Y0B/ffTe+pnEjDiI/2EhYipO5JisWEBxG
PNln0bHauFgBh5F+HZg4DOEudqfQtyEbTAU8Z467j7RC5u6kpblnQlhFSMXX
Ff+KPZi7l6HD52NT3BVqRtoUN3VxTY4Pw90/aFNcilnC98c7tWOH0++KbgcL
ARFIokhideyltmAILz+MOTMMHXVm1xD0BsXZTYSh+0pyAoqGLL4877xQe3Ot
CerN9So8N/kx8A1MhSb/ONFkdvk4RvgHxZowBBrFw8L/8Pe/ExVGGuNV/V/e
LFShYZs2hX25en+cY6jBxqkpAP/BisiDA7vRk1RhG+k92nvQ2uM5WYp7c8py
6jxfWIARgfJkdLwPGVru2xYcUE+nQi5Nt4J/bO6imQV3Kc8LhqV1cZdJk+Je
5Lc22WTJHpFUTtTzAiMjbTiYqLtnA0caCFDZUiTh0oOot2QcZX6nv4uj52fI
saWco7tKv8+OVzn6B6UGXTY25+hSv1K55+7i3uYmwyk3ip2UOiQEvafdzqg4
Vjh/F+02E6sevPSNZtNurk5yhbIX7abVzCaJd28gHwQpQa3h2mTpjkiNOrui
v3QihNu87hlK6ylgExWWktVKhRvVISVPvPLKoJQtaXW6bTPArhDnRch3oFpB
e6R212ddZ9lLQasfTz0znym7zuoN0m15DvJ/qLDUWd+jK/kCXVvsHaICeKe7
F8MRleNNVDRzzu1yngVpiKi01ll//Wh4sNj/gZZXAyTTcvJg0HKICp85JlLZ
CzYtd9KdbfLcRwx30tXe3HXgfLLpo/ByKW0ZEi49pCFSr4quBmr0mUxh0uXg
N3BsfAB+CBQArV05dSTOjSRAAnNuTvxB83LOzc65kB3OXV67mqexGf2XkEja
UmSRo/EoaC2PiUfHw8dmtPCRTkkPp+Tzk0m1pXTWuUSzG3c99pjv3ZT3yObk
7FycCHG34uAg6Ugt24HV1sLRy5fWwgJ+URI0l0Mh0WueGo0CapqCG7BzSnJd
oiRXmpJwoLVKSWS7ZNqh/FgaFGlbwRX4QjhF0L/IR6TevdaHazdsN7ImVJcB
rcEh57zydCLUW7A8EK//1AceVvXuuR23K9+NtJHTi3pTy8C8w7w6rxhdVV9D
MaqbGomGqsrA6+jraARTmyeQP2dpDhGYMueyYWekADmvXTVweLTmAY8ur7rO
39xa0+d0Pxs4cGcUigMbJM0urfarnj49dl/y7q6k+Z6Z0fased8zz/iyY3ky
cuwA+TXvG5I7h9MOaYMtkMcS9Og65lAbE9+O65ziHnGsVOiKTnYhcKp206nw
4NtvVXIh4+PVZyVyQetrEpxEDPkZMmFIXJ8iBdf/b6TQsAZTaBYGGg0bHIFC
l7trC83UuVJ00kUeMQ13NvsgCo15keko4bZswekS84bZvLuOG3FYR5N+hsmS
yoB2i2jVUf569JWax61F44Nx52cVc1LMWVJutXPfpgcp3rJkDw329iKNkY7D
neIMXWpYHf24hQbh0wWvbHOjr0AsQMjnR9vtxh0PP5wUNBXq+BLVRxoNPRYw
s56ieCjYHemRKCVNqKELPB4whLX6IChDQLcBzkQXAu1zJjwiXdBzOpfoRRcg
4eOFTvnZG1/L1oq0tDoAam3hD0mFq+FKdRMFheQGDVQYRAFkKT9USToFFZaW
rT0jizdTx0FRTNlFPa6SfTbeOBITRoc8o6qOmtq6vQYUAGKU66d1k+dAaxke
JisfIIymk9fche/zuJcXQzTFRQpQXKotsGtFtrkXxd2qTE6wI95md+GIVMc3
AFWrioZca40SCWMDmt2K+wWadfpo1vra0rCBK265JUPQWnnYdtn+vSdPbnCo
zocveNw16XxbpmhtKV6bk5umHiiUb1pymqnq+aeN5PlTihnPH3eJk+c/RKLp
tVmQ7ZYVabd3jjLERDfp4MJHrc7fs/4bOS6kEzghlQS3pSQYR0G5ANmL4+p3
y42ApWfqKKjBHE0FYd0JrspxQTiG7y5VVU3t1QgGm0Z0LjDOVBEp40G8TFtk
qM7g+qJj2lwxTgiSmyFDVjkfx51cDrUQtvYgqziW2rYphbb1hAmtI9Kht3yX
GeeJekAIwT356PbtDzzQuExamWoblXW3xvRPPu64wQMOPbShYL3xgwsuGDyz
2RxUhMMNyE5KmA1FUrOxlyK+RnznMg1D/bp0cSS/nlLAaP4Z4p1gC9OvdOka
cjbcfl0ELMH9nCggUNm1b+t9KzcXSnu3LX3N/i2RWTmtz3T19s13rj4KjaVU
FggL0rJz5QrMVRorjSjzn0vN1CFQZ9ZS7edO00c3N0AyzhrAbHo14nW96bzn
BLaOweRKCtqjlKwENkovutHRl26O8AJeIeyViIpNUGyzengl0dNaWUJwNjBv
cMqRRzakQU3BaFPOtnnRVVdxMHjwgssvH9h2p51qs5dKWdYqXCwO0k1NvWnZ
840DoOnaYdU/V+Gvl3/mVP7BohzDJRyrZ2Nz/yx2Ff45bXnbP3fBHaKv9rdl
GRQl1HHedRakFjunbX3Qxysxtrm7CGleeoUxWS16Zd3dX6aslKjFqM0aBwgq
ni0npGVacskPPMKZd0F1WXXIHt/P7czBUC9ts/M2JNppVzWNZWCKLAnjEGz3
Rb+OsYHgfCtv5IdzqFaBTfyyrLFbWzDpkNQusPH76UhClwsVPs6sCz1Fv/9h
brVXzqjahTYW7fR+/diwXaIrOzV14MibkPx/lQ/mlU168cHqrSLzQXZo8DVE
m/YxWVkt+GCZEFlipg5NGhBRSwARNa7useYNsKtdvKwjRiO3h8n1g2lhuugp
76Y3SF/ZmpsvZ+t0J0Rb+EVzYLM7rWHtwFJFyqLMszcIayF3PiNwYXa7337t
5i6/Nn+nOutV+pmZ3bur3hzJ/RpxqnsoD5f/dXuqyuZdHWF68849CrFBXwYc
Kf9rxsWmPkZF4Ibz4kgialJNOnD5Rr+7eYhu0Zk6kghaIYaqKozU+du951zV
2U2d8vZnqRJqJ36W6EfxwrJNfF+emZRoadXU18WeykLttbJsez+byqWzkSbk
d09yZ8NJ7FtyZ6OPoySZ4Q7mfNCVTzsbrWY929ny4n/kna1PhtsCdoY7NTzc
+QTcBiSGs9TkNrjJUgVaSIx+HhJT1rP80ohH+/gadazu1dld5EXx876D1bV3
BVw3664SJNQ5b203Uo8WLkXqIwhK2bAhtW/4dDiMo3AY7GJcfHHEZ3HBW2wV
h0Hal+0vHMSlN9zwga/8IIchhlvz4o+UJa929+2x81PH5Pti52eBWPWcQLhk
Xa+7ZdBUmklQWIa9Mk6l5AQidfuJQ22YTtkY5IvDHmoDxasKnHelzVtk510O
8+Z6lYLHXU1uPHZXJYMX+0RF3mrS9pia2Lc0vtSPJR25nz3KW5CbiaPlXN9J
l4UAfzgjd/aPoBfTfvtpmbTYtUW6SkzODPgzLabvzIfjyXyJezVv9tLCIYbZ
CBGmUfl5vk4D2modfft9lpKaxPh9DJuDpQB+7vdTSN3U720f4vlC12kuPpz8
rmpmDuIuAD5c5/i8Cnq+9UQI7qM4+B6iCo4Vu+CFO/DZ4hA/02S6aGVa2f74
e6EOoOPafVHdgH7GBRd02pVVsaO6usMBOtus9WzL1oFX3v0uX01vaXkVnS1A
VDKC2iiQrx54MG+AIHLqtVfrNkn4apaSo0pu49TDV9fGl5EmZ5VCDavN6/OW
l24Ay8CIvatdFXOr7HXDFrrF+NjPgUMwRo6KkzPHUlPhna62l+4XCd1Pa1je
MpsdMG77CiAndEg5HEjblUQ5sy6ByTpnGxaMfdWBULZct3lHzEECsM5BIhKv
F4DF8qDeKU+e9ojIk8/XlSdH9asuljwkAAvzJngGeHtdFsXFyqrLzndLDduo
1HeDqp3eHdnlDRarJ9NcJoYVYWho0c0yDy6lcAKdXVM0Da1yL0w3VnS5i9Tv
IUp+J1e6aMLWA4U73JjHnfrsXf56V06dga0L98RW3CbTdJzNilWb31VTHHku
zmkO5+OyrPGoSBrP00ka899IzAfa2IckUYxXJLEDN8q7Aju0Tp5xp7RYedNS
U3aPMjexaldZ89teO/PuesMC8FrgEfNyH11OLpItBAbc6Mf1N92HmWdQTThb
rMWSqe2y997NCXJaSKG6PVXpnZoW65ND4BIoyx1clebnTcqdGcjzUM4OIA50
F9TpTph+vCthys/hERAFjg1zImfc6xYguWKNdWJaIYZXRepeTS/zDtgjNVH0
6lSbXrrltIMqTkSSKnMaz+UIDIyIVM/MV6isMDo7NW7atuqR6tvMWKGF4nGY
XDU7WF0V9wy27wb7vSJ5ZhDJI4Y8O1gPSJ07FBfx8MH4+H9fOwdFWB329ocr
6iDFrH23jMna+KhqP1J3UOtlPGhF3kGrWgir2t+S96auWhq/PGht9gBlvse4
3EvOtRFZopRxbcsS7KfK0piLBAnOt45HQLrQEqaQE32H7flyGMVsIKCXjaOa
OkPkKS7WdDrJszmHJM8ceYBrwzidQWFg2QN8yaZvlle5TLWbr9XSFtKrHwEY
5KVwYzPUgFPWiJ5QE6qAhQCxabejsxTGtLRb09az0yqU/dUXgfG1quW/ekEY
/x4ueZlLP2/NbENIezhDkpbM2KEKmahRM5JSs3eSUg4I+AUnphxbkZzlGPau
pegHXTnLamHtd8/IXh158/5x7uzuPtNVesPkUEfuBYOZABUBAXGft+zdNw7x
+zKSRN+UWifRl8eTP9fBJu8VVx0Yo89DHmA3d4jVaNB2bQbD7Cy5PAHA85OR
iYBhmWM7ByPyKi55g3iWLF2v4oTcbqXAYx8oT0/msIiwqk06cz3nM//vjgDW
ql7pTiCWxYdOoPc2w7wevL1DEviAppAEXt57+GIgTn5XE/VCWNW4EvXx2+3X
qkLOyb3ZRy5gbwbkffccag933tV7LCn52cRF7BFjX7ydpwKMJjmo5z0hPTee
g+NyDJ3T4fx0SzUIZUygCsDunTjnuDMp0wBuSinhsvDlMoEmrs7LSFDXaujL
9z4o7K3mrvKcpfOj6RhFGFreTC2vM5pL2v1oeR7SFWSXwp2z4R5p+aJXoTrv
csJnCbaMiD7Rka2DxCpRMPJ7rRg9EU0uW88gnR9tatRJtuUlsaUjFHWSqHoU
1M3sZjYMzbcg8urcvk4L3QDYIImkFvAj5sN58s5yTfnBptZvzxju2K68VbXF
WbUBvH6mvIUz/4hy7DVDZNers1lKb4ECtSTI5VJMjznkZmA3NhyNtZMeLo43
h7RCsqQcPoS3EQ1CYd29zFm3PJa3IFPGrU2Cdc8UDnq7qpr9q3a4FKTVRocI
5+sZSVQDKYMzImQc1VZbGJUAt6WFPqRLeoMou5+c+0aebJtxn17DfrWPXy45
Uzwk4susgA9ZGqrNcY0SP0u+FQNx8XjH05YgakyTN/KVe8VYP8aph7DnqqfM
JacVrgqu11EAL0CebQdNqq2fuMeM3skaKoLzOYk8ekKrq+TENmskr9KCXGgI
wDkSfCJhN4d/uI5APTjfyGN0JiOObX3mDHzUs9t4myQ4joB2mYMFl29laryj
R0gJ5T27q1aFDvTQtsi8TR0qtfyRXtLc9+UtofOefcNJDNVBEs4sQefILCE5
MgIcVMX3MTwzaMebTpnzPCEfOyK1vWOss1GAsav3vFP0dh2cYR6dnTY164kz
DJpX1QXlz+EZuQ/WmJoax6Fd0uKIzhACbMOswkZulPnxhTwqdz8SdIc3E2MQ
lmKQdJXlygt+Ah+RwqGu8C+vXqWVaKFj+8RYZ235rFDu/80bJLXRKU3MlJbT
dL6RSjbkRUq4SbOZ/v0t6ZV9NY+xTqWiArXDSil9pWStXQzTTGRmWsp714zP
1i10iVdh+/gh9IaMEieZcACc8CUxD/jbN+VSchsuJE4rVb1z3xjmmJYvkubO
nGHhH/qS5QFZX9KCu0MDFQLpOUVJF5ev6rQi0ULspuFb2Kk8XuThcJNdUloo
GKeNuNqEvRfbRIeQFmvai8szFXQOC8QdkkCow+hrc4S0iGHRo1zLLSkXn8Ty
JH2KsNb2i3HO0mD1vPhGAo3Lx7qR0PIQCHr96kejG5ekRMEbegpQAYFyBPR3
4x6S66pzk2M7fV8Lzn23Ri6cJZq9YjEPompgfGbyPixnk++Fkpg86ocHBMSp
QgWHQKXyKNNBvuEp9VEmwE8ds2clvuxyKoyJdyeJ1BFJbc5iVTZC2R3Tj66f
2ohQbm2r1CCH6iBckuAeIqVRDzj0UCKTI7oEQtnxITvTvdopg9EMIu8F18tt
WONy78MGO/XkiALZLPEFAmuMW3FbILQYJplQnl2ZJXa3eJZTACziMssuOyoE
MUcxwDah/psuEy7j1SkOkzpNcPqe+6FHnHhic9/Jk2tJCssnwpH7dGOu3+b4
N04nlUU/hhNATjiqwScpH/YbbC69epH7trx0d0CmUOZE+5h/m5Gtsuqq8kPl
pDu9vVJzOgo/b5n6elE5gc5x0V6DuO+EE5rHnXpq96RnG0SMrtljlu8gMOUy
E14t1MUUenHTnGLZoIFZGlwArb06aDPjdIiewuSJ7ve1V9Qzv8qCaKJe46+x
kZhamTFdKlNumQpFUHyKS7ZcKZ9cdrRpH3PKKZ5uWdB71rY1PG+A64OocZag
e6YjBTLVoxtYKTNkN7BXUOPLhXReJ22ZZtpajcIdsvZ8ptV+lnlrQHcHYiOf
o/qpb0plpnSg7ZyrNLhZkzWNcqYLBp6MFPrmIVs+U4iBZ1llgymQp0P4IWmS
aOiqXKn7+tfTJOcsVrfbS21lXY3X/Q9xe1zpBsxpf3TUSSf1T5YUy3mukBwt
ypczEbPcqNaTJum4dLjcieN7O2tnnWFU+QQrS0k3FU6EpUk2qeywkX41n+Rq
yWtVfXt4Lfl2vJYrQKQeNQONE09MkyyrEcwSbCLfAYBQakLl/BboOKaAIJij
Fi/nRw7tqvODt1RzGMkg22ThSKlPTZNbS6rOoFfNJtdxyXif5JI3Sy6ZxpjR
6iTzPkd+//uDMsquyY3mUE1oaZbgrXlmqOdKmkX0yEyGYJPfTii3uVbaBLK6
ZwCI5vlFQ42+34AyHZpmhqHhKjSTzsxWSX51rdSedohLwa9WXIrQNc1spfj7
08ysZdaF7H1gv0P6konn2L0NGxhgNxkwzYDqN9+hVnW2VQgjN4lIDAsimM1q
FGfJm1hXmlnuMsJPsmGvR0URNbsM/GQPl5FmVXZl+zgnwVs+7ctsVtT65E14
O94ok1fn0RRAokPfbMX2UpK0Kd2himm7g+Rkg33qktWOiq6TwAUC2oDwIk1G
ds8b19Dqo4c4BzQlevmxYwQFrDiENJlV4+8Fm5EyTgyTj69xQZADKkk+XnTI
FIued6xy1zSuuQGr+bbmvvvuOyBlLCcwutM2EzgAyKlf5VnA4Sy/aNItnUMr
mAU670bdkF2GANh3z6KxrGbR6cypDwRjNtTLKKGEqC6rzCy4mzVVXwOcDvnS
TsPgdhMmHJo42Erwj/QKRs1MhNizxERmC91iOQD09bOezigCmCfDVdAgacq8
pRQDm2xW3uU9rHtJVkny6EwGlc0QpgqfRhjskIvATIYbFDvp/739yaQUezQP
PeaYcjJjZryGk6MSPY/F/cxA77k6BMtKxVKgWJtnHYAxWLSD4RCtKRbhbnJl
Vp2uv/4I1p45harns1M4pESXuDLKUd0p1DJO21PRSeCoo5qnnndeCdNjOksE
NPMKFCpqhmtEOY/qrJNnxVnt1M8dcGUmUEgEHHeiACROnu+9d2v8ruWe3dSu
Gbbz2bk9bMft5dVJE4HBt7sJVj7DY9NpAd9dv+Saa9o/vuqqNMPo9rZqejw6
jqmgFlonjY8Zztvpd593F2eGnfbKHGkTJCFoSDLCpqIHlo0qYRsCjpYYpWdZ
1kxZqMsGLOjoPdTDQ9EMN2ZKupN8AVkWUUTOX3JK75i08Q70XXjZZXG8WjNN
r5wldMZeCFTl+ZKonRTayQzdByNXIawcwOXVzIZyS2CW1KkebXhHxWjwyoJj
rgQcks/zk0PmOay/ysg3IoSSwtbyeR5dHnooLrvuuihbTHHvS66/fmDcttuW
bx3dBnftl3j8xkECmOfHQ5mYa97fpoPJ7HlyjZEEA6Ej6TVRGvfKlFLVGYfQ
Nu/SqhHGVb8p+aQ/NVCddE+XlgdYOGkcDHFbSVHjABi39E8WBN318MNxb/vB
Z5+N4hYcxRz87ncHpSTp1aPL5zuikfJAQ8rwfu7weV0z5ywQp07ICiXmGNCX
cDz6J7I5ddZZ0QHl1B/+UM86/YIL9B73UKQ80bGnndaSCLqnv3Cjy4JHcIad
oDqRhZi+2zem6VNHnWqPXF3nKjt1hrkvjrj0u009p9zhHRXrbhiUBOrJiIEp
LAsV9+Tx6OBHaFsKgFJsEAUgODfJyWYuNHB+kustP4wjL+dfeqmEwL+5FcXV
F/kIKjz4aEsphE8PEUJPX5qnV6CBFUZwfLrAR52JEMKrr0aRCK5NcwEL7UQQ
cl10fkgHnxYK43KPEN5p94eOmGSj/VtlYsgITqi4m6lxBJjpXnD55XGMlAv6
l1x3nUQh05MoOBrsspvSkObRJ53ULYrRQ3zW1+IEMAo6thxSlooDePZItGJK
RivSXcY6shBHoPoG1YooR8A1NAAfB4D09KtxK/Kg5FBQu4BTWRyKEH5L6ojf
cjdRrBFrAGaRBM9x46Lo86lVoIQuUuCoO6URuAp31bRpfVzKlSC47OKG09wk
PuvCC7sF8ZmhgkgeFAGADWhvQq0QBqrK+uwn28wpCbJGH9ALCmtTipg2Btys
Ql3RHVT58OOPb8thlIL4XJPJbpZIFAzSjR6RfRSC1fddbw2rmJyEcHxqYZn3
vPNdQC4lc63nFw8+2N2oON0f5eoHl8L0e/0D667rs3llEDBHl3uwt83dFFLA
46LJeN0t49zcuDg3x79BTjt8bvp3SYViik89FTeOGDLazO0UpiPwbuw5eXJK
C35uENEwfawCV7lOUkkzNfeBJTMMWLgVYIhFFtLV3VaKwI0nSvlTufnFN9+M
vlD30hdK6H17alCFmLgn95PrrhvYf+pUi2alNKRVMmWJtrQptd+hxJS0TAQS
Q8aDsnoksYNA6gNw4Ws4LahJjaUAE32moBdVZygWQvEQpnBuKmeU6uYmE+oP
80jkqBPHBhHiagI7I/TMpEdsKkpysvCz0/TXlUH0fm6EUtCaFtfvpOKTVD99
5vXXow4EwIbYuHWPeK647bbBE04/PUmmjPQX6YJWZ3/WrixYlYQSC0NmoGrA
HSPmM/9mYVGQ6Zl0wt3K91CfB3f7Mxk8UJcsGwnBO5ICzd/EVJHQOhl/c4TB
e7GnKakJeDTZST2h4t6MpHN1kg6KQUMd6meW5TpnLf7wzjvFbwR29Au5J0kJ
Ccm+BgW5STplJmueLr3JMyvDEdgdTWAlEdSbke5LaRLhqFgTjplv4aS51Nvx
RckhIyBAwN3ImQz+4IxmsyEuU2rQfCELuz7CHtYGTeWtnUYutAPq0cjFvTEw
HjT2lb/+1aL5vUTDSPAFLBf2TmGxm3/96wGJOImmTGbON4SMOiTsFVoAgl3M
V8QbQGQRMadgwHI5Cu/4Fv8NMFg8dlCdBu5cOEmd6MDNH11xRVP8JlnYZ6P7
wQboTc6HpbNs2EXz+NQ3xDdywF8DDTrjOlK08njprbc6Fenf1sdLf/5zAGKU
/nnppVg2SllJptECMkmpzOXPi5S6PBXMBeAhJ7lZYo6AS2QAOHlBCWpuOXD4
KuPMx5x6qrBaHFFYjecyacal8LOU3EBcGP+rGvILqXQ9FO+O1AGZW4NSg9bp
55+fhjlvKLEzETuk4B0tBXysQtTZwLQQNfwA1Ylic5o6JeHoDPGn995LxZ1n
jY4R7dQxAvOHafFz9z39dFvh1MFdEuqYGOZlXp1XUh+fBTIRsKXQ1P4bL2Re
3cd4ZWfBqQUMzMAly6nb+/b/lkvJCN2DhfYXLDgSkoG0xc9K4czTiqrXsjXr
j+3LlfjOSFd0ITCYLWiLcwJjKOb+6ttvF2/+85+2r/dSZeCo554aGjAKQVHr
lnvuSXL5ygz7Cs1ZPYubLZcow53voJWZwZBJxDmSB81FUHCq6mlOfcG5ZynO
1WLCtvlv6hHgYS6lp285Rkq8ot4Pp4ZOmAFRkmCjJTMrJTNnuPi8YDJY5649
vJxLq9RgBe0hUpCq/5nRdOFf+vR+KgnuavcUMna1ezQHA1NgOnj5tGm1LtEs
EcX27cXXTpCzWSYW7666lTdq0mkwr5HhK36UUXA8NhXv+cy/XT0WEoT3RYV+
r8ViyICkPT6YhJCo5aVZtuSd01DHtrdIrcXxBkA+uMPyEOWwBhelyvx02Xzq
tddGpWrS/6pUk/5b0hmK4FIX9+myd1FbUOhIMSlMeHLzGtan0/eTM56p7ycN
hpgNAWd0d9YMzUKpaoKXSFS8HlR87vBDrtmEoiMcdAoAvVdgzB+KA1Nucnpy
9sRVaI6svSFjSUKZY5CKwAjFkQF629VTKdVdwxbp3fvW++8nVBkb4Ctjis/Q
nL/ow8WvLR3qBmpRmkKpLuEs0XJexoQv2lGn3mdBttiUSC0maat9Ttb913UY
MPFbU/k2iJd5Z5R3EbZCz5EStRuwvDv1s/z5r/ffL8skp9Y9YCHIg8s47pRT
0jrO3domtUYDf8H0YzLJoJ64b4wputxLyrgmmvXQaeoFzf6lKBP+8t/+JjPP
yzNHLdtXX23rnYfkUlm8E0NvxK5D6lAcI9DakIZCVb6fuhiitM0sWHFhJyTx
iNDieb3leekAyAFrwFGzjkgIyYWjlkRv1u8VqZC066ODhDhTkbW2nHo5ynn6
19XQwiExnNTv69QeJfpwcKgbr8Yuo5ykVIFHSzD1qO47uoMuMl/KVQ+c3WzW
us4UlqQG1unEz5apyeKeCd9AEwD29CQQ7Ca6mHJTW5O8KbVshjm8+e67pe7O
HQ6BwUE276SbrX4kqqbqV6LlrjSMuvEU1kYmjBJvjqYIXAakhSkBuQBEOeDW
XSbjWmpq9XGFm0hx8C7VLHRJWGwTDUQoNM7jHTTVQxoa7sANd9/tvGqpHvOE
sXhzFGzFbN28Om8q2ExSCCORIbDkLD+u9dk//tEIj+99SqOIRoGiTNEhVUun
H5feXnHrrfoZlxa3ZtBxSly0JZhM2fu5yEdEH0PTXNywmwrxerQOKfOOB7vL
1uo9UozaqJCuvtd+6NlnG/rdQ/OJz1v2CE+JNfir5X1UpeEcVnlFmjSWyaTR
fYILZPyvrP8buIXXD3atUVH4EX1greD7PMc9A4xlson2XY891i9NPTwRSvrj
wY3d+w4tjP5h8Ne09AwBgOE1vA7Twi74rKWmKmD/z265pfuA2rxtwj03+SCL
Bg65LPDpWWfR6ITLOWwXHtQ68jqUnlnP6Ho3V/HGu++G1qGBrAMpSH4WxuUQ
jdna6z/28sttrduA1qR2ZIxrdpLCbBOGC89Nn+lScZu1RpL6Pb1XT6/1taVb
jWvkv/hzeNc0m5uQokoRExrtYt5AfyysVAltBuAotAKFRmXdo+ppqQ4O7/2s
GyVd2ihfH3RXqsZUzQzABBab6UUqRYuqiIGQ6phyhnGE4rjTTmudJU3+carF
eHXZGbut6KstSTcVoGZSSbOZa3ATrl5x/4vbBxTTEUohLCjwuRlxp+gdxJ1+
iDSbLdsWa3kET+9XSAeuFTUMkppc+kMJvhA6sBLNE599ti3p9J8tZnlCjKcP
BO2XU+Nz7dh8qHNwLKPs0pVyP3h/tiPQLejWJWld0av79YrX//73ThOZbIhd
3ZbBCgT/dFkxONAOoTNMCbkt7toQzasVDKGs6ZYij7HRNMkFtnEvkSGmkQ2l
C1O5VvQT5Na7yr5JsxVvvPdeGKrpGK99qHR6jZ/ddFO0Z4rXLdj1ugEO1jJ1
AhmC3oCuSnFkXgd4aIXcn/dvKV6hzwhpnj+JA70MI8yGwAJJ3dp0SOdlZVWp
FKp/vMmpjL1SzgS6xSTjrVQQTTlHjBjdIL7FaOG5dIeSgOswUMUG/NMIFX5U
hiB4AaGYdP7mMn/ycTbrSr+puAAqwzJHxebUexAYAA7IyGAbgF6qW4677kue
+/k8Jnj66cZVt91WivhTXa+LjhOOhTBnkh8/yYqZg1Y4JUzTXoFZdJVKHx2O
56n0Ov1oQ2ZYvq4sjJtyZ/MHFgevl0xhBHZC0QogVWVndi4bjKY8WdZOj+k8
NQMR4j10tYv3lHWAUmJ3ngZTiqSs0Al7dq/I25ObD6wXsBrrGbcbnApw22im
F+gz5aPLLPrHQJ7mccmHujdHpIhSGiThah0EkxlC0HhaZ6T95eNWS0BGUVlF
Wy1gGnM2IxAGopwBZNe2WpT2LH+/LLJR+0ZCj8ZxxwVy8Cf+v6wMUKv9x/8D
hegAZw==\
\>"]], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAtc9Mfb3l87+dOYmC1MnhP9gvHdxV
S+o/Rds4K86c2b+BvjIPhs/vP14hxLXfUNe/I14hVodp6D/+QYP2Gl+zP/HN
qBLDd+i/xxe0xLOx7j8rcy4Jr+/yv8tTPX5URLA/p9vutcmX+7+MWiD9gSra
v+ZT+wj/TOQ/85XNfY2Q5L8lJsr84d/eP5Fr8Emfuvs/NbuMYBpJAMDWMQ7b
2Z/0P1AiBZaeHPA/6HUj3EYYWD9orXRqweT/P+HVhAtavsO/rsg6MaX18L8g
873kOefxP0Dx7zXHtvO/KnF12cYT+z+SmiPwzg/lP79OsoEAj+e/eA8rQzcw
5D9XkRIPAa3Lv2oGgy98Bv2/t0qVQp3wtD891Cw+CV39v64O0kgD/Ik/VdMa
vIye8j8+h3hU4DTuv+HpztAXyPE/TzvXh74H/T8fzElzuwT8v7tDacxWXNS/
rtWdmcO+979cMeQPTtKyP99BjHIqTOc/rpozPAQu7r9YJnfA4pzgP76B/xsl
cPQ/ECMzH/k7+r+kzlIcxITtPzy6E4RJQu0/z7dc5LWEyb9UBgc5Qub3PydG
w10GmNC/gP8IvNhc578wqSt2fufwP5j5YCP/ium/HhBDQkWk8z/SAvROsnvX
P1iOLcphA+i/zjamTN9M5j9Y8NCTc/2xv7K2a9wuofS/j2CDtuOn4D+0o60j
XCb4v6GVV+fUg6M/nG86T7P78D9lW7WZDwXxvx2/shhdzOI/maMYNUww9j+l
Hzw+NXr3v8ju2axBS8C/LRM3HA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2, 3, 4}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], 
         SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{15, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{16, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{17, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{18, 8}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{19, 9}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-2.0532712821320276`, -1.691447123291026, \
-2.0850620305119016`}]}], "}"}]], "Output",
 CellChangeTimes->{3.919797287998393*^9},
 CellLabel->
  "Out[1379]=",ExpressionUUID->"bb82a5ea-8bbb-4cb7-9b48-973b9a1e53ac"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"torsionList", "=", 
   RowBox[{"MoleculePlot3D", "/@", "relaxedScan"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.919798901581025*^9, 3.919798971933345*^9}},
 CellLabel->
  "In[1464]:=",ExpressionUUID->"2f778574-0916-455a-85a5-73483cf43938"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListAnimate", "[", "torsionList", "]"}]], "Input",
 CellChangeTimes->{{3.919798996742024*^9, 3.9197990006357737`*^9}},
 CellLabel->
  "In[1465]:=",ExpressionUUID->"ea8e3bf2-aefd-49c8-9024-11254f8bc356"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i9476$$ = 292, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i9476$$ = 1}, 
     "\"max\"" :> {$CellContext`i9476$$ = 361}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i9476$$], 1, ""}, 1, 361, 1, ControlType -> 
      Animator}}, Typeset`size$$ = Automatic, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i9476$$], {1, 361, 1},
                 AnimationRate->Automatic,
                 AnimationRunTime->10.798966884613037`,
                 AnimationRunning->False,
                 AnimationTimeIndex->4.041666666666667,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Pvf4EWLr+D+sqvcylX/8v6hqG4Oh5sA/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/LPMsGL5p8z+8NvAueDfVP5gPDE0MJrK/NJi/R60J
4z8dIjbuDofkvyhxFhyja/a/toq1rynm8D8K772FxdwFwMBO2adsIbK/4PYJ
iKqU/D+TPYHRVbH7vzE1+cSLNfM/UGS9JJ0QBEDuf7a6TG38v/T2e11ITNq/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Bu8NJp6X7j8YHOV8RZfB
v0yDsWBGZMi/9MfAsbay5D/EZRDiNvfjvwERcu9TYuu/+kDX4MXo9D8w4pwP
SA4CwCANu7ysV58/D3cBTQbA+j8gdDyCdRj8v4aiXPVfUuU/+O/cFidDAEBN
Fdf2cHb8v6BB7pv32MG/XxAwTQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1548967627242623`, 1.8234532286818796`, 
                 2.601082811111297}], 2->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+xlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO//0w1Ch3J+D85dZoyqLT8vzKgEEpW+rw/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxv7PQbPX9E/5f8KFBxw8r/25FB/
o034P55rgfrGE80/snRlqEhL879+Hxok7JL4vzAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/p+peV9eE8z/0rRVB3rrUP/j89PURq6y/LrjzZCoI
4z8o/3RwbfLjv2x1OslWbfa/gXydoGKo8D/s6ms9HekFwKxwwZOc07q/k/1S
IZZz/D+24j8e5DL8vwBDxBAL6/I//gAbyI7/A0DPr2Yfe5r8v3fScW6Yf9u/
54NOcX6B+b8uJuFmj+biP6utV1g2r+W/pIR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwK3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/guY/Zbey7j/gpL9q3xPC
vwYfLYwlcMe/8tdaQPWx5D9J1C8j5qzjv0YVlpwHZOu/wGRp1b+49D/Eklyr
uCECwDB8ebLNNXE/SSXElVme+j/4K20oxnP8vwNNZXWwuuQ/v9Oapg4yAECE
kgCpkaf8v2uq7dsCQcS/7us1Kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1613101163782538`, 1.7985485359324265`, 
                 2.615527093626226}], 3->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/aXF9Hnmm+D/7rkrTP+j8v6ipoiAOGrg/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/3VPiDbef8z/4aoHInznUP9h8Ttk9GqW/prkrC7UH
4z9UibgawV3jv9ISoe/abfa/I26mOHFq8D+cX7FlIPQFwExDE0DhxcG/LxZf
IJhR/D88Fo0qAbP8v3g2wDx8nvI/4BJyIFjuA0DHSrEvMMb8v2ZhFH2+tdy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/uE/DG5fN7j/e51PjHZXC
vwFPmAgLfsa/rth2k7qx5D9gmVH4j2Ljv6uy/MKLZOu/xu+RK3WI9D+NW6sn
IDQCwOC5B79o45a/zENunwh8+j+c4ut+oM38vxNhyh4dIOQ/ymXYV8ogAEDh
/H0BONf8v/y26/Q6r8a/d1YyvQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1676350316748276`, 1.7735068766303983`, 
                 2.629772193812691}], 4->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8kdherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8vOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/789WAnmD+D9iyRkPWBr9vyilQOHLLLM/kkxZ4ZoX+r831qoispzj
P+7gKiFikvO/qytNXGePBMCje3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4798
cz4vHITjv1mBce6ydfY/eyg8I1u68z8mW0nZxrPTP5C5t5lmNJu/rkWOQ00I
4z/4bfOEFcniv3Iw/IQvbfa/ezFgTFos8D+Svrcizv0FwETxcC6YJMa/n3zD
K7Mu/D+Co+T4ojH9v2CEPkHlT/I/CjdkhfrcA0DyJhCDaPD8v8gg7Fmi7t2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD72SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8LHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9WVvOAvXXjv7EypsVjbOs/ViQdMTvo7j+s94vS9hrD
v//6CbcJjsW/sh6orway5D+wC28tOhjjv0vQV1jgY+u/tYBbp+lX9D+iUSIV
fUUCwGA9oXtkHKm/RyYNFxZZ+j9yNv+D/SX9v7OOUv+xguM/gc9Hg1sPAEAq
+BRJYAX9v373m2FvI8m/sVwsZQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1738710269471466`, 1.7483301577949144`, 
                 2.6438170268456287`}], 5->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/HDF3cB9g+D8z3v797Er9v7B7mczjZaw/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/IsOXg8HU8z9A+GjjXSnTP2Ab0iggroi/UZo8AvMJ
4z87YglHdjTivyLHqZZUa/a/ixSPZkXc7z+UL0izJQYGwMgbMNibhcq/eOQX
/OkK/D8/G1Wpv679vyprID9M//E/gpycUXfLA0DJvK3OIBn9v8x6x54rKt+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs//L54kaEC7z+UWmzIX6XD
v0EQtU40oMS/A0n/jtmy5D/SBXqO6s3iv/tmBWoFYuu/sV3fESEn9D9XzyMZ
zlUCwNy8CeUibLO/yopHtoQ1+j+5/KlT1nz9vwc3hV174uI/EDXYCYf7/z9+
TVbmBjL9v1ZLNCVvncu/fg4uUw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.180017627299735, 1.723020296730065, 
                 2.6576605231515447`}], 6->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/Rz6OKm88+D8LqyTW+nn9v/BbGAvHWaI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/LVjwH+ju8z8I7PCxb5rSP4Dvzf34EmM/bndTJqYM
4z+Ds+f37p/hv7DWsklKaPa/zgzLjp5f7z/YodpwJg0GwFhPntKU6M6/8SbA
Wz/m+z929ER6TSr+v6CbXH+3rPE/wvu04s+5A0CD4KblVUD9v1rtUNggNOC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/CFTRLcgc7z/KZuT5TTTE
v4XjcludtMO/krcKITO05D92LunmpoPiv4l2Dh37Xuu/V+L5OB/28z+ve/bt
EWUCwFw42A8jUrq/nDInQ1cR+j/AzzQoJNL9v39etbeFP+I/5hr8dwfY/z/H
xeVdKF39vzbPPs8IHc6/Qko3iA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1860743646446408`, 1.6975792208788987`, 
                 2.67130162848994}], 7->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/CnoO+WoY+D8yMjXsfaf9v4DfoCEUbJA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/rA467swI9D8ImS9qBwfSP7C82BHB9pA/V6/teWYQ
4z+g6p0siwvhv4KCyNoQZPa/RUbdycni7j9wyKLPzxIGwNuy+MWVptG/io20
JrbA+z8lUDXJQqT+vxvBgXItWPE/oFMamQWoA0DKJUq5BGb9vzJwx+Bl1OC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/hgob/Kw27z/MuaVBtsfE
v5rzUDxXy8K/htPXShO25D8FSkQBdTniv1wiJK7BWuu/lo7+7ufE8z/EsN5i
R3MCwOOk3oPUn8C/yoPhj5Ds+T8sQbVa4CX+v5lECMPdmeE/pZChFTu0/z/+
q79SwYb9vzZpuj8FUdC/UGg1xw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1920407777370778`, 1.672008867676621, 
                 2.684739304033583}], 8->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/xLH1qhX09z9O+qKzctP9vwCbPb5FJHC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/zrWK6W0i9D/ImtKKMG/RP+A9xbTyZJ8/q1oosjMV
4z8KlXZ3VnfgvwBWP56oXva/zY7D09Bl7j8aAZteIRcGwEDTDSmE2dO/9L1I
SlGa+z8/T4ITlhz/v8bzNbC0AfE/9G3x1xmWA0Bj6FRZKor9vwrFVGnYdeG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/qLFr901Q7z8MuAIhjV/F
v4YrIiJ05MG/MCn15nm45D86n7CmWu/hv9n1mnFZVeu/lbxrCn+T8z8gPzZc
bYACwKzJBkAVGsS/3DefejPH+T/GpJJjBHj+vyu2d2qQ8eA/1kZsrSSQ/z9Y
8XuGzq79v0BA0fQgltG/+GAymw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.1979164122105437`, -1.64631118440306, \
-2.697972526447593}], 9->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/c7I5RRJB8D9urXXP7SzlPx6M3TRMZ/G/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/7AIBQpUU6j9CrHaRHJz3v1v2M6GH+e6/53JEDhr7
9j/ozkBGYevmvwt3SU9tmN8/Fy+U95g87D+XU7K41sz4P6Nlk5J0ld2/xk6i
RAgz2D9evcxAvlfoP5U2wpoNif+/yQM/JaRxAECi7Ew1yorkPxygVVWQ4va/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/UH3hrio46D98ADb+5afw
vwab9aN0c+S/YLcSDn0U8T8pvBUOYCnlv1DvtQNUe7c//skDwV5f7j8nlTbQ
prHxP4dlglmpzOi/JEZiVtRN5j9mNSEIVsLmP1rhz+csePi/At3bRy2S+D8I
TWEC3NvkPx2WGUXuJPS/bXs5IA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.203701568661845, 1.6204881280343475`, 
                 2.7109999558282456`}], 10->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/JNtXFIOq9z9/qvG/oyb+vzh4sjL9uqa/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/3MwxbtxU9D+0bXC5ZjLQP6gnRukj5a0/E3ojPPMh
4z84su0KUZ/ev4JdqoNNUPa/n3ZdUZlr7T8QPxnPuxsGwKNyO2KaQNi/yvAH
pgBL+z9xKK2ZGAQAwERgQCoST/A/uql4iONxA0Bx0R3Xzs39vwYaV4gTvOK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/tsgSfLyC7z8g5WTyVpzG
v3C6RdAeHsC/5Ljyq9m+5D9DwbCtg1vhv1z9BVf+Ruu/OkuD3icw8z8oConX
hpcCwKrBkQj6F8u/9+Uv3cF6+T+w/aV5ahf/vwWZVYF0Mt8/TJekEiVH/z/4
vYdLOfr9v4lBglvDJ9S/jSUweQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2093935624330308`, 1.5945416650938762`, 
                 2.7238215964752888`}], 11->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/9c+LiEuF9z/BuBOI2U3+v8i7UbSgmrC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/I9nECKZt9D8I0932GBvPP4A5HBzNb7I/7jlmj+Qp
4z/NSXqujHjdv/JMNMRbR/a/5tceSG7u7D+0MrpUBBwGwH72Z1RqdNq/UX2O
DRsi+z8qQMJUsz0AwPX4UKns5e8/BhQPzZtfA0BHk4RuSO39v0wNSK7CYOO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs//tSlFoab7z9QaWYwMUHH
vwzizgygfb6/0hiUVdLC5D8o55OW0hHhv8vsj5cMPuu/9J1NVkH+8j+KB2KM
eKECwHBlfIESm86/oyYNS7NT+T+KHMwYoGT/v3zBxpKY0t0/APxUkUEi/z8E
Jkz7kB3+v8VE0sQWdNW/Dgwv8g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2149942041491717`, 1.5684737715025168`, 
                 2.7364354755763176`}], 12->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/xl+oAbaw8D/4iMNiKhjmP6x/HVnca/C/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/vwk4gN9/6T9jU7EZfCD3vw34iI06JPC/AdynYDDv
9j/CFLpSfKXov8C5+B8bLd8/mBqYUBC07T/diSjPic74P3z5YbMw+ta/rr2l
qL4d2j+yxvsN7QrrPwhuvEjBdP6/Wb6O6nmoAEAwrQvZnkflP8CjNQiQ6/W/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/uQD9zc/t5z8MVFPCFWrw
v+aX5GDrGuW/7WtEN4gO8T8WX1KUbQbmv7x0FKWvpLY/Em30Kb6K7z8sJ0WA
T+3xPwv+9YVoKua/Ms/RqyU45z/Vp1+4i5HoP9r27NBOcPe/PO5i69QA+T8U
m+ed5K/lP7aRqTC2K/O/GsRDOQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2205030683566382`, 1.5422864324281234`, 
                 2.748840632062936}], 13->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/cs+Kcg469z9yGs5ScJf+vyCBWgLkMbu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/REBpRFSe9D9YZew0W27MP4hbkzIISrk/eR63Oec8
4z8spucMSi3bv5wiqV3zMfa/G09fcir06z84dXneixgGwFJ6tRK4296/9EvD
QeXN+j9mssI7Oq4AwP0X8dqaau4/Si1mT7o6A0DYNt8Ifif+v4Z9K/IDreS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/HjxKUjTM7z8oIF8RkJfI
vwRRk4GCELu/F4u8qlPM5D9APi/uAX/gv3XCBDGkKOu/gDvd1RGa8j84QfAD
IrICwE0NpokY1NK/sw0n2vkD+T+fvyll8vn/v9jHpVpeBNs/A5WriMHX/j+l
qNYtd1/+v6rNdnJAE9i/oNEpmQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.225917488260096, 1.5159816421343506`, 
                 2.761037119035108}], 14->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/Y/5Qxg4U9z9ngFmYy7n+v+BsX+SYRcC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/H0qsGTW29D+Y1WlUhwvLPwBdCFZ/prw/8IFEFfdH
4z/6izOT+Qjav7S58GF+Jfa/8jTiKSV36z8AC+AnyxQGwBMUS/tuh+C/K7GF
n5ui+j/ouVChHeUAwG6JEkyep+0/GGdmbSMoA0A34cuBNUL+v4tCWCd8VOW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/+kWNJxXk7z8IaKAB+kjJ
v0jQ2O9GYrm/0zyDmNvR5D+0N8LP7TXgv41ZTDUvHOu/bgyhrdBn8j+aZQZ6
2LgCwEvvYjTVmNS/x1frMlXb+D8Ovb62ASEAwDau+hI4ltk/SuaO0Cqy/j/P
sBKNAH7+v8MdcGDiZdm/WVYuCg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2312392987991663`, 1.48956140382869, 
                 2.7730230098786475`}], 15->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/ClwJS9Lt9j+P5V0rg9r+v/wvC2uH9sK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/hs1BlsTN9D8QtrMhiqDJPwBTVx2D978/++81gA9U
4z/m8IITqOXYvzKiuHnfF/a/6UGZ+D/66j+QoOZ5sg8GwCGvyaa5oOG/PCxd
pYx2+j9mrcuXEBsBwB1HPtEo4ew/NjvFDHUVA0BHoHubUlv+vz9DnAXI/OW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/YskipKT77z/Md/uaeP7J
v0xVMQzFube/2fP7zefX5D/dIazfMtrfvwtCFE2QDuu/f/6qI3k18j+sycoH
er4CwCB7jIFbXta/I0QzeC+y+D8XUL0WKUQAwB57e/aGI9g/O+lJMl6M/j/r
wmzj6pr+vz4PX+Bputq/F1oyXQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2364673455846533`, 1.463027729509951, 
                 2.784797724429513}], 16->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/GmQC/FvH9j9uiLp+lPn+vyAiHdyHq8W/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/utLT4wDl9D+4gRrrfy3IP8AV2qlonsE/8e0ViS9h
4z9sBGVFbMPXv5qj6bQXCfa/+x7Km4R96j80Zko6QgkGwGS4cBymueK/etbS
wrtJ+j+crDjqDlABwIsNReRJF+w/tslworACA0CP9pZg03L+v4yGSG3apea/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/SmfaeHAJ8D/4EUi2/bfK
vwjpAvEdF7a/0/Jr0nfe5D+gK534FEnfv3NDRYjI/+q/zLnzJA8D8j821dM8
BsMCwOwAeBOIJNi/Sp1q34uI+D9q+MqUbGYAwATFPe1nrNY/w/txoF5m/j9+
v6jvM7b+vxTPT2S8ENy/rh403Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.241601230476937, 1.436382639814946, 
                 2.7963603659965584`}], 17->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/6qbBgdVv8T9gyg2ePF/nPy1vMLDReu2/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/rTpzAVeU6D9QKquKrz32vxR6pAt3LfG/f5HosPXQ
9j+mYfBHj33rv/SpcTnGHN4/En21yiwS8D+PZr78lpv4P0v9/K1C/Me/uX4s
fqWO3T8mNk0tlEHvP8ommUXChPy/RA4rhdoFAUCYbcxErkLmPyYSPivzRvS/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/MJmajgt45z8Ff6D1XvHv
v+wZAN8nJOa/rMZk32r/8D+Ihe0Od3LnvyRVBtgFhLQ//pE7JgHB8D/gpeKl
miXyP0DX1y3xvOG/mMZM4X7T6D9DgK1laFDrPzCv2I4VofW/ueELRsW9+T/8
G21x9dDmP94kqwEugvG/PmVAVA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.2466413181225935`, -1.4096281638645876`, \
-2.807709718540952}], 18->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/7n5A5s159j9zaMzWujL/v8h4HgfmIMu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/gJ4ouXgS9T9wYNbMuC/FP6ChH2ik0cQ/rVIXSIJ+
4z/wShQukILVv+4m0kgS6PW/yYOeQ7KE6T+UZQkjXfgFwJKdEc8M6uS/oCcS
TuLt+T8ugLIuHbcBwCr2eu6Oeeo/bhLhjOvcAkDDlpu4+Jz+vxpKvA0e+ue/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/Lc2EYywg8D+cImpF4TbM
vyhdvTLi47K/MaXsMSHt5D/izvTspijev8fGLRzD3uq/aeAHhBOe8T/nzDdH
3cgCwMQ72VBGstu/R1MpGtgz+D80WgxNPagAwPhXs2xVsdM/5VEBgNIZ/j+b
/7PH2ef+v0zog49Xwt6/N941ew==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{1.251584957904995, 1.382766339109303, 
                 2.818845924234279}], 19->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/C7G+K7xS9j+ji6Fmy0z/v/z6icnW4M2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/j48+tbAo9T/g2lCcN6XDPyyL8Cj5YcY/iEzYtLKO
4z9ImazgHGTUv3R8vDTX1fW/GsF1r64I6T/q+qmc6e0FwErrz1hbAea//ZZw
5eC++T8gwHQXJekBwLbm6yjTpek/8sOk0+3JAkDrRyoCmq/+v27o2r00pei/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/tcWPYUgr8D9k5azdIfzM
v5xz7HGNU7G/HyJNaDn15D8O9kBGbZndv00cGAiIzOq/zMi8wYlr8T9eYP2n
J8oCwAlqMguRed2/BKSXiM4I+D/5wmJlxccAwPZniXadLdI/eByE6Uvz/T/H
6WW0Mv7+v5azHji1DuC/OlE9HA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.256434040131718, 1.355799211173779, 
                 2.829767128542356}], 20->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/MhF3tXwr9j/Ir2fNLGX/v4iZ6cf/UdC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/NB8+a44+9T9o94rRIBPCP+BIt2Hz68c/Q6L0LOaf
4z8kzOs4GUfTv5wqQmp4wvW/v+GqvPuM6D+oKhgnIeIFwHTsp0n0F+e/wsoH
5yuP+T98UDRKKBoCwApuN3Xuzug/blJ49N+2AkCh+rBkmMD+v6a2IejcUOm/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/h42PPDc28D8g1w9DLcXN
v9BrS3Imk6+//ExbJNP95D98j2By6wrdv3XKnT0pueq/CUHmSf048T9GAebG
W8oCwDi5nC30QN+/+m0/TlTd9z8wFHRYX+YAwEahQpHupdA/B9szT57M/T80
VQyZ4hL/v7VBC2buvOC/UjAyYw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.26118743990494, 1.3287288337011298`, 
                 2.840472835271842}], 21->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/ZxvqkhIE9j8BW2ok3Xv/v3Rvg5oUtdG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/o8GkJhBU9T8QuGHHk3nAP1g2hVl0b8k/iE8KWRuy
4z+ME4hwmyvSv+4KE2z3rfW/YgmiEKMR6D9qO42tBNUFwJXJ/OfBLei/cYo2
C8de+T8UuYL0IkoCwAikQpXx9Oc/4jW8a8OjAkAVYvGM8s/+vzm2yykJ/em/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/v95CGvhA8D/MdiTI85HO
v+iQr4IkjKy/nyNmuu0G5T8wsy6OLH3cv8eqbj+opOq/DJCdDXIG8T91NOGf
eckCwKhAnxomhOC/7FIQz2yx9z9K81vDCAQBwJzYAZDONM4/lkMxtcyl/T+L
3q3Y5yX/v/q2hrvJa+G/6GIvzQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2658447952286285`, 1.3015572681964203`, 
                 2.850962229142586}], 22->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/xyvs1oDc9T+0Pbqm2pD/vxRsHiyOGdO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/axUcOjRp9T+gaFDbYLG9P9xGp9hd7Mo/AtCezVDF
4z8mo9CiuRHRv+I8gNNVmPW/vi21Sa6W5z/8JcY1lcYFwEaSDIquQum/bWMS
GLYt+T8sWpJYEXkCwBeyuIjtF+c/Npr1tpmQAkDXJ3JIp93+vz77xhWsqeq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/o4j+I4pL8D+sOAF1ZWLP
v9hva4RRkqm/3GOwdIgQ5T/9+lKnO/Dbv7vc26YGj+q/U2Hj/evT8D9ropFE
gccCwCjkDdC6Z+G/mkd/dxuF9z+DvPdVvyABwBj4UuVMFss/GrBrItp+/T/G
Mpb3QDf/v6QY65U5G+K/e7E0kA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.270405751420189, 1.2742865838695494`, 
                 2.861234511347956}], 23->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/PiNol8q09T9uhFCxI6T/v2rMdLBQf9S/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/VF6b//h99T8gF1SNLmG6P2BAASuSYsw/k3c7C4XZ
4z+8w+iVE/PPv7o6XFCVgfW/VRN0/iYc5z9KLO/f07YFwMuyoJekVuq/KFMc
4fz7+D/+HIHN76YCwP96t4vzN+Y/Gp+wVGR9AkD10ZaFten+v4uywDW4Vuu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/GC2+huxV8D+GJkAEORvQ
v9h8t9/opaa/pbd+k6Ia5T9Z2mS7I2Tbv5PatyNGeOq/dBZRC2+h8D9At0vc
csQCwICM7XcmS+K/MztCvGNY9z+arxTTgDwBwJQp+maW8Mc/ubBkoMlX/T8y
q3Ob7Eb/v2CM/UYwy+K/Tjs0gQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2748699611374108`, 1.2469188574775645`, 
                 2.8712888996157004`}], 24->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/UM4h7fKM9T/rhC/DtrX/v/gKmkFA5tW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/XG6I2FyS9T9Q2ETJ0gK3P8SzXiL00c0/N1mLfrbu
4z8INpaEQ8bNvxAt2ai3afW/1+TkvBai5j+YYI3mwaUFwC4LvYuOaeu/XmX0
Rp/J+D+rgqG/utMCwFiMdxUVVeU/KoNixCRqAkAVGbVTHPT+v0TgMQsgBOy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/G7U0cx5g8D9gDsJ8BIfQ
vwiW/PAkx6O/dqgmTTsl5T/sNhC379jav+nMNHxoYOq/XiDKJf9u8D+HkRKk
TsACwFUIRVZXLuO/1xkLGkkr9z+QopwQS1cBwLgNVenpw8Q/UmrzOp4w/T8A
T3KL6VT/v+By/xWge+O/M3kvHg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2792370844048073`, 1.2194561731663522`, 
                 2.8811246282675738`}], 25->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/WxN48/xk9T+Qw4B9ksX/v2TNJ+JATte/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/ZfrXLV6m9T9YwU/OkJazP4iDuRhnOs8/1rp6gOME
5D/kpUJ9Lp3Lv8x/Zbm+UPW/uHXFCYco5j/IHmaeYJMFwJSGTfZWe+y/Z0wM
N6GW+D/GC8Kwbv8CwPVz79Zjb+Q/Er1LhtxWAkDHrCfj2vz+vzjCbBDWsey/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/IHvcHR9q8D8+sSC8jPTQ
v4D2RgQ/9qC/RlkezlEw5T/iUjt1qk7av6UfwYxvR+q/HGctPKA88D9IQJPu
FLsCwKO2sLM7EeS/4S9CFc/99j/HNsH3G3EBwIgat8uGkME/wMYHAFsJ/T8s
OFSwNmH/v3VUwEB7LOS/XTExqA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2835067886394143`, 1.19190062231179, 
                 2.8907409482776734`}], 26->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/pOwmyOs89T87T7CjtdP/v36mbH82t9i/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY//lctcPu59T9QLxrxrBywPzrmOnnnTdA/AxNYVgoc
5D+Ywg2h/3fJvzK7hnSsNvW/pz3NX4Gv5T+YeWR2sX8FwDAR0n3oi+2/tPlY
qwZj+D8M83I4CCoDwLuUcrnxhuM/tgRaG41DAkDJZF6F8AP/vwTBqrnMX+2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/7CkHv+1z8D+AY8c3yWPR
v1DJnKHeZpy/XAUNOeU75T8QGi6+XsXZvwtb4kddLeq/vMUGPFYK8D+bUB4k
xrQCwDgyxN7B8+S/LPO/OfnP9j9VjSWF8YkBwPAF8eZZrbw/CHtt/wLi/D8C
WocU02v/vyKKsPyz3eS/l0MxOg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2876787486759687`, 1.1642543033602646`, 
                 2.9001371273295677`}], 27->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/NjMJi8IU9T8AcYUbH+D/v46BnPMEIdq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/0KH5FzPN9T8gZ9ss2SqpPzyBSRAI+9A/dY72MSk0
5D8s5UDD4VbHv+ajsuKCG/W/OxzwLg835T/enXz3tWoFwHLLCOEtm+6/VjwD
qtMu+D++NUoEhFMDwCmWS93Qm+I/9k4KBTgwAkDJ3eusXAn/v/TaGnb2De6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/1U7tkol98D/48hxDsdTR
v0DxJ+nZ/Za/FUPcpvRH5T+14rpGFz3Zv79DDrYzEuq/VEGBIkqw7z8vq5/C
Yq0CwByGay3Y1eW/xjeGGsuh9j8fdwbJyaEBwIhV9Y05LbY/keiOSpm6/D9k
pzjkvXT/v96N9Hc8j+W/cWww3w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2917526467915248`, 1.1365193216686567`, 
                 2.909312449872118}], 28->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/hz/aXYTs9D8prjjtzer/v9GKAgiQi9u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/NUCapQPg9T8gjZ1bLAKiP6kLadGHpNE/XhrSMT5N
5D9YJfhl/znFvxSlJiJE//S/mvOh2zm/5D8ILo3Eb1QFwFZZlvgRqe+/IWwX
RQz69z9c5CXY3nsDwL6KUpgTruE/LL5Kxd4cAkCzgJDtHg3/v3Rz8LBFvO6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/CJ692fGG8D+Y0DAQPEfS
v+CdK+DbsZG/CgnKJn9U5T/Asmiv3rXYv+5EgvX09em/VDmrSyFM7z+OwpRd
66QCwGDPS/5st+a/1NV4UUhz9j+4HWHnorgBwKgqiqJcQq8/8N039CCT/D9u
l2Rt9nv/v27ceNoGQea/IPk0tw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.295728172729466, 1.1086977893437382`, 
                 2.9182662171740716`}], 29->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/hGT3YzTE9D+bGodDwfP/v+ZpNHe79ty/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/xtN2oWvy9T/AufqvxH+VP3Q/6IRZStI/8fA0YUdn
5D/4wtG2giHDv7yHvWby4fS/fygbvgpI5D9CmD6a4DwFwF4WVty/WvC/RCc0
mrTE9z+UtmyOFaMDwBvpfnTMveA/7olc3oIJAkCg80L8Ng//vyhyctKsau+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/0Oer1yWQ8D+c02qwYLvS
vwD/Y4icBom/U3R7voNh5T8oGp+Dvy/Yv5UnGTqj2Om/xPgEwzno7j/IEgGe
YJsCwNgwI7pumOe/5MUVf3RE9j/xIRgYe84BwEChJcd1E6I/MDxYEJ1r/D8e
B+UffIH/v45TBkcF8+a/FGkzNA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.299605023722923, 1.0807918250810298`, 
                 2.9269977473773627`}], 30->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/HEohwtWb9D8n+sJr+Pr/v4KhRu9qYt6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/Qn8enGkE9j+Aa5BWYCR7P/Dzizxw7NI/76ReuEKC
5D9UJqSLlQ3Bv4Z6w/mPw/S/qxaeIYvR4z/OaeBOCiQFwMhUVhkx4PC/DCk4
0tCO9z9e3UwYJckDwJjp6lwclt8/PuC10iX2AUDV8zWvpA//vyROhSCPDPC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jr3/1CSZ8D+TiD0VFjHT
v8BuURxiyn2/Uk4QagFv5T//stM4xKrXv2AaH81Auum/clXwUpuE7j9x82BC
w5ACwCj9J9XLeOi/lLksSlMV9j85LRenUOMBwGCBRNoWO4M/TIXGsxBE/D/+
dnyNToX/v4T2Vtwppee/BR0vKA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3033829045175696`, 1.0528035540030745`, 
                 2.9355063755491724`}], 31->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/Eiw9nmtz9D+61/BqOQAAwJLoARSCzt+/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/wY5kLvwV9j8APRW8Dj2Av6Q/kVS/itM/aqmsHC6e
5D/QcXW+wvy9v4htyDkfpPS/Aoi9Q8Rb4z8+okTS7gkFwJaBZkvSZPG/+z/v
IGVY9z9HDvl9Cu4DwBRnJGjXq90/sMLjJMniAUA0mNv9Zw7/v4CJKjHGY/C/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/TsUiHu6h8D9e/toQU6jT
vwDwTzf+AGS/kFA3HPd85T+kV7kt9ybXv2ENJA3Qmum/E/AbwE0h7j/8vJoe
FIUCwLr7ZtByWOm/BjaWX+jl9T8A83T0IfcBwPAL7F5VFZG/uVgC9H4c/D/U
o95pbYf/v6QDK7ZmV+i/72suUg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3070615273938042`, 1.024735107497167, 
                 2.94379145373271},
                ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 32->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/6gEWH/lK9D/Be0MKGAIAwOCojEByneC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/6Hl8+SEn9j/gNysg8DWXv4XLqXQ6JdQ/hVLEYAe7
5D8QrjOcHui5v4DFcJqig/S/tTykU7/m4j90CZktkO4EwG5Z2hqZ6PG/xGm+
xHUh9z9bw+PewhEEwPsW3UXwvNs/tOFrV27PAUD+++UAgQv/vyzxF870uvC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/4bquA4Gq8D8pA+xWDiHU
vwAI087JnWI/HSVDvmOL5T8sH3GpYqTWv1plzG1Teum/RCDoyFi+7T+aQu4b
VHgCwN6tIDtSN+q/1zXqcTe29T+On5N07QkCwBDr8OzQ96W/qeL25ur0+z/A
ebaK2If/v5xFXu6tCem/Dlc2DA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3106406121883012`, 0.9965886230525097, 
                 2.9518523509967394`}], 33->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/FpUdbIEi9D9ruIbuFwMAwKCJMOa6U+G/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/0D4Vp9k39j+gl/F1+j2jv7RD8pDVu9Q/00u+RMzY
5D/oOJQmkN21v1RqRKQcYvS/T5NdcYVy4j9giz6D8NEEwPQyDUF7a/K/uBtP
Bgfq9j/UqvhxSzQEwDhSx42Nydk/hHiu7Ba8AUDlUUXy7wb/vzZF5SoUEvG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/VR172tyy8D/jwkl9PpvU
vwCKeHBIInw/xCFAMEaa5T+GML3aECPWvy0KoHfNWOm/vl7MJMRb7T/moeI4
hGoCwMR3JbRYFeu/Z1g2OUSG9T+gsT+wsRsCwBCCM33Qu7G/D0O9olfN+z9e
Yannj4b/vwaK/Z3xu+m/TnEvjg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3141198863149062`, 0.9683662440968118, 
                 2.9596884534838344`}], 34->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/6YktrQf68z/LNsYDOQMAwG/iAsQMCuK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/txN06SFI9j8A+PBssveqvxDT4uqETtU/FIFTdnr3
5D84lFYKaN2xv240fPSPP/S/Ul4frR//4T+znJ4OErQEwEoiL4lu7fK/Lb45
OB2y9j9EQtSFoVUEwICSEjHW0dc/7CvIZsSoAUBbXyMttQD/v2S3WnwdafG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/yYeq+wC78D/quLn82RbV
v6A6RdcZPIc/ZbwKSZ2p5T/xezXXC6PVv0jU18dANum/Ejm9g5f57D+/aTKJ
pVsCwIKTMOt08uu/C6SzchJW9T+IPM1EbSwCwLxk5q2GhLi/4PBePcil+z94
5leak4P/v5woXN4jbuq/yZIvZA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3174990847848664`, 0.9400701198322832, 
                 2.967299164457395}], 35->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/rmBICo/R8z8eiG1HewIAwAPzYaJZwOK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/Km2Oe/lX9j+w5AnewmOxvwKWORI93dU/sXULkQ8X
5T8wGDxJ7M+rvzq9zTz/G/S/Q/aUBpeM4T/aq/4j95QEwCS4ENFobvO/vGGv
trx59j/CmPmAwnUEwNEMYnfx1dU/au5zR3iVAUC6YNwt0fj+v+yK+PgJwPG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/grS3xOzC8D8A5qsx15PV
v/C0WCbOE5A/s7Zm1me55T/tan6aXSTVvxNdKRCwEum/0NuSjdqX7D/8GbY1
uUsCwKaxQaKVzuy/NeF74KUl9T9wkDPkHjwCwGiyw5qDVb+/wR6YzD9++z97
uFve437/v26EKco2IOu/3No3JQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.320777950226341, 0.9117024050710087, 
                 2.9746839043474256`}], 36->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/TnNaqxqp8z9OWUjI3gAAwKvAD0qTduO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/zlYjIV9n9j+wlYQ4bFa1v0Tz3uXyZ9Y/ZQdsHok3
5T9QzG75Evujv26WNUNt9/O/j5UrbPQa4T+uoVEwonQEwGpN7Qlg7vO/urQi
5+lA9j/8Mwbiq5QEwH+NvPsG1tM/2OvsDzSCAUCqVvWRRO/+vw6SftnSFvK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/VCmCl5/K8D8gPPtcLBLW
vwCfg8N8aZQ/jf8WnaTJ5T8vloEFEKfUv0c2kRYe7ui/Fj5w4ZQ27D9+/Ux8
wDoCwMAt9a6pqe2/BJQ+SQL19D+lRidVxUoCwNjzYpgfF8O/fyWaZcFW+z+j
BEMRgXj/v2Ryhn4c0uu/zXsubQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3239562329032313`, 0.8832652600697264, 
                 2.9818421107950437`}], 37->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/9/T6t62A8z8vlwJNx/z/vyTgTYWrLOS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/vRzUplF29j8AOyx2hlO5v9nHw5Sb7tY/fJgqluRY
5T9A+bz3wHmYv8Lsv+Hc0fO/+AxgukCq4D9/dQe5FVMEwAzLMzlKbfS/EUDw
N6kH9j8oFOQ/W7IEwL3Tdak+0tE/Hn/QQPluAUCXvQ8YEOT+v8J+c1lxbfK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/TIxa2hjS8D/KMLCkz5HW
v6BDqjrCnpg/GUj2WFLa5T80kajdLCvUv5yMG7WNyOi/c/sqFc7V6z+LYMSv
vCgCwB672vufg+6/hJr1dyvE9D/grzJzX1gCwIzsJWEYh8a/mvnNHFAv+z9j
Komya3D/v9RuGhzHg+y/hTE20w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3270336907331888`, 0.8547608503638616, 
                 2.9887732386958192`}], 38->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/IPgsV0tY8z+75D4nFPb/v1Qh+SCU4uS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/eEM84s+E9j9Q6tX2wVq9v5BVuZ4scdc/g51eXh97
5T8AW8yLvVeCv/6ZTwZRq/O/890Nu4Q64D9K2NpbVDAEwGreTXkd6/S/HvIF
IP/N9T/F0vlJzs4EwDRVI3KBlc8/KjQAWslbAUAlsNqfNNf+v8D7q7few/K/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/qZ8O+FfZ8D+0ZsUUtxLX
v2CxVopKs5w/nEoQvW/r5T/W2hnMvbDTv9c5q9kBoui/GueztI116z9UJb03
rxUCwBRvyolnXO+/H3WZOyWT9D+Roswu7GQCwA6Y4Ihn+sm/OrCWBe8H+z9w
yoxjpGb/v2qMKMgoNe2/jCg0uQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3300100893048223`, 0.8261913466008382, 
                 2.9954767602418935`}], 39->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/VIAgr/Yv8z/47ASlpO3/v18Hpe0+mOW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/u8wIstiS9j902Q4o57XAv+riQtWb79c/woq1yzae
5T8AslN5PMl3Px6rY7LMg/O/BJJ/SZKX3z8C+5zOYAwEwEKLZfrPZ/W/c/6J
HvCT9T+q2FjIAuoEwOD4QVprf8s/kNiD2qVIAUDNdQEqs8j+v+yD0TYUGvO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/S+T0X1zg8D/HX+6f2JTX
vxiOUR9iU6A/PMG7c/v85T8GAvhczDfTv/dKv4V9eui/1WSAQdsV6z+/uI+Q
mQECwHkHnLj3GfC/ZD/VZvNh9D+Tp22NanACwE4SKS7IcM2/uhgUMqHg+j9i
MYPnK1v/v5wHpK0z5u2/hpQ31w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3328852018940092`, 0.7975589243725453, 
                 3.0019521649629386`},
                ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 40->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/T6Tz5LIH8z+HvrpueeP/v1L2tsCdTea/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/L8cO/mqg9j+0+NUpLcPCvy78YFzfadg/YB2oISjC
5T/gdfPomt+UP+xe2/pSW/O/BLsDNC283j/oc//ePecDwCILKQNY4/W/oxmB
uoBZ9T+Sp+mb9gMFwIRAMp6MYsc/Ip1rQJA1AUABfxfYjLj+v/js6B0LcPO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/heH3hSXn8D+XJ2AgKhjY
vyjzyTtwPKI/iwq1HvQO5j+7DaP+YcDSv8X+Ns4DUui/EJP0Mb626j+WaS5L
fewBwCZDwnEThfC/+V66z5kw9D9rg6Op2XoCwDFmKpn6dNC/Sm/lsmm5+j/E
HmkjA07/vyFoRP7Zlu6/UEU0zw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.335658809479164, 0.768865764046777, 
                 3.008198959766037}], 41->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/iMVzHIPf8j8/A2BPk9f/v7wAgXWiAue/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/dydht4Wt9j/Y9cQKCtXEv7JFVqvt39g/8vuwkvDm
5T+QJedObc2hP9ihuAfnMfO/wDFqUevi3T9YR1xy7sADwHrrjPGrXfa/0Rd0
grUe9T/MM5a+pxwFwM4/S1g3P8M/3EqyCIoiAUBn0IHswqb+v0Kb2Li8xfO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/qRGh4rLt8D/g5ptYoZzY
vzgZn3epFKQ/1Hk5V1gh5j8RN/wAiErSv7FBFNuXKOi/+FHO8D1Y6j98JAYN
XNYBwOy1JpZ+7/C/rO5zTxz/8z+2GiOzOIQCwMgwbp/UMtK/oC3slkuS+j/T
6fAdKz//v6AbmfMNR++/guY2+w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3383307007554224`, 0.740114050597572, 
                 3.0142166689744707`},
                ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]], 42->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/8uHed2q38j+3K34088n/v8Q+XO4+t+e/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/jOhl2Ce69j/kmkJ5VOvGvyTQZY29Udk/PaqEQI0M
5j9gVOoTdBGpP8YL4ROMB/O/VkTJkt0L3T87GHyFdZkDwPJajDvC1va/VvUU
DJPj9D+6SnJDFDQFwADc0kd8K74/aI0fr5QPAUDs3l3KVpP+vwpU7lgiG/S/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/M3Ij8wP08D8jUDv0MyLZ
vwBD3f/o26U/+VAjriY05j8kBKyUR9bRv5+rPOc8/ue/CDOR3GH66T8Ll92P
N78BwCo9XdkwWfG/pOv5wX7N8z9LsNjuhowCwETjYWXP8dO/Yf4O60lr+j9S
BW7/pC7/v2xzHNDB9u+/UgczFg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3409006721474432`, 0.7113059734340785, 
                 3.020004834365589}], 43->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/7wSlF2yP8j9e6RUumrr/v2SZwhVla+i/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/J3LqZFDG9j+8sFDL4gXJv8zfiiJGv9k/8MtKPPsy
5j8ouv5bqB2wP85k3WxF3PK/fF85vRQ33D++hFos1nADwEyX52+RTve/XVDj
8x2o9D8AA+JWOkoFwPAj+y3ozLU/plUqrrH8AECf3mX1SX7+vwSkZFU1cPS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/AbdlORj68D+Z1b6I16jZ
v6CBcVQLkqc/02EGrF1H5j8l0mrKqWPRv6cEOUD20ue/zlzzRjGd6T+2vLKh
EacBwP9xZP0hwvG/pirEBcWb8z/Ye/a2w5MCwOY0AxDIsdW/Htj8uWdE+j/+
470Rchz/v1v4IvDzUvC/W9A3FQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3433685278205985`, 0.6824437262275764, 
                 3.02556301520787}], 44->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/RlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/NNwpGotn8j+A+Iluian/v/byZ98GH+m/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/snRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/TkM3av7R9j9Au8sBiyTLv70YKuB+KNo/nbHYhjda
5j8QY/YcOqWzP+21l3IWsPK/jkeGaKFk2z/gs+iRE0cDwJ1s4DYQxfe/sFrQ
3Fps9D9UM74+GF8FwJCESO6yxqo/XFbbfuLpAECIhtIRnmf+v3vP5wvvxPS/
54NOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/lB8MPO//8D86mF2WgTDa
v2hl7kruNqk/qVRN0fta5j8I3UuSt/LQv8ZV80XHpue/GG5LdLNA6T8Q2JYk
7I0BwAwzStNJKvK/cht9+/Jp8z/KlwF77pkCwK1qg7Cbcte/dkTwC6gd+j+E
Py7Akwj/v3vkzT05qvC/Zpw1BQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.345734079690209, 0.653529506736219, 
                 3.0308907882973046`}], 45->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/s3WGm8o/8j/yO4dKwpb/v7yXUkkW0um/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/p98i/zDd9j/oWLHLIkfNv64BvJFfjdo/sCvtED+C
5j+gs/7WKB+3P8bqF5cCg/K/nNrj/ZOU2j+2GM73MBwDwG639FI1Ovi/90ri
b04w9D8s7XZarHIFwJCBPErgvZM/nJ2vmCjXAEDZSzrkVE/+v9ZBGuFIGfW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/we2BhogF8T+k/9aIJ7na
vygJNhFxyqo/s5FXlv9u5j/20gq7eYPQv5+Kc2qzeee/Wmz/mu/k6D9Y24gO
yXMBwKYBzzugkfK/VWC0hQw48z+SRd2/Bp8CwLCzAEcnNNm/dthy5g33+T/m
w2CXC/P+v9rG4QIqAfG/Ec43Xg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3479971474281327`, 0.6245655166264886, 
                 3.03598774799351}], 46->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/GitLtS0Y8j8vLOo4RoL/v1Pg8lyFhOq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/HP4jROfn9j9iBW2Jf23Pv9LQcFng7do/VZ5tuw6r
5j9gQXUkL4u6P8AJP14NVfK/DnSmtvzG2T9CcCe2MfACwDDblqH3rfi/eFTX
W/3z8z9++DMj9YQFwCB+fhOacIy/0kx7cYXEAEDrFm5RcDX+vyhyGEE8bfW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/+3wCqeMK8T/C6kW4vkLb
v7BFCTB0TKw/BcuXa2eD5j8+AVzx+BXQv5qpmjG+S+e/Hsj04uyJ6D8tQ05p
qlgBwK0lCCgd+PK/yT+RiBUG8z9Lh9QfDKMCwEzaQMVH9tq/X+IgTJzQ+T+N
ISxF29v+vynxyHe/V/G/hxIttw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3501575584659946`, 0.5955539612903507, 
                 3.040853506255853}], 47->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/DcBBfrfw8T8InKHSFmz/v3TwOTBGNuu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/PfdiYyDy9j8mfhUou8vQvzV1zbD5Sds/ElKkV6PU
5j84Bly1COm9P9AHgV06JvK/BAz/muv72D/4/kM7GcMCwIQe5BtOIPm/syzI
VGy38z8yTvMr8ZUFwKg6MhM+Kai/KnJMffqxAEDzdFNe8hn+v4oy/J/CwPW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/jPmhOAAQ8T99aPVpPM3b
v0DXe43ZvK0/5CSzuTGY5j9GUX5+e1TPv6qn3DDrHOe/DoMBZbIv6D9+ZkpS
kjwBwF+LAJq4XfO/YPaE6RHU8j8bDqJK/qUCwB4UbRHauNy/MFJtPFaq+T9+
iHqYBMP+v2KVDNzyrfG/kLAuVQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3522151479936007`, 0.566497049656015, 
                 3.0454876926803816`}], 48->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/qrcvCmvJ8T8t1Y7SNVT/v9p7r+ZK5+u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/NHLKkNv79j8WfZj2beLRvwTRQWmkods/n/t/p/n+
5j/Ii1YqOZzAP3Q9nTuN9vG//iu7gHAz2D8cE2EL65QCwD7fWNcvkfm/GibK
E6B68z+2jqUhn6UFwCTq+RCBo7S/KgVOLomfAEA3Sbwv3fz9v+ZfX3rVE/a/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/B7dVz90U8T/15zbRlVjc
v4BGTW+EG68/qvmg4Vyt5j/wDKoWoYDOv03d+A4+7ea/qoJeKkfW5z/ZPlT6
gh8BwJZOWKVqwvO/4u78jgWi8j+mfHYF3acCwB65zgi7e96//+Blsz6E+T8y
jyWBiaj+v+qO23a9A/K/yeM4Pg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3541697589506425`, 0.5373969939895885, 
                 3.0498899545384437`}], 49->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/YOaYaUui8T/2DmMVpTr/v/N7hrKFl+y/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/zk4XChgF9z86TJ50wvrSv3IYuKzZ9Ns/dHbUXQ4q
5z8EJsz2lDzCP3aCVbAJxvG//NAICptt1z9o0WPAqmUCwOaPggaUAPq/UueQ
Vp098z+ackjL/bMFwFCBMYAOOr2/LAmr9DKNAEALATwKM979vwDo3VVuZva/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/VCX8C3wZ8T+HzzkQwOTc
vxgyk74sNLA/FDfLPOfC5j/SP28wc7DNv1AisYO6vOa/nxobLLJ95z9yrIql
fgEBwPDm4m8rJvS/2eYUYPRv8j8K/fwqqKgCwA5WRsFjH+C/XHx3qVhe+T8A
iM8PbIz+v/2SkJcYWfK/6oYsHQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3560212420082967`, 0.5082560096827323, 
                 3.0540599568187368`}], 50->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/BlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/vkSCqVt78T9GQnqZZh//v+jAsNXoRu2/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/sXRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/nMvnFtUN9z8NgfPFohTUv59KHf6SQ9w/Aq2cHt5V
5z9QNFVId9XDPwr2I4SzlPG/qFQ+pHqq1j9UUZEJXDUCwCxxr/lxbvq/JMYP
32gA8z8wM/8JDMEFwE704fLN68K/mtdxPvl6AEDYTfpR9r39v94bl8GGuPa/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/62
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/u2Nkktod8T/waeQ4sHHd
v3SWXWGf0bA/W1IvHc/Y5j+suKoHAuTMv+SVf1dki+a/6NmRUvol5z88OSer
h+IAwNDoQzLziPS/cQVJROI98j8qKl6rX6gCwP6eNCnuAOG/+fkyE6c4+T8P
SLp1rm7+vym+N5b9rfK//KI1kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.357769455535375, 0.4790763150185853, 
                 3.05799738227543}], 51->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/4ZaZh+W79j86mPxOOzbnP2HPPmIQesa/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/xl3xVANg5D/UQqk1wTbsv0X5Ow+H6fW/EPY5Bm7H
9D+RYDbeNhT2v/MuyR2/hMc/QJTHjyOY9z8HKCKApqDwPxujhR9T5Os/XSL+
xZx57T9zQ5fbMjL4P8Ukj58D8Oe/K53CstSMA0DI0vdhlWnkP/dQUthbyeG/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/vKpZuOFd5T8f9skFEM/n
vx6Zl+I34Oq/6vEaFE717z9GtStJ5sfvv9TPE33HMLC/kJWwiwQq9z8kdKAn
xDvsP0Tv9QbPRdY/CFRM9Vm88j/Ix4pBqObxP57YHriHjt2/nGiPdsfq/j+B
NXpY6M/lP9AE4vDfZ9e/43RDXg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3594155083295971`, 0.449860130902606, 
                 3.061701379680467}], 52->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/MAUC7Bcu8T8h2kUG6eP+v2BD7X7xou6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/9/dIO84d9z87ICDZrkzWv1WWeJZ509w/UsfKBqGv
5z/MzEiIUPDGP2DhvryeL/G/FJJQsZUs1T80tqV+otEBwMjbHQZ5Rfu/EXcH
3H2F8j8633ROM9cFwN5pYRCDksu/8s47CeFWAEA+45VWz3j9v1ptyrgcW/e/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/6fmUJNcl8T+IuXpCto3e
v+AtFJJs8bE/hF9GkbAF5z9u7LBnlVbLvzqBGpBPJua/tSlWWD155j+iUeSA
y6EAwLw+yuJ4S/W/IL4E5MrZ8T8l5svok6QCwOzOgiHJw+K/itE8/+zt+D+w
3m0uXC7+v4WHILxKVvO/5jg2iA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3609555455686586`, 0.42060968053452535`, 
                 3.0651733229340485`}], 53->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+xlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO/kmMF9ckH8T8mvJSSrsP+vwy6O+F7T++/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxv7PQbPX9E/5f8KFBxw8r/25FB/
o034P55rgfrGE80/snRlqEhL879+Hxok7JL4vzAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/e4T6Ewkl9z+WDxlPrmrXv5d6waSbFN0/QAlLLo3d
5z9gZzd7CXLIP87oagPo+/C/pD3l6+5x1D8zU1hxP54BwNSkzFqRrvu/eBxN
5tBH8j882PSZSuAFwJ6CG8fE6c+/XFHMWgVFAEDwCe536lP9v9RilZaNq/e/
54NOcX6B+b8uJuFmj+biP6utV1g2r+W/pIR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwK3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/K8DtkHQp8T81MXf9tRzf
v2D2pa6wc7I/e4AGpaYc5z8knznuuJXKv6iIxtaY8uW/+7L+r0Uk5j+jWFFd
C4AAwO1AtaUnq/W/BUCpbc2n8T8om5/xEKECwFpNgYn2pOO/JQNPVerI+D8L
Y0GFzAv+v+2fmcOlqfO/puM1ig==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3623931765366755`, 0.3913271889766751, 
                 3.0684112931114567`}], 54->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/RlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/5KLq6rfh8D+m9v6mz6H+v4axc1X4+u+/kUxZ4ZoX+r841qoispzj
P+/gKiFikvO/qitNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/sXRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/tEiKAsIr9z9otxgE4YnYvxXiflArUd0/oH7/YCYM
6D/07xYBzevJP4PjTmxux/C/uCt/xDi60z/W4zGF3WkBwCfap+sBFvy/CS0l
YQUK8j+SRS0GDugFwGksQY+WIdK/6CCp0EszAEBm2w7PfS39vw3NOapk+/e/
5oNOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/R6I1CNEs8T8eBfdXT6zf
v2TFIAbQ7LI/KrtgPvMz5z/a2kkr19jJv1yDqj8fvuW/0m0KHEbQ5T+Ur1is
Yl0AwHXZMAu/Cfa/9ucHpt518T9yYNbsepwCwN0jis7hheS/WnIexiek+D8G
6Qa7puf9v+jSeWpw/PO//3I1hg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3637270464213729`, 0.3620148825314108, 
                 3.0714155967053056`}], 55->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/avqwxeS78D9tQa3nTn7+v55iHL6sUvC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/8nnFgPgx9z9VnNCSMKrZv9aPtuAjid0/u8Kq/Gg7
6D8Mv6SkfV3LP2Y++A42kvC/WqSIjoEF0z+eWufPgDQBwFSVuqfCe/y/Sior
HiDM8T9cbiP4fO4FwBbV3qEyT9S/JrGozLUhAECRmQhbjAX9v/Rq4LmbSvi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/5jpTR+wv8T/Ke6mPOx7g
v+QgkCbBXLM/OF02jJRL5z9O84LZ/h/Jvz/eU+LmiOW/gCNTKUV95T+q/d4h
1DkAwPl767I3Z/a/WhLucQJE8T+JB/010pYCwOQXlGZ5ZuW/Wy6BL6h/+D9/
7Vqh7cH9v8lm/jukTvS/QcY3Qg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3649570496981074`, 0.33267498774244486`, 
                 3.0741860068984117`}], 56->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/KRVweFOW8D+kXl0ZL1n+v2oNIwZJp/C/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Pz2lEqw39z/o0bt/hsvav8bUEPiAvN0/eIbZUVFr
6D9ILcuR/sbMPxrP1BFDXPC/woadYddT0j8IE7x6Lf4AwESKvJ/L3/y/r3X8
8CWO8T8whWnvlvMFwC4q5R+Lfda/TkzcrUQQAEDg+Dw5Gdz8v4JbLJgsmfi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jRxDEMYy8T8vSeQKkWbg
v8CqRFV7w7M/F7/Ntohj5z8wvO9iPmvIv/RuMOXzUuW/2nbXUEkr5T8tYbWD
YhUAwNfL71KKw/a/bEW2tDwS8T9BGgw+F5ACwPZXHM6rRua/4lYUam5b+D/C
K00ppJr9v3a0J886oPS/pokuqw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3660830862226072`, 0.30330972959872043`, 
                 3.076722315950412}], 57->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/CDAd8QZx8D9S1iohczL+v8LOu2lK+/C/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/XFNYRtw89z98y986zO3bvxqxL5U+690/eCIspNub
6D9gE+GXMyjOP8T636mZJfC/LvdxGEil0T/Yvy7C58YAwIZtsAYVQv2/JPbX
rhtQ8T/4qyiGW/cFwNQzIX90rNi/4mXpoPP9/z818iClJ7H8v2RutiQR5/i/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/m6ccKl418T+UR615Iq/g
v2hjgo/2ILQ/Fg3338175z8kyeTfo7rHv56aO31KHOW/1K0591ja5D8BK8RS
IeD/vyQeNrivHve/FpP6T5Hg8D+QC1+LSogCwLcbhIlnJue/9UoDSX03+D9E
5CVjzXH9v5MeOcct8fS/q4My3g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3671050588232776`, 0.27392132787421114`, 
                 3.0790243364214303`}], 58->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/ZlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1rF0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2J/
bk3D2tO/hp5QGAJM8D+rK1UEHgr+v8W16FuqTvG/kUxZ4ZoX+r841qoispzj
P+/gKiFikvO/qitNXGePBMCle3QCO9bdPxb7PQbPX9E/5P8KFBxw8r/25FB/
o034P5RrgfrGE80/sXRlqEhL879+Hxok7JL4v+AZDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/4PhLtIhB9z+gxY4h6xDdv5rJ/hJZFd4/BCuhKgTN
6D+wi9wrAYHPP810nTR83O+/Tsy9T+H50D9c2aT1s44AwAWufzKXov2/DJ09
LgYS8T/w5ChxyvkFwDTCEyrD29q/JupNG63b/z9vPPz3uoT8v89xh0xDNPm/
5oNOcX6B+b8uJuFmj+biP66tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzaQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwPzwLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/i2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/XXoWYbQ38T8dBlkz6vfg
v3CUIIsrdbQ/XJExI2KU5z/8DOcVPQ7Hvz9aqu3u5OS/mhFAbHqK5D8yb8/3
wpP/v+UxNMegePe/yR1HIwSv8D9jvam5bH8CwFKmbSabBei/VkTPmdcT+D8N
tCh+bEf9v8oTONR2QfW/xwEwzQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.368022867472294, 0.2445119885239335, 
                 3.0810919041049316`}], 59->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/d7oL0Ucn8D/PkAPoMuD9v7KwQlxiofG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/1/kz/7BF9z+RpCuAzDTev54q/CjNOt4/VgDhD8f+
6D+sZDw1pmjQP2UGdWhpbO+/VNIsZbBR0D98khR3llUAwPh1k5xKAf6/ONKN
RurT8D848NZ/4/oFwCp9V4NLC92/vQ0jd7i5/z+hcqao1lb8vy50kQq9gPm/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/2XqKhsg58T/ZPQCL4kDh
v3BWG7cTwLQ/BnzRlUOt5z8o7ph2F2bGvwwjloflrOS/DO9W6rM75D/kWhbr
r0X/v1UTa3xW0fe/WMbMC5l98D9QXOx5fnUCwPyPGD015Oi/GmQXJIDw9z+4
AVXIhBv9v3ASarMPkfW/RG4xWw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3688363926345968`, 0.21508387944001758`, 
                 3.0829248863707552`}], 60->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/RlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/PkN/+NoC8D+XHQYRtbT9vytXe/dr8/G/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/snRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/MvgR1FRJ9z/aJO+TWVnfvwvTeeuXW94/z1SKciAx
6T8KbSeNfQzRPy4zlqwD++6/aPCn7IRZzz8iW626kxsAwDfnauInXv6/Us6o
z8yV8D+SFUicpvoFwOmRB+nhOt+/viVDWhiY/z8l7EFLfif8v+/vJ2h4zPm/
54NOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/Bnr5cJo78T/sHfHPBYrh
v1CnFjypAbU/QiYmR3DG5z/K5a0eQMLFv3C5pqkydOS/S0EUlgvu4z/uaTBD
7vX+vzEf8+zJKPi/yAgU5FNM8D8vkmWSgGoCwKU7vXEkwum/fjRhqXnN9z/e
BCSuGe78v42j0S/y3/W/854z1g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3695454339095965`, 0.18563904159520878`, 
                 3.084523212863373}], 61->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/kGKky3y97z9cjpTjp4f9vyav3cfARPK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/reQ76nNM9z90HVfGPT/gvx0C2Mu2d94/8qN/ZQxk
6T/ElPDW+avRPy6rvthTiO6/vPlWv0gWzj+E7f2MYMH/vyqHLsYnuf6/Y+uN
obJX8D/Y2TvLE/kFwHBdE1wtteC/SxjxY892/z/gS/SQtfb7v37Ydn1vF/q/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/RHAO/Ck98T9v4yBOTtPh
v3AF0/zmObU/1M2gQObf5z8QvuTUwyLFv3D1ur/aOuS/gBC9fYeh4z/wPUk4
hKT+vygbBkf0fvi/Vg6wgzgb8D+DEIPec14CwN5d53VXn+q/yqTh5Maq9z8e
bUS6Lr/8v9JDqiIYLva/U4c9RA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.370149350670413, 0.15617886949835366`, 
                 3.0858870552208586`}], 62->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/4gPS0+l17z/cjwrjDln9v0LizXValfK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/T6lhAw5P9z/BvlDHDdLgv7RDuJgnj94/PJM18IaX
6T8GzsyiDkfSP82+ad5iFO6/tF8cd8XZzD9LXD5k4Un/v87OQC9DEv+/1fL6
k6AZ8D9CoBssK/YFwEEuAyjFzOG/HQSkLOBV/z9wzJxHgMT7v6Z++HGcYfq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/lVKhCHc+8T8WtJ1Othzi
v5yIk5bIaLU/ecX7haP55z/OhAgJr4fEv0B/kELiAOS/6I3MmC1W4z8UdqQj
eFH+v4hYh9LO0/i/xvTjfZXU7z8YdNBOWVECwGJ5zwm9e+u/B4NGi2qI9z8m
rlOVx478v3Qw43N7e/a/Mi01bQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3706375469036904`, 0.12669035924855904`, 
                 3.087021585264882}], 63->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/RlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/zgBbngIv7z9hnaGx7Sj9v7vZR7gy5fK/kUxZ4ZoX+r841qoispzj
P+/gKiFikvO/qitNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/sXRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/ZAWS6yJR9z9AvBZaEWXhv8c2KX7ood4/cDcCD4zL
6T88Dd3Yr93SPxzWHcg5n+2/mLN7whOkyz+PRpxMs9D+v63Tyypzaf+/SOEW
/Da37z9ON/j47PEFwI661ooi5OK/3m/TRU01/z/NTohZ4pD7v4dD6nz5qvq/
5oNOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/n4C5fIE/8T/VsgAYOGbi
v8hudWFKjrU/khdiFaYT6D+YRfjSDfHDv+aKardNxuO/2vZ8xwMM4z/48R5/
0Pz9v7TWifFSJ/m/C/E4zRxz7z//guToMUMCwAI3s/1DV+y/IniASmdm9z8X
9pQF6Fz8v6EOmRoWyPa/1tU5cA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8514956511142988`, 
                 2.6785723597645803`, -0.9064292401561427}], 64->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/6h+usszo7j/TdigQSPf8vwa3XFVDNPO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/cZo+ebJS9z+d4dUHPfjhv+QKywX4r94/tDdtsxcA
6j+Esx+60W/TP0j0t7jhKO2/pMHZx0t1yj8+nTK531X+v4z+S+ywvv+/bCaw
a1A77z+WUYWGWewFwNmMn7sv++O/WwXEORkV/z+EMSPN31v7v9wQwOWA8/q/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/JsuPQ0lA8T+EReDuza/i
vwAXuXBpqrU/tZeX5+st6D9Qn7Xx617Dv/2Zt68hi+O/KkhS0g/D4j8Iiq3k
k6b9v8la1CB6efm/KyMvjw4S7z+AxkzH/jMCwHJ9LDPbMe2/qIqNyb9E9z8s
1KXukyn8v/Fjjh3iE/e/SBE6cQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.853663567168515, 
                 2.685239325476667, -0.8819416900598969}], 65->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/rfdmik2j7j8rNLjdIcT8v14fryKGgvO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5v8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1iBce6ydfY/tik/jbxT9z8DXJpWhYviv+qx7BZVud4/YciAxCU1
6j9OC1vhaP3TP/hUtepjsey/tHWaI4VNyT/MWfo9cNn9v5DiC+f6CADAmT4s
IJe/7j/q6hJEceUFwN4esPfWEeW/DNxUi0b1/j9v9qjEfCX7v5KNlgQtO/u/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/y2
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/yRKQTc5A8T+2gkIWcvni
vwxl/JIjvbU/DGAh8HJI6D+GR3rKVNHCv1VKtshiT+O/jcqmaVd74j/8RtkN
yU79vz9yY/g9yvm/I5tJVXKx7j+AgncZwSMCwM0uh55xC+6/8StEqHYj9z9N
lTBRz/T7v3jWopPZXve/sSE15A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8557290620477356`, 
                 2.6917872799971727`, -0.8572927665137807}], 66->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/b6LgkIpe7j9D/GYXf4/8v4BQ7gX1z/O/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/OgLUEkFU9z8V1DTK3h7jv1LDofb+vd4/W3cbH7Jq
6j+wxABEaobUPzwye6/JOOy/SIRJ5tYsyD+/SQuPblv9vxou8qidMQDAj/9t
vxRE7j88moS7NN0FwHhAToQCKOa/qFfNtdfV/j9ZvdF9ve36v9YFpEL4gfu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/Cn9akBBB8T/Avg/QHkPj
v9yHZlJ3xrU/iLduHTlj6D8kjtRnU0jCv/c4GasVE+O/wIE5JeA04j8BIznT
dvX8v1pW6SuYGfq//1AnqE9R7j8vDJwjehICwLxwFUj24+6/cNQef44C9z/O
XJxKnr77vysrSaT2qPe/8r0v9w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{1.8576922920581251`, 
                 2.6982138912019122`, -0.8324789158608555}], 67->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/zY7JIoka7j8MZfjXY1n8vwD1T/WJHPS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY//J6n/z9U9z+GtB/lPbLjv7sP0Uf1vd4/acNClrig
6j+EXwozywrVPzjBnG4cv+u/sPrNklcTxz8JWdp/5Nv8v+aro5A9WQDAOfEP
69LI7T/k0EaRpNMFwKLfZLCcPee/Ip6rLM+2/j/lmX1RprT6v8r9pxrdx/u/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/a03EBhBB8T/4LoVdzozj
v6wgxfRjxrU/j10CWTx+6D9Q88p48sPBv3YAqgo/1uK/vIa+g6/v4T8KX+kr
pJr8v2amS4uCZ/q/A8DsBq7x7T+1gaE+KwACwNFkgk1Yu++/xDII3wni9j94
/7oUBYf7v2X5+4cz8ve/ldI8pA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8595524106644403`, 
                 2.704516674028199, -0.8074988494700871}], 68->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/0nS4jU7X7T8tg4tX1CH8v8KuCPg+aPS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/QXXPU7lT9z+Gi2Qpl0Xkv4jjOws4ud4/EHh28zTX
6j+ccs5bgYrVP8xzH6VlROu/UNqoHB0Bxj8banUC3Fr8v6OXGofXfwDAAgmk
P9tN7T9QCEKEwcgFwFIQNdaPUui/B6lzWy+Y/j9Ky12zO3r6vxZmWRnWDPy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/jjjYsMxA8T94mqf/etbj
v0jImnvpvLU/4zech3qZ6D844AZQPETBv79Z66XjmOK/s1Vx6sqr4T+kdgAt
WD78vwTvHgP3s/q/6j6u5pSS7T/z5APY1ewBwHabkXHDSPC/uPEnUevB9j88
p3QFCE77v2wKsYiKOvi/g4wzWA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.861308422443316, 
                 2.7106930649356373`, -0.782351624432015}], 69->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/oHjCD+CU7T+3r0br1Oj7vyJOwyYOs/S/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/4fLLGa1S9z+2dIEZ39jkv6L3fZ/Hr94/nMcE9yIO
6z/Mvs7IggXWP2eOveSuyOq/fOM+5jz2xD9py7wmX9j7v8pNvolopQDAwMnz
UzfT7D/q3sttjLwFwJUxBl3GZum/L/Z+pfp5/j/R3Jsxgj76v9Rp093dUPy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/XnfWk0ZA8T8QD7b3HiDk
v3jwHqQIqrU/qV9jifG06D8IlAbjOsnAvw1nukUIW+K/wBippDdp4T+QvQEJ
muD7v9v0H53v/vq/MCHbsQs07T9jm7dxe9gBwHYzo6o4s/C/QBmwVjWi9j9E
RnGOqxP7v/tbSwL2gfi/pgM7qQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8629592800864554`, 
                 2.716740430294729, -0.7570364292038811}], 70->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/moIS10JT7T9CCgEFaq77v4ysFqzx/PS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/p6yHZhtR9z9Vek45Cmzlv/kQBsGkod4/phxfWH5F
6z9W/n7ixXvWP0ogJ9MBTOq/dLAtv8vywz9MWZoZeFT7v/Rin6rtyQDABNdA
uPBY7D90JZZBBq8FwBoP1boqeuq/b9vMZTNc/j/PtX50fgH6v3DNABrvk/y/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/QVQ0un0/8T/gkZyHtGnk
vygjL+fCjbU/LooQOp/Q6D9+VFbJ91LAv/4v77yxHOK/XPdu4/on4T/HsU0P
cYH7vzq5qoBmSPu/z6ypxxnW7D9KVQuiHcMBwAyawIQDHfG/Xg6raOqC9j8I
4L889Nf6v/68C2NwyPi/jsQy1Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8645039069065446`, 
                 2.722656068342011, -0.7315525371773745}], 71->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/J9WBAXwS7T9dvukymHL7v1Ah+sTjRfW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/yLxVWQRP9z8k2+IODf/lv9BOB4rQjt4/jZxvxkJ9
6z+oYARwQe3WP2xtQSlozum/7EKs4t32wj+IXDYkMc/6v7UeshBk7QDA3QqG
9RDf6z823psNMKAFwJDcAXanjOu/DIHT7ts+/j9eoA0+NcP5v9jVBZME1vy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/UVybM3I+8T9HwmbyNbPk
v9ieMXkaaLU/IcoYcYHs6D9Y5KF3+MK/v49W/Ofk3eG/8XIWvRno4D9yDZCr
5CD7v10vL/NVkPu/AvCDe8Z47D+yXogTvqwBwMyH/b8bhvG/0DXK9wxk9j9e
r3u45pr6v5T7/yv0Dfm/2uY42w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8659412043745025`, 
                 2.728437209908021, -0.7058992940970857}], 72->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/dugxnJDS7D8gEy0fZDX7v5CHOMHejfW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/gVHvG2hM9z+8I3oj3JHmvxopY3JMd94/LFTv52u1
6z/wo+2X7FnXP+3YZLLrT+m/sCP39YYCwj+2NCqrlEj6v4hVB/jIDwHAtBy5
jKFl6z9gLwz6CpAFwJXq/CYnnuy/eYZRivYh/j/yTbFpq4P5vxSwqCEZF/2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/riboFCQ98T+TZrJ8nfzk
v2hT6UkSObU/8aXYAZYI6T/IXc8noum+v1AMjqymnuG/sdjXLJmp4D/roytl
/L76v1CZo1i41vu/lYJ1FBkc7D94XNGEXpUBwG1+Wyp57vG/Wj01bJ9F9j+J
MG/Eh1z6v9KbcPF7Uvm/GIo0hQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8672700554457797`, 
                 2.7340810188629354`, -0.6800761150995711}], 73->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/rpMno4WT7D/+S5eP0vb6v17M4QPd1PW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/O2xw4kZJ9z/kCFkEbCTnv/YgjE8aW94/Dgi9W/Xt
6z/gvePgvsHXPylfmUuW0Oi/rDTIBtoVwT8Z37AtrcD5vyudA7IZMQHAdugM
9qvs6j9aSjNJmH4FwDXy8XmUru2/SVUgeYUF/j9Z4dLr5UL5v7xQuLInV/2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/C7QoeJM78T8n2SFt5UXl
vyBDOwSuALU/4n+/u9ok6T/oKeOV/Rm+v25PKPn7XuG/bNBsEn5s4D+MFaTe
v1v6v1qD9DOIG/y/Ej6azBjA6z8seH/IAH0BwLxibaATVvK/kA9aJaQn9j+s
FrU93Bz6v40OTVsClvm/VGAxEw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.868489326438782, 
                 2.7395845925261764`, -0.6540824851481126}], 74->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/CIznAGBV7D8tYjVl6Lb6vzr8ugPZGva/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/R9FT66BF9z+W8bFDsbbnvxolYVQ8Ot4/gqE0udom
7D8KBlMysCTYP8Ou0eJxUOi/NFPaiekwwD+YadVEhTf5v1fXlKVTUQHAbmQ0
oDl06j/ESWFX2WsFwFHXcTDave6/gyUH84rp/T+GBXnR6QD5v7DDcUcrlv2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/kWaafMA58T+ATc4MCI/l
v2hL5Q3yvrQ/nEx7ak1B6T+UmQTzGlS9vzt3xMTpHuG/ahCvMc0w4D/iZQXV
Nvf5v3RVcifAXvy/O/iN0Mxk6z9t/f3EpmMBwPHz+Q3jvPK/xHW9eR0K9j/a
M1cb6dv5v/VfliWC2Pm/Tz00XQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8695978683499923`, 
                 2.7449449621221804`, -0.6279179608684773}], 75->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/CkEUjiQY7D/2nfObqnX6vwjHrEvNX/a/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/iChuf3ZB9z9oHol5oEjovz6tARG1FN4/cDGHkBdg
7D9y1AzVuILYPxfwJHaIz+e/kNHxso6nvj+mYp+iJ634v3YOZk90cAHABFWm
71P86T8kCM+az1cFwEe/GiPjy++/LreOJgnO/T8QGeM/vL34v9jj4/Ue1P2/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/MZKnRqs38T/p47mn/9fl
v7BbJofjc7Q/kpQk1utd6T/E/JCtCZi8v+UXbg513uC/PHtyZBbt3z9OgEkf
aZH5v/pxPPVaoPy/B0vdPjwK6z+Qa2R0UkkBwFYTnW7fIvO/2mvMtg3t9T+D
W+tts5n5v3BVyCD2Gfq/GKwzWw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.870594517935979, 
                 2.750159093316166, -0.6015821730389498}], 76->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/+B0NEdjb6z+RFzpKHjP6vyJyMHu0o/a/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/pU/o8cc89z/5XJhELtrov/yPmnKH6t0/hoITa6eZ
7D8KiOFz0dvYPzJKBxPkTee/0A03aAn9vD8jVj0RnyH4v22gEUJ5jgHAlszh
PQSF6T9U8YCjfEIFwOotnyFNbPC/XcTVOAKz/T8TdiJ0Ynn4v1BzUen9EP6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/wKXk/1M18T8yg0GNxiDm
vzAhWEqIH7Q/Hr1qw7N66T+Uledv2OW7v/JE39yineC/sv8TPnl73z/atrut
Xir5v37ZqX9T4Py/R3V3J26w6j+O/k7kBS4BwAbQZ84AiPO/rCmuIHfQ9T/S
Ri5fQFb5v7nyQDJZWvq/CP0yDg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8714780987009574`, 
                 2.7552238868468937`, -0.5750748294186967}], 77->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/lDePPX+g6z9aJ4egSO/5v7ovu0aJ5va/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/0904oJU39z9SNTJLT2vpv0GXK8O2u90/TjO/y4XT
7D+i6DIc8y/ZP0Y1gdWOy+a/IFIbdmRiuz9GaC1y9pT3v36zUSZgqwHAQIaz
2FMO6T/80Ccb4isFwFwkQ0718fC/Fy9mRXiY/T+a3rHC4TP4v16MkWLDTP6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/1+wM17oy8T9eb44QV2nm
v7gveuvmwbM/gpXA86KX6T9k1EQflT27v3w6HD54XOC/2KFSzMsM3z/QR1qJ
H8L4v1tLr8mkHv2/6l4hi2lX6j9UsrU1wxEBwAsqf0o/7PO/cOUW8lu09T/6
gpwxlRH5vwxeplSmmfq/amwy7w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8722474218531127`, 
                 2.760136179266959, -0.5483957177677095}], 78->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/G25XtB5m6z88zQfpLqr5v3TTJ3hGKPe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/Gtoc8t8x9z+afyQ8+Pvpv1jXRalGiN0/o1FQL64N
7T9o2X4+F3/ZPwmqZeeSSOa/mHJF4r/XuT8WH2S9OAf3v3rxLrsmxwHAayp8
AUyY6D+YoP/EARQFwKAtS6vfdvG/qu4KXm1+/T+sFQuXP+33v3Bjbrhqh/6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/++r+/98v8T+ClAeJq7Hm
v+SvrrcGW7M/rSSJJbe06T/Y8qzaTJ+6v950Dkf6GuC/bhygsBah3j8p9jXT
s1j4vzTbQvdJW/2/Q8zpWjX/6T+bw8GcjPQAwIqAuRGTT/S/3FIbXL6Y9T90
cQlAt8v4v3IbS5jY1/q/oEQ1AQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.872901287261083, 
                 2.764892743798214, -0.5215447089826141}], 79->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/dArGArss6z9oFy6H1mP5v8DbHu/maPe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Y6SPWacr9z+PUJrPHYzqv27Owic7UN0/XnDHDBxI
7T+sUOKuN8nZP8Y9h3/6xOW/qN7scjpduD94a3EAcXj2v7iFLdbK4QHAAIt3
7PUi6D98V6x93foEwNphVtsB+/G/Z7+miuNk/T87rTpzgaX3vyRTAljvwP6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/H1C4s8Ms8T/8fMJSvvnm
vxCeqLTv6rI/CrREFO7R6T9QBOb5Cwu6v3l9PiZcst+/SaYjUWI43j9wwc/D
I+73v5jzvE0+lv2/usqed9in6T+YsaFgZNYAwM2eOmX0sfS/UOIEhqB99T9S
YjT9q4T4v3KXkCPrFPu/AYI5IQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8734384844267276`, 
                 2.769490291308573, -0.4945217603062989}], 80->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/RlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/592Dolj06j+WkEX3RBz5vxnIfKFlqPe/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxf7PQbPX9E/5v8KFBxw8r/25FB/
o034P5ZrgfrGE80/snRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DyJhX4rj4797
cz4vHITjv1iBce6ydfY/DBLCUuwk9z8OK/3HtBvrv5NRdJ2YE90/STC61cqC
7T8Ai5SlTg7aP8467ODPQOW/4ElzrPHytj/oAqRdquj1vyhaeGNK+wHAP+YE
wFqu5z+6vxQ7d+AEwMXvn5BRfvK/RpgLydxL/T96EXLvrFz3v8UqE8VM+f6/
54NOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/q2
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/9IZRMGYp8T886vPOiUHn
v2CkC6CqcbI/ABS+eEXv6T+oj4EM3oC5v4B6o4cxLt+/I0cS2LbS3T+/yXSq
d4L3vzS+NjR9z/2/E2JEsVlR6T8CxFvbTLcAwO9bDplbE/W/ncMmjQRj9T8I
0VvzeDz4v2/5RzPZUPu/sP82Ig==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8738577934828236`, 
                 2.7739254714157684`, -0.4673269185853622}], 81->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/Zuso+fu86j87vgXOf9P4v9aztpu95ve/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/vb4QZK8d9z8EZdXysarrv95NzcRj0tw/BDWu9rW9
7T8kcFq/Vk7aP4/FAVodvOS/yGsXzwGZtT8YGysL8Ff1v0GQCmajEwLAGj7w
k4M65z+2UjsM0cQEwDjOzI3EAPO/U+nSDFsz/T8k2pe5xxL3vzi4a5p+MP+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/TN34uMcl8T83B2BkCInn
v/Scve5A77E/XRY4CbsM6j9gxfXYzQC5v0EFuQB/qd6/39gLMxxw3T+qbJjs
txX3vyzq5TMCB/6/wJSMxr/76D/qGJ95SJcAwAfBwRTBc/W/g6+zhOxI9T8w
zM7DI/P3vwc2ERuei/u/p280+w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8741579862205955`, 
                 2.778194873723049, -0.4399603235571734}], 82->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/a6HkV6mG6j82tyK4jIn4vwwuPQHqI/i/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/IpL5HfEV9z92rqkpCjnsv1Zkg7OhjNw/Q39019j4
7T9IIPL9SonaP+gdzkPtNuS/wAfB1IVPtD+0mDZSTcb0v30y1/fTKgLAu9K8
cHnH5j+CIBUZ7acEwAAmuKZQgvO/UKY2P2Ab/T9oataU18f2v2qGM4qAZv+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs//kbtlegh8T/wK8p/NNDn
v+TJKcy8Y7E/fDubeUwq6j8YZcZb5Yq4v5pdhepOJN6/Y8J8EpoQ3T/1pywF
7af2v4PJdfjIPP6/E7pQZBGn6D8OPpO6WXYAwAaq+lMd0/W/g3uUdVov9T/P
kHwmsqj3vztauEU1xfu/SkQ0mA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.874337827149309, 
                 2.782295029191648, -0.41242221115339234`}], 83->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/WKsn+2RR6j+a29t5cT74v45G3QzmX/i/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/aXsQG7IN9z8eqd1SssbsvxBoKdpXQtw/vCSF2y40
7j/ooXbIJr/aP90MIgFKseO/EGfmbpcWsz/WwhWOzTP0v1Yb70naQALA+M3w
TkVV5j80xV6izYkEwCpkPsHrAvS/QSDrPu4D/T9Q6ChZ4nv2v1bJRF5Om/+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/ort4FMkd8T9EKWSUCBfo
v1jRdRkpz7A/OY6je/dH6j/YYb3GLR+4v49M2aernt2/OngE6Te03D84z/iD
Hzn2v52+XVDNcP6/qDwMJVVT6D+AWaYvg1QAwFzVDedoMfa/9no/XlAW9T/1
YYLpKV33v/IHkTWa/fu/kOovxQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.874396074589323, 
                 2.78622241165439, -0.38471291680801034`}], 84->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/32BPCjMd6j+WtojuM/L3v5rIHxGtmvi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/gmPz//IE9z8Pf49in1Ptv27GwgOM89s/DV9bYrNv
7j/4p7vr5e/aPySPyf09K+O/OHCLBE/usT/GjFQrfKDzv8UOpaS0VQLAMS5i
FvDj5T+Ob28BdWoEwLzkBtaLgvS/LrH53wbt/D+0lOby7S72v/RwgPjjzv+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/ri/qhmkZ8T88FD0cf13o
vxSOqGyRMbA/YasOv7ll6j+4VTOAr723v9bOgKSfGN2/5s7g6vxa3D+uoe4M
WMn1vxLzNC0Lo/6/iMdYkJEA6D9s5Vl8xzEAwKtWk3Ocjva/z7CQMtD99D+l
pbfwkBD3v8cc0ITINPy/4Ug74A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.874331481798702, 
                 2.7899734394746627`, -0.35683287876007597`}], 85->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/FNpSlxfq6T8eEyQI2qT3v8abpng61Pi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/01Y9e7T79j+sZ3Rbxt/tv9DhT1VEoNs/HOrRx2Gr
7j9waaGahBvbP9zLu63TpOK/EIFasMPWsD9jh9emZAzzv4ADsGdhaQLA/P2E
nYJz5T+B/Amo5UkEwJomTPEmAfW/sTyc66vW/D+OjExiAOH1v0gukKmeAADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/VymPRMoU8T+LiK+YkqPo
v7CJhR8EFq8/6fDJ8ZCD6j/I0mcicma3v44Lc1Q1kty/NipeDfAE3D9AzX1X
n1j1v2NRA6R+0/6/COxrGs2u5z8IAw5WKQ4AwDBh+bSw6va/3tSi29vl9D/W
Tzg17cL2vyt84+W7avy/ANo2cg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.87414279813307, 
                 2.793544477354644, -0.3287826413412301}], 86->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/3K5xnha46T/eTNXOaVb3v8RDiMaJDPm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ned4Rffx9j/0CLRPHGvuv9xnU02HSNs/6Kp/ZDXn
7j+4g2Bu/0HbP9RoSowVHuK/wGuufRagrz99jPaMknfyvzuZSwrfewLAEue6
qAUE5T8kKywgIigEwDp4ojOzfvW/ZYgZIN/A/D9G/QW7H5L1vw7Ug0ArGQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/vPGsqesP8T8vWc+SPeno
v9ihk/8Pt60/T9EgwHqh6j84nul6fBm3v4eoATN3C9y/mJVMBhiy2z+u7OUt
/ub0vx27j+0jAv+/90qWIw5e5z+T0ZYHV9P/v/9dFX2eRfe/6i+pN3XO9D8S
pe3ERHT2v/D1xyNwn/y/M1sz2w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8738287702380374`, 
                 2.796931838296349, -0.30056285823835915`}], 87->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/12fkBTSH6T9s5ndg6Qb3vw54qZaWQ/m/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5v8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1iBce6ydfY/AMoRIbzn9j+0pMJhlvXuvxKtUMNb7No/qZcUjikj
7z/84c1mU2PbP3pLUBsOl+G/sHxWWXS0rT+eNZZ4EeLxv2y5VhssjQLADy6k
6YGV5D8D7dsLLQUEwGoOvdIm+/W/DG+iMKKr/D8A1bIjUkL1v4aGCNcVMQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/y2
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/7mJ5F84K8T8Pp9abei7p
v7i2iNdhRqw/sEfr1HS/6j+w4Q6K1Na2vyyLB8JvhNu/os95S3ti2z8FDods
fXT0v3N1q2b3Lv+/80rE91oO5z854Be8oYj/vzxDs7Ren/e/fFHKGZ639D+2
XRXCnST2v41CXSLh0vy/L0Ex0g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8733881432728325`, 
                 2.8001317857188277`, -0.27217429572216867`}], 88->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/3qaOnXNX6T8+biHwXrb2v0bMFJ5cefm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/y6pF2gPd9j8kADrFKX/vv3gXQ+fIi9o/nNm2lzlf
7z/go5bqfX/bP7bXX+LHD+G/wMMaSsfqqz9wMEAS7UvxvyxgcEFHnQLAXCRy
/v8n5D+t1vIkCeEDwEB1MRp4dva/ufAvxfaW/D+S+GzVnfH0v36orY9cSADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/U1MT9HEF8T/HVJJNRHPp
v1BgUmcWxKo/qWi82Xzd6j/oXX2Cf562v2gXF4kp/dq/GlMwEiAW2z9XzzAB
JgH0v0/GepD1Wf+/nWUAzrm/5j/MjQOdODz/v8MgI1zq9/e/FKL7SVih9D9o
M8di/tP1v6EOuN4KBf2/5vkziQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.872819662163891, 
                 2.803140535734348, -0.2436178358316193}], 89->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/mg2zHtko6T/Yu6XF0GT2v6JiUKvXrfm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/O0IUR8/R9j+6etjf5QPwvzKjDkHWJto/tiFg0mCb
7z94/3PHfJbbP3C88G1NiOC/UK2FADNDqj+ugjoPMbXwvwSLEjsvrALASB47
cYi74z+UtOc8ubsDwEpMOWyd8Pa/PSNiet6C/D+SCEwbCaD0v+ndyZn9XgDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/C596qtf/8D9vz81Klbfp
vzCPgM5LMKk/tgwRd5D76j+4psLIgXC2vyP8pxSvddq/b2i7TgzN2j9DH3Dq
AI3zv1W8uhAbg/+/8RX3xzBy5j+AkrqfIe7+v3bXxIs6T/i/BdXdhKWL9D81
4njwbIL1vzoPcm/pNf2/XUw09A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.872122072886464, 
                 2.8059542595861604`, -0.21489447950464943`}], 90->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/fOeoK2j76D/hjhk9RRL2v6qhsaYD4fm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/66MuRx/G9j8Iz8jUuEfwv0iM6a+Lvdk/pig7jZrX
7z/cGVcyTqjbP1dejU6pAOC/oAh2hNi9qD/Sz50w6R3wv3JLq97iuQLARvpP
tyNQ4z+FSJY8QJUDwLg+ckKNafe/0wRg4Vpv/D8/v+dRmk30v9tHnzH3dADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/48+Hqv/58D+9I74/aPvp
v5Az7Ikhi6c/LpB+VK0Z6z/wcfzy3ky2vwmeRPUK7tm/Bkjws0WH2j9ar9s2
Fxjzv0ccBLJkqv+/4XB88cUl5j/2DyPbYp7+vzHwkXRIpfi/SDyae4d29D8Q
p4DH7y/1v7AY+AR5Zf2/85s3lg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8712941237723577`, 
                 2.8085690862498853`, -0.18600534964491244`}], 91->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/nJ2TTyTP6D/xmVPGwr71v5rmrpLcEvq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Vc3lw/S59j+WAnd3CIvwvxEpv2nxT9k/dakAC/EJ
8D8804zH8LTbP9/i/y/M8d6/4KaLMtZapz+0ZdWEQgzvv0L7sxphxgLADEeT
MNrl4j8mNAUkoW0DwKAonC4+4fe/DTS4f21c/D8Z8djmV/rzv6O+fqBHigDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/mGTjaOrz8D9LV2zitz7q
v7CmQnG41KU/UKXhGNE36z8w/5DImTO2vyIxt75HZtm/Cli8stFE2j9mJl8E
cqLyv49uC2TPz/+/VHITQH/a5T8eAS+HAk3+v52HpWAN+vi/bgHB0/9h9D+F
RZZWjdz0v/Ax1um1k/2/cjo44w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{1.8703345668414753`, 
                 2.8109811052002054`, -0.15695169411428198`}], 92->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/hPkb/hCk6D/sAmzkT2r1v0YuL4xeQ/q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/JXQYsFCt9j/sqCmIz83wv+4BjPoP3tg/4TisXBko
8D/Ug9mKY7zbP4qj/sAc4t2/wDzJuUcapj+UfDw1ytvtv/KQxvWo0QLAXBXS
JrR84j/xFCoK30QDwExaVdumV/i/H49CzxdK/D/8OTlYSKbzvygH6jztngDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ALj8Xpjt8D+h/R7zfoHq
vyAKdrQyDaQ/vDSNavlV6z8AnvdBtCS2v3iRNgdw3ti/UI24ebUF2j+bIIV/
GizyvxUo3jtY8/+/cAd3kmKQ5T9nFmD8Bvr9v0lEwrOCTfm/8EUoJxBO9D90
nlIeTIj0v0ueAYOcwP2/wFswHg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.869242159154652, 
                 2.8131863693439905`, -0.12773488864062593`}], 93->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/xjwrkzF66D/6Yjot8xT1vyiu18qFcvq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/zxUgCDSg9j8lrM3RCBDxv6sys0PwZ9g/xEyY4UNG
8D8Up4znpb7bP11Xt39Z0ty/IL9rGUb8pD+RaYswgarsv2sSsY652wLAvoIe
zbkU4j9U1qsc/RoDwFTr1Ay+zPi//7wCPls4/D/KYCE0clHzvwgBtWrmsgDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/1YgACwrn8D/aAMM8uMPq
vxjNEtmzNKI/n0h57yN06z+AV5GILyC2v2HrkmaOVti/uPjB9PXJ2T/hC8Di
GbXxv8B0Djp+CgDAwt8ksHVH5T/RB0mzdqX9v75M1uuhn/m/sS3MA7o69D/i
4a2wMjP0vxzYIFAp7P2/UK00Bw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8680156641851304`, 
                 2.8151808981204587`, -0.09835643962994191}], 94->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/vRKoUolR6D82UNJIs770v4JXV6FOoPq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5v8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1iBce6ydfY/8km90Z+S9j/9QF4qr1HxvxYjTXub7dc/LAORP25k
8D/8c4ywt7vbPx4IVp2Xwtu/sF33nucApD+WGSNFf3jrv4skhxyS5ALA5wks
P/Ot4T/aPqOf/u8CwKIOo6F6QPm/rqILLjkn/D+5eyYY3Pvyv7rKJZsxxgDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/y2
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/5yLP7z/g8D+ylVOVXgXr
v8iOerdgS6A/CP9xTU6S6z+wvZH2Cya2v8FDYnWtzte/mIiXzJeR2T+A7rF1
eT3xvyZombZcGgDAUg7qSL7/5D/1ZgxEWE/9vxIzfaFk8Pm/Btav6/4n9D/4
ZXywR93zv3t20etYFv6/gds1jg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8666538532055723`, 
                 2.8169606807684864`, -0.06881798687217133}], 95->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAOrtDAWLr+L8ldherbDDiP/JlZrmh
5sC//wIXR8Bb5r8uOajSXmfjv1zF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/b2E1aBsq6D9ie/7wlmf0v8o+sH21zPq/kExZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/sHRlqEhL879+Hxok7JL4vwAaDzsW5Zk/CyJhX4rj4797
cz4vHITjv1iBce6ydfY/AlkDHJWE9j8g/ktzvZLxv5Kkbysbb9c/roNlHJaC
8D9oYVkgmbPbP7pi60rsstq/EEp65D8ooz/Uo89P3EXqvye2se4x7ALAwaWt
gGhI4T9EvVnt5sMCwAZZT5PTsvm/8MZj9bIW/D+E39WwjKXyv0rZE03N2ADA
5YNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/j12nCr+t9b8EUG7q7LLwP0wLNoJKWqg/MPbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hRI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/birylDrZ8D/VUkHebEbr
v3ApCfC+opw/iH9GKnaw6z/Y4vcWSTa2vw/xLMzXRte/EAZ9Zp9c2T+mJnOM
QsXwv8bqxFZGKQDAmINx9EG55D/1+thlsvf8v+jLf4jEP/q/1Du/VOAV9D9z
LerQkYbzv6/46wsoP/6/mkk6dw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.865155506687546, 
                 2.818521679760482, -0.039121306129421204`}], 96->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/VR9V544O/D8gWKswwwilP0XHfBeDW+I/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/bfn+Z/2f5T9wozTNA0O5v6QrH80ygfS/LKuDT8/P
7z9Q7+qM8VD6vzHRifw2EuC/Kwb5Mhh//D+g/MflGnjbv+piIEqZ/Pg/CvW+
F8UN+T9xZlIVFMbxP5anK6YMiOY/W95EO03yBUDQuHkFQo2xv4ZeSXOdar4/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/kHjgwd795T/YPZFPv4/W
v3zLeqDjd+m/cNGitccV6z8CIvB7UALyv+IQQaOY/9m/wBInjdNG/D+ckbJ/
AtfIv0Zj72otFfE/MAqK/ymO+j8ywdcuWm7iP2431N7HceQ/A7d3V8r8AUAA
M5C0gSOMvxbz5cXWKNY/g108+g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.2566370860334617`, -2.8198598479579613`, \
-1.3761008945131286`}], 97->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/rlBAyfre5z/Y5Koj5Lbzv6xFP4pPIfu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/uxD1nCBn9j92eLCX/RLyv82XG72/ZdY/WG4H69S+
8D+QRTzkzZPbPyfTyQ8ulNi/AAtbjVXfoT8oTIT3Et/nv7Y9oxfF9wLAyoAY
BSaB4D+Ztom/eWgCwK543P42k/q/k/o+JX/3+z/UhiH63PbxvzhuT3Xw+wDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/SwZrVYDK8D8rzaUCrcbr
v0DDaH3jV5Q/M2ro+LTs6z+IGjKP33W2v0YpnK54N9a/XgEWIvD82D/sCm2f
babvv0ZwYW42RADAvGgsZxAw5D8FKV/R60P8vy3fjURD2vq/dZHvRH7z8z/W
NeaO4Nbyvw4RbzqYjP6/FOM2OA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8617443833732903`, 2.820971064593127, 
                 0.020738941784110076`}], 98->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/49aA8E275z/4/JR1W13zvwDrjyF8Sfu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/yOaiH7lX9j95bOZyJVLyv5xu8U/52tU/puEoKufc
8D9c+ASzI3zbP1DWzHlFhde/cM/TlixvoT+6Y3iFHKvmv1jvWIe3+wLAd/DO
0X0f4D+EcyZlKzkCwL4GTPkvAfu/svSl/NPo+z/M+/xJip7xv0SHKy51DAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/UfHBlszC8D8uwdvd1AXs
v8B5FxSwAZA/gN0JOMcK7D/wtKDxM6W2v9qqnWMEsNW/2hPuuUDS2D/VLlG4
6bLuv2xyEMw6UADAreMn4WXt4z8A8vAf2ef7v9/4bQ1WJfu/EjBzej3j8z9i
/Mjf8n3yv8R88z4zsf6/c5Q98Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8598292262145448`, 2.8218512747555775`, 
                 0.05089825614427135}], 99->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/ZlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1rF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2J/
bk3D2tO/na3iJOeY5z9C9dPhEQPzvw+Nco05cPu/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxb7PQbPX9E/5P8KFBxw8r/25FB/
o034P5RrgfrGE80/snRlqEhL879+Hxok7JL4v+AZDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/LBjQut9H9j+BnL8+oZDyvxyLS7wwTNU/Qvorg+36
8D9Qxc4dTl/bP2B57RXIdta/0Lt5qu0hoT9EPZzn5Hblv56cUm1v/gLA4kq7
AGF+3z9CdzoX0ggCwC98FFOibfu/PHDziMna+z/mLPGLmUXxv2a92O1EHAHA
54NOcX6B+b8uJuFmj+biP66tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzaQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwPzwLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/i2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/A4pY5N+68D828bSpUETs
v6C70O3WFoc/HPYMkc0o7D8IGw0c3962v2H8rbHFKNW/WkmK/wWr2D/kE6JV
hL7tv5PxBRpGWwDAhymg0gus4z/jcSQIW4r7v5+EQ/Dtbvu/hmOyjZ7T8z8U
keK2VSTyv+4DkrRh1P6/Jpw3Ew==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8577727756210693`, 2.822496357911603, 
                 0.08120728869336587}], 100->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/cx070J9U/D/gJOeMDOqnv0xdlNUel+M/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/XS7BEPwc5j9As5laVx6jvxuj5clw9PO/YrtTTnbf
7j9SaLavsjb6v0VeddqHL+K/VWT+Ou6K/D9bBveFOYziv+oWv5ZBF/k/x7B7
DLPP+T9Jvy5fhEfwP3lqe+aX8ek/JaMAuQEPBkCwDzpQadrDv4jDaHS1P8M/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/CJNBFl485j+eRJRLRJnU
v/RCQZ0h6+i/itkKNZud6j+E3lUNMfXxv/adLIHpHNy/5MCcBcdv/D+peMVO
2grUv8iixIBocfE/HWdbbikS+z9EDI/1ZxDfP+LjB15bxOY/7xiP0KgcAkDo
2HNz7NS5vy6OrjIMZ9g/7bU7Xg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.161603916158639, -2.822902213030345, \
-1.4513095595472718`}], 101->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/AYlsVvZX5z/A62ZBWEzyv5TeWepaufu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/3iIHNdwm9j/P0b04gQvzv2ANMfrFItQ//DRsJs02
8T/0uOIsKhbbP2zukTljW9S/cOYKT0PwoD+kl0xPEg7jv+CjjNsuAAPA8kCA
4ogF3j+EwwnKDaUBwDTRKnDRQfy/KqPSFJvA+z/6FPWv+ZHwv4KmSKHAOQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/XA90IV6q8D+EJrOjML/s
vwB/ozCrAGI/1jBNNK1k7D/AM+X9JnG3v+g2gEMTG9S/aDddi/pm2D+SNw1p
YdPrv5XJXChubgDAvVTWY10t4z9kOb3qOcv6v+RXQi2W/fu/1nMEIEu28z9d
AK74KG/xv8yVdRZuFv+/b1cuJQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8532314023589918`, 2.8230646838685534`, 
                 0.14226440174783453`}], 102->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/Gun7Y3E55z/UBHR09u/xv8TZeSe52/u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/q+Mdp7QV9j/GT/LR20fzv8DmCv06iNM/BzxpxaFU
8T/IC0WF4enaPywV9NClTtO/EJdtv9sLoT/Au2pup9nhv8n66EA2/wLAfBcP
ymhN3T9Mi2eSqnEBwNShqad9qfy/scQMH3m0+z/KANiTWDfwv+RYeUhqRwHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/w29/Wsqh8D97pOc8i/vs
vwAp5hgUomS/4jdK04GC7D8YjiBNuMm3v0hKMY+0lNO/i8LyHy9K2D+0Yqkr
ytzqv9bzUmqJdgDAbLqB5BLw4j+2jaHMpWn6v8y9kWebQvy/n1yF6Jio8z/P
AiaEpxPxv8ZFNtxGNf+/0bc6Mw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.850744229317457, 2.8229796945883106`, 
                 0.1730070564752115}], 103->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/k4JDC2aC/D8gCJVw6Ua9v62FJ+hOZeQ/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/f1ZQt+aD5j8A/OnxWxh8P7EGUY+LgPO/SMdnO38s
7j8cRwIPfRX6vxA7+HyZwuO/VTmsAViI/D/2OLQbYinmv7jXrh1uEfk/N0Tl
h8dZ+j/SCCQqcibuP+HkPAiRX+w/h3SPMDQhBkD8YihpS1nMv1NnlcFzz8U/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/GSeJadNv5j9y1QYeLi/T
v4qmrGI8d+i/ft+Uqx9E6j/ozfs8luTxv8J6ryP7r92/9N13Bl+F/D/62cZJ
P9LZv0dN4cgKovE/ZWOUyRZu+z/OZxH8lH3aP0c1MvhvYug/6JoYmzMxAkCG
c7kQYH7Fv4LfjNgr2dk//L84TA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.0881886996001344`, -2.8226431360928883`, \
-1.5076243167083332`}], 104->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/+nbFTloA5z/ktZblTDXxv2Ii2FgDHPy/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/bPdrpSDy9T/TOvK0Tr7zv/xAPAu2R9I/BQbG/AiQ
8T/cAKAb9IHaP278WNF9N9G/0KwkGt2roT8ec7mDjeLev4gWDcmU+QLAoMPI
Twjm2z961/gJ9gcBwFBrJf3Wc/2/DhAHdySe+z+v2uOpLgHvv5n9JN6PYAHA
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/o3mmWQCQ8D+Ij+cf/nHt
v6DmIyPUMIm/3wGnCum97D/wo2ogk5m4v+q9Y48gidK/x8FnIBgb2D+sEoVG
8O3ov9yTvDrLgwDAZexUO6954j9sMsR8nKL5v9nG/irtx/y/xuU0zyiP8z+e
UUQd8lrwv8oOkYqRbv+/4zE3SA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8453314353727615`, 2.822050872581381, 
                 0.23490586665251745`}], 105->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/jxavn8zl5j+1pP6xE9fwv9YrrUnqOfy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/JIXh97bf9T/64ijCXfjzv6SFEhXVodE/+KNJ85at
8T+Q10l0V0baPyQSofU8LdC/0KFNijkwoj+sCsANAnvcvzu+PFzs9ALA1vkn
9OM22z+cFVv3rNEAwLiEqVN01v2/iESQgvOT+z8WRPTkCknuv10Tn9YJbAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/gEDhgsuG8D+wNx4tDazt
vxDO38Jxx5G/1J8qAXfb7D+I9hZvzBC5v8XIhyEABNK/rPBTONAI2D9gp241
1PXnvxOqicDwiADAvYnhTJ9A4j/2Z1rQNj35v0dYq04vCP2/6Ocz6WyD8z/A
xngkmfvvv0ipdfv+iP+/FnA6Jg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8424036904185597`, 2.8211988609350844`, 
                 0.26605568701055193`}], 106->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/KZToo5XM5j9Islz+S3jwvziLZE9PVvy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/NMKNvuTM9T+4nEbTnzH0vyaKJUdG+NA/GjCxvQjL
8T9wYmuRpwXaP1QM483zR86/kDfK9nDXoj9AQVrARBTavw06T+0J7wLALs1H
ztmK2j8g5b75dJoAwAasF3tSN/6/TGZj4WmK+z+ep+zlDZDtv9Dj2GHHdgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/CF83ZmJ98D9t8Ts+T+Xt
vwCqRzLoE5e/9iuSy+j47D/I4NM0LJK5v8gCMJpef9G/ojdVswz61z+YQnMu
Xf3mv9S/gMoYjQDAYD2GRQEJ4j9EPu34mtb4v58bPuXQRv2/MNirWVp48z8X
BlPxUkDvv2wpiwnvof+/cLcyag==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8393270037794667`, 2.8200830281781157`, 
                 0.2973346386639144}], 107->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/Qo5nsSi2/D9wr3JDDXPKvzb7zap1TuU/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/xVowhNAY5z9wd7ioGSuwP1YMWDfa2PK/d5RQa4lA
7T8tiT82Wdf5v52QFK4I1uW/tGDFfp91/D8vFg7nevfqv756oVNE5/g/a471
A1gH+z8aemnQi7rqPy9oO4Ngbe8/1fVGAe40BkDC8bUy7/DTv0+e3X9Ilsg/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/PCn5T0i65j98mtOg+2HR
vy6sswqLz+e/FUaJwyTO6T/xbppQhMXxv07Qy1Rqw9+/e3cWGOSV/D8GYfUb
H8rgvyw8hJQ/x/E/Vo6uWsDe+z8+zox/yB3UP7KxBBfrXeo/e179LAFIAkC9
pDfqOpXQv8pixcoHdNs/4tc9BQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.9875222879710978, -2.8186993526729918`, \
-1.5824454777341266`}], 108->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/N2PbiDOe5j/9j7djXXLvv+x4Y9yKivy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/zO56jwym9T8BYGY1q6H0v9hLxZ+oNM8/aqdboY4F
8j+oxV6rInXZP4ictrF/Kcq/cIxw5TmOpD9sVWdL9EnVv+glc/eY3wLAfs5y
jkk82T8CQSSJSSkAwAK0Gymz8/6/3lRkhU95+z944AH9wRvsv2B9quUJigHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/U/WtTvZp8D+2tFugWlXu
v+BlL/a7AaG/RKM8r24z7T9YGu0ANrO6v9TmJJPBd9C//msyJxfn1z9anbXE
qwvlvy9x0jJvkgDAO2UKKCye4T8CJRLi4AX4v3eWvwIfv/2/PAPppDRk8z86
uFywD8ftv9Y53FNPz/+/mWwxSQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8327228295903675`, 2.8170437952593166`, 
                 0.36026557633121514`}], 109->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/mkuGBwyJ5j8SXl8A0LHuv2QX9FBdovy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/GZ8uoQmS9T/+4qzJa9j0v4Dq8OAYzM0/g5tUKp4i
8j+cBTbtWCXZP9zQ3OzjHci/sAAvMKmdpT8McKTEwObSv/YjxaQL1gLAdHZZ
i92Z2D9ui6/Svd7/v2wZIf8mT/+/O+L+H8Bx+z/wBj0bkGDrv5flxl2NkgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/es2H1/Rf8D+zN6I0G4zu
v5go2HPb0qO/Xpc1OH5Q7T9wmj59yVK7v9Tn3EO16c+/pTuJmubi1z8My1gx
mBLkv9SXnyadkwDAaoOZZv1q4T88nW/p0pv3v2iYCijC+P2/BAThESNb8z+B
Ms4NMAntv0nxQAa84/+/7Kg2dg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8291934220995056`, 2.815112427252962, 
                 0.39190999792533704`}], 110->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/RlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/XgscdUJ15j+S4Gs3YfDtv7F7SrWluPy/kUxZ4ZoX+r841qoispzj
P+/gKiFikvO/qitNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/sXRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/EgjCNaR99T8Y1hHpTQ71vxJjA5aaXMw/C6r4Zog/
8j+Sz658ktDYPx5gkS/oFMa/II8VC6/Ppj+OoJSgGoXQv5YIY7hGywLACN6u
6b/61z/fQIEILmn/v+nVFEa+qP+/Ij6iuNpq+z9RO1kNv6TqvxJCymdRmgHA
5oNOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/9oHRIcJV8D/NKgdU/cHu
v2g3swnYsaa/5aXZdGht7T+EBk1eVvy7v3IvN2U35c6/UGTNZT3i1z9sGNtD
dxnjvzcjhMnMkwDAMb35NFE54T+UmBtSrzD3v82or/2xMP6/6CGY+b1S8z/y
jWIikErsv+p/b0Kk9v+/ah4zTA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8255112352754412`, 2.8129013131603102`, 
                 0.42366842259499776`}], 111->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/oiSgXNhi5j/GqlceIC7tv2xwkkxizfy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/39df5N1o9T/bhupfTUP1vxRNOGdK5so/x7QNFktc
8j+WxyT21XbYP6gMKxq1DsS/cJAJmTMkqD/ULSnTYkrMv5oDSQlLvwLAvHPc
Ef1e1z+745ze7PH+v+UgvAA5AADA7fz42J9k+z9+yrN4Xejpv+2LrWhVoQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/3Wkg+V5L8D+Q29/K/Pbu
v2hjSWd4nqm/orDuIyuK7T98FmFrz6+8v7gFhNod4s2/qb0wlhvl1z8e+5Bp
XCDiv+gdyRf+kgDAQC/HcisJ4T+PXOR2fsT2vxtZBSfqZv6/n4ekAwZL8z+i
uoXLPovrvxJie0cDBADAcNIydw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8216753820631595`, 2.810406577472051, 
                 0.4555366853359576}], 112->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Cp2tLc9R5j8GxQPbG2vsvzoW1XiR4Py/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/iBvBS7hT9T8XBTkMZnf1vxBI8IRFack/CjVv+eN4
8j9IK/5YKhjYPyTrbRVzC8K/IP1RTBybqT/M/p0OaY7Hv8jzroYZsgLAWL1T
KaHG1j+rG62hA3n+vxzWQK0dKwDAjGxh/Q9f+z/IK+8Neivpv+dSY9SYpwHA
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/sQvRLMxA8D/MWS53FSvv
v3ht2SuCmKy/5DBQB8Sm7T8YT66lJm29v/h0Jdh84My/3Lxy8oDr1z9colUP
Wyfhv3K/jCExkQDA270r4Y/a4D8Xf5fHSFf2vzlhq2lmm/6/iB0cyvtD8z9n
eHn0SsvqvwLvZsjwCwDA7zksGw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8176850063827161`, 2.807624397897928, 
                 0.48751046952836063`}], 113->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/SVNaPChC5j8SR4miY6frv6YrGbsx8vy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/8ucMEjU+9T98o/7dk6r1v85IaqWp5cc/OgE71lCV
8j9mICAHl7TXPzizZE9KC8C/wISp6Es0qz9IVxR2ptbCv06/9TezowLAnt6b
Ebgx1j+YUW6/e/79v/9wUtAJVQDAyOHjlCta+z/Uv82HI27ov0Sp4i0brQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/5vH2jwo28D8x+PNIQ17v
v/hr5eq5n6+/FP0b5DDD7T/cZGpJTTS+vwHZIHVo4Mu/levk+mz11z9yLgeg
hi7gv5AqwQpmjgDATCGUIoKt4D+QelnIFun1v9IG360izv6/toWI2Z898z9z
gyuVwwrqv4yftwUaEwDAlYIyzQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8135392840343043`, 2.804551010904494, 
                 0.5195853082015742}], 114->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/BXocweQz5j+ewgm4BuPqv4DqgLNBAv2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/ZG635FUo9T/iEI3X0tz1v+x2cgKVW8Y/QtH9dI+x
8j/oVFvEI0zXP0xJfXDFHLy/4CyGhaLvrD9o6OJv8ka8vwbKkjwZlALAmmtk
Z02g1T+GdvLFXoL9v3FcDCX6fQDAsg8qAfNV+z9gxQuqaLDnv9TjMAfcsQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/IDVM+Ror8D+XZYJCgpDv
v+CHapjxWbG/Hs3egm/f7T/Y+/POMwW/v7nRjan04cq/09x06d4C2D+rHwYG
5Wvev6OfKQudigDA6VdnugWC4D/qq/sQ8Xn1v7HRzP4a//6/WibcsPI38z//
wwqxt0npv4qseHB+GQDAN0E4Kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8092374235333146`, 2.8011827172741772`, 
                 0.5517565855800813}], 115->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/Kjqy2AUn5j9xlX5rFB7qvwB4ZSHAEP2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/eX9geBwS9T8JBNYNHw72v6DHBlcmy8Q/pH7foZ3N
8j+E/NC12N7WP1B8ZP7HKbi/UE2WkP3Mrj+oEzZOfuqyv+CK+ctMgwLA9Jid
gWwS1T/bROJitgT9v67KLHrrpQDAEWp3lmZS+z+ZmjhAWPLmv34tagHbtQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/qr0gQ/4f8D++WMt4zsHv
vyw31kNg6rK/f3rAr3377T+crAjsyd+/v3qeB0015cm//567sdUT2D/mV0U1
ZHvcv3AjVm7WhQDAUoPADB5Y4D/Kx1BM4An1v66G34pLLv+/k0NowfQy8z8F
mNtVNojov790DokdHwDAo0Mw4A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.8047786668715444`, 2.797515887671475, 
                 0.5840195389120532}], 116->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/RlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/tX4LhIwb5j+aO4cYnFjpvw/mb+OrHf2/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/snRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/yn6xiIr79D96c7modD72vz6G8dx8NMM/SPzOLHnp
8j9+N1BhvmzWP7QNyh7rPbS/2Fo56BtmsD8QGJnOVjGjv35CgzVPcQLAOt2V
cCCI1D85C7xijIX8vxVwVLLazADAKpOim4ZP+z+oYo8cATTmv3jtyMwXuQHA
54NOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/Uj1JS7UU8D8vyK4TJPLv
v4h4670JgbS/IvivOlkX7j9WG4VK/2HAv9ACIRU+6si/EKoSAVAo2D8bzXCF
sYvav8OanZMSgADAqTYrXs4v4D+D1H837Zj0vxxjDKSwW/+/QinUbqYu8z8h
T4uaTsbnv0BwQN/2IwDAMlQrsw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{1.8001622902011118`, 2.793546968201627, 
                 0.6163692605811757}], 117->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/b+s1qHkR5j+auDYlrZLovzjDr/cDKf2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/LMo62KHk9D+FU1Ljz232v4r4WUq4l8E/MAOu6R8F
8z9Q76us3fXVPzxKsRl9WbC/aOTCs5R2sT8AdELH8YxUv6PUVOAhXgLAehMd
/XMB1D+ODxCw6gT8vwqxRMTE8gDAqtUPSlNN+z+aJc8WcnXlv9j/qyiSuwHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/A+MN80AJ8D8d1COnvxDw
v0AGg1DOHba/Cv+O9/8y7j+GYyn/39jAv/TR2pMi8ce//EeuPkxA2D/UWRqe
85zYvyBbFu5ReQDAljpi0xkJ4D/utVWhICf0v6aSHMBGh/+/sGUVDwgr8z8a
7wKeDwTnv7rwQRIKKADAXPAuxw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.795387604437881, 2.789272485946835, 
                 0.6488007005011389}], 118->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/BlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tPfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/YgBLDs4I5j9JMOAAV8znv/A3r3vHMv2/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/sXRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/HJdQMGTN9D9i1EEMLZz2v9Shlp7x6b8/HnB8sI8g
8z+4NgndP3rVP9gJdkWX+ai/0KiT69OXsj9wyi7SXtChP6DGQkvGSQLAwDGt
p3F+0z8RmrpS24L7vwM+HLumFwHA8KqszcxL+z+SghILurbkv6y/m+NJvQHA
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/62
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/9pIxPkT77z+MlJs77ifw
v+CtkcuNwLe/+Gtdvm9O7j8cHMzOfVTBv6BAHTb2+ca/fHW9i8hb2D+iQ70T
Ua/Wv0wxjQSVcQDAQpkh4gbI3z8bWZVpg7Tzv/vZ83gKsf+/kBVp6hko8z9u
WfmFiEHmv9KtudBWKwDAz+U0OA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7904539557815633`, 2.784689054464853, 
                 0.68130866879102}], 119->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/PmkeKb8P/T/Ctg4XKZLfv6tiiJ0A4uY/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/zJi2pIAg6T/oCxZ6TRHLP9WOKWOgj/C/3vaq0LSZ
6j9/GDJ82qX4v6bYCd7ozuu/2spZAQ/W+z/RUHs1u4j0vzaijYnkf/c/GLYz
7AzA/D84ooRhJmDeP48ZFclBl/M/jQrEhzhQBkDD82fa1dbivznEIp67bcw/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/QEg8YCC+5z/gTMruFkbJ
v64uhTZRhuW/SHc2drp66D+atpPzxCzxvyyMYEIl3uK/DBo8Fedy/D+C/j57
RW3sv8bpKGxyePE/qw+pCubn/D+gSKFYKyCDv+RK2RdCCO8/lp8pDgxsAkCS
p/cy9U/hv7kTEYVv/d0/rqE7Dg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.6677993460974242, -2.779793389892864, \
-1.8031064147353555`}], 120->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/PIh6OK/75T+74HQJsz7mv1QK4uaNQf2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/BURvQPGd9D8/awHH3vX2v8TmoGQYPLk/lZF/0cFW
8z9E1JnZ83TUP6AP+I1Ib5O/sAoXGkoMtT+Yd6aY2DW7P2sSf9KKHQLA8FU+
6pOD0j8SwUxFnHr6vyUAL+tGXgHAGVzFwMZK+z/xXORgCjnjvyYlqPxwvgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/4D9QTtHL7z/6X/sYx1Tw
v2iLjGh6F7u/cI1g36GE7j+SfjvSyVnCv18ATta3EcW/kmm9ezid2D/IEWD2
99fSv8oL+OIoXwDANLOZLXk93z+4mAPl+szyv08FoN4N//+/HFCBLk8k8z/W
niy13rvkvyiVDPibLwDAWQwyPA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7801073335262503`, 2.7745822630329005`, 
                 0.7465327499777171}], 121->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/8xKBAj335T+I2G44hHflv3xbIaePRv2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/Rjywq7+F9D/kyEJaLCH3v8DAUXZD1LU/KGvM8X9x
8z9sxQsGWuvTP8AcDmQmgnG/sNPeDlBftj88r0+a2CPCPwvDzmGuBQLAvo9D
EswL0j99vVMwgfT5vxU4haL/fwHAPoGwREdL+z8wFwOGMHriv4bIwUPgvQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/IDiRuZ+z7z/MDpzibWrw
v2wetN9ky7y/Amet/1+f7j9ojcmlY+PCv9m3/ubLIMS/ae1cBCfD2D+57NoR
ju7Qv2S4rxp7VADA0tqiCyP93j/glEWmIVjyv+ryCrujEQDAXIX44nIj8z/c
9zhf2vjjvyI7qQuUMADA1zcxDg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7746932322147568`, 2.7690526112283824`, 
                 0.7792378120833305}], 122->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/wwg2GjT05T9uRhU4LLDkv0YrT4n6Sf2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/bgmkhUBt9D9c90jfbUv3vxg2wVeDYbI/0FKNqP6L
8z/QuGXWK13TPyAsNvUBFYU/wILqb7rCtz889ytbTaXGP8+l+Jaq7AHArpLT
dtWX0T8ypVSlIW35vzOzZjuloAHAuDOoxnRM+z+PuPMpabvhvyng47uMvAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/SAWFkyCb7z8IJh+ljn/w
v7xj/O7EhL6/qk5utt657j8Emm/VkXHDvwPOxD0bMsO/G1kzaIvs2D8+kZTC
sQ3Ov7kd0O3TSADAGtKf1R7A3j80pK/gm+Lxv2skB0DRIgDADJzhaUcj8z9+
fwSxyjXjv+a6RQDFMADASLsvwg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7691179130091552`, 2.763201436974583, 
                 0.8119973082293638}], 123->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/5LwuvJTy5T/77eKTuujjv1ZDMknOS/2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/T/xQt3VU9D9a5YYKoHT3v3iEY745yK0/MaTX5Dum
8z9YDP1gdMrSPwCFv12tUJk/sBAahm02uT8A8JOc8B7LP5D/WmWB0gHAiifl
Irkn0T/Fn8AyiOT4vwCQGSo1wAHAvXspL09O+z9bhzUtw/zgv7xwiH92ugHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/KvgxxVWC7z8IHb66J5Tw
v9YOohW8IcC/DKC48hvU7j98RthKSQTEvxWHkne4RcK/+v7xbGIZ2T/243vZ
/EHKv54Q+kQ0PADAqVChTXGG3j9hC1m+cmzxv9ZYWScOMwDAGG2gxswj8z+r
OozgvnLivzTJENIuMADAXzQv1g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.763380903267396, 2.757025866289637, 
                 0.8448053992498727}], 124->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/RlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/6R7PCF/y5T8IbFLZPiHjv1kAUcIKTP2/kkxZ4ZoX+r841qoispzj
P+/gKiFikvO/qytNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/snRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/uryjL2E79D8WdJilv5z3v2CF/26ruKY/TN7bmjXA
8z/ke7UWPzPSP/CToVBq+KM/CPc5VUy6uj8EKkcIaZDPPx46Ndc0twHAAhiG
1H+70D8KR4N/v1r4v4frivis3gHA3sg1WdZQ+z9slK1tTT7gv3hfWLidtwHA
54NOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/lLiEPUFp7z9m5EaIN6jw
v7eOjt+tA8G/Jtq8qBXu7j/w1h+VfpvEv+VMWgO2W8G/yl12k6hJ2T8OQ4Eu
SXrGvyXdLhydLgDA6ioS8x5Q3j+HPhZ2r/Xwv9q12SxZQgDAKqzO7gIl8z86
AIAjxq/hv9JvwIzRLgDA5/8uLg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7574817668962992`, 2.75052314300608, 
                 0.8776561278855263}], 125->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/VDRHBJPz5T8YvaeWyFniv0Aq9O+vSv2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/W7FI4wQi9D+RmIKPycP3v9DPymrRKZ8/UXwOxOnZ
8z9MvBzCl5fRPxhffmbpNKs/cNJFnjhOvD/gKoj1rvzRP8Qqfw3HmgHA+Kgs
/DFT0D8AAi5K0s/3v3EDgEYK/AHAndRVEgpU+z8z5fuKLQDfv5cyKJ8CtAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/Nq0p8eRP7z+j9jt9vLvw
v2jSwTYm6MG/LHjv0ckH7z+IlrjpJTfFv4KzniAmdMC/ou4PGFp92T9QT8c3
4rbCv/KfvIIPIADA0IhdAiwd3j9G8MBKW37wv0gMPR+xUADAZLc8yukm8z/Z
1xKu7+zgv9wjkUutLADAtvUv1Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7514201042452586`, 2.743690633576624, 
                 0.9105434232750403}], 126->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/ezyFD2wV/T+4brBUVjzlv7iozR6R++Y/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/c0F7zWF76j8w4u2YbwnSP59eFgMBEu6/psoQzZQq
6T/NT0h4QaX3v3/OIJDBCe+/ke5UA4oz+z+W9N29jXL4v2v+o+/cEfY/jxYW
5x+E/T/gxDeLZOPOP5UvfO/bUPU/t2jrHL1JBkCkxTGpjwzov/TGfqglhMs/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/k5ye9JBr6D+kcOcSTsXE
vyjP5lSx/+O/LGFpdCrD5z9B0p5xeKzwvxgHbJuRe+S/hhVtCXsk/D/5FRt0
XIjxv2Rphb/Sx/A/halN+8VM/T8A+8Rj+gbLv/iBcT9SZ/A/egNXkjlqAkAu
GvH+cqTmv3Va7Yia3N0/J7s/0g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.47057045763528477`, 2.7365258413486604`, 
                 1.9272752175109618`}], 127->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/JlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tPfBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/njl7izf65T/fdruuKsvgv4C3tvQ0Q/2/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/sXRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/GNsO63zu8z8D7XY4kA74v4AVd5YaMGE/Ve8WcXkM
9D9EIfXeI1PQP4aD79V0uLQ/sE47Yrqlvz/O9NzQLljWP3nf2ruQXgHA6NMC
z/Eczz8JmbXEtbb2v5jeXU5sMwLAeiixJHZc+z8Az9wTRAncvwD+16WGqgHA
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/8tbv+Fwc7z/cILbRH+Hw
vzmRQRhjuMO/L+v3flk67z+SMeDMmXvGvwQ95S9MWb2/dKPC1+7u2T/g8TMZ
TXy2v5wdG5sVAADAmO47/3PB3T94VBMcSxzvvyydXGSDagDApGI39cgs8z9f
3qm4zM/ev+CsGZAQJgDA7dwyhw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7388077824490764`, 2.729026362905367, 
                 0.976402891363001}], 128->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/y8aAkbAQ/T9r/2OPm8rmv0pk1AZA5uY/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/pha53nzj6j/c/y4woSvTP7wSu/CIJ+2/Lq2KhJ/G
6D8NLAP++lH3v5CLlUPi6u+/1EQFXxr8+j/AkvQlFof5v5gmBTwClfU/3aiD
lU6z/T/ozyNN7AnGP6jvSMkfu/U/O7JUP9tEBkCAuXUlPIfpvy5qGho21Mo/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/LIc9fZ6f6D/4UqZ7HKPD
vzYpuUt1iuO/cFIm0C+R5z9hQHw01YLwv6BlJvUh7OS/0AVDeGUG/D87SdP2
MXbyv16stx8RhPA/1DeCk/9h/T9xCxt8IEjRv+aQWeYfl/A/0IoKxJlmAkB2
3Gza6yjov9b+Wo1Nm90/jyo9yg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.4130088436120227, -2.721189997946458, \
-1.9618737701937938`}], 129->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/qD5nP4AG5j+tQcVfunrevz6bwKxfNf2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/kSkr4e258z8gOtyy3FT4v/D0NRbqcZu/a3HaJts9
9D8AaTzT+/rNP84D7Hjzq7s/GNrK/vOdwT9kC6b0m6DaP5JwGjjxHQHAQEms
gJazzT+/F9RPipn1v4/hnvtJZgLAK8zCxZBn+z9pm8aothXZv9ap3ogFngHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/bCUM783n7j9qx+gORgTx
v7Xe0e7hkcW/Rm27NLtr7z9UHjfCP9HHv+T8Zt6M37m/LvUZP/1t2j9QsvlY
89CevzG+eg6huP+/+FCS32Vz3T8qaMXnODjtv5eX/+h8gADAwDW7cmg18z+L
7kWEOMjbv7p7n69aHADAMdc6/g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7255414598859644`, 2.7130146105095467`, 
                 1.0423331489386436`}], 130->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/NGsxCcEO5j9ooafC1u3cv85XYXEULP2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/lSr30Uif8z8VhV42Tnb4vxBOSu1FOaW/ljYK8RVW
9D8gOjeAspjMP+w6uj8UFb8/rJt8PxOPwj+cqJBlQL3cP48+TkIA/ADAOFEr
CRULzT9vQS+7ign1vwk62SwCfgLAk7kVfx5u+z8UkJIofJ3Xv1x7oDuklgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/cCbY3yjN7j/l7KnQ/hTx
vyjJFwvsgca/cTLr/vWD7z/EtblrZILIv1bh/3r8Kri/H5IQ2YWy2j8AZnyL
LktYv3bq/noKkv+/gj98S4ZR3T/JKdlrAEXsv/jyxDIGigDAljfXgb868z++
GJ11qUXav6KTKDpXFgDAFIgoDw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7186624279629892`, 2.704498274195984, 
                 1.075308580631302}], 131->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/INQ4S2kY5j/EOMJZuGHbv5hElWg0If2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/bS4yKmiE8z9xVKgRmZb4vwirMvRdyqy/nBZxfv9t
9D/sLVviIC7LP2tkw8tiOcE/HKn1h9GHwz/gOChooNTeP9RpG6r82ADAULwL
wsJqzD9+gxDdqHj0v4V72HCTlALAm4rvflZ1+z/1MjPxcCbWv8DCpi6DjgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/SCoTOEiy7j+T1E4+JCXx
v8fU9AsPdMe/dxJSjN+b7z/eu6c6rTfJv2CaGc8jfLa/Zz42rV362j/gADBz
QJebPyAMZt6Waf+/NMO7+xkz3T+vEYHzFlHrv+iOkdKWkgDAVvpFksVA8z/c
tXqlFMTYv4ayeLGODwDAo6wuvg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7116192201275355`, 2.695639173003396, 
                 1.1082820463490222`}], 132->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPbtDAWLr+L8ldherbDDiP+5lZrmh
5sC/BAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/uPfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/IAm0RHgj5j8+GMMIftbZvzzIdWvAFP2/k0xZ4ZoX+r841qoispzj
P+7gKiFikvO/rCtNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/s3RlqEhL879+Hxok7JL4vyAaDzsW5Zk/ECJhX4rj4797
cz4vHITjv1mBce6ydfY/mgtqAk5p8z/EOBPAurX4vySF6AjTNbK/zyCz8ZWF
9D/cG5U/Y7vJPzxdNydi4sI/UMiSchuIxD+Wn2QeSXPgP8pKfSrptADA2HLI
K6zSyz8DNL0B8Obzv4erGQX8qQLAltE0NTh9+z/O3p5BsrDUv8ZOOQSjhQHA
6INOcX6B+b8uJuFmj+biP6ytV1g2r+W/pYR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kl2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Nfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/ihI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/dgdLEC6X7j+8RoQVtTTx
v6+gqA84aMi/qxyU/3Wz7z/mxAoMDPHJv5ChpXMk07S/NLtYIX9F2z+4mxjQ
UECsP+guOGBJP/+/1iWmTyMY3T8S+u2Dj1zqv9JHah0umgDAE2vHK3pH8z+G
+zAlmEPXv3IZ+pwBCADA3SknrA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.7044116815750203`, 2.6864356513652616`, 
                 1.141246822902177}], 133->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/rJPgGO0v5j+A6I6hRkzYv0xjnHK5Bv2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/vXaod/xN8z+aPSXUsNP4v+guffpCDra/Flrvc9ec
9D8AofSAlkDIP9ZKCg5nhcQ/AL4PA92PxT9gIRxIdnnhP803o5PIjwDAgL2A
It1Cyz9Kdz6Ga1Tzv66IPD46vgLASyyOBMOF+z+bqN0+XTzTvyIkh20EfAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/mHKJhdx77j8oSY0fsEPx
vx/LDQxUXsm/8VXQgbfK7z9WAltrcq7Kv/Sz0owfMLO/LIOkWeST2z+AtFLd
S021P3Np8UwlE/+/DMOAYaQA3T9qMaIufWfpvypdxXvLoADAEDt/yNxO8z+O
SDbwUcTVv8hV1SZh//+/nqAswg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.6970396900619376`, 2.6768862080288773`, 
                 1.174196116336305}], 134->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Iy4Uz8Y95j9uqdnhMMPWv5xND5Yg9/y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/7tFIq3Uy8z/5X8H3ePD4v9gfngoy7rm/EnXkNMKz
9D/w/Gow2L3GPx/FZdNQIsY/PEUWqAGfxj9+Y20/w3ziPz9cuMqdaQDAvIML
3WC7yj8bZ37XJsHyv1DeJIhM0QLA7Ih0QvaO+z/ej8PxjsnRv1qsmCqocQHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/yM0puVVg7j9XWlsxFFLx
v1wHFtBPVsq/7HDFQqLh7z9c1J+T0W/Lv6w5d8c1k7G/cr8ZOYfl2z8cOwI6
q2y8Pw0DwBUu5f6/Eg9XBp/s3D920fQP83Hov49ClmlupgDA/k//1OxW8z+m
nM7pX0bUvyhToHU47f+/bmgzng==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.6895031550944422`, 2.666989499008254, 
                 1.2071230679204281`}], 135->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/2CfQUgRN5j/qA8FwWzvVvw6gKw335fy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/yaXNwrsW8z90MlbsEAz5v1D1at9S1b2/BQYVa1TK
9D+4Y312RjPFP7wDWET/uMc/6KbYPHS1xz+kx/PLG33jP53sqclrQgDAhG0X
7EE8yj/k/GNxLS3yv70HGmYx4wLAXXI+N9GY+z+74axEZFjQv0K8QAqPZgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/pKGu0JtE7j+Vw6Ur4F/x
v7g8SQUYUMu/4AH2eDT47z/6oJZwGjXMvxj2Ca0O+a+/klEGYmE63D9eiyYn
3L7BP6S8P1Bntf6/OQPWzRTc3D/ePZRNBHznv+LrV3YWqwDAJENTsKlf8z/S
8rba38nSv0mM1pCK2f+/cPcx5g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.6818020170611023`, 2.6567443402846767`, 
                 1.2400207602191768`}], 136->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/pfTWc6Rd5j/gXmjc5LTTv+IMjS4+0/y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/tMe159D68j8yqwqLdib5v2Ihsser4cC/mC/rU4zg
9D/k8eoXAKHDP6mmVqpSSck/xNC3Ch/TyD8890bwa3rkP0S86541GgDA3PlX
OYrFyT/V0O3dipjxv3yg5HLn8wLAjGIuHlOj+z9Q+XkC9NHNvy1zDOq5WgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jsOW9bAo7j/0///6Em3x
vxeQRzGZS8y/uRXmMDYH8D/i2d+fPf7Mv0iwDOFn2Ky/1uiENmyS3D+YjyUE
8z/FP7VCMrbUg/6/HPMsAgfP3D+N6AcVxIXmv3aTFUXDrgDAcO4MrBJp8z/E
rdJu707Rv575UgFZxP+/SyQ7ig==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.673936246316169, -2.64614971024937, \
-1.2728822232304595`}], 137->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/iOZD5qVv5j9f5paX6y/Sv1Ao82/3vvy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/ZTBRR7fe8j98GOnEpz/5v4Z2v9P428K/3cXbM2j2
9D/AcUZzJAfCPzjMt80r08o/2Mv0yuv3yT/c8Ynrn3TlP8pydtr84f+/JJu/
BkNXyT+Av0u0SgPxv3Ff6mBtAwPACxqCJXuu+z9EQT+c2fbKvx70MbYpTgHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/QCwyVZcM7j+ZNu+Xq3nx
v6c6Tre/SM2/3GDeICQS8D/2GTJyK8vNvyBlSpq1xKm/fhkB2aDt3D9a/Xw/
VLnIP43NNCV6UP6/Uc3zp3bF3D8YeTGaRY/lv8z5cYx0sQDAqAZSDCdz8z8B
h7ZlWKvPv0aIK26lrf+/gtY2uQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.665905842220165, -2.63520475188386, \
-1.30570044057029}], 138->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/HA+lQgeD5j95tVf3jazQv1xDJGYkqfy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/YoaVEnHC8j9YOAijolf5v4YeoRhp2cS/w+SIVuYL
9T+sIYR+02XAP8xBIfhrVsw/4G9tqMMjyz/SYvU6pGvmPwaowdaSjf+/+OfG
7XTxyD84iPeXeG3wv3waSPrBEQPAYfuCbki6+z+A9JlZsh/Iv1b6fWnfQAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/PYJ2IFHw7T+Hxv4GqYXx
v6gOv9l3R86/T/A0MuMc8D8AQpPs05vOv/h5d0U1vqa/FGvALPhL3T8qEJN+
uirMP7H1cp5bG/6/GskWfmS/3D+Wdc0VnJjkvxUerRYqswDAeMHqB+Z98z+5
ryQkZ7zMvwQckJxxlf+/ILIzJg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.657710832144939, -2.6239087746748817`, \
-1.338468355686262}], 139->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPbtDAWLr+L8ldherbDDiP+5lZrmh
5sC/BAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/uPfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/QEcXBseX5j/Yojhh1FXOv2LbzcTGkfy/k0xZ4ZoX+r841qoispzj
P+7gKiFikvO/rCtNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/s3RlqEhL879+Hxok7JL4vyAaDzsW5Zk/ECJhX4rj4797
cz4vHITjv1mBce6ydfY/m1/yfQCm8j8gcLJGZW75v+QZeNzU2ca/NvfjDgUh
9T+oWfeIW3q9Pw6f7fb00s0/xDBkQY9WzD9mH12bZV/nP6ip38czN/+/gO/A
3ieUyD867JhvQK7vv7zw6SDkHgPAGmmXDbrG+z/EJ6HutkzFv5tKQA3cMgHA
6INOcX6B+b8uJuFmj+biP6ytV1g2r+W/pYR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kl2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Nfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/ihI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/d1vTi+DT7T9r4tNYCpHx
v1iMqrutR8+/iXlijnIn8D9sfJfJJnDPv4C/3kcjxaO/cVNw1mqt3T9g7R0G
4ZPPP4XCVkZ95P2/IIPH/dC83D94ivPD2qHjvzZvqMHjswDAXYZRyE6J8z9O
5eynRdHJv0w4p2+/e/+/CXA6Pw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.649351270450797, -2.6122612562616867`, \
-1.3711788780813594`}], 140->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/YlpkkuOt5j8MS8OrPFbLv7agYl7gePy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/nT0lwWeJ8j/wIIvp7YP5v1rR2ykU3ci/TSxPt8I1
9T9gDr3EqBq6Pz8chx2pSM8/tONSqTaQzT9+r7AK0U/oP/BRCWrm3v6/SL48
IGM/yD++SzyamoDuv4WZoc7SKgPA/SRVCs/T+z/0sya8H37Cv9wCN7kgJAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/eDkGz0e37T/SOkCqzpvx
vwk0LrGmJNC/FBSYYtEx8D+eB1O9CSTQvxjFq/q62aC/TxO5PPER3j+73L/f
QXrRP1P5NWTjq/2/9IlzWry93D9Aj5biFKviv/B06X6hswDAF6nDaWCV8z+A
//QzLurGvzdTaOiQYP+/DkM0Ng==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.640827237443478, -2.600261843814968, \
-1.403824889529882}], 141->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/elMjLlvF5j90Xq+pkFrIv/wW9iNzXvy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/40cNF6ls8j8CFrLdOpj5vzjG99L+4sq/C1i+sR1K
9T+wwEUK0qy2P+X526O1W9A/IFbIaqHQzj8mwnbJ0zzpP5hPA6CxhP6/LCB0
Ti3zxz9U9Zw1F1Ltv0HWOhWNNQPAK6+UX4bh+z9Ie6OWSWi/v7TJeJOuFAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/vkPuJIma7T9ctVMk9aXx
v0AxdVshptC/86nP3/478D9V8aGUxJHQvwAslExt+Ju/AmnViIN53j+J6gqf
LybTP0qz/GGScf2/hVvAgSbC3D94ZgSwXbThv+DwmlNjsgDAdCxT+xmi8z8M
joC6WgfEvzLVcyXoQ/+/TaozHg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.6321388383191573`, -2.587910355147731, \
-1.4363992502676028`}], 142->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/uOjaBCze5j+sEBjoC2PFvwzSFSWBQvy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/f8d+vcZP8j9FCuWNSqv5v86prXRs68y/6zzXZxRe
9T/Av8bNGzGzPw0R+G2PD9E/SEmoRNsL0D8+cUNcWybqP7avlHKcKP6/zKrH
Woyvxz8nqMXYzSLsv6oFjh4SPwPAe6OF+97v+z9YI4CS+925v43fXdCGBAHA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/WsNfy6Z97T99L238fK/x
vyaq4sM8KNG/YxzcOvpF8D9y0TFcOwHRv8Bys/ueWZa/XA0vpxnk3j8TbT1i
mM3UP+FA1cuONf2/a9OMGw/K3D8p1mVpyL3gv1h3jFgpsADA7Iv5fnqv8z8s
EazYBCnBv5PI6GLHJf+/5J8zjQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.6232862021057695`, -2.5752067795595677`, \
-1.4688948051387023`}], 143->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/wQMmJ1T45j8Y/i6h6W/Cv3ZSoI8MJfy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/3mcW9cIy8j9+Qp99G735v96bu3k09s6/4jsRS6Vx
9T8ggs8wl0+vP24qwObTv9E/CNazQa6y0D8mNimNVQzrPyJx+g+uyv2/ABpI
i4V0xz+iLzEq1vLqv/bWkCxhRwPAphPEv9f++z8gYF0FxF20vy4TaLKq8wDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/uGP3AqNg7T+aS0p0Zbjx
v6omJsXuqtG/3ht5rMJP8D9Isd1iZXLRv7CncjV715C/xe7/R6tR3z+gdt0k
W3DWP8xhzU/d9/y/QQr4iXXV3D8o73yS0I7fvxiAMLrzrADAxIqr6YC98z8o
rt2jy568v2k8OPowBv+/u3o2DA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.6142694806091464`, -2.562151278417011, \
-1.5013043896825038`}], 144->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/JGPaitET5z8cpDtvyQK/v96Ema8XBvy/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/7z8MAaAV8j+KOTdJrM35v0Mp8w6XgdC/N2jU1M6E
9T+Ae60FUCKoP0PvZE91bNI/THU7qrxc0T9+cyRtsO7rP8wrWMvtav2/UAlN
eh1Cxz9XQvLdR8Lpv5UbZZl5TgPAc9xugW8O/D/QaKd+IdCtv42bKYob4gDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/yjvtDoBD7T8gRxbarcDx
v1TUMC4tLtK/CbJacVdZ8D+z0Y/VOeXRvyACmeDf5Ia/yh343y/C3z/7/jw/
Vw7YP1XYeL2CuPy/eKVt6Vjk3D/bttkLoaLdvwLvmLjCqADAAgduIyzM8z9C
rEcXbfW2v/xd9mEn5f6/yDgwow==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.6050888473726195`, -2.548744185473677, \
-1.5336208361437176`}], 145->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/QFIxC6Iw5z8Agt1jby+5v27n/O6k5fu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/NacGJ2D48T9nXPql+9z5v8x1kzgYidG/6/yXho+X
9T+gRo1f8dqgP8XAsTFmFdM/uBduO/kJ0j8Kd4FVWs3sP47XJRxjCf2/EBAZ
FlgYxz+tUdqzOpHov2y2ZddaVAPAIfQ+CaUe/D+Q7RN9nfqiv9/YKrbazwDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/EKPnNEAm7T+O2HeIVcjx
v5n6AMPtsdK/Y3w8yrdi8D8B1fG/r1nSvwDUl3ejq3i/Di90VM8a4D/KxgVp
bKfZP35fkQWEd/y/RJa3ELj23D/tAVagKLfbvxIVcqeWowDAoM5rB3vb8z9k
vDMRX1axv5ZMqS2twv6/w1ExEw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5957444966587069`, -2.5349860069350316`, \
-1.5658369793905873`}], 146->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/eXTyaMNO5z9YY/hrOWazvyZZjdW2w/u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/ZNrsrgXb8T/t00ZiCOv5vy4Ubi2JkdK/PjEA6uWp
9T/AF2UZGfSSP3N0GWGZutM/DrX9cla60j8e2DzpQajtP7i9mp0Vpvy/BEqL
oDj3xj8eb591xl/nv22nMXEEWQPAkLCfE3cv/D9ACNaaqHeQv/D+zqLpvADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/PtbNvOUI7T9SFJ7mW8/x
v8lJbj0mNtO/jJbw++Jr8D+tgB8Nvs/SvwB4hSr2FFC/gKc4UfdV4D+yy727
ejvbP28LlDnmNPy/+kYVkZEM3T+Jex6jjczZvwAq/O1vnQDAZnUMZGzr8z9o
5a2SI4Snv4OrlQ3Fnv6/g7Uzww==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5862366424615943`, -2.520877421273578, \
-1.597945662726128}], 147->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/SaCgSjNu5z8AwJ8RNk+rv66WoghQoPu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/+HK54pK98T8RWqNl0ff5v/Rpf07VmtO/5Gn7kNC7
9T+AQlDHpgFwP/RRvfsBXNQ/7vkskMZt0z/yFl4WVn/uP/qgFQ4NQfy/0FDe
rsHexj/YawH1Ai7mv+IytQl2XAPAtgLIUORA/D+AJEl1HFtzP+6qN8pJqQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/0m6a8HLr7D9kV0xowNXx
v6309k3MutO/3zJuT9h08D/mCFyIW0fTv8BR2snVJ3A/oI5bSYuS4D/yGkS1
YsrcP9QbXIuu8Pu/fTRYtuMl3T/YZxtW9uLXvxw/AwdPlgDAbikM+/778z9w
m/aC0uOYv0X2iM5xef6/ark2nw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5765655175590254`, -2.5064192788012694`, \
-1.6299397435786276`}], 148->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/s8aoPO+O5z+AKtKgG9Cfv5Jo9Epze/u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/YLVMDgqg8T/3GNWwVQP6v/+JrOvnpNS/6sTeFU7N
9T+An8v3AUiGvys+bmuT+dQ/JtThlDsk1D/uYUwXhlLvP4gngk5R2vu/zKt0
KfXOxj8NWO4JCPzkv3EjMVyvXgPA/KXUZOtS/D+gHvLXavSZP8ZmJ7T8lADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/OrEtHOrN7D/WNuWNgtvx
v7KEjZzVP9S/YuDfEZd98D/p18ndfsDTv2Ds+98B7YE/Y9iMg4bQ4D+a0EU6
BVTePw1Iu0ziqvu/pvEFh6xC3T9h6fTmiPrVv92r1YA0jgDAqoSUgTEN9D+A
L4Ajw25nvw+boVm2Uv6/mI87oQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.56673137261212, -2.491612601006796, \
-1.661812099058461}], 149->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/c+OSsfSw5z8A6JTcdl+CvyqHY3wjVfu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/PLk+f22C8T8dkvNdlA36vxAyYEWsr9W/rv2BG13e
9T9AKUOn+Heav1z/p2ZBk9U/jse8Rqfd1D8xsw664BDwP4aTu2Hqcfu/ZLqy
S9THxj/AhqaQ7cnjv40mQDywXwPA+kDj54pl/D8wbWWGzm+nP4Qc4/UDgADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/FrUfjU2w7D9oc3TkoeDx
v7tYZ8k3xdS/xHyxlB6G8D+zwiSbHjvUv2D/l5Phh4s/naN4KuQP4T/CEquY
Q9jfP1iND++GY/u/DJJ/xOli3T9g2hhsaxPUvxH1OP0ghQDAWllWoAIf9D8w
M0DP8NeSPxngFLSVKv6/p1MzFw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5567344753214787`, -2.476458579666274, \
-1.6935556313693567`}], 150->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/JPI0AkHU5z8AWHGH4YGKP044wJljLfu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/cG+xhL9k8T/xi3qgjBb6v3j9KI4Nu9a/J6daTfzu
9T8AND+pJf2kv7iGhvH/KNY/nPY0MPuZ1T8lCe8BfHbwP/rV7GvgB/u/GBzm
o1/Jxj9nO+Bny5fiv7NC2pV4XwPA8XUuZsF4/D8IT6cIr+WwP/B7EjJhagDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/S2uSkp+S7D9U8LcFHuXx
v2++y23oStW/gdGdLW6O8D+rnH4wMbfUv5A6wCDlcZI/ubYnTZ9Q4T/V6/3E
f6vgPySH1gKiGvu/Knku65iG3T8HdsLhwy3Sv20vXTEVewDAgnek83Ax9D8I
epU56zWkPxeY8v4SAf6/CoMw1w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5465751096477471`, -2.4609585757365338`, \
-1.7251632730634128`}], 151->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/YOTnbdH45z/QnXF+FMChP3arjrw2BPu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/W4kibwJH8T+aBFrFPR76v2esWOz2xte/C7qWXyr/
9T/gHjex4dSsv40stV7DutY/xMe4oShZ1j/9lur2DNrwP8QI7rE7nPq/wJc6
E5fTxj9EJutuuWXhv1NnVm0IXgPASeAqYI2M/D9Qd+6jCga2PwdVnxgWVADA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/NoUDfeJ07D+orCeY9ujx
v+aV4xzd0NW/89q7NoWW8D9YG/7wrDTVv0BpNYoAAJc/ISRi37KS4T/rI96a
DWjhPx1aPjc50Pq/UIq2Mret3T9nDAQnuEnQv4fezuURcADAPGmPC3tE9D84
RifjFOauP8Kq5nYx1v2/ficw3Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5362535751044812`, -2.445114118040967, \
-1.7566279921302186`}], 152->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/jZS+GqMe6D9AgA2QGMasP9oYyRqg2fq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/BEU9kDgp8T+JKAQzpyT6v19fpHtT09i/6HQ2D+YO
9j+wkKrtSWGyv8LLV1CASNc/DhHTsiAb1z/02V/VizvxP1Rcn5gEL/q/qIK8
zXnmxj8k1dODzzPgvyUWat9fWwPAUP2kSu2g/D+wJZC+kxi7P7fpk2YkPQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/3kAenhhX7D+fvvxOK+zx
v2JviWQLV9a/YbiLDmOe8D+A+58TiLPVv/BiShfobZs/ig4UuhnW4T/2ReCZ
vCHiP5c6tFlShPq/N7UtjkHY3T9A+qX1287Mv0lRZ/YXZADAzCMCbB9Y9D/o
cksD0L20PyR2+HP0qf2/EDwurw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5257701861309307`, -2.428926901758389, \
-1.7879427969116861`}], 153->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/f7G+FbNF6D+AVIhD1NizP1ionwajrfq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/xiGsOmQL8T/kS3lpyCn6v9emxU4O4Nm/JIwlIi4e
9j/QeH3wzmK2vzur7bgr0tc/KrRUQ9Tf1z9PZwMD8ZrxP7yFQaRDwPm/oKho
WgYCxz+LeQ4DSwTevxEmJyF/VwPAjP3fjt+1/D+oiwGLcg7AP485+OWNJQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/oB2NSEQ57D9MUDfqu+7x
vx4TGs5o3da//0MDGAem8D+EWPqzuDPWv7Be+VtDu58/yoW0m84a4j+X7DtH
ftjiPwqXcFXzNvq/p9tYrDQG3j9sZCzyFQ7Jvx59O1IoVwDAJqvfjFxs9D/o
tcWs3Pq5P7sNSGlffP2/98ctFQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5151252715518935`, -2.4123987867259076`, \
-1.8191007408354742`}], 154->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/yJ0bU/5t6D+wTPkx9UC5P04lNu5CgPq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/A4HqwYft8D+75VECoS36v8ZFHHES7dq/6adTZwEt
9j/o6bvor266v+YiLty6V9g/7JGC/DOn2D/1sXcPNfjxP6q6y3cBUPm/gLFJ
kzomxz89Au17pqHbv8Sf939mUgPAa3y1imLL/D/oH8lBTYnCPy1Krm1UDQDA
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/3nzLz2cb7D84naM2qPDx
v5ZiRd/qY9e/4lGaunCt8D+mJgLTNLXWvwCO/jre86E/X3OuKMxg4j/ARpdi
RIzjP/zvADMi6Pm/KAru94w33j8Qr24vaVHFvzZZiftDSQDAqKUh2jCB9D9A
xsXaxym/P9RcyeR1Tf2/DXo1Fg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.5043191741314785`, -2.395531795567202, \
-1.850094926961038}], 155->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8mdherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8tOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO//j5zroGX6D9oxCAkA5u+P06EX1uDUfq/kkxZ4ZoX+r851qoispzj
P+7gKiFikvO/qytNXGePBMCne3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4796
cz4vHITjv1mBce6ydfY/oTYWeqXP8D9UjMawMDD6v0SHUOhK+tu/JS7Mtl47
9j9gvEAPnIS+v3Tr3k8j2dg/pL9HUjBx2T8oi+G0UFPyPwZIP9RG3vi/hASj
pRNTxz+cQXYQ4T/Zv0K0l2EWTAPAtxu2kHTh/D+YDBaCqPzEP/bdmsLz6P+/
54NOcX6B+b8wJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD92SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/fDL3h4X96z+E8N0N8PHx
v1WD3xqH6te/AJVWYp+08D/3wNJX8jfXvziwwQmA+aM/aI/L6wyo4j9vlyPn
AD3kPypmzxfll/m/HwDcl0Zs3j+CEG5HIJnBvzS7owdsOgDAm933s5qW9D9m
NxMKFSXCPyIx/Y47Hf2/ZREvqw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4933522502270784`, -2.378328111657894, \
-1.8809185123336754`}], 156->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/W7cM6znC6D/g8N2hSfPBP05AV/NnIfq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/0AzBt7+x8D/h8bVBdzH6vxsG9rWiB92/lFbN8URJ
9j+YRzPqIFLBv/EHpPxaVtk/4uRrhLk92j+KUnnYPKzyPw7R+Jcca/i/9CMp
Eo6Ixz+JUndNKt/Wv/jNDUSPRAPAXgBL6BP4/D8Ymg1gU2jHP7Qm+WEAtv+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/qgiixZ/f6z9Mo1VWk/Lx
v8BCsgEzcdi/NynXf5K78D9Re3cQ57vXvzAi1rxe7qU/5lShVovw4j+mELUM
purkP64IqEVCRvm/WACXb12k3j8ytBD5Csu7vxC33J6hKgDABq7obpis9D98
xfWAzq3EP4EzqCq06/y/5NA0sg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4822248695494111`, -2.360790076939943, \
-1.9115647121432027`}], 157->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/owUZtCPu6D8QTuntnZHEP5yUeHb07/m/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/xj7Cz9iT8D9D4aibdDH6v93FLtkEFd6/YofeArNW
9j/A/DFzp2bDvyM5yR5Yz9k/VqrNn78M2z9ByhiL8gLzPzxE/72L9ve/9H1H
raXGxz8aMaKqsX/Uv/G8oL3ROwPA8C3YzT4P/T/ouFOJHczJP/wTl7LSgf+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/oDqj3bjB6z/8Gk8DkvLx
v6GiThPk99i/nsFfiEnC8D+aKLeyCEHYv/jmakVT0qc/Z+3/wUE64z8D9NVI
JpXlP2zsOxpA8/i/IOVqH83f3j8kFFtnxW20v6CDbvzlGQDAYFjyUyjD9D98
g5673S7HP0zUh5TjuPy/5GE8Bw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.470937415033926, 2.342920189597134, 
                 1.9420268036851198`}], 158->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/hIX1nDsb6T98+XowSijHP1qZ878svfm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Fu4HF/N18D9ROtS+KDD6v8R8TlBcIt+/Mfjl3adj
9j+gcNsbuH/Fv+7qBEcRRNo/7CChfzLe2z8RhMUJa1fzPySUUF2dgPe/SKxz
n1UNyD+HI9qGpiHSv9f+y3zeMQPA+b3fcvMm/T+kpc9I1yfMPxbJFsZuTP+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/8enoJNOj6z+Dx+QU7PHx
vxV+3s6Pftm/Bnrj9cPI8D+SheHcTMfYvyCuWeY3pak//QpjbiqF4z9B49RP
dDzmP78Wog7lnvi/lnDSBJEe3z8km3K6BTaqv8LlYm46CADAXkCtoEja9D+Q
T6W8EKjJPzgxBcPNhPy/FWY0rw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4594902828283027`, -2.3247211016037124`, \
-1.97229813012338}], 159->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/2EtwIX5J6T8QebO8GrfJP2JIgMUUifm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/O5Zo4hBY8D/R7RjFky36v872Pg3KF+C/K5o9gCJw
9j/6Oc8CKZ3Hv2OMNFt9tNo/ZAiyzgGy3D+83De+n6nzP9pBLKhaCfe/gB2O
ZZhcyD+iJARJcIrPv8gjMki2JgPAtfAl/i8//T8ISmSKUXvOPzCtS8bYFf+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/FpJJ8PCF6z9EIQeYofDx
v4A29rMrBdq/A0sPRwHP8D/qd54WqU7Zv/gzGDfoZqs/BahkhD/R4z/eS84V
g+DmPx5F1rY3Sfi/ONPTOqRg3z9IrkIxVk2Xv/lH8qpA6/+/UAtvh/fx9D+M
4YsjNhnMP8n65cV2T/y/iT0tbg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4478838824001845`, -2.306195616158262, \
-2.0023721040551328`}], 160->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/GlkOpud46T+A75KC3D3MP4JwD5ewU/m/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/84F0hjQ68D/H+AHitSn6v5QYr5xLnuC/e0PH8CF8
9j9WoVHvz77JvxZEEpeTINs/TNypCB2I3T8Ge14/ivnzP1jHW+vMkPa/sB5Q
0We0yD+OMppLK9XKvwtRjf5ZGgPAORTWi/JX/T8UCE7vLmPQP1RO5/QU3v6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/zn1VlBRo6z++pnumsu7x
v0dYZkOti9q/qx9U/wDV8D/AEb/REtfZv8ASjyZBF60/oKMxFXse5D/22LDP
RYHnP+2bNcE+8ve/xmBimgGm3z8gz4tvE4t2P0wJFUoyxP+/Y6BuLzMK9T/U
f5cwHYLOP2tf+8XiGPy/6Isu9A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4361186367686485`, -2.2873466850146866`, \
-2.032242210878931}], 161->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/05xTeHSp6T9Id/QSXbzOPzqdeV4EHfm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/LEZHV2Ac8D+RX8BijyT6vw7nVVmoJOG/ThwAQKWH
9j+CfpZUguTLvzny44xLiNs/9o1Ze3Ng3j80SN5RJEf0PyLweI39Fva/vD7H
Cb0UyT+6NiMS3CPGv7ninZbKDAPADD+oLTlx/T8a7yM/Z4TRPw5oJKsnpf6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/BkIoZUBK6z8k2tpmH+zx
v8EmDQAKEtu/FIzwpsLa8D8MSRBrf2Dav1DL1f0gtq4/5zEAG9ds5D8d1zz0
rx7oP65G+fUAmve/gmzFuqPu3z8cgaIBAjGhP1ax2sVMm/+/ugbptPki9T9f
FU/kSnHQP6QCzwQW4fu/zYIoeg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4241949828622362`, -2.2681774057220156`, \
-2.061902011969089}], 162->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/FMQMzyDb6T84eb5RNZnQP2T5K18U5fi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/youyUC397z/nKCWuIB76v5i/8MjVquG/M0wTiKuS
9j+GpBJVFQ7OvzVzIyad69s/bNEGSPQ63z/v147oZ5L0P3guMg72m/W/qP/d
i5B9yT8+RD5K4HbBv+wtFx8J/gLAd9sH6wGL/T/ueQgnO6HSPwgUcFkVa/6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/wEE6tnYs6z/OPo0M6Ojx
v0r/p283mNu/ByT6ykXg8D+MUi8r5Orav6DnabGzIbA/ZRaIeU285D89dv48
tbjoP+4TrzaFQPe//yECeUId4D9kXH2yFHevP54qrU6TcP+/wB5HKUk89T+T
eWM8OJ3RP7YGTtwUqPu/zhYtGw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.4121133720057386`, -2.2486910187844296`, \
-2.091345147659952}], 163->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/os2ayugN6j+MgD4J6s/RPygz0/Xkq/i/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/2oWimLPB7z9bWZlEahb6vzxD7XTJMOK/Q+br7DOd
9j+rzOnirh3QvzUVIKSAStw/8nFeMscL4D8BNvMkT9v0P/z7jAXAH/W/gM3x
KtruyT9gSV2WKp25v7xkir4W7gLAbwA7wUql/T8wsP5wlLnTP8IrEYfiL/6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/yD4y2rkO6z8IV8fXDOXx
v+6CpBsrHty/D3Fm/Ynl8D/Aj19HNnbbv6ArY61637A/yp98/tcM5T8k1kKn
SU/pP5IXsH3S5fa/gaCrqs9E4D9oXE7HPtG2P1D+czkJRP+/oDNEkx9W9T9e
mB49v8TSP3Uvcr7jbfu/TZs2XQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3998742705371907`, -2.2288909047525167`, \
-2.120565340044836}], 164->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/dF1AdchB6j8g6GJ1NALTP+pnBJh6cfi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/zv2rKViG7z/p7xPAbA36v8Y2Out4tuK/gRJGnD2n
9j9sq+4YGDbRv4Y0maDupNw/fljQThh74D9REK9X1CH1P1BUJiNlovS/JC12
EZFoyj/w+igdsFawv9ydT7P03ALA8ZSKoxHA/T8uZnNAXc3UPwDizdGT8/2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/wvq2Igzx6j9QooQVjuDx
v3l28ZHao9y/LocT1Y7q8D8h/2HiagLcv0BqVaZWlLE/+VoIYnBe5T9Zygd1
YeLpPx1eld3vifa/XvTOXPZt4D/IUjHcENm9P9HRUf+xFf+/1mEV73pw9T8n
J+vayOfTP/Uk6TSHMvu/sz41NA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3874781605558513`, -2.2087805812563523`, \
-2.1495563955954715`}], 165->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/B8pww7t26j+oOriz/C/UP/we5NPZNfi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/i+C/pB9L7z9b5A3UKAP6v+0IGL/ZO+O/bHO/zcew
9j/c6MZuMFDSvz/yUQ7g+tw/QR4ky2Tr4D8dNPgA8mX1P+ZYcS3vI/S/TBel
wavqyj8gEWZJKWycv4MBbVOkygLA6jpre1Tb/T+mqPETgNzVPy6bj+0ttv2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/IOxA4G/T6j+InIEfbNvx
v6BIz2U7Kd2/ozfQ7VPv8D/YHU4Nd4/cv7DlxoE5QLI/JHRKRxCx5T/HQuYt
8XHqP/G7qoDkLPa/7QftWbOY4D+W2SEfOmnCPwERXz2R5f6/9s+RLlmL9T+n
8dRjPgbVPxXdueAD9vq/3E02Sw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3749255408012053`, -2.1883636999904765`, \
-2.178312207608567}], 166->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/0dwglL6s6j9Excs7K1nVPxJay08H+fe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/vx0WqA4Q7z+JKHRNn/f5vzzu6InhwOO/OsbmwtG5
9j9rAQPl4WvTvx36nTlOTN0/55qK5aNc4T+PVQTRoqf1P8Ys9ABopPO/9HE8
FiB1yz8ArW/Gc6iAP6cdfAwntwLAPP6mKBH3/T/aDdDG5+bWP8ALBaS1d/2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/ugrsYee16j+fvjRcp9Xx
v+4toDBDrt2/CuFj6Njz8D8gKmzITx3dv3D1XtgV47I/3LvVPLEE5j/gRvef
7f3qP2zDX6i3zvW/p/zXTAPF4D+sQv/Zbt7FP7DKYbSqs/6/UrZbObim9T+P
6U2BCSDWP+ky6HleuPq/z3o7mw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3622169276623068`, -2.167644043660298, \
-2.2068267584870127`}], 167->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/A0AZsczj6j/mYAHhqH3WP2TC6skHu/e/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/ZXfRzinV7j9krZcS0er5v6iCAOyFReS/mLxKx1rC
9j9wF0xcFonUv09M58gymd0/6UxJyczO4T8RGXOo4eb1P8gXg4/ZI/O/JJlI
Q+MHzD/AJUGzxXGmP4ZjjWN+ogLAzMSHgUUT/j/GydaSf+zXPxqkQtQvOP2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/jbdJ9XSY6j8MgcY+QM/x
v1rCt5LnMt6/OdyVah348D8itRAE6qvdv9SZ8fbefLM/dkYxvUxZ5j9LcbPg
S4brPxbttqxwb/W/JrP1wOLy4D+ehWmX4UvJP7jEgkgCgP6/ZjIK7ZXC9T9W
Few5FDXXPz+zFs+befq/2z034A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3493528563160515`, -2.146625522898808, \
-2.235094121864028}], 168->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/xJJKz+Eb6z9wEmLUXp3XPwT66xfge/e/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wo6jsHWa7j87bRsjv9z5v3Xgco28yeS/5Q6IMGLK
9j+6kx2Xt6fVv9IALb2H4d0/OqRqj9ZB4j83VrSYqSP2P24Aet9NovK/hOf7
1umizD84QFVavE+0P9TQCfWrjALAH3wCU+8v/j9cZd4RM+3YPyhRYXKh9/y/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/PMMy5hp76j/4YAhHN8jx
vyggKjQet96/YIU0HyH88D9Hc3mhOjvev9gCfd+IDbQ/f5taL9yu5j/T2sxN
AQvsPzn9svsWD/W/UsaEIk4i4T9+YvfqTbHMP9bN/wCcSv6/wOJTHfDe9T/m
OyDzSEXYP5alJsXAOfq/1RgzAQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.3363338819922292`, -2.1253121731618547`, \
-2.2631084645791093`}], 169->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/tx0jj/lU6z9gXWOmNrjYP24YkSaVO/e/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/IzZx4fZf7j9ufOCXas35v34c4x57TeW/lsVWXufR
9j/nIIE7r8fWv7P6enJHJd4/+7hvP7i14j8ljGrk9V32P+RL9ArPH/K/nC2T
uidGzT8gJkGI5Vi9P9DGknSxdQLAdgHjYAxN/j+892Y/7ujZP3qZG4cPtvy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/7JaZfttd6j+S6GoBjcDx
vzBcmsXcOt+/uOAbtuP/8D/eOatzNsvev6D2GEoIlbQ/WWtJ51gF5z99YwOO
A4zsPymywhiyrfS/j/TjvkFT4T900zkEOAfQPwdT2wd8E/6/KEg6lMT79T+O
KuVyklDZP/RY1lbS+Pm/Zyw0qw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3231605813624876`, 2.1037081516095077`, 
                 2.290864048515361}], 170->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/wCDmfA+P6z+gJadIGs7ZP0BaUvkr+va/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/eg738LEl7j9SIvCi1Lz5v3MXUVq30OW/07iWuunY
9j8X3szU5ujXv12BWqBsZN4/DmAD0Ggq4z/bf8n/wZX2P9wzAz9nnPG/WAZH
M5DxzT/48P4A1SnDP9ER4KyQXQLAg8D4ZZpq/j8kwid6nd/aP5YeaS9/c/y/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/GINcBrlA6j+Eu/IGQrjx
vyZXCAEZvt+/V9o75GQD8T92GFFA0lvfv/AD2KVSE7U/Z8B0Jrxc5z9DSfOR
SAntPw7HKpxJS/S/K/HbxLmF4T8OT5NkgrHRP/E+iamm2v2/cug1EhEZ9j/i
c2fh21baP2u8XZTVtvm/YGwzNw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.309833554049609, -2.0818177339803166`, \
-2.318355232308205}], 171->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/iLMEER/K6z80/bMP9N7aP1gL+qmpt/a/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/+Hduaqvr7T/I+2OP/qr5v1mU5gNnU+a/j0VbuWjf
9j8op2PVRwvZv9q3O1rynt4/FpCuJ9+f4z/z/PCQCcv2P86h4rogGPG/nPVJ
4xWlzj/UOL1Cq5/HP/QjnH9LRALArwVEFJeI/j8kD5eFLdHbPwyKGJz1L/y/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/1zcYw7Uj6j8/qCz9Vq/x
vwbqTlVkIOC/tSCeY6QG8T//fJzAAu3fv+hwmhleiLU/z6FZHP+05z9A/N2U
xoLtP5NWbjLl5/O/eJjrRLK54T/PTInYZFfTP6ApmVQgoP2/ui9jTtM29j8s
hqXKEFjbP7JKCaPPc/m/kCQ20w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2963534242527746`, 2.059645311464495, 
                 2.3455764729359023`}], 172->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/jDF4sCMG7D8ovKW0rurbP46zPmgTdPa/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ttwy1Oex7T+IKUzB6Zf5vwuEw+p/1ea/rTb22GPl
9j+fTneYuy7av0Dp1w/U1N4/OAiOHRIW5D/psUNwyP32P6SfLM8Fk/C/eD3T
yqpgzz8c2/p+nA3MP6KFPuXjKQLAQwAkFQCn/j/UNmqLi73cP8DuZxF46/u/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Nmr699MG6j8evyCWzKXx
v99hvchwYeC/RJlr86EJ8T9dKBNRXj/gv7TT0oQh9LU/4hwD5xoO6D/zIG0d
dPjtP5mptZuMg/O/dYCWMSfv4T/blBF6vvjUP2nfXZntY/2/hAyw9ghV9j9+
+QcgHVTcPydR07zFL/m/u4U1cg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2827208424838217`, 2.037195387581319, 
                 2.3725223272026317`}], 173->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/ByserRhD7D8cQNZWNfHcP6SNW3luL/a/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/f1xnr2t47T8TjJO1l4P5v/51yen3Vue/5OEBotrq
9j/UpsxjK1Pbv9uijI0NBt8/7SoJeviM5D/TILqo+i33P6RtC90gDfC/ciqb
JCAS0D/kXXgkqDnQP/h+5OxbDgLAqHCFCdPF/j90qQ0dpaTdP/ylm+YLpvu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/GqqU5RXq6T9kcESQo5vx
v9haQMgsouC/327xV10M8T9qfuhDeojgv+xGPICUVrY/+qqTkwho6D/asG/+
R2ruP6R9M6tHHvO/IOC1XxQm4j8AT6e9bpXWP8pFkikTJv2/FkMKsK9z9j/I
9PE57UrdP9CZ+y+96vi/uKY0KA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.2689364874087863`, -2.0144725750651316`, \
-2.3991874531251423`}], 174->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/GtMVRvmA7D8MM359c/LdP7xQpzfA6fW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/6uCcdzs/7T+ED+IBCm75vzoeZujE1+e/PXdqp8zv
9j+fNoFpgHjcv/mUr/yaMt8/Yv6J94gE5T99njF4nFv3P3qb1Kr4DO+/InUD
j+N30D/0NCtsN2jSPwX9J7y18QHAef8Rig3l/j9A5BQ1aIbeP+Swk4W2X/u/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/UGyvyX3N6T8csmu23JDx
v/aujkeT4uC/jLmlWtYO8T9dolWFz9Hgvygrgl6vr7Y/vujPHsHC6D9AK5FX
OdjuPzzPiEYeuPK/1sbLhnVe4j8AtNR0VS3YP2Ol+9eV5vy/g3SOFsWS9j+m
i0nZbTzeP9CAnV67pPi/aSc6Sg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2550010677883379`, 1.9914815927637146`, 
                 2.4255666112340486`}], 175->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/NeQeqMC/7D90uE0ZVe7eP2ZUKRIOo/W/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/naB4olsG7T9wCX1UQlf5v+rgXNvcV+i/kIJ2hjn0
9j+JdtLJo57dv8kz2+N4Wt8/F0Q2Q7p85T9XWbdPqob3P5AoSnBF/u2/fK0k
tZfh0D/cQR2IUJLUPyy29I7z0wHAWjlgJ60E/z90MqI4w2LfP1CmX2p9GPu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/KUwd3w2x6T8SL7nfeIXx
v04QCkGfIuG/Nb8rygwR8T9X8mldWBvhv8ho2Sxr/7Y/JpSqdT0e6T90xwqW
P0LvP1c0J2UYUfK/ep1YQUaY4j8ofbXQUsDZP19gCZh6pfy/utW3vUay9j90
9fcojCjfP1t9RL7FXfi/NKctIA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2409153245101165`, 1.9682272625518022`, 
                 2.451654665800995}], 176->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/R/P57Wn/7D8M4fyFxuTfP6oXLYxdW/W/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/pxhbn9DN7D9+qyV0Qj/5v7lTj8U11+i/WJ7O5iD4
9j+ncuaUfsXev0gSNCekfd8/b5mp/YL15T+rYs/TIK/3PykdbSY97uy/LMTX
WDRP0T8U3+ZCyLfWP/OQW7cXtQHAJiwkaq8k/z/SD2N80hzgP7w10SJm0Pq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/LoiOXciU6T8agI3veHnx
v7ZJI7ZLYuG/Gc1XegAT8T9f8S4QD2Xhv8Qli7PBRbc/W8bRdXZ66T/umk51
UqjvPx/TsQ8+6fG/ruoyDYLT4j8Q4HFkR07bP8gccn3GYvy/5JKQMDLS9j8s
wLDfmgfgP7Mmf9fhFfi/GMs0Iw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.2266800327052954`, 1.944714506261846, 
                 2.4774465860027903`}], 177->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/RirKIPA/7T/k4ulF2mrgP3oz1Dy0EvW/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/MIMH156V7D8kjfU/DCb5v1GlxLjFVem/QFeEeoL7
9j/jrZXM+ezfv9HxpgganN8/bJKwu9lu5j9ttLfc/NT3PzmfywP13Ou/nvjw
7bDA0T/8A5DDc9jYP7RQZJ0klQHAYqFg0xFF/z+GP+tZfoXgP5hHDU52h/q/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/cr1kea946T/tcHXV3Wzx
v4Lyva+ToeG/jakyRLEU8T8uwBre7a7hv9jkcHatgrc/WV497mTX6T/wUtb/
NAXwP4sBXV+XgPG/SlPhSyQQ4z/i5LEnFNfcP3Fqzrt+Hvy/Qtvi8YTy9j81
kepPLHjgP4m9cEUVzfe/o/c8zg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.2122960039411266`, -1.920948342633291, \
-2.5029374470335433`}], 178->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/NGJ4OE6B7T/kFZUwhuDgPyzBps4XyfS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/BtJLq8pd7D91TzmvoQv5v3rbb9aC0+m/5T8Y/l3+
9j9QERszf4rgv6WBHyjYtd8/YsAEB7Xo5j9hLqd2O/j3Py7m5FeCyuq/PHvq
mgQ20j+koeeQKPTaP+CL3b4cdAHAX/KY3NFl/z/+dl4LXevgP9DDG5yzPfq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/3uSGY8Vc6T8VUheNqF/x
v5aNkz5y4OG/4J38BR8W8T9c3YIE7/jhv4AEYrUptrc/S5G+nwE16j+q3HhH
PzTwPyKaTH0sF/G/6c/2QihO4z+25gh5mlreP3bsMKao2Pu/vJFqfDwT9z9x
xvmd8eXgP35CYbVlg/e/+8A2kQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1977640884806375`, 1.8969338842809134`, 
                 2.5281224311755706`}], 179->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/NpUXHH/D7T+ASe/VXVPhP6w9Iv+NfvS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/MDSpdlgm7D/RXUnRBPD4v1fYdFBjUOq/QzR/OLMA
9z+enjOmuh7hv/TJt4Pcyt8/dpUJXwtj5z/PhQji2Rj4P6HPf4n6tum/0BeV
OSav0j/UhtOUvArdP4fvKq8CUgHA8XED+OyG/z8eWx6fZk7hPzgHds0j8/m/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/85U1SQxB6T9DWR8e2lHx
vwUMlnviHuK/Dxgwo0kX8T8EJA++DEPivxyVkmwy4Lc/VpWQPUWT6j9IFYBm
RGHwP74S8aEFrfC/jxBxHImN4z/qDFkgvNjfP10OvK5Jkfu/Rp4HQ1Y09z9P
0oY64lDhP3IiTObYOPe/M1soXw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.1830851776001154`, -1.8726763346819704`, \
-2.55299682883959}], 180->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/oqBKon0G7j9GSWJBWMPhPyzyRp4cM/S/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Mi39i0zv6z+EzmDNN9P4v5MX7GldzOq/d8wm+4EC
9z8kVm+wI7Phv6o+4Hcl298/sBaKOdPd5z8VI7GT1Tb4P/Gi/xRzoui/WtrO
Vwws0z+sipgfBhzfPwjUERfZLgHA82e8kGCo/z8K/Bdck67hP6YQlLLMp/m/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/dJLfU4Yl6T+cESucc0Px
v6OrUYjfXOK/KeSDBDEY8T/H/yxDQY3iv4h+41TEALg/qVvqbSjy6j/cIzHa
QIzwP9JhYxQrQvC/6AYZ50HO4z9OR5eorajgPx5NNWZnSPu/ItzwsM9V9z+o
Ir3O9bjhP2mBbah07fa/XAYwsQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1682602059544878`, 1.8481809851812299`, 
                 2.577556039584341}], 181->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/Rk+rkURK7j8KM4W3bDDiP1jrI47J5vO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wkQrNqu46z+oZnLiPLX4v90T5XdnR+u/e/74IcoD
9z9s8Rq/rkfivzB3gL+x5t8/eE13AwNZ6D/H6BM1LFL4P48lt4oBjee/5J8/
OK2s0z+eXY317ZPgP9wmhLSiCgHAjZr5CirK/z9GAV7C2wviP9ZueCu0W/m/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/PJ72qDUK6T+u3bMmdjTx
v8gpTo9kmuK/K/3sF9UY8T9qzYLKhtfiv5TvI+TcF7g/X06RyqNR6z8mQWtI
MbXwPyB+f1NKre+/nI/llk0Q5D9USIlWLWLhP4gclnsH/vq/GKHnKaZ39z8o
mvE8JB7iPxctztw+ofa/GKEvxA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.153290153980238, 1.8234532120122962`, 
                 2.6017955731252758`}], 182->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/xqMyoc6O7j8gyMq2kpriPwqIYcKamfO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/zlXHt3iC6z94xPtmFpb4v/1FJ+J3weu/f+5ek4sE
9z9bFNw8UNzivz2IEHSA7d8/4mmnIZHU6D+J4G+k22r4P10hOo27dua/FIUb
0/4w1D/apwqPCpfhP8WtaVpi5QDAN2E+xEbs/z8GYb6LOGbiP/r3OifgDvm/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/wqbEaRzv6D+XjPjo4iTx
v9hCb8Rs1+K/LfWf0DUZ8T/jXmOJ1yHjv7ARRE16Jbg/1AZt4a+x6z9Moup/
EtzwP7iY/oj41O6/KDNgBadT5D/9t+qizhjiP8pxmrsvsvq/jdlrCteZ9z+T
lEShZYDiPwJAznQ9VPa/YH45WA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1381760503250669`, 1.798498473332969, 
                 2.625711050341489}], 183->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/8lqieBbU7j+kOyv4wQHjP56oyj+WS/O/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/YoPASrlM6z+4s9bIxnX4vwGu8SOFOuy/w+1CQMYE
9z8yipiS/HDjv9b9qg2R798/noaV8XNQ6T/pyfr04YD4P5p+rc+2X+W/pCLr
1va41D/oDqWnRJfiP3+nZ/AavwDAuh7ICVoHAED4llOsor3iPzpUkqNWwfi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jD1BszzU6D82BOYZuxTx
v9p2VGXzE+O/z/QRJ1MZ8T/OmUG0LWzjv+D8eICbKbg/yPAbNUUS7D/eM4h4
4QDxP+tnoadx++2/IvYL8kiY5D9GJehPg8ziP877TBDmZPq/drXwp1+89z9O
aT9Sst/iP2x+rnF2Bva/CB45/A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.1229189742930954`, -1.773322306271805, \
-2.6492982042894657`}], 184->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/4p3vsBYa7z9ycMlv8mXjP1aI1BvC/PK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ItoMIHEX6z/ErwiNUFT4vwXYuMyFsuy/u6cRJHoE
9z+QpV0oqAXkv1N0F2Pj7N8/7P8hyqHM6T/VhwdvPZT4PxwTFhQJSOS/4IhZ
qYpE1T92KVREiJTjP3TOpnLPlwDAjvrVpLcYAEBMTxFTExLjP2JkXKwdc/i/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/7GjnnZi56D89Av/7/wPx
v9wLuLnzT+O/y1H5GC0Z8T9+JyR/g7bjv9jpUStAJLg/586IPVxz7D8HIHZT
myPxP+SR36XGIO2/KTHOAi7e5D/0zA5aPX3jP58SkYAwFvq/BuIRUT3f9z/f
X23hAjzjP1x2GOTvt/W/QR4tgg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.107520058294058, 1.747930323982514, 
                 2.672552881231484}], 185->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/jNuu1Mlg7z8UmpNNHMfjP+JJJXwkrfK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/2qRVX6Ti6j8Ll5BPtjH4v1xN44BwKe2/a326RKcD
9z9FsUdmR5rkvxjPzal35d8/Uk5T/BBJ6j/baSiQ7KT4P4RIpinIL+O/fOkH
aK/T1T/kGDWlwY7kP9rBl/GCbwDAFpWd2DoqAED6ekzqg2PjP+SNJVs7JPi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/SM6LPTKf6D/g9ULdsvLw
v4dGzRNpi+O/o7xNqcMY8T9YLRke0wDkv2ifvrhoFbg/7xSBaO3U7D9yG3lb
PUTxPyRu+JAIRey/JWhZxFAl5T98WWT57irkP8tmqi8Vxvm/+UvJTW0C+D+H
CvAbUJXjP+NrpeuvaPW/9tsySA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.091980490284605, -1.7223282127023047`, \
-2.695471041685938}], 186->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/NsGAYCqo7z/KM9/9NyXkP+BAGZbDXPK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wHqkJleu6j/8kzLD+g34v8JjhPo7n+2/3w6vsk0C
9z8GYGm1zi7lv1EN8nVO2d8/GlYX1LfF6j9jTk0L7rL4P5C7CusJF+K/oN9m
6Vlm1j9kyxRH3YXlPxPatZE4RgDA2DWFR+I7AEB0wj4Y7rHjP+T1rta11Pe/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/OzkzoQuF6D9Z9BMX1eDw
v7rRndBOxuO/XQVI4BYY8T+4BKrFFkvkv9gbB1EW/bc/qAtMGvE27T8kdB4F
xWLxP6ienotIaOu/gxiaqqtt5T+X/3miitXkP4N6wlyadPm/Jmal3+wl+D8f
+w4Lk+vjP2IbZLa8GPW/7FkxlQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0763015161896117`, 1.6965217288098844`, 
                 2.7180487615059197`}], 187->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/q0mAwzLw7z8QQgAqPoDkP4QBR66lC/K/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/ww0Rio166j89P0KxIOn3v7FbFQrfE+6/6vLhiG0A
9z/jKLOAMsPlv5W8SLpoyN8/mRwFmYxC6z+Tm93IQL74PwX2tTzk/eC/KkWV
vX781j+2gvXkx3nmP9JsSIvzGwDA+N0fkaxNAED6TIW/S/3jP3y0c1KThPe/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/vILp0iZr6D/5yRsOaM7w
v7JNZligAOS/YndhyyYX8T8m6U6rSJXkv2B6tNlK27c/IrNCrl+Z7T9O3u7u
L3/xP4b8ocyXiuq/IHYlETm35T9j4noHA33lP5Tta2LGIfm/YvD/QblJ+D+F
x8L0xD7kPwBbXYAcyPS/wvs0dg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.060484442291099, -1.670516695878432, \
-2.7402822329916945`}], 188->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/He3Yr24c8D9I0tu4J9jkP2pAAhjRufG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/fr9vk0tH6j+s/2r5KsP3v7u/LJdQh+6/QZ3E7Ab+
9j98fto1Z1fmv44KJMjHst8/GNQej4W/6z/jDM7m48b4P5rLVhbayN+/lINE
LxKW1z/ugI95bmrnP0wMRVRu4f+/psNIUphfAEAs0pr/lkXkPw4KLQ7aM/e/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/mtuY14VR6D8xKjAybbvw
v7f/8R5ZOuS/jsxSffMV8T/0k+IFY9/kv1AWa/UIsLc/KVdodzH87T8E+53h
e5nxP1Dzl50HrOm/Ag6qO/MB5j+bqTUZSyHmP1umI7afzfi/NDo1qs9t+D86
Ujtc347kPzylF5PVdvS/Auwyjg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0445306375722891`, -1.6443190017185416`, \
-2.7621677660417667`}], 189->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv13F0lzD2tM/t/fBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/dLI5RRJB8D9urXXP7SzlPx6M3TRMZ/G/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5v8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/7QIBQpUU6j9DrHaRHJz3v172M6GH+e6/6HJEDhr7
9j/ozkBGYevmvwd3SU9tmN8/Gy+U95g87D+ZU7K41sz4P6llk5J0ld2/0k6i
RAgz2D9gvcxAvlfoP5Q2wpoNif+/ygM/JaRxAECg7Ew1yorkPyCgVVWQ4va/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/62
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/Un3hrio46D98ADb+5afw
vwib9aN0c+S/YrcSDn0U8T8qvBUOYCnlv0TvtQNUe7c/AsoDwV5f7j8olTbQ
prHxP4hlglmpzOi/KEZiVtRN5j9nNSEIVsLmP1nhz+csePi/BN3bRy2S+D8H
TWEC3NvkPx+WGUXuJPS/o4UsOg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0284415360041408`, -1.6179345954058844`, \
-2.783701789346381}], 190->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/vMN2RgFm8D+uMnnRiX7lP0TqKnQdFPG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/ZZEhim7i6T9pdBKF+HP3v0X4GkB7au+/jA3HJ6f3
9j9lOtonFX/nv6Ao0F1bed8/P+yEEb257D/PiMrHGND4P0YsKd3DYdu/NrhH
wFTT2D8yhD+5pEHpP854T87LLv+/3IfBoc6DAEBOpCz738zkP5Lfq368kPa/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jcTxUhcf6D+P5AP405Pw
v/wbaXPuq+S/swTUmsMS8T/oceL+OXPlv3RSwyAwPbc/3Dk5z9/C7j8TkUPY
rsfxP1Y1dWuO7Oe/yrGIdtaa5j9wW1xFF2DnP4kxPaF0Ifi/uun8RM+2+D9+
61LmtCXlP+tka/ls0vO/AgI4yg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0122186387616752`, -1.5913694842881736`, \
-2.804880851626296}], 191->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/7s5C0jiL8D8yT71h9czlP0pie1JLwPC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/2Xj7VNuw6T9cE5L1wUr3v/8cCqUi2u+/oK0lfq7z
9j+d7hNWdxLov1fm91+UVd8/AYvDGug27T8ZcAzTqdD4P2io/OrzLdm/GoYt
Iut22T8U45OlDyjqPwSVt/iv0v6/lh0rXRaWAED2J/op0wvlP/Bls+tkPva/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/SLheuE0G6D8ItEOwOH/w
v1mu4CXC4+S/vlQDRscQ8T8ETP8V67zlv+DNEiWi9bY/bpSk36wm7z/Zi/VB
ktvxP2SMOk3IC+e/dDDOmvPo5j8jmaiDgvrnP6d7maV9yfe/DYVMxrLb+D+U
u9tFZGzlPx1kFx9Yf/O/kZA2wg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.9958635163574128, -1.5646297309658466`, \
-2.8257016229188094`}], 192->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/xl+oAbaw8D/4iMNiKhjmP65/HVnca/C/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wgk4gN9/6T9kU7EZfCD3vwz4iI06JPC/A9ynYDDv
9j/BFLpSfKXov8K5+B8bLd8/mBqYUBC07T/diSjPic74P4D5YbMw+ta/sL2l
qL4d2j+wxvsN7QrrPwpuvEjBdP6/Wr6O6nmoAEAyrQvZnkflP8KjNQiQ6/W/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/vAD9zc/t5z8MVFPCFWrw
v+aX5GDrGuW/72tEN4gO8T8WX1KUbQbmv7h0FKWvpLY/Em30Kb6K7z8sJ0WA
T+3xPw7+9YVoKua/Ms/RqyU45z/Up1+4i5HoP9z27NBOcPe/Pe5i69QA+T8V
m+ed5K/lP7iRqTC2K/O/EE42Yg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.9793778106792782, -1.5377214502408698`, \
-2.846160895911926}], 193->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/cc9D6HXW8D+UEjL3ImDmP/LVmh3XFvC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/lqqy3X5P6T+l5VM9KvX2v6CA7AO1WvC/WTv9KC3q
9j9wQN2mGDjpv/48y8Xy/94/yBOD8Csx7j8h9YrmuMn4P4QkryymxtS/jEta
UcLH2j8IrJVBK+rrP4SkhxEHFf6/TgTU2ve6AEAYb69ePoDlP9KtwUlEmPW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/JlG6fJ/V5z8tnSTUbFTw
v3ogSNdlUeW/mhtvmwYM8T/t9GO+u0/mvzB7ufBeSrY/VVmF4Avv7z82/xEx
5fzxPxOfxqiASOW/VGKafGaI5z9O32McJyXpPzs9kRfvFfe/Buz1zjIm+T/W
wPCqMPDlP+JBrrON1/K/eGk1tw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9627632369204558, 1.5106508060281123`, 
                 2.866255587326619}], 194->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/f6B9lHX88D983kiC2aTmP80gaYKEgu+/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/3pYsM70f6T+sk0PBz8j2v7jQI3Z8kPC/nYk2O6Xk
9j+LTbfjQMrpv2WZ6dYezt4/9C0AOTGu7j+xIFh5N8L4P7B2zkiAk9K/rLZQ
2uh02z8Wys3XuMXsPz5dGMqIs/2/gMrTvI7NAEDWw4hQrbXlP05LKy+IRPW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Skd3p7695z8wdByWPz7w
v5Jwf0kth+W/vMKLpEIJ8T96+9Dcz5jmvwA09hK35rU/vNt+GMcp8D/4Rz4d
UgryPxIuaFMiZuS/Ks4Ry6/Z5z9JVAstSbXpP9J2poVluva/wJoSh8lL+T8p
0WhpQy3mP9rtLzjlgvK/lE02CA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.946021585388859, 1.4834240082237262`, 
                 2.8859827393461317`}], 195->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/1kLFD7Ii8T/KqFGoSObmPwwwvuBI1u6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/EpABOp7w6D+9z+wacJv2vxbAmLKMxfC/l9K9BZne
9j8Qm4+j6Vvqv1E7CTajl94/9iBJahYr7z/NS2UdBrj4P59A0fHqYNC/ZMry
wiQl3D8GmLmxhJ3tPxY8rgxOUP2/YvZ0HT3gAED2QeiD5+flP/ZKCUBi8PS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/5MPhKi+m5z85EvHCjyfw
v/Bf9IU9vOW/OWfPiTwG8T89Ir08pOHmv9h3NdG/ebU/qOl0oh5c8D8ZEMc4
lRXyPy5o0yxfg+O/b/WBQPsr6D9ooAWt5kHqPw6qhj65Xfa/zZdXJZZx+T9g
9RwWGGfmP34xNFjDLfK/oQIyTQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.92915472318412, 1.456047309525211, 
                 2.905339521090269}], 196->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/xzrMXihJ8T+K7gpPayTnP4WzecQIKe6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/qoXdniXC6D8zqRnUDm32v56N/pXh+fC/ndNNAQnY
9j9OkZ6KB+3qv/xAzSKEXN4/5kMYx9Gn7z8Z1yyeJav4PzxcBg0kXsy/dCEc
TWjY3D/elG37fXHuP1CfMZZe6/y/5GfJhwHzAECI7h4O6RbmP1ApMwzZm/S/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/sL5P3fKO5z/0focfXxDw
v3gtWmmS8OW/vGeXh/QC8T9cnUQwMyrnvyyDvaqBA7U/XS4soYiO8D8vJ9mi
rR7yP0ql3eNIoOK/JEMTckJ/6D+0QTyl9MrqP4k8N3zx//W/SIUvt5WX+T+J
7pQuqp3mP4kBOLcu2PG/yq0v+A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9121645957303006, 1.4285270021980763`, 
                 2.9243232301315727`}], 197->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/66bBgdVv8T9cyg2ePF/nPzFvMLDReu2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/sDpzAVeU6D9QKquKrz32vxR6pAt3LfG/gZHosPXQ
9j+mYfBHj33rv++pcTnGHN4/E321yiwS8D+NZr78lpv4P1T9/K1C/Me/wH4s
fqWO3T8qNk0tlEHvP8wmmUXChPy/SA4rhdoFAUCWbcxErkLmPygSPivzRvS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/M5majgt45z8Ff6D1XvHv
v+4ZAN8nJOa/rsZk32r/8D+Ihe0Od3LnvxBVBtgFhLQ//5E7JgHB8D/epeKl
miXyP0PX1y3xvOG/m8ZM4X7T6D9DgK1laFDrPzKv2I4VofW/vuELRsW9+T/5
G21x9dDmP+AkqwEugvG/Ns8zeQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8950532281529098, 1.4008694147841778`, 
                 2.9429312940494023`}], 198->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/8h+OdLaW8T+Uri7/t5bnP9lduTmxy+y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/H+4z9DVn6D8KJVHwVQ32vxo/xw1JYPG/QCHNoV/J
9j8M7kaWdQ3sv0lOb3Ju2N0/ju+hD1JQ8D/Z1apvW4n4P3THgkKJnMO/2twe
IM5H3j+UcaqG2wbwP56TTBuBHPy/Kh9ZncYYAUDuLii+M2vmP4hH+Tu38fO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/6vL6B3th5z+/eUZbBcHv
v/TeIuH5Vua/jQ7X15/78D+7yxg2arrnv8idAUpW+7M/wAcYQoTz8D+SFqG3
WyryP9sHLcVp2eC/KNeV/Kko6T/eyEGGN9LrP0WhFNwsQfW/Iy+g1yHk+T/B
bqve9QDnPzr7auzHK/G/40M0jQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8778227264892391, 1.373080908747329, 
                 2.9611612720168763`}], 199->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/1u0PL8i98T/y9Nge2crnP0l9Hgm1G+y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/AAwI/MU66D9WdEDKBdz1v0xc4aVTkvG/UaRsa0fB
9j/ixvo8r5zsv1ykGCKCj90/6FC22VOO8D+FAOxidHT4PyAhEzeefr6/cB+l
wtMD3z948S5Y62rwP+QLhTijsvu/qG2VVsQrAUA8kUVRdpDmP1746eMrnPO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/2wHlC0NL5z8MyTU1tY/v
vyb8PHkEiea/FtCmvJP38D8muHIJBwLov+xJVKl9abM/Xx9jBA4m8T9/PSx5
8CzyP23hANCI69+/sjW5H71+6T/xa5vnV1DsP0Qlit4+4PS/k2QdbqgK+j8X
Qw+4py3nP4GbPDQD1fC/52stQA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.860475278721527, 1.3451678750520597`, 
                 2.979010856414766}], 200->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/sI1XpQfl8T8+PWXsm/vnP0MvjNfqauu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/tewIkAoP6D/mt+fwwqn1vwQ0+uySw/G/dHler624
9j92LdsQMSvtvwBdL/gGQt0/ksAbUy3M8D//X8h341z4P6gXU7DWybW/WlBI
vKfC3z8wEq698czwP4zPqt4wR/u/Kt/BNdI+AUCq9lIWc7LmP0CRxs5XRvO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/NnLlVWU15z+bDN1bcl3v
v97TVcBDuua/qLqf3kbz8D9w62LzR0novzS7gVWHzrI/Iac5fJpY8T9Pf/22
WC3yPziSlq0lJN6/xqFplLHV6T/PsOCzv8rsP5dzOCVTfvS/AqZtCFYx+j/0
GVyBB1fnP3FURp3mffC/q282pQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8430131556230195, 1.3171367306719508`, 
                 2.996477874465507}], 201->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/e4Pkx3EM8j+yk2qa/CjoP1BEP25gueq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/2Kc7GQfk5z/8j6JPkXb1v7Lx8wsD9PG/06JTGZOv
9j/ACQ3177jtv0recv8C8Nw/wywgqdkJ8T+BgbKEqkL4P6hdWHvTNqq/zKjG
lR1C4D9g40oS5yzxP4xqsG4y2vq/uPt9vu5RAUCQxdNmJ9HmP3iR8a1B8PK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/x89+muMf5z+x5Je6QCrv
v4yRT9+z6ua/V0+ak7nu8D+V2XtlJ5Dov8y9CGR/KrI/H1iCuCWL8T+t5fNo
lCvyPyrK9KXNXNy/4dfHkoAt6j85LYBfZUHtP1oG6FJxG/S/dj1woidY+j+h
LJ8AEn3nP9CZiPJ4JvC/qt05gQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8254387114076467, 1.2889939150244614`, 
                 3.013560289879663}], 202->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/GnPigwM08j8WWQqf91LoPwHGcaUjB+q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/RwBN8r655z+GX2vkdEL1v8Iz2DugI/K/lmIJX/il
9j/xwejb4EXuvxymJ518mdw/kJqWDFRH8T+pViSVyyX4P0Clt7QS0JG/0/YO
fD+k4D+OJWraw4rxP5Rxa2iwa/q/YpdEcxhlAUAWUdXdkOzmP/ju8zfwmfK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs//nsHh78K5z87tGBPJPbu
v5zTMw9RGue/OC91Nuzp8D+utenYn9bov2xNcp9yfbE/1YY8yKu98T+awVSy
oyfyPyuDFzukldq/hO7pQSOG6j8ZUu+pP7TtP0oqkh2ht/O/79A1NRp/+j8W
1W8+xJ/nP/jRrAqCne+/6xAzsg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8077543841746815, 1.260745886329766, 
                 3.0302562045063373`}], 203->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/pHtmw7lb8j+M5ja0iXnoP9eVRmNCVOm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/c25OZzWQ5z9umou/cQ31v/RyI8ZmUvK/zA47QN6b
9j+U4tbH+NHuv3mdl5B6Ptw/yCc3speE8T9FY3bpSAb4P2BrzP2urpA/XRf7
6bEH4T81q0fEgObxPwrW6mmz+/m/gJKJ1U14AUBWpR5YrQTnP1AT9ydqQ/K/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/FTOIwfr15j8j74AqIcHu
v84Sf5kXSee/VAUOJ9/k8D//xeDOqxzpvyg8UoZux7A/ttHOuijw8T9G68jh
hiHyP3wyWOvMzti/UgdkuJLf6j97HmOeRSPuP3sQx03qUvO/UtA8tyqm+j/x
xSqGG7/nPzxemlmL7e6/OD41ag==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7899626961405389, -1.2323991178917872`, \
-3.046563859978306}], 204->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/lNCsbZGD8j+C5/TXr5zoP432s5rKoOi/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Zk50tW1n5z+ApkoDjNf0v2AhDwVTgPK/+R2ThkWR
9j8EhivMLF3vv9Jmi/ID39s/B7/+0p/B8T/fy7L2JOT3PxC8q8D2hak/+PJK
Hm1s4T+NdoioFkDyP7Leyi5Eivm/bq7XZY2LAUCQM1v0ehnnP3J8Pj227PG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/DiOb6Jbh5j82+z9uO4vu
vzrBatgDd+e/6gw6ypLf8D+4FwvRRWLpv9jOOUqBCLA/zsdVoJgi8j/Qn1Zx
PhnyP8w6qS5rCNe/EErS/Mc56z9O6oKUbo7uP/xsEr5U7fK/uBauHFbN+j+J
DShmFdvnP7h3mIobPe6/ohE1OA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7720662536506444, -1.20396009430014, \
-3.0624816393419656`}], 205->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/hotWZ4er8j/SZJdMZ7zoP1UVbUrK7Oe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/UjbVCms/5z8OVZvjx6D0v1p72mNhrfK/KW2bBS+G
9j8NagAOcufvv8ixvDQge9s/lnaOrGf+8T9BSGRmYr/3P1i52bQ+UbU/3iQb
PmnS4T/GiMmKfpfyP4LSho9rF/m/iHTuo9WeAUD4WkAT+CrnP3gLoTrblfG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/BJdLk5XN5j/DqZBOd1Tu
vzQbNjcSpOe/gjS+iQfa8D+8ifVxaKfpv4jJOJ1zga4/DoHyifdU8j9V/VcG
yw7yPyre0XOiQtW/9R1kBryU6z8vOxUxsvXuP5auXlrohvK/S7qZV5n0+j/l
3+uvr/PnPyKW119AjO2/tRYzFA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7540677469651828, 1.1754353075526796`, 
                 3.0780080686615148`}], 206->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/PrKnkpjT8j8mfPaYrdjoP8moyntPOOe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/HXsqhjAY5z/w+8elKWn0v3YEEl+O2fK/EsGsmpt6
9j9w0YbiXjjwv1ufQSHXEts/npKKgeo68j/h/WAWBJj3PyAO/vDK1b0/R8qB
VZ454j9SVyuasezyP+ZiyIAyo/i/4izgDiWyAUD8yq1XIznnPxIMAubfPvG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ajn2UPi55j+lUL0Q2Rzu
v1CkbTI/0Oe/d95G1D3U8D8lJnxNDuzpv9B/TE9P4Kw/biIZikGH8j/6HW5x
LQLyPwXnqh2WfdO/YpdovWfw6z9llaZmCFnvP6XbVh+tH/K/AQY0WPEb+z+R
I1J46AjoP3Zg56MH2+y/Dd4viw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.735969949813446, 1.146831253098756, 
                 3.093141818586327}], 207->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/rGvFz8H78j+uv6CIgPHoP0W7skFog+a/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/f+eRNsHx5j80NB2gtTD0vzir1YTWBPO/XIPdLIxu
9j8dbUCegnzwvypC8dkwpto/VCP5mSN38j9tRpEYDW73PwTwWQX7J8M/AUUt
WASi4j+13NkxqT/zP57jtBKiLfi/ouIvJXrFAUD6vMim+0PnPxz/yQfL5/C/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/mu8pqcCm5j/piBILZeTt
vxJLMViH++e/mz9fHTbO8D/SwTUJMjDqvxALCzK2Las/gEfftHK58j8i03Cu
ZvPxP0Q/XIBpudG/LA7c+8NM7D+MPCp2abjvP6Agxxmrt/G/eJgSDVtD+z9U
vrQXvhroP75coyh/Key/cmcvWw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7177757187124513, 1.118154425804358, 
                 3.107881705869924}], 208->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/Wl/0/P8j8z8AOgcs3gbpP6G2f7cizuW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/tapQGyDM5j9kRZM5cPfzv9KNHXU2L/O/aL3vrAFi
9j8YhenpHsDwv+BGwdc1Ndo/pDegQw6z8j/BZrKygEH3P6AnkGOLX8c/beUE
IpML4z/uOZHZXpDzP+hdOHDDtve/bHPvZNPYAUDKAhIogEvnP9wyX2qjkPC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/NVGJG/CT5j8amoikH6vt
v6wteUjnJei/oVxo3fDH8D/O2d5UznPqv+gdSynKaak/f0tKIIfr8j/gAVvk
d+LxP3JZN71/7M+/ENL2jcmp7D93a8r35gnwP5wc/GXqTvG/GaNpY9Nq+z9l
ngwqLynoPywOH8a0d+u/SKMyVw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6994879920465209, 1.0894113158409453`, 
                 3.1222266948286164`}], 209->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/XzrX9k9M8z/mEqTYxBjpPxHH5v+MGOW/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/koOXI1Cn5j/gQ3bpXb3zv8Za/eGqWPO/HVI+Ff1U
9j9lUc5/LgPxv4HRHOruv9k/NJ1j0qXu8j81OxVeYhL3P1B152NCkcs/KG/L
d0J24z9i3h5GzN7zPxSNTt6fPve/rKfdSy/sAUCo6HZFsE/nP4AzntlvOfC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/pL2sH4iB5j+VmGtUDXHt
v6D6WLVbT+i//KaPkW7B8D8apsPq3bbqv3BIuXKulKc/ymud5Hod8z9UojNl
Ys/xP3rT2c14aMy/8/G8MnEH7T/qczhZlzXwP074IC9z5fC/3ERJR1eS+z/H
fQ2POjToPwiXkVm2xeq/Ugs17w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6811097889055341, 1.060608404500615, 
                 3.136175898727576}], 210->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/xVStmK508z/80RspMyfpP0ur3UO1YuS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/mixILlSD5j9m6Qw3g4Lzv+RH5o8wgfO/HXipaX9H
9j/4BDQlrEXxv6qcNDZlRtk/GyaioOUp8z9N3ljHteD2P4ho6UvMvM8/mmvD
Bwri4z/zK99Z6yr0P/DSSbtAxfa/XFGEV4z/AUAS6Vyri1DnP+U8pERuxO+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/KBIFJYpv5j8bPgKiMjbt
v77nQWPhd+i//DnFu6+68D+tWSmQW/nqvxB1GKOHrqU/cL2nHEpP8z+mY/Ot
J7rxP1KixmEE58i/kgqPnLNl7T94ijZ3Ql/wP0tUnK5Ne/C/vvvao+O5+z+H
XTxq3zvoPxj0QMSRE+q/MIoxQg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6626442076806541, 1.0317521599410764`, 
                 3.1497285810819}], 211->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/0HKRvBid8z+UPFn9JzLpP74HgLGprOO/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/mg28CS9g5j+BLj655Ebzv9Ca51XEqPO/33WCt4k5
9j+mMsGqkofxv69oSDaiyNg/c22SD8lk8z8tTyHOfqz2P4hnNe7q8NE/uj1V
auFO5D/GjTcltnT0P0wyGH6vSva/6m5WBekSAkDOMahIEk7nPyvGWSMAFu+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/qAK/kvdd5j82gzMklPrs
v6o6Qyl1n+i/3bix4rSz8D9bh7YVQjvrvyClZ6N7t6M/IvAR5vCA8z+89mZm
yaLxP/SnynRoaMW/rRG8cYnE7T8IFvIR5YbwPxYbbCuCEPC/UiifY3Xh+z8x
twAjHUDoP/TmbOpUYem/yp8wGw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6440944244174347, 1.0028490328647721`, 
                 3.16288415686009}], 212->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/9py4O4vF8z+yzKN6ojnpPyxT9Hp49uK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/TTeMc+M95j8crDUWhwrzv8a97R1jz/O/VKF2FR0r
9j/hTuXs3Mjxv5XI6bivRtg/FhOfh0uf8z+ZHcqEwXX2P9TGBCwGANQ/J+q2
IsC85D/t9wznJrz0P0hehrX1zvW/5E/O0kMmAkBm+bxOREjnP9X2fumiZ+6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/gRenx9FM5j/RACuBNr7s
v6BdSfETxui/l86rkX6s8D+Wo9pXjHzrv8Ak7a2xr6E/BtirYWuy8z/5AQ5h
SYnxP4Tf48nq7MG/ChIUTesj7j8jby8SfKzwP96HAPMxSu+/X56qcAkJ/D8M
Y7Bk80DoPwClObINr+i/Xs81kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.625463690927322, 0.973905452137176, 
                 3.1756421935773957`}], 213->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/zAmx7gLu8z9cv7ALoj3pP2dyUNUvQOK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/e61aGHQc5j8+zAYDb83yv9Tb/+QJ9fO/rKR5ozoc
9j80Rj/UhQnyv91bOOCXwNc/zGfCeGjZ8z9wIRUwgjz2PwAt0MSOC9Y/RYaV
n50r5T/gxjYNOAH1PxTtgAcdUvW/FrmLPZs5AkAypXsxIj/nP7lO5C9kue2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/mVIOGho85j/0IPxtHoHs
v657W7i66+i/RFCtWA2l8D/qmjQ/Nb3rv8DjTpakLp8/zLi5s7Xj8z+PwPaa
qW3xP5xvocuh6by/7sx7vtGD7j9Hk4eJBNDwP0gmKfI0cu6//D3ktJww/D9H
MpYeYj7oP5BgmgLK/Oe/AlIwKg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6067553326597039, 0.9449278203502484, 
                 3.1880024122665187`}], 214->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/+BShrXwW9D/YuK5gJj7pP50ZfvfdieG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/sAOdk+P75T870U5DoY/yv6r/e7u1GfS/CwqviuMM
9j9+IANWiEnyv02EFyFlNtc/SILhWhsT9D8XRNVGxQD2P0bqV+VbE9g/VEHA
O3Gb5T+/9e005EP1Pyq9UzAv1PS/rAVyw+1MAkAgwDenrDLnP2Vq+YxRC+2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/s32v19Er5j/wJUSuUEPs
v4Sf145mEOm/8wJIzGGd8D8zdfjAN/3rv0AnSJ0O3Zo/oEtBBMwU9D9CUJY7
7E/xP+iRSBPAALa/ojWBSzXk7j8WqaKye/HwP/jJEiweme2/KJBCGixY/D98
PPODaTjoPwHCO8KXSue/yB0sFg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5879727463378213, 0.9159225093376802, 
                 3.199964688313377}], 215->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/Mz6GUPU+9D8k/ktvLzvpPwgJHxmR0+C/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ylBobzTc5T+wutWoIlHyv2iwUcVjPfS/vw9T/Rj9
9T8CqV5034jyv3OnXUIiqNY/UrYmrl9M9D9mYpVxj8L1P7NB3gRFF9o/NvrU
PjIM5j+7ojgrJoT1P76b5wE2VfS/LkPG4jlgAkDawqmo5CLnP1LDvZN4Xey/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/QCSVRfob5j9lD8sT0gTs
v0JQrZgUNOm/zQWahXyV8D+3/VPfjjzsv3BAeaf3apY/QnpWf6pF9D+8sJ2U
EzDxP3BBf7V0P66/Trvwbw5F7z/mUG/x3hDxP0Igd47+vuy/SGIJi7R//D9/
4PoLCi/oPy1mbtaEmOa/vsUs6Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.569119397362968, 0.8868958556493874, 
                 3.211529052145901}], 216->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/lCt0r2ln9D/oQrdyvTTpP1o7cXFXHeC/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/gX0+JGm95T+eDy4T+BHyv7gHOzoRYPS/4saiNtzs
9T9hE90+hsfyv0cM/VvaFdY/rGZb+zCF9D8NTjuK5YH1P+GWUOghF9w/PVTu
3dd95j8z2VHt+MH1P+Y7/mI71fO/wEVNGn5zAkC+rttwyw/nPwa1sdLmr+u/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/mzoAoJQM5j9TZCN+p8Xr
v5Knlg3CVum/XuFBIl6N8D8WaNKpNXvsvxBndHS42JE/IMlnVU129D/Ad8sh
Ig7xP1B/R+ozjqC/slVrnlWm7z9UvVbTKy7xP5PZthvn4+u/ilsH8jKn/D/T
eMlxRCLoPzB4ESKf5uW/LXYvvQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.5501988169925732, 0.8578541559934247, 
                 3.2226956897642043`}], 217->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/6qnTotaP9D8MDJvr0CrpP8o3Zmx+zt6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/o/HcGISf5T9LlVNvJtLxv9489GW7gfS/Vn7Dei7c
9T/elcnSdwXzv5RlJtaYf9U/+CpB1Iq99D+u9aabzD71P1SNaqXKEt4/iz1T
PFnw5j+JmQ2pV/31P3iNbE5JVPO/erJp6biGAkCWfBB9YvnmP6nbx9KpAuu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/rXRPGqL95T8A6kja1YXr
v7jcTzlseOm/GT1SRAeF8D+T6r49J7nsv+BifotYTYo/cWqKu7Cm9D/aPbqI
GurwP8BOdd94dne/WKR+oAEE8D/Ij20PYEnxP2obhunoB+u/b4fTOqTO/D9R
xFW0GRLoP8d7fYT0NOW/p143FQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5312145992988403, 0.8288036626541379, 
                 3.233464943100955}], 218->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/waahAzm49D8mpxOgah3pP261DzWtYt2/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/KqQMooeC5T9W+ki3spHxv0qgcahfovS/03upFhHL
9T8M8ZBbr0Lzv4caZWhp5dQ/d0Lq02j19D9Hu03hSfn0P2Vt6dILBeA/dNkn
bK1j5z/BFjm9PTb2PzKDU9Jp0vK/bv050OiZAkCyYaaMq9/mP63hVhbPVeq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/8E3n3iPv5T8LTz4iYkXr
vyRAzXsQmem/1ztFknh88D/BRYbGXvbsvwCyaa9hqoA/nPTF69DW9D9tx6uY
/8PwP+AqGYZTO5U/vsna3Ac18D8qdaGGeWLxP45wlx8VK+q/ztAKUgX2/D9s
BF0Wi/7nPzJeb9iSg+S/HQ0yzA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5121703979157481, 0.7997505788960483, 
                 3.243837310201339}], 219->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/jx6uq43g9D+gt5+biwzpP1fpt5tX99u/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/qpFzAnZm5T/MfbTxoVDxv6IDFHb7wfS/NQX+X4W5
9T913SETKH/zvwVftRhYR9Q/80wRn8Ys9T+1ANLGYrH0PxbHGNVw/uA/yMAf
b8vX5z+NIve5pmz2P6ZXVw+nT/K/Clm2TwytAkAC7fOgqMLmP1bRCxhkqem/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/sMQaDxvh5T+B0qlcUQTr
v3yjb0msuOm/iIDvtrJz8D8qMhd+1zLtvwDot9EyJWs/wbVfJaoG9T9C7lBK
1JvwP1iT5jkoFqg/ev+esTlm8D8uf+NDdnnxP/xRRfZ8Tem/UmiNJVMd/T9R
0kkemufnPwHj8/KH0uO/MhgyfA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.4930699225832585, 0.7707010543635028, 
                 3.253813445212667}], 220->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/kfraddEI9T+8WgsvNfjoP2kLlPWZjNq/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/upxnalFL5T/kmXsx+Q7xv/KJ21eM4PS/47sEtYyn
9T+bV0xC3brzv0EulDpxpdM/s0Jw5J9j9T+A8pbnHGf0P9rGn+aA9eE/aoox
N6pM6D9dwBhhjqD2P5Zg1TcLzPG/dpTO6SHAAkBo/x/9W6LmPzb/3El2/ei/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/OMoUw4jT5T+Z7nCcqMLq
v8wpNys91+m/39tyYbZq8D9QrEGtjG7tvwCSKG0JqVq/op4lrTg29T/vT46/
m3HwP5QEV6/PvLI/49+5SJOX8D/eNk98VI7xP3BjOrUxb+i/vhG8pIpE/T8S
rRWWSM3nP3WCU6LhIeO/cRo4dA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.47391693549860364`, 0.7416611804866827, 
                 3.2633941581743864`}], 221->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+xlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO/WdlaPgEx9T8s5FXwaODoP6P2/4uQItm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxv7PQbPX9E/5f8KFBxw8r/25FB/
o034P55rgfrGE80/snRlqEhL879+Hxok7JL4vzAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/LNzC9xsx5T9Aul2Vvczwv1TcmOsP/vS/m0yAfCiV
9T/vwh9ByvXzv/M5CW7B/9I/AaUWXfCZ9T9hmVAOfhr0P4aHZ8Mo6uI/Do5L
p0DC6D/P2HGm8NH2P4SAGI+gR/G/vuaHISjTAkA4ovQlyH7mP6Si/RMTUui/
54NOcX6B+b8uJuFmj+biP6utV1g2r+W/pIR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwK3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/8WnCCW7G5T/1DlMAbYDq
vy589L7A9Om/O6QwRYRh8D+kFxWseantv4CuqOw7YHu/Lb+4zXhl9T+8xT1D
WUXwP9QwnvWBY7k/MFAAyRDJ8D9yZU6PEqHxPyx+GLJEkOe/alO1wKhr/T8y
QyWLmK/nP/vO/qytceK/TRg1KA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.45471524748550163`, 0.7126369859049789, 
                 3.272580414600146}], 222->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/77zv4hlZ9T8eNZK6KMXoP4l6SZpXude/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Alq5tdcX5T+eBY5H9Inwv/C+HOSDGvW/d3WWJVqC
9T9m3Ed36i/0v6Xhqp5VVtI/X+C+zLPP9T8nO5A0jMvzP3xmZldV3OM/BNMJ
lIU46T+rBiqwyQD3P0hGjGhxwvC/MKQaex3mAkBAv6zh71fmPxQx0tNHp+e/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/3Ki96Mu55T9TWoOyoz3q
v8peeLc0Eeq/qbi7GR1Y8D8bMT3imePtvwDcOezaRoi/p07X12aU9T/bquxI
EBfwP9ykBimm/r8/OFN6Vq768D+dkLkGr7HxP+qkHk/HsOa/qIKSbKqS/T8v
eh9OjI7nPyx3e9D5weG/Pl02Ug==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.4354687139930762, 0.6836344319191785, 
                 3.2813733348443845`}], 223->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/9pkpQxiB9T9osMGtdqboP0DFfEsLUda/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/zUawnIb/5D/hQkx9okbwv9wCZgnmNfW/nmSzJyNv
9T9mdWhcOWn0v8ZFnAI7qdE/ltkiAuYE9j8sFE2CTXrzPy/fHMDzy+Q/+Rxt
xG+v6T85dwnXFS33P8TK7iaIPPC/9NsPfAD5AkCkvrw31i3mPx2R5doh/ea/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/QR85XKOt5T+Wl0HoUfrp
v7WiwdyWLOq/PDDKmoFO8D8byl3H6BzuvwDNkVZCjJG/xjmmIv/C9T9g7C3Z
iM3vPx75vDTcRsM/ORSwEmgs8T+2J/WWKMDxPxT8zfnK0OW/76iknYy5/T+G
N79yJmrnP975UcDTEuG/+wcz/g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.4161812309371061, 0.6546594079841798, 
                 3.2897741932469287`}], 224->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/rMKkQPmo9T+uzqkuVYToPyASMrjH6dS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/gaQWkiro5D+S4Xx2zQLwvxbRzTg0UPW/xHFsAoVb
9T/073d4sqH0v0CKhRl/+NA/kJ9P14I59j9xcmlNyCbzP8yJDk7xuOU/TwiT
8vUm6j/j18Gm0Vb3P1e5Anfea++/PNteq88LA0B6DpZwfgDmPzE6322uU+a/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/HE7sVvWh5T9HNnLhfLbp
v+9wKQzlRuq/0LYmiLJE8D+pRG3jYVXuvzCpR58hEpe/HjH6Cz7x9T/IWb7k
8mjvP3gB6+MaiMY/aiP3HDpe8T+dXwsffszxPzThjSlh8OS/kjyxS0zg/T+U
7p/PaULnP6Ah/CRJZOC/u7cy0A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.3968567303970318, 0.6257177272542459, 
                 3.2977844170500834`}], 225->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/LylIv7nQ9T+WVaTmxl7oP6LIXOSog9O/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/zms/aMXR5D+9W4D69Hzvv1RLMmVsafW/vTRiPYFH
9T/8dBhkUdn0v6ddhqsvRNA/yzr4MYZt9j8fPDQZA9HyP2ofN4Y7o+Y/widv
zA6f6j+RSzPe+X33PyUVcEpiXe6//pOKkYkeA0AcmWUV7M/lP4FVesP6quW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/wrEAwsKW5T+UgjXoKXLp
vy3rjTgdYOq/TJihpbA68D+xyQ3PAI3uvwAOQQ+dtJy//TGg+B8f9j/qZoaM
ZgDvPzR2ESjOwsk/iN6/kiCQ8T8uu8KortbxP7s8T16bD+S/lqguceYG/j9Z
9wR+WRfnP9K5qDXPbN+/DFMv+Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.3774991761828542, 0.5968151221928781, 
                 3.3054055850837982`}], 226->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/yHODpVb49T8MNmrDzjXoP2w3HL3KHtK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/5S493li85D+ccBHLXfPuvx5/H5eMgfW/avshaBkz
9T/Y3e/IERD1vxazRZC1GM8/cJTHA+yg9j846+aVBHnyP/JmeyPAiuc/vxSF
9LAX6z83Yq1vi6L3Pxk30N+wTe2/xOS+uCwxA0BCL83vIpzlP9n0fQMUA+W/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/TZP/fAyM5T8DDX5QXi3p
v/cee2o9eOq/onsBu3ww8D+NMuUzwcPuv3CXLhWiOaG/HISlVKFM9j8+Bpz3
65PuP3iW2om19sw/FP/ijxfC8T+ePrFoud7xP2gpLx+LLuO/qJ6AC1gt/j+n
spvZ+OjmP48QDGJ5Et6/340vvQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.3581125592867123, 0.5679572402596057, 
                 3.312639426215569}], 227->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/1N6M3Mwf9j/AFdn2bwnoPyYXjhZJu9C/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/oTy/n+an5D/h8mEZ4Gjuvzao9uySmPW/jKEGGk8e
9T8mSv5h70X1v5KjVYodos0/cm6xSrDT9j+iCCCg0x7yP57tFRhtb+g/S2Sj
AtOQ6z+bDSyBg8T3P2UN62bfPOy/cL/trLdDA0BQ65cJJ2XlPxJ0tkUHXOS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/K5rAXdOB5T8mTqZ3H+jo
vw9IUsBDj+q/s87zkxcm8D/bnvPMnvnuv3C2DiHSJqS/oyafk7559j+Ck4yb
iyPuPwrizozIEdA/fUjvLhv08T8+TEy+neTxP3wMGflBTeK/2i40G55T/j+I
gDiAS7fmP6V//dCrudy/HW0yLw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.33870089323446273`, 0.5391496396858514, 
                 3.319487817562943}], 228->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAR+/AeURK7r+IjOkmlX/8v8K9p3zJ
5vM/BAMXR8Bb5r8vOajSXmfjv1zF0lzD2tM/uPfBG8Bb5j9sqerVXmfjv2Z/
bk3D2tO/q7cvCmvJ8T8u1Y7SNVT/v9R7r+ZK5+u/+6k9937Yx79xWIDjtzX9
v+iWm7l8PQBAvOj8c5XM/r88gqiP7dz6v9eJCWTSlvs/Id2MCXQf7r9jnJQo
gdoFwGU2pq2BeuY/gDZbYrB66r+cGr9INa7UP8ZkAqHEFOw/IUX81k5U97+8
n3p0oUrjv5AjwFB5vt6/M3LKkNv79j8WfZj2beLRvwTRQWmkods/n/t/p/n+
5j/Ai1YqOZzAP3Q9nTuN9vG/BSy7gHAz2D8cE2EL65QCwD7fWNcvkfm/GybK
E6B68z+2jqUhn6UFwPbp+RCBo7S/LAVOLomfAEA4Sbwv3fz9v+NfX3rVE/a/
4yzIGzIg4r988jSFptr8v8l173fhMPo/MLBu2Nv49r9iB0lbQa77v8yjWPDN
vvc/NOamQdw07r9UsQTeJQ0CwPTYelMKJO8/why5VDhr6L/CV5FciCDCv7rj
tScTAeM/UuNDfRdB8b92bJEjAFnjv2i82udrx7W/CLdVz90U8T/35zbRlVjc
v3hGTW+EG68/rPmg4Vyt5j/4DKoWoYDOv07d+A4+7ea/rIJeKkfW5z/aPlT6
gh8BwJROWKVqwvO/4+78jgWi8j+mfHYF3acCwBO5zgi7e96/AuFlsz6E+T8z
jyWBiaj+v+aO23a9A/K/03hCzQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-2.253000754380117, -0.5103977769504843, \
-2.467363311319723}], 229->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/gLg18Thu9j+c+1t8jKbnP2gA6iOU8cu/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/f41WUveB5D/bix1zXFHtvwRR8etKw/W/XI/ulpnz
9D+CDoJ18a71v9R4+SCYoMo/Mv3ubkQ39z+DrV+q9mPxP1vQUu34L+o/Ce8R
/3CE7D9tVta/nAD4P+8AGHgxGOq/bCiPNX9oA0CEA2lhqO3kPy8J89mvEOO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/mkIMt9tu5T+iGoSkXVzo
v93wTL/7ueq/m8Vn0rwQ8D83Y3fgoGLvv/ALx/PcKaq/2VoSsL7S9j9Rq43o
PDftP0BQWOSTM9M/AlhfuDhY8j8eKgJ/8enxP4RAiUBLiuC/rAQqrpuf/j+Q
f+JuGkrmP0mJ7eIUDdq/Cow0Lg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.2998185519699588, 0.4817070447779554, 
                 3.3320364882314726`}], 230->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/JFpMsSiV9j9AYoqED3DnP4zsQJcHNMm/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/5ZO1OH1w5D9w8XJKbMTsv5CdSkD51vW/FnSKtrHd
9D9MMLO/DeL1v3cVbb/mFck/SJxhiAxo9z9arbo8WQPxP+iSrNO0C+s/ZzEU
7tn+7D+b10M9uRr4PwG0Zct/BOm//FnI67h6A0AaneXwLq3kP3WhgAJ/bOK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/zcU7qh5m5T9tzS6Q5RXo
v2k9phOqzeq/+Lc14sgF8D8BhagqvZXvv6jS37Y/P62/NvvWnJr+9j963v/+
YLvsP8ZX3O2yvtQ/bDkr1EqK8j9ehMR/YOnxPyTvNbGBUd+/DoduRE3F/j+t
/7c6nw7mP5jcUOiAudi/tZs3ZQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.2803559735608174, 0.45308268423795667`, 
                 3.337741243615582}], 231->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/45aZh+W79j86mPxOOzbnP2rPPmIQesa/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/yF3xVANg5D/UQqk1wTbsv0T5Ow+H6fW/EvY5Bm7H
9D+SYDbeNhT2v+8uyR2/hMc/QZTHjyOY9z8JKCKApqDwPxmjhR9T5Os/YCL+
xZx57T9xQ5fbMjL4P8Ukj58D8Oe/Lp3CstSMA0DI0vdhlWnkP/lQUthbyeG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/v6pZuOFd5T8f9skFEM/n
vx2Zl+I34Oq/7fEaFE717z9HtStJ5sfvv9zPE33HMLC/kpWwiwQq9z8mdKAn
xDvsPz/v9QbPRdY/ClRM9Vm88j/Hx4pBqObxP5/YHriHjt2/oGiPdsfq/j+B
NXpY6M/lP9QE4vDfZ9e/4i42lA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.26088452986242117`, 0.4245298650126531, 
                 3.3430694961054583`}], 232->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/sZnMbmzi9j/ykSFeFPnmP7TiTvLkw8O/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Ljvz74pQ5D/ZodxAZqjrv3xwYeby+vW/62ZzQtCw
9D9co7HnaEX2vy1wRIRA7cU/7QwdxYXH9z8ad+Mm5jvwPyFoiezCuew/iM8k
9K/07T+tLy/GB0f4P53WBYTS2ua/qGL+INGeA0Dmxxz64CLkP3n+GRRTJ+G/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/cpnahSVW5T+ipWOL4ofn
v1UQvbmj8eq/xmJUULDe7z8R+KZSGPnvv6COmBZGyLG/T9P0GflU9z8TQPRV
cLjrP3Sv9a/JyNc/uoBvNGLu8j9T/J/6yOHxP0qPmcDLy9u/gK9kWAcQ/z/s
LB+s+o3lPya3rVBMGNa/vYg94w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.24140827496725098`, 0.39605363978783714`, 
                 3.348023828945687}], 233->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/TzvJZboI9z/8Vb92n7jmP+wHFWm7EcG/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/KCKQPhVC5D8qKuCFZhnrv46p82k7C/a/9UWzLtqZ
9D+vdg8GoHX2v4arpLmKT8Q/C+J3di/29z8wYpEYQKrvPz365pXzi+0/wISZ
3wlw7j+vIS9dNln4P2xQVxYCxeW/PuBtz6ywA0BIFc08F9njP4EThFhxhuC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/7wwprepO5T/KaeWtYkDn
v2dJTz3sAeu/0EGUPLrH7z+yZYK4pxTwv0ZTOOH7ZbO/rY4g7nR/9z8WXKjH
bzHrP0K4obuER9k/2P7Kql8g8z9WZkcMw9rxP2eSnPBwCdq/5n1SAgo1/z+i
NcZZ20jlP3xVyTLgytS/EuEuog==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.22193125641657072`, 0.3676589492113312, 
                 3.3526069579493183`}], 234->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO//fvjb8wu9z/8ypOf4XTmP/BTajCTx7y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/splwYaM05D8/VmArzYnqv2wD41RfGva/RAtZlY2C
9D/CZ8t22KT2vyaBxAC+q8I/hWZRAB0k+D+4pPdnuNjuP+RknbfUWu4/oGPp
6aDr7j9d/J81vWj4P9eafQCoruS/sBCRWWbCA0AyuA7rPYzjPxZ+dmKGzd+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/tEiZvjFI5T/Uf6UAlvjm
v0WjPigQEeu/Hwc6o22w7z88XuDwQyzwv6Z9GJrICbW/QbEauHSp9z/at8UD
zabqP2YakFHiwdo/5lZsck5S8z/u8LQCl9HxP1XlimaaR9i/rg6DkcxZ/z+X
QVHFjwDlP4mJSJe1f9O/0z80/A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.20245751030857342`, 0.339350618617697, 
                 3.35682172808796}], 235->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/d6QdlZ9U9z+KYPAg4C3mP3C2QfqJdLe/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ODf6ZDYo5D/KYwRkpfnpv9zu8HhdKPa/OGmDR+xq
9D+kIT2LDtP2v1FYDxb7AcE/WwjPzUpR+D/Yf82SRQPuPzzbwi9WJu8/Gmnd
b2tn7z/xTYwZm3X4P4XGLvfZl+O/coCRXfzTA0CKNAIDWzzjP4QG3COqkN6/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/dxdeQPtB5T+ahvccgrDm
v7WOTEwOH+u/E2VkVcyY7z8sOxn7XkPwv3ymzYSLs7a/aVZ2MfXS9z8x8N7Z
khjqP26kevDEN9w/giyGpiqE8z8bPwKVRcbxP1P9djZrhta/rlIgKEx+/z+K
SvmRHbXkPxA6NlHmNtK/SQAr/Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.18299105643797473`, 0.3111333549301635, 
                 3.360671109869815}], 236->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/tole4jB69z/4mlCEoOPlP8AJ13nFKrK/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/n7A6Qc8c5D8DyY5t+mjpvxiAx740Nfa/WgfsHPhS
9D9s7+GoPgD3v+a751nGpL4/ws8JWbV9+D+IYSA++CntPxrFxh9o7u8/UdI6
yl/j7z+ZexgIz3/4P/+bK7itgOK/SuVdfG3lA0Aq82q/dOniP05ErKpmVt2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/K1R+rkc85T82ubyhLGjm
v/EfI5LlK+u/NgPNKtiA7z8QousJ91nwv9gg6W0jY7i/vCy0HfP79z9Afjhh
zIbpP+Lji3APqd0/b/m9Y/C18z+KZCClz7jxPzd9ZmcGxtS/JSqN7YWi/z8R
x92himbkP18DkQSM8NC/K4E1Pw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.16353589348314587`, 0.2830117437484973, 
                 3.364158195513865}], 237->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/2m6xaX2f9z9SiuuTKJblP0DolYBe1am/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/YYTU2W4S5D83zPyP19fovy43DybkQPa/WrnC87I6
9D8vrKRJZSz3v4R2mtovOrs/prNUK1mp+D/CFOtb4UzsP9BF13Z9WfA/tOhB
J7ov8D8pyZY1WIf4PyWXjQg5aeG/qH7FWbj2A0DU5TKXkZPiP8T4g3jUHty/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/DD7Lehc35T/QuvMymx/m
vwfXavmUN+u/NrWjAZNo7z9yAE1aCnDwv4rDj61uGLq/QBGDSmsk+D+KT+v3
hPHoPxwtpQWlFd8/x6t5yJvn8z8pR8Y/NqnxP6n1lvCOBtO/FTaeDnfG/z8T
OI8V3RTkP8y1lkiAWc+/wUQxAQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.14409599425648922`, -0.25499024663080244`, \
-3.367286194929441}], 238->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/WwB+QoLE9z8INUBafkXlP4AP8nXA0p6/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/WDnt/RUJ5D8kT6UcSEbov079gsVqS/a/EjWIsB4i
9D86GyT8flf3v55whuF2xLc/Xb6B3TLU+D/QesMpEmzrP1CGpqL/ufA/ykHc
p89t8D8XO5cLNoz4P/VPFLORUeC/hDyTnNsHBEBIeuk8uDriPw7rP9kL6tq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/h5jXDGsy5T9H/Ed509bl
vyed3pgbQuu/7TBpvv5P7z/4t4wzl4Xwv3zGGSpL07u/XN//j1pM+D/s1wFC
yFjoPxK+zqC0PuA/EiEt9SgZ9D/OqlucepfxP3Hgw7YnSNG/sjzSvRzq/z+o
15RLG8DjPwYMn+A318y/7UwwUw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.12467530103328783`, 0.2270731985764455, 
                 3.3700584315113176`}], 239->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/a+TCiTzp9z9M/5whqPHkP0Cp5r6ASYS/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/cDcdaMUA5D+s31ZtV7Tnv5BVAsvHVPa/akroPT0J
9D/uovdjiIH3v3T9QoDgQ7Q/3/wlGD/++D9UX4IvnIfqP0ROugyzGPE/nwyM
j+ur8D+rUfMoaI74P/jk5Aybc96/vKqo7tUYBECq5j2e797hP57hF+EkuNm/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/k5fvwUIu5T+LxKAh243l
v2n1XZ54S+u/RUbJSx037z/Se3bnm5rwvxKAu1qWk72/pXD00L1z+D9Qr48o
orznP/GAPAsg8OA/hXinDJRK9D+o6OAcnoPxP0Ia3BLnFc+/eQ7FGboGAED7
cu3fS2jjP+gWD+dwWsq/HAg2vQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.10527772097370208`, 0.199264805716518, 
                 3.372478337761318}], 240->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/pVtPYqkN+D/cGKJzrJrkPwCTbN1Mu4Q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/uDphvn354z+IH3XjECLnv6q/oXv6XPa/LqCTjBDw
8z8GZfI5fqr3v8JjTKGyuLA/ZzPck3on+T/sgeU9kZ/pP4K/kVKQdfE/gxBx
Bgnq8D9ZnNVh7o34PzbQNKcERNy/up4Y/aUpBECy2XTjPoDhP5byvWo3idi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/N5kR7Z4q5T955K/ct0Tl
v4Nf/U6rU+u/CZx0mvAd7z/e3HPSFq/wv+zMNkotWb+/hscV+5Ga+D9kzcPY
Hh3nP6iYTOwGn+E/FDZgNNl79D9kVNNNom3xP55rSUAqnsu/RiYgVz0YAEBH
eYurdQ3jP/6N0gNd48e/czQw4Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.08590712165196918, 0.17156914321738698`, 
                 3.374549450748222}], 241->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+xlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO/m2389MUx+D9o+r4YkkDkP3BITIfasp4/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxv7PQbPX9E/5f8KFBxw8r/25FB/
o034P55rgfrGE80/snRlqEhL879+Hxok7JL4vzAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wmENkj/z4z+ElBXnf4/mv3BLuTMCZPa/nfgYk5rW
8z/0rmRMXdL3v2hHIAVoRqo/O1KGGeJP+T9w8CttA7ToP3NfVTaQ0PE/dPOL
NCMo8T/pJL2/yIr4P0mnFdiLFNq/dKVBeEo6BEAqmdlurR7hP1tQghVbXde/
54NOcX6B+b8uJuFmj+biP6utV1g2r+W/pIR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwK3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/vKzn1n8n5T/3HoBeb/vk
v0rrFAezWuu/ePT5oHoE7z/UAa1bBsPwv3p2ykz2kcC/619BB9TA+D9sdfXC
SnrmP5SQcqBbS+I/iDDElPSs9D8OUQ7miFXxP8LioC9eKci/Ie5fuZYpAEDJ
SczDn6/iP9SLDW0tcsW/kyEwFQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.06656732670615224, 0.14399015340201515`, 
                 3.3762754074184262`}], 242->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/8ZzlcI9V+D9o/aoXYOPjP7CHrAGjbKk/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/gNjBXwvu4z818xvmr/zlv9Rb8Wbeafa/+AC+Td28
8z9EvVt/Ivn3v0CB0V9YB6M/faWNgnJ3+T/6zawbBcXnPxenZ5+rKfI/A+we
QjVm8T+9sXyB94T4P6AFNkBc5de/ii/oE8JKBEBImircQrrgP763e0OnNNa/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/G+jBveUk5T9QTgNeB7Lk
v637TDqPYOu/0/yeW73q7j/8iCj1aNbwvz5PdEHYecG/N6G5+YDm+D+x5auZ
MtTlP1ULdbcQ9eI/ekSCWeLd9D84GKnGUzvxP6p0AODHt8S/AX8t5sQ6AEDY
y+p50U7iP8gmRuMSB8O/Qk42Nw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.04726211162103581, 0.11653164409283988`, 
                 3.377659939770453}], 243->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+xlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO/dx6hCwN5+D90GNm0HYPjP167dajVs7E/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxv7PQbPX9E/5f8KFBxw8r/25FB/
o034P55rgfrGE80/snRlqEhL879+Hxok7JL4vzAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/UiBhj+Hp4z+49VVTrGnlv5iYTaCObva/3K5Xvtqi
8z8Rzd/Myh74v9DsJfaNaZc//bohuSie+T+EomjsqNLmP/ar8prbgPI/Mm4O
WDqk8T/V3zUbe3z4PwntjnqhttW/pnlQhwtbBEAEnwEAB1PgPzmktBczD9W/
54NOcX6B+b8uJuFmj+biP6utV1g2r+W/pIR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwK3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/BIyR1dAi5T+RT6CUhWjk
v3I4qXM/Zeu/t6o4zLrQ7j/jkOobPenwv5ogDG4qZMK/umxh4pUL+T983aBQ
4yrlP6wHevUYnOM/VMbXsZ4O9T8INtH6BB/xPzF+cRCsScG/cYSQhsZLAEC8
W21aEuvhP2E1l609osC/poowUw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.02799519965594027, 0.08919728717907277, 
                 3.378706869906906}], 244->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/7o53AR6c+D9Yy+Zx0h/jPxKQw3nfpLY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/OfYHdMLm4z9Y0JalgNbkv6ANNoIScva/ui4i7JSI
8z+kdjBFU0P4vyBk0xIYPYE/Pvl1uAHE+T/eT5XFAd3lP9XWclwZ1vI/ostB
oC3i8T9jFFA2VHH4P3JI/RiHiNO/7C5YjSVrBEDgyG7OA9LfP+ZuXXQV7dO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/+PbkR0Eh5T/hvMC97x7k
v3mtkVXDaOu/lioD+nS27j+s5RJYgfvwv0Xk14zaUMO/FsT23A8w+T+bDb4b
an7kP9YPD1RnQOQ/SK3c0CU/9T8IvaG3ngDxP9rIGHWevru/MvsJR5pcAEDk
F48saoThP8IV2Su7h7y/I8cw4Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.008770257928365287, 0.06199061741040481, 
                 3.3794201049779153`}], 245->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/DSObld2++D8CRgYNhrniP6gV6k4Mibs/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/stcGTK7k4z/wVdJWOEPkv2J3fsZpdPa/ZWaY4w1u
8z+XTP8OuWb4v0DhqNu2RHm/veL9jPro+T/2yCTPIuTkP2qdPj5eKfM/jL8D
Rgog8j8NR2uxg2P4P1wk3KA4W9G/lMOP5A57BECM3IWsd/jePwx8A/lkztK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/tGfkMzcg5T+tf16WS9Xj
vzsX2pkaa+u/QGJ58e2b7j+mUPo8NA3xv+si3SjWP8S/5YJMEexT+T98hxVu
1M7jP8U+LQPv4eQ/THHP7XNv9T8HNfdbI+DwP+Q9Qxrr8bS/jaqu1z5tAEAk
mqTx4BrhP0TtkcpD2Le/Ao0yNw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.010409106336530732`, 0.03491503141814706, 
                 3.379803632030468}], 246->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/q01eEj/h+D821mOAQFDiP+mTbkH9L8A/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/qibdQKXj4z/h3Tfj3q/jv7y7az6Udfa/6A5LtkdT
8z/vuqhn+Yj4v2CPLh51ZJW/6QCoVBAN+j/gqEZxH+jjP380C8KjevM/EN9i
dstd8j+xpU6gClP4P2DCPw/DXc6/xoVTT8aKBEA0+CiRehneP/KazQA4s9G/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/MI9PrrIf5T+mQ5Hcnovj
v5VbxxFFbOu/wwosxCeB7j/SB09pVB7xv1xoUZ8KMcW/SieDsyd3+T+LP9X4
LxzjP/wGOWqjgOU/XpZgRIWf9T9mSEBwlb3wP+xcopuLW6y/TlZB7LJ9AEAo
KXzkfq7gP/qhLMByNrO/Bj0szg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.02953934938155748, 0.00797378696395962, 
                 3.379861512778233}], 247->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/eddpyT8D+T/Ip4YBCuThP+O3e7yklMI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/IO01Z6fj4z9v/UzIfxzjv9iOt9KRdfa/4Gi3ekQ4
8z+kIWujEar4v/BX/pwOTaK/HXIXP0Aw+j90x+RSC+niPxUwbpHjyfM/OuaR
YGyb8j8DE9NL6j/4P8BF5V5aB8q/iGLkk0qaBEBkatjfHTXdPyK7vaCkm9C/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/a/J7wbMf5T9s0xtP70Hj
v7EuE6ZCbOu/u2SYiCRm7j8sOzCH4C7xv2RKDiFlJMa/y6RABMCZ+T+etzWq
imbiPxKn/Sh4HOY/2t79FFbP9T90M0um95jwP3g3ponWyp2/IqdMPPWNAEB9
brl4TD/gP8R8/wlJRa2/MJ0vUQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.04861699431012668, -0.018829997584587758`, 
                 3.37959787830671}], 248->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/d2TyE90k+T8K5KwA63ThP/OFQdJM8sQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/lkDmvrTk4z9vJgiEJoniv8pDkoNidPa/jI4dTAYd
8z9qJpwt/8n4v8gu0zR7+Km/KRbcjYdS+j+a6RpY+ubhP5EHXH4XF/Q/V9pH
NujY8j/ZgckxJCr4PwCDpMeNs8W/Fl2AfJqpBED8L1lnc0vcP/Qz8EuBD8+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/JhxUbTog5T/sZ/msQvji
v6Pj7VYTa+u/Z4r+WeZK7j+QvUhM1z7xvz/lCLTSGce/UD3nULK7+T/S5mOs
8q3hP1A4pBhhteY/Zx8dpeL+9T/v+Q/ZTHLwP8ChX6weKGi/qcc8gwSeAEAI
fFm0pJrfPwRcXfNoOqS/8Q8wJw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.06763863428878568, -0.045493343553248064`, 
                 3.3790169237285412`}], 249->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/k2LtUhRG+T8ePSMo7ALhP+WAFkjGSMc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/WkXtMs3m4z8/PeuT3vXhv9DIomgGcva/yGZWSo8B
8z92OdyIv+j4v4DCeJ3z2bC/A1WplONz+j80rKmgAOLgP99zo4M5YvQ/+Pkf
LDoW8z8NL90EuhH4P+79X6yzYsG/grZ617S4BEAcdlFgjVzbPwgWIChD78y/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/iJ5Xp0Yh5T9U8+q0nq7i
v6lo/ju3aOu/o2I3WG8v7j8Wx+h5N07xvwawzDRAEci/y1vL8/vc+T+pdGZk
dvLgP/tDpkxSS+c/Rq6GPycu9j/OZncMmEnwP9gL2m5KmJc/5rN4gN+tAEAs
+EvYMrHeP4hUJoDzmZa/LDoxAg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.08660093555353586, -0.07201341203758155, 
                 3.378122902803857}], 250->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/lV1F7+Jm+T808pdbFo7gP0Z0sXLil8k/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/zNF1mfDp4z+gNx50s2LhvybPBLF9bva/QzypmeHl
8j9ZSUhPUAb5v3wzLCpcv7S/ZXuLuVGU+j/4j8kMZbTfPzKeZcVDq/Q/VnP5
eV1T8z8hvHGsrfb3P8gPSWpEKrq/4sNTd5jHBEAQ2txrfmjaPyj5tEa51sq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/weSbWtgi5T+FcAQlCWXi
v/9uYIQuZeu/HjiKp8ET7j8Hzx7d/1zxv0WM+VeaCsm/fWxoVJr9+T8YXf5w
JDTgP7rMuxNA3uc/dmifNCBd9j+e2h5t3B7wP8TYGXuABak/Vjl794S9AEA8
X4aRVcLdPyBOOEBt7XO/jL8uSQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.10550064021483045`, -0.09838750375999755, 
                 3.37692012254038}], 251->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/TbQNWkaH+T9sWmm3chbgP14azTlz38s/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/jrHZsx7u4z/R1omesM/gv5weRaPIafa/T/ygYv/J
8j/soakyryL5v1DKWXkprLi/Fakbdc+z+j/onDk3SZ/dP7QVi5Ew8vQ/aNlW
W02Q8z+lLX1EAdn3P/ij4pBelrG/FHHQMkTWBEBMhBiSWW/ZP9y1jH4Nxsi/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/otTNZ+8k5T8eQDq6hxvi
v3W+oHZ5YOu/KviBcN/37T9Qe89OL2vxv/rxxKvNBcq/sa6U54od+j/gKAZT
F+bePwC5xPgebug/2kay2smL9j/b2jGgOuTvP2LIW/FDFLM/naXrr/PMAECS
nHWAH87cPxAkA9oty4g/X1M04A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.12433456885712742`, -0.12461305871139591`, 
                 3.3754129377878646`}], 252->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/paq1DDyn+T/gB+AfFTjfP1hMwBtLH84/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/HIimLlfz4z87jvKJ4Tzgvy4VXJ3nY/a/gCDh0eqt
8j++8qP82T35v0xuPjANoLy/+0yyUlrS+j+s/QhT14TbP1qDNWD6NvU/fFC9
DwXN8z/7z10dt7j3PwBoFBLCFKK/XG4R5bbkBECgOqdAMnHYPwTkdQlpvca/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/6T80pYsn5T/Sm+4vINLh
vwe1t3CYWuu/WxzC38rb7T+6o8yzxHjxv/kafpnGAsu/0PuzL8s8+j/GgnQ5
dl7dP+WMrcPj+ug/kH05jiC69j/z0VVlvIbvP1gyO5camrk/1yG2dSrcAEBA
oUOwo9TbP1ChKUmIh50//eUxSw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.14309962292988487`, -0.15068765558222913`, 
                 3.373605745841155}], 253->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/C9U6icHG+T9Y64jhzj3eP2g5hZieK9A/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/pFKkoZn54z8iUidSo1TfvyZTphTbXPa/j0b6F6aR
8j86eeGOzlf5v0AeTTNcTcC/3SqY8O/v+j8opyNdOWXZP6ASLtSbefU/n2oT
238J9D/rBay70ZX3PwDdPizO3mC/9gaqbe/yBEA4iC1JHG7XP8Te+ID0vMS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/LSWz3qwq5T8+KX8/2Ijh
v//yAeiLU+u/akLbJYa/7T/4Zuv8voXxv4YOFWdxAcy/9H/pvFhb+j9ASVYf
hNHbP/pgT3qDhOk/1R8nsiDo9j/BQA50RSXvP667LPzgCcA/vrgjGSjrAEDI
OVuV9dXaPxgoI2CRNKc/B4YvSw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.16179278692782703`, -0.17660901098846443`, 
                 3.371502981065834}], 254->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/39haWtTl+T8URAE4Jj7dP9T46ZeOQ9E/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/kojdj+UA5D/DgHXTGDDevy6U25WjVPa/1Xk+aTN1
8j9ESz3jinD5v8rfa9btTcK/Dec1AI4M+z8w0bW5mUDXP/iGULsPuvU/oaz/
BblF9D/BBAjYU3D3P7DHdArdzJ8/2J62sOwABUDuGMbfK2bWPyRHLdvXxMK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/JMDP1VIu5T/mtNKftT/h
vwc0N2lUS+u/sHUfdxOj7T/8TxknHZLxv0tvpDi6Ac2/9l9ILTF5+j+iitv4
Xz/aPy0FS2HzCuo/wEItsMYV9z/GVQhm3b/uP09FkWhcQMM/pAXybuv5AECB
ruMLKdLZPwhVTamKhK8/uPQt/A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.18041113035928968`, -0.20237497849860792`, 
                 3.3691091095599988`}], 255->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/XH7EE3IE+j80M/oSLzncPxYksbdfV9I/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/CdqoZzoJ5D8bJ8dnOgzdvza2A8VBS/a/3DGV/ZRY
8j/gvusLDYj5v4DaHomTUcS/WBRCRjIo+z9ctd0wIxfVPzj18g5R+PU/VLRG
3quB9D+DgeNeQEj3P7xx5Nd+Y7A/Atbylq0OBUASZ26ZdVnVP+BFnGc61cC/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/4Gi1QX0y5T98HucEvvbg
vw9WX5jyQeu/uC12C3WG7T/KiXA73p3xv6bs/RGNA86/WkkDLVKW+j9I9Osh
KajYPz0+3/wojuo/WJkF+Q5D9z9QDqIjjFbuP4VAqm0/cMY/mIpqUHMIAUAj
TTRWUsnYP0wCxgeF2bM/GXYkkA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.19895180950234329`, -0.22798354746849056`, 
                 3.3664286238652714`}], 256->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/5Q9IUpgi+j+kGRTM/S7bP33Qv3X8ZtM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/0Iu0gpcS5D/0qajRHunbv+buaV22QPa/UQlPEM07
8j/G66AzU575vxxylRUlWMa/l8DtmtpC+z9Og1XrAOnSPyYZSvRaNPY/jvgo
t1O99D/hU0dwmh33P0xWAdk3ybg/ak/PDTEcBUAc22tqDkjUPwyUX5iF3L2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/w0E7zys35T8yf18f963g
v7+OxTBnN+u/LAUwHq1p7T8+IEtPAanxv3Q4OdjVBs+/Puiadrmy+j95zrRb
/wvXP0YNuhEaDus/OoS4BPZv9z9KWkzjWentPxAmAGxKmck/rqt5m74WAUBg
+j8bhrvXP/TWTx+237c/eGoofQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.21741206894929965`, -0.2534328416911295, 
                 3.3634660377395726`}], 257->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/GQMHvERA+j/IWEglpx/aP9vG6qNPctQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/dG8TJvwc5D9G+XTE3Mbav7YwjjECNfa/7jD5390e
8j/sQ7WdW7P5v87FrQt6Yci/UXwP6oRc+z/eyxVvXrbQP0Q/yrwobvY/txvA
6av49D8xE5VfZfD2P5heoFHdkcA/DhqHB3YpBUA6famkCzLTP2QDXgQuILq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/lbPqIF485T8GkxKcZmXg
v5DQ6QSzK+u/ySza7b1M7T9QTFWEhbPxvyaxoinABdC/tT8L02TO+j9TEi/K
AmvVP/rwxKW8ius/aI/jUnic9z9jKecoT3jtPyf2ukw+u8w/zU3FMswkAUAB
6/hk2ajWPwSMpkWI1Ls/f4osyQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.23578924294104572`, -0.2787211178693968, 
                 3.3602258810036747`}], 258->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/1eeiAHVd+j9Y8EpHQAvZP7NVnWlEedU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/6HZLgmco5D+9ZJDiiqXZv77AFCsmKPa/xaEwrskB
8j8cQEimJMf5v6zyG8Rpbcq/SdpMMy91+z9cTuE3z/7MPzy7hOa1pfY/oclb
1a8z9T9pskSzpMD2P5yo4DkwucQ/RLo0e3s2BUCKWQ72ghfSP3CSkKa4dba/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/T7cGzxNC5T/kbZkjEh3g
v5dgcP7WHuu/oJ0RvKkv7T9oyp4Iar3xv148vhe8iNC/D+H3GVLp+j/Dy53x
U8XTP6gQ7AAHBOw/u1j/apLI9z9/bhfFdAPtPwGqjYbc1c8/FxfD/ZoyAUDx
pKyeYZHVPy5i8n+st78/rMovsA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.2540807564934592, -0.3038467639196967, 
                 3.3567126944728587`}], 259->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/qZlr2SZ6+j8AGeS/3vHXP/B2eUXGe9Y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/WuJls9g05D/MwqS7P4XYv4T+s0ojGva/ZxJ1v5Lk
8T/tHWHCrNn5v8yjlWPLe8y/h2NCiteM+z9MsUtQkYjIP7rjgRz+2vY/Vxne
31pu9T8xIJ4kXI72P4JKOrpB2sg/5tHmZEBDBUDAt8xmivjQPxiXUa1u3bK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/CO2TZ0xI5T/QCr2z/qnf
v12eDx7UEOu/Qg5WzXIS7T9ROasWrsbxv6aonH9UDNG/mP7WMX8D+z/T+AS0
ExvSP3ZB4K3veew/gNmk3ED09z9xJpfU04rsPxhOS5FzdNE/XU/O6ClAAUBg
aFiTNHXUPyoRJZpqxME/otMyjQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.27228412631891313`, -0.3288082971152067, 
                 3.3529310249844}], 260->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/76+MCViW+j+0/UGAmNPWP1Qo8Q7Bedc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/BAcBwU5C5D/ODd/KEWbXv0xfIKj6Cva/crL7WjvH
8T+DrA2A8ur5v6yvAd51jM6/1/ypFnyj+z/UbOA5XArEP5yMFzf9Dfc/uWsX
dqio9T+v8G6fj1n2P+K5hmS/9Mw/dmW0xcNPBUB0kVSvcKrPPwA6iLgvr66/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/XX9hbgdP5T9RMFq7Zxrf
vyX/e3urAeu/Ta7caBv17D+cgIH1UM/xv56rNx5/kNG/Y1YbEOoc+z8PGplO
Y2zQP7HW03pt7Ow/1A3SP4Af+D8ccH+/dQ7sP6JCmmAQ+tI/t1495XdNAUA3
I/ZraFTTPxQh4Bfbo8M/TdAtRg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.2903969615465995, -0.3536043620775616, 
                 3.3488854205308707`}], 261->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Lyk6Xgay+j9GtELbg7DVP07X2Pcgc9g/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/oK1jnshQ5D/fmS51F0jWv16e9nGt+vW/E7CBysWp
8T/MJX+G9Pr5v1TC1fyfT9C/t7p/FBu5+z+AXDJMEwm/P874OzyvPvc/zb8h
DJTi9T+mFrxBQyL2P8fW9qYrhNA/8LzQowRcBUC41oIAR1vNP2CLdg31yKe/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/q9ISXURW5T9a9oGQaove
vzc+UkVe8eq/7qti2KXX7D9APbr4Udfxv90gIqUxFdK/8/FcuZA1+z9mS0+u
yHLNP6EuMnp3W+0/fvQtNU1K+D+3w4w4ZI7rPwrXZ0+me9Q/xOh26YNaAUDR
D8KtEy/SP+IFKlYCesU/Y3IwlQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.30841696424605375`, -0.37823372862611426`, 
                 3.3445804255085325`}], 262->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Lk7cri/N+j8umLaDt4jUPyjA8o3SZ9k/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/2QaSKkVg5D/2BoYHZyvVv/wjpO086fW/9IoeWjSM
8T/WESWWsQn6v6oRPSkAWtG/+CAl1LLN+z8wNuq85+61P0g91V8Qbfc/fnW7
HRkc9j8+sm9be+j1P+41pApcitI/ct6eCgJoBUDYWHfaxQPLP+DEfBS3CKG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/R/8powJe5T/lrK1ZEv3d
v9XD/8Dt3+q/zob/ZxS67D9GM42AsN7xv4jIVbthmtK/k7eAQXFN+z+6JfFy
cQTKP1LtUQMFx+0/1uFLZqR0+D9JWF08qQrrPwt7S0wX+dU/xIIG8UxnAUBN
Ink4TQXRP4wnY6u7Rsc/4uYr2Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.32634192975887377`, -0.4026952894941034, 
                 3.3400205760893917`}], 263->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Nck63dHn+j/QKZuKSlzTPysic7zCV9o/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/SjRkMMNw5D+0ER61FhDUv+ykTXeq1vW/NzgWWIlu
8T8+MsaIKBf6v7Azla5GZdK//8qCukHh+z8wsbn11o2pP/gOBQQdmfc/23eh
LjNV9j+j+wJuPKz1P4AuvXTIjNQ/eKHECrtzBUAsSAv9G6TIPyDPqCT53ZS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ABYTpkFm5T9Esnkwam/d
v8VEqUpbzeq/EjT3ZWmc7D96w935a+Xxv4vZAf4EINO/Gsrey4lk+z/2X1Jp
BY7GP4LXIbMNL+4/iCDuhYKe+D8XxqkQT4PqP1YomJhFctc/CQOx/NFzAUDm
zSCJWK7PPzmVKCrjCck/CCgqCw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.3441697468441779, -0.42698805792121924`, 
                 3.3352103957246655`}], 264->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/ce6m1eoB+z++lU5dVCvSP14qfc3eQts/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/FmSeZkGC5D/MZbqVPPbSv4T8s4H3wvW/DhurFMdQ
8T/Bc5dRWCP6vy4vRrVecdO/b3ooQcbz+z+AvEt2qo6MP9b1cLnRwvc/v8fo
yt2N9j9XUCQsi231P9gw38dIi9Y/Alk9ui5/BUBMq/jKeDzGP8Cf+1ZK4n+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/5i0wwQBv5T9Q3McgfeLc
v12cD1Woueq/6RaMIqd+7D87ZEbeg+vxv0pXWgERptO/cLRni9h6+z+i8wCx
yQ/DP21A0GyJk+4/GNtHUOTH+D/H9XdDYPjpP5strsoT59g/HWiIEhKAAUBk
68rCkEnNP987IaRVw8o/zE8x9w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.3618983976438483, -0.45111116513212723`, 
                 3.330154390786702}], 265->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/2TElj3gb+z/UB7zD7PXQPwt3mGsUKdw/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/eH0KcL6U5D+OlPCj7t3Rv1pDF5YlrvW/idXv4e8y
8T8f5FD9Py76v7u1YVUzftS/Y4lr9j4F/D8gexvki76Wv0zfhj8r6vc/3V9X
hxTG9j87all5bCz1P0849DS1hdg/QhNsNFyKBUAUaihGDM3DP0D+70gQd3I/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/lzrmRT945T+x8+InVlbc
vzTjcmnWpOq/ZNHQ789g7D9qHCO09/Dxv5AaaFF7LNS/nl3IwluQ+z9EoPQK
CBS/Pw79bFpw9O4/20g+i8bw+D8wbEiq52npP61XRtBkV9o/F1b/PQyMAUDe
PNDmctzKPwQ3vKzwcsw/XaUusw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.3795259574740507, -0.47506385771060294`, 
                 3.3248570463556057`}], 266->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/c8eVC3k0+z+o3QG9V3jPPwcXH6NRCt0/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/4luT2zio5D/8UXG7QsfQv+AkGFQ2mPW/IfWYEwYV
8T+xqkCy3jf6v9B7RJivi9W/Fb6DfaoV/D9gGi0uifmtv8IKvoQmD/g/UWu8
AdP99j+Bx51p5ej0P85+TT7me9o/Zm0tmkKVBUDQ7/MLB1bBP9DhDowP5JA/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/zKmqe/yB5T9oUqMzAMvb
v7nEcyfnjuq//PB5IeZC7D+z/5oOx/Xxv5t92XI5s9S/xMKMxBGl+z8Ql3Zx
9fm3P4TQhe26Ue8/YhmpBiYZ+T82Az5h8NfoP+pKtvAbw9s/kCj8j7+XAUC8
5npkL2fIPyQF4JuSGM4/JcwxJg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.39705059444989294`, -0.4988454948788167, 
                 3.3193228221560633`}], 267->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/+GrcV+pM+z8QqhZKVPzMPyzoo+OE5t0/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/HZdhJK+85D8ENagunWTPvyx2l3ErgfW/wH7O/gv3
8D9CAlywM0D6v4a2OHq+mda/jn2mjgcl/D8w+xvd1VS4vyJL1KbAMfg/0sdH
4RQ19z8+S/1A+6L0P5DXt7q0bdw/FProEeGfBUAwW7WiNK+9P/AdaM5a2Zw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/accRoDeM5T+rtpQhhkDb
vwUW80Tcd+q/mnqvDOwk7D98q6iN8fnxv/aa0+NAOtW/Q3RB8/i4+z94rIhb
6dGwPy1Fvd9hq+8/ZRmSnP9A+T+AIEDKhULoP97fLc8cKt0/yJfrHiujAUDU
q7hN9+nFPwtqipAatM8/txI0Fg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.4144705689504537, -0.5224555456914199, 
                 3.3135561486490865`}], 268->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/cUsHjMpk+z+86GLHAHjKPwU5UQGdvd4/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/hNX5sR/S5D9Mx8qgTz7Nv8YQlLoGafW/yF39+QPZ
8D+7Mk5RPkf6vwCeGexKqNe/VVsg91Qz/D/mJj4hjtvAv6KYB/P2Ufg/qczg
1tVr9z+UHitzs1r0P9pyidj5Wt4/PDmixzaqBUB4lFe+76O4P/iMfJBbPqQ/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/nebd5u+W5T89Wx2+8rba
v5+w7423X+q/o1neB+QG7D+4wyHedv3xv7MOxByHwdW/Y9OTwQ/M+z+sg0lM
5TijP3LzrRmvAPA/DQx0MVBo+T+rexeMs6nnP/BV7WxLjN4/eu/SBk6uAUB8
WUdT/GTDP1JlsDm0otA/2g4zrA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.4317842329316394, -0.5458935861537936, 
                 3.3075614232826855`}], 269->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/FRh1yxd8+z+AVYVzj+vHP36SPzaJj98/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/qKZc2Ijo5D8I8u62xxvLv7bzBhHKT/W/urmoXPC6
8D+hiYUI/kz6v47U99Q/t9i/CwRtmZFA/D8AlWs5bpHFv1TuS+bGb/g/s098
nRGi9z9h2hSjExD0P4JnVJDHIeA//B8J7UK0BUBolEgcpIqzP7jniRee5qk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/L08PeiSi5T/sZabDUC7a
v4+TYuR6Ruq/lbWJatDo6z8rb725VgDyv/opM5EBSda/EA5xslTe+z8ABM7Q
CdGCP3rp7ZnUKfA/5LN4tBSP+T8RhYWRhQ3nP8EwdCuM6d8/A9ZhaSe5AUDa
z9TAcNjAP7pnmHwuZtE/76cvTg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.44899002909461583`, -0.5691592962738239, 
                 3.3013430069047205`}], 270->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Iyv6RNCS+z/A7SMvM1fFP09H4pEcLuA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/SOMn2Oj/5D+ST2wPMP3Iv/qtvWx3NfW/QjY7f9Oc
8D85UD5jclH6v8iQvhOIxtm/L4FNbbxM/D/2K1EurUvKvy5vfS0ui/g/teFx
+sPX9z9CAnKiIcPzP2ZMxjynE+E/MC+KuQS+BUBQ/gcMb8esP2hk5AwEZa8/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/f+30edSt5T9OvcXZqqbZ
v9NNGUAoLOq/HTIcjbPK6z930hnnkALyvxeIlrCl0Na/KdYjWcbv+z/Y+LT8
59GTv2pJNzseUfA/bAa2H0q1+T/6f1YICG7mP9pJVOfhoOA/YaIDbrbDAUBU
7SXyDom8P5aNsNJsJNI/fbMtRw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.46608648991767804`, -0.5922524570563465, 
                 3.2949052203404783`}], 271->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/EtAEM/Ko+z9ARvR4H7vCPyzR3GnOkeA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/cZC53j0Y5T8gs/r5suLGvywVM9sQGvW/ICHYuq9+
8D+SvosIm1T6v5Zq2YAO1tq/PNTcf9RX/D+mE+qf7AnPv87OjqUqpPg/UDvQ
vegM+D+H2U9x43PzPy0gGhUJA+I/khdeanvHBUDAOS6qIV+iPwwLYeKPXLI/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/FMQ9/f655T8yVmmUCyDZ
vwW1jq7BEOq//By5yI+s6z+kicA5JQTyv/70I+doWNe/J9JwWWMA/D/MmutN
mp2ov7KbPu2IdvA/sYVqeO3a+T9PYm5gR8vlP6x4e79rSuE/zj/wQfrNAUCw
1H/j51K3P47yKGZg3dI/Fe8x7Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.48307223655958814`, -0.6151729474490911, 
                 3.2882523411368716`}], 272->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/IqLA23u++z8cjrdpiBfAP4Zg3VzS8uA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/00JUBoYx5T90gGV0eszEv2RLZn+Y/fS/tpEsaYdg
8D+36l65d1b6v+ap2u+95du/juei89hh/D8K3Cbv5uXRvy76s1u6uvg/KtSw
wntB+D8dm5k9XyLzP4KDjG7a7+I/CuqYQqbQBUAAWd1Yv3SPP6gbym9D8bQ/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/RB0LEaPG5T+HCQRzfZrY
vz3rwVJJ9Om/kI0Nd2eO6z+2HyqSEwXyv6aUpJ5A4Ne/2MSxZyoQ/D/4KZZ0
RbSzvzhVEcURmvA/Jrs4z/v/+T/hjNBKUCXlPwTytGVW8eE/jp08GPLXAUCs
Y0Vf1A6yP/uj1sr6kNM/pIc1aA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.4999459776424762, -0.6379207412488959, 
                 3.281388600474435}], 273->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/fQA5kWvT+z8oHVVgRdm6P0dgLtogUeE/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/fP9EVr9L5T+wZkUnsLrCv5QXsJEQ4PS/0n1A5FxC
8D+Hs4tQCFf6vxb2ITGB9dy/edOlAMlq/D8SAon4eEjUvyL9iI3bzvg/eZ2K
73h1+D/iHZ1im87yP5Sli9EI2uM/GtM4i4TZBUAAfx5mpex1v6BXKSlpcLc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/mXsDub/T5T8WA7zfChbY
v263C2XB1um/rXkh8jxw6z8ehMDdWwXyv746SD8iaNi/+2nvSBof/D+QdedA
TyS7v6IWUP21u/A/+85hQHIk+j+1b6K4L3zkP+4C3dWUleI/rKnqKZ3hAUA4
NfMJe3qpPzuLU/8tP9Q/1tMtFg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5167065079224262, -0.6604959039764484, 
                 3.274318180247751}], 274->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/hZV6sb/n+z/g8NMZR3W1P/uyLYeyrOE/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/NpcKw+dm5T/ov8Bifa3Av6yTll97wfS/bMdHhjIk
8D/CpsvCTFb6v1ZFgxNDBd6/h3Z59KNy/D8WolnPfKzWv2AhNamM4Pg/59mD
Ntyo+D/s7otonnjyPzrsJ/uBweQ/RGA0kxXiBUAA5UBYsOCav/SNQjfP2bk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/dkdm71Ph5T9k2ZouvpLX
v4Yz8jIsuOm/R8MolBJS6z+8feAW/gTyv17ieDAD8Ni/Bgb60jEt/D/epeQI
K0/Bv279ZfZy2/A/tjf/801I+j/6LSna8s/jP5rPKkEaN+M/g9X4tfrqAUBA
b4cHNnqdP7oEFm7s59Q/QEc3Aw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5333527068558719, -0.6828985897276533, 
                 3.267045210314283}], 275->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Ke6zpnb7+z+Qo5acgQOwP5KB3z+ABeI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/FHl+Lv2C5T+QraU2Fkq9vww0n0vbofS/5kZzqQoG
8D8d4r4eRVT6v7rq7WXuFN+/IV9NMml5/D+jjQC6whHZv5pEik3M7/g/9wvD
laHb+D/A6/gDbyDyPwSBgN4zpuU/IE6Ir1jqBUBQ+TMWRTqovyBgBHVFLbw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ZTggpV7v5T8cX7+coRDX
v+bT+h6MmOm/wUJUt+oz6z9pG9pE+gPyvxA1rtnYd9m/paaA7G86/D+/5NpS
4hDFv7ICvTZG+fA/EH07Hoxr+j/5VcIdpyDjP0sBMA/a1eM/miJxAQr0AUBA
N+WL+DJ/P5YNgO4oi9U/afYrnQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5498835370698741, -0.7051290380093286, 
                 3.259573765911053}], 276->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/VR9V544O/D9wWKswwwilP0LHfBeDW+I/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/bPn+Z/2f5T+QozTNA0O5v6YrH80ygfS/MKuDT8/P
7z9R7+qM8VD6vzHRifw2EuC/Kwb5Mhh//D+U/MflGnjbv+xiIEqZ/Pg/CfW+
F8UN+T9yZlIVFMbxP5KnK6YMiOY/Xt5EO03yBUCwuHkFQo2xv3xeSXOdar4/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/kXjgwd795T/cPZFPv4/W
v4DLeqDjd+m/c9GitccV6z8DIvB7UALyv+QQQaOY/9m/wBInjdNG/D+GkbJ/
AtfIv0Zj72otFfE/LwqK/ymO+j81wdcuWm7iP2o31N7HceQ/BLd3V8r8AUDg
MZC0gSOMvxLz5cXWKNY//7ExFw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.566298042744253, -0.7271875705664949, 
                 3.2519078652381324`}], 277->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/i3Yu9gYh/D9g7HQdU+GTP1GP/Vi0ruI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ogmbLOa95T9QCF7wE0a1v9wwCnCEX/S/fLiitZeT
7z8om7dPUkz6vyO9h1DWmeC/HVkGhbCD/D/jPJdqVd/dv7hTbZ/yBvk/c56N
00I/+T9u3liolGnxP07AmrX6Zuc/ULSal/L5BUBQh1/2HQi3v/R+Oz7VSMA/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/rIAuJNMM5j90avZTIRDW
v7bQZUM1Vum/GViy6Kv36j/ud1bdAADyv9b8Pvc3h9q/1GeavVtS/D8d7r84
QKHMv7AN9mUmL/E/fwre5CSw+j8fss70GbnhP9AnTIfXCuU/y/dYCTsFAkA4
TAIvyQ+ivw5vjKjpwNY/4fAvBg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5825953479134263, -0.749074588208144, 
                 3.244051467207392}], 278->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/cjOOYt0y/D8AXihAwwZkv/rZnocN/+I/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/j10/J7Xc5T8gyP48llOxv46mv9TSPPS/4dFfN3NX
7z/Zx2nDZ0b6v447hptKIeG/+JK6zDGH/D/ghlcnoSPgv/y22H7XDvk/nGYy
7RZw+T9CWJLz9wrxP2zcearsQug/QDfnK0gBBkDwN6j4SI28v7gP/csgUcE/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/oqqAoToc5j9ugoqd0ZHV
v2hGG6iDM+m/y+SQqZnZ6j9Hji+XC/3xv0F7PUKsDtu/NWOklwdd/D8+r5fq
pzfQv/wRVCEvR/E/B03gJ3rR+j8TRPKR9ADhPzNbDBn9oOU/fCiXblsNAkDg
eqkSfy2tv+gdnrpVU9c/tmcunQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5987746546956553, -0.7707905676379215, 
                 3.2360084693545703`}], 279->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/EUhdyBBE/D9g+UZYPROZvxUeZF+ITOM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wPrk8Gf85T8wj9f+steqv64t1q8gGfS/pqBZhWYb
7z8XOxxeMj/6vwfqdU2JqOG/lWMdxJuJ/D9YrTPF2Ffhv4oRzEpHFPk/Hwzr
lT2g+T+9X7pXRarwP0zHCl7RG+k/ennAZU0IBkAqk7JsKg7Bv9Rx0MYcTsI/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/O3lTBhQs5j9dItgF2hTV
v4jNMYPRD+m/LsyNUJO76j/mx4jkcPnxv7opLfTqldu/01U9RtZm/D8j5fWv
ciDSv0oQP71FXfE/GCokLyfy+j/XQ1li+EXgP7Byt94sNOY/wY735CoVAkBW
crsXkjC0v4o6GJEP4Nc/Ev0phg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{-0.6148352414571698, -0.7923360582956027, 
                 3.2277827059123565`}], 280->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/dR070J9U/D/wJOeMDOqnv0xdlNUel+M/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Yi7BEPwc5j8Qs5laVx6jvxyj5clw9PO/ZrtTTnbf
7j9SaLavsjb6v0deddqHL+K/VWT+Ou6K/D9gBveFOYziv+oWv5ZBF/k/ybB7
DLPP+T9Jvy5fhEfwP3lqe+aX8ek/JqMAuQEPBkCyDzpQadrDv4TDaHS1P8M/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/DJNBFl485j+bRJRLRJnU
v/ZCQZ0h6+i/jtkKNZud6j+E3lUNMfXxv/qdLIHpHNy/5cCcBcdv/D+veMVO
2grUv8iixIBocfE/H2dbbikS+z9CDI/1ZxDfP+LjB15bxOY/8BiP0KgcAkDu
2HNz7NS5vy2OrjIMZ9g/yH8udw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.630776460918424, -0.8137116792146186, 
                 3.2193779460418983`}], 281->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/YVqYL4lk/D9gVuJcabCxvx7BMhnL3uM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/YuV2/G4+5j8gyyF+Z/eWv0COT//FzvO/NCvZPqej
7j8AOOFh6Sz6v4Gvo7s7tuK/P9r4FimL/D/0UoNdq8DjvwogQCfGF/k/m855
nXP++T+C8LF6ecXvP1dxN5gvxOo/BODQn2QVBkCIUpNMKavGv34Dz/3XJcQ/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/jG4cjBdN5j/Dt9sRGh/U
vxouq9J2xei/dZFNrbN/6j9aRmtmTPDxvzTvWmKdo9y/UJpII9l3/D/AnR+J
uPbVv0zA7NmVg/E/fhSJZn4x+z+2pRVPbI/dPzoZtVh9Uec/mobOm9QjAkC4
fQT7XYO/v/6BphhB6Ng/NxkxbA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6465977382094548, -0.8349181159002178, 
                 3.2107978922199463`}], 282->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/VarQqMtz/D9QxRAshna3v4C3cpOHI+Q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/xGNJGL5g5j8ANAnEBIN/v5gEBkAjqPO/Gh3fAP5n
7j+2zPk31yH6vyOc8m+aPOO/u8R1U0yK/D/fLmU+FvXkv9zN+PHUFfk/+RiW
o3ss+j+gDymc7PfuP5sSNQeIk+s/QM+zmnUbBkAQ9HstMoDJv5wp2nByAMU/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/va0FGj9e5j/Su3LfZKbT
v3KkYRPUnui/aIpQDt9h6j+2kHdRw+rxv9bbqRb8Kd2/iDcj/gt//D+JR+cD
5+PXv84U2V3Mk/E/p2EzpiNQ+z/29qbWGwncPw7lU82H2+c/NRKOt60qAkBc
K8Khup3Cv+dBqS+kY9k/4gMwHw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6622985688809595, -0.8559561172320007, 
                 3.202046178778712}], 283->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/k4JDC2aC/D8YCJVw6Ua9v6yFJ+hOZeQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/flZQt+aD5j8A/OnxWxh8P7IGUY+LgPO/TMdnO38s
7j8cRwIPfRX6vxM7+HyZwuO/VzmsAViI/D/0OLQbYinmv7rXrh1uEfk/N0Tl
h8dZ+j/aCCQqcibuP9/kPAiRX+w/inSPMDQhBkD2YihpS1nMv0RnlcFzz8U/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/GieJadNv5j9y1QYeLi/T
v4ymrGI8d+i/gd+Uqx9E6j/ozfs8luTxv8Z6ryP7r92/9d13Bl+F/D/32cZJ
P9LZv0hN4cgKovE/ZWOUyRZu+z/WZxH8lH3aP0Y1MvhvYug/6poYmzMxAkCB
c7kQYH7Fv33fjNgr2dk/zBErVQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6778785168773254, -0.876826492393374, 
                 3.193126370595647}], 284->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Y+NrM1eQ/D8Y2vKMj5DBv71IL/YbpOQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/QjytG+an5j9AdviO97uVPyhbkgMCWPO/Ioklki/x
7T/7iZDd2wf6v30owG8uSOS/CwygSEyF/D8KMfPqdl3nv1wFQQKSCvk/760n
wlOG+j9cQG56GlHtP42lLLI6KO0/kKm27p8mBkCYj6wkPDbPv+p0lMvLksY/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs//Jm3G9OB5j+45XIZf7nS
vwL77dayTui/bMDz1ncm6j9Y70Kkxd3xvzBodxaQNd6/t/cFvtGK/D+Q5y/O
msHbv91UrP5PrvE/qcjJelWL+z/WiTGX9uzYPyX3LVQr5ug/oU02xGU3AkDY
tM/YZWPIv/hlFOnOSNo/2EA1Ag==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6933372124773154, -0.8975301078288821, 
                 3.1840419619305997`}], 285->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/nRP3Cp6d/D+eY7MpWYLEv6Rb2dfp3+Q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/1CDCdrnM5j/gP1Fu3R+iP1DsB8aJLvO/PE0epRO2
7T+o/7qz9Pj5v6cdnN1OzeS/ZcQeZSmB/D9I5e+lPJHov8BUoChBAfk/Y+AP
2Ryy+j/kOPcv9nfsP2PYNF917e0/Vg/yaLgrBkAGdTWcZQvRvxzRNVNrSsc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/RQxCyTyU5j9slQX/YEXS
vyqMY5k6Jei/eSJw4OkI6j8uKlgPUtbxv1pdU4Swut6/AewKuGOP/D8vvlzw
0rHdv0mBRgqbuPE/AHoDct2n+z/9X4rlX1fXPwQah5uvZuk/ksw2t0M9AkDV
Jg8xkkzLv+vPpqyEsto//zEuYg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7086743502074943, -0.9180678842283853, 
                 3.1747963754084134`}], 286->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/0FTaiDmq/D/y9sLGlnjHv2oaSOOzGOU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/taZp6V3y5j+wdwiSH0ipP3KtjBImBPO/+zRPEDB7
7T9fYgO7yOj5v6bj82TwUeW/uN+6qe97/D/7yaJMm8Tpv2RMxUp89fg/kOuH
Yh/d+j/0doY5FpvrP/wmEa4xr+4/dH6IOX0wBkDvrUSaX33Sv1jY0gZE9sc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/Nc+VAg+n5j/vIcrc3NLR
v0xN6OXW+ue/WJYIFnjr6T+KW/wSPM7xv1gjqwtSP9+/RJpKmRST/D+3h1P+
wKLfv8ysNB7rwPE/MCCxdazD+z83udWH8LzVP7OgrMjy4+k/btT6/sxCAkBo
Kab9qjnOv4DQ/OREFts/WFY8Dg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7238896867325159, -0.9384407935332564, 
                 3.165392961146368}], 287->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/RY5nsSi2/D9kr3JDDXPKvzX7zap1TuU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/yFowhNAY5z9gd7ioGSuwP1gMWDfa2PK/fJRQa4lA
7T8uiT82Wdf5v56QFK4I1uW/t2DFfp91/D8sFg7nevfqv8B6oVNE5/g/a471
A1gH+z8eemnQi7rqPy9oO4Ngbe8/2PVGAe40BkC98bUy7/DTv0qe3X9Ilsg/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Pyn5T0i65j9+mtOg+2HR
vzKsswqLz+e/GUaJwyTO6T/ybppQhMXxv1HQy1Rqw9+/fncWGOSV/D8CYfUb
H8rgvy08hJQ/x/E/WI6uWsDe+z9Gzox/yB3UP7KxBBfrXeo/fV79LAFIAkC4
pDfqOpXQv8hixcoHdNs/rckwGQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7389830387251143, -0.9586498559548424, 
                 3.155834996027891}], 288->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Ru1glmrB/D9QScoqgXHNv9T1Rf0qgeU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/g02PRw5A5z+AcADrxaSzP2L0u5SprPK/VUb6SCQG
7T8tO4CBp8T5v5f//muNWea/Dq1FYjlu/D/qPxyHwynsvxwkDV+a1vg/OCt9
csMw+z925ht3aNbpP32bDIX5E/A/KAeIZwo5BkA+PBps92XVv2xx7ENsKsk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/nKKoMefN5j9am4oYxvLQ
vzyUF2hao+e/BR9eMvKw6T/xxzp2K7zxv6UfW4l3I+C/Kk1T/NGX/D8faefo
EcPhv4MP2O6Xy/E/PwxvBBf5+z8iVGksCHrSP2eWrwOP1Oo/5j5c2d9MAkBz
sL8AXA/Svy8SQQ7Gy9s/eFAqFQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7539542807164693, -0.9786961369856828, 
                 3.1461256831281568`}], 289->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/F3kLV/7L/D98iBVc2znQv8MyZ+bPsOU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/6uwnJBRo5z9AoGgvzxC3Pzho4ZyXf/K/Il4INwXM
7D8qC/YRtbD5v4NyNV103Oa/b7nv571l/D+Wsn1KXVvtvzggsbl/w/g/PYFD
c15Z+z9O+en3ve7oP+YAElttb/A/fMA6GtI8BkBM76MvW9zWv9T0ssWjssk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/UPL0H+rh5j9ilf3vRIXQ
vxIIPXBIdue/7CplqeKT6T/wr3U+MrLxvxtZ9gHrZOC/Q5l9H96Y/D9qO0R8
Jbziv81cctbzzfE/Kn0nZa4S/D8QNd9J0NHQP0iaRU7VR+s/hD7gomhRAkDk
u9xFG4vTv/jv09d4Hdw/arEzow==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7688033429241059, 
                 0.9985807443684545, -3.136268151304231}], 290->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/M5lAIOPV/D9ug/ztuLzRv1r7E69g3eU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/+BoB+96Q5z/Q0bcl8W66P0q3g9OnUfK/GkHAvTCS
7D+oPdR1g5v5v61OiEyzXue/+4QYuS1c/D9MmoVcMIzuv3bp7OD1rfg/Uyeu
2yWB+z82ZI1jngPoP169BaIEyfA/iBLpzURABkB8hmtL/VPYv4i86GXkLso/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/V4lhi0/25j8wrzOxgBnQ
vyRX36ZYSOe/aBzBbPh26T8uyWRwmafxvzDHn3kKpuC/F4+sbAiZ/D8C7sFp
RrXjv5JzOxxTzvE/Q2D3fYQr/D/8RB7Zg0rOPwu7j/m0t+s/ka8EL5tVAkD1
BLQcWwjVv3wqjsgZadw/ZpAyCA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7835302090479922, -1.0183048249569837`, 
                 3.1262654549763584`}], 291->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/k4x+LBjf/D8Q7yQgO0HTv9Lko93ZBuY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/XHvFnWu65z8I3kKT6L69P4xUqs3dIvK/niuWX6tY
7D+puzFUFIX5v43j4RFA4Oe/7+SolIlR/D8mnwX4JLzvv4DfuIL+lfg/6cGi
kRao+z/qqcQPHBXnP0ApaV24IPE/IrO9PWJDBkAtaLZ0wMzZvy5aHXQkn8o/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ibnD3BUL5z9SmwSHA1/P
v2b0BaGOGee/qhGsvTVa6T8viJPfYZzxv6CRTNzQ5uC/wbiT4FCY/D9XCwxE
Ya7kv/Roxbi1zPE/PqcQX5dD/D/EZGT//OjKP6kbO0wlJOw/tnz+KXdZAkCe
q23K/YbWv147q/qirtw/R+Uz1w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.7981349140131053, -1.0378695613449067`, 
                 3.1161205741541873`}], 292->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/XdD3w5zn/D+WusymQ8fUv2swKTY4LeY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/CPQCz7bk5z/oYBWsOYDAP+pTYTE98/G/FivTmHkf
7D+UFOhsaW35v/ErEZMQYei/i6EOT9JF/D92NZS0kXXwv9q/hH2be/g/g+/E
iy3O+z/KGeWVSSPmP7KTcraBdvE/VHuJKypGBkCepT9Kh0bbv9bJeS9bA8s/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/33VidTsg5z9gosrVoI7O
v8TzvATu6ea/ZpFK2pw96T+ktO5rjJDxv9I15Bw5J+G/9DiDibeW/D8cZEee
YqflvwisTMwbyfE/8F/eJ+Va/D/8eP2ET3/HP+grh9Edjew/wbHCRvxcAkAa
MIZ45QbYv+CiBwIP7tw/AHEzbQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8126175416111245, -1.0572761680147642`, 
                 3.105836414818705}], 293->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/PnWhPHDv/D92tsEXtE7Wv0pbsbp4UOY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/OVtrQr0P6D8QVEI6qBnCPwKUcLXJwvG/t5I735/m
6z/ckXCYhFT5v+l5k8Qa4ei/TOUr0gg5/D9laqUHigzxv+pWEuDOXvg/Muey
0Wfz+z+mhWfROS7lP3bJlfxZyvE/tkDIX5xIBkB/fYJWNMHcv6Yvb8eAW8s/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/d6kWr7415z/MKLSO6cHN
v9wzzIh6uea/NsV+/S8h6T9I87IBGoTxv85cpTU+Z+G/Ra1mhzyU/D8C2JUN
N6Dmv0iCtZ6Fw/E/OC4qB2xx/D/UVA2Lvw3EPxt37lmW8uw/qn0MPypgAkD6
GSI39IfZvzQnjexYJ90/VCsu0A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8269782219367892, -1.0765258864847427`, 
                 3.095415809898648}], 294->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/4GFA+pH2/D9jv8DsbdfXv/fYgKuYcOY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/U04WnXs76D84v7UGoKvDP8SZESGHkfG/o/K1oSKu
6z/+Xr/HZzr5v4/9XKpUYOm/DgBFHS4r/D/Hxmmv76Lxv1ZsTOmaP/g/9MNA
fMIX/D+Cz2/e/zXkP1qgCaY6HPI/wCmlqbhKBkBscgYSqjzev6zYUlyOp8s/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/BCNs3J1L5z84c3qo7fjM
v545bfQ3iOa/LPW7XvEE6T/aWVqZC3fxv6EeiijbpuG/97DCC+CQ/D+g9pkq
y5jnv2lshp/zu/E/6pJAOyqH/D+i3x7QkZTAP9YMyvuGVO0/WK1i0wBjAkDo
mGP/CwrbvyKPlUJ8Wt0/ICY2Ew==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8412171283757545, -1.095619978260181, 
                 3.0848615213919097`}], 295->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/zIF1bgH9/D+0GdeFUmHZv/rzSYeVjeY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/KSzEde5n6D9wWP24ATbFP9wjpEt5X/G/45fyRwZ2
6z/kyBwEFR/5vysXoFi03um/CH/sREMc/D8QlITxtjjyvwruGQgCHvg/mHiy
tTo7/D8ubE8YrzrjP9J8SlAdbPI/kHz+3n5MBkDtx6zlyrjfvyxz5/9958s/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/8BHDSNdh5z+cplbPvDPM
v7bD/x4qVua/zUfaMePo6D/MDok3Ymnxv2+rq/8K5uG/agCxWaKM/D99WvqS
C5HovwR032VmsvE/Mv0TEh6c/D9QfY9VFyi6P8927xPosu0/u54cy39lAkDQ
8MG1Do3cv8XQQwd1h90/yT8xxw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8553344735247765, -1.114559712577614, 
                 3.074176245028739}], 296->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/iN/IGL4C/T9ozcUrQ+zavxjQXgttp+Y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/hy0iVRKV6D/00xiQrrjGP7B7YRykLPG/m5wTMk8+
6z+jl/xujgL5vwFlk/QvXOq/xpvtckkM/D+MLPMf1M3yv0pdLdsG+vc/jGf0
uc1d/D/m+AIYWzziP6LHmcD7ufI/BOho3O5NBkDum3+WvJrgv/hy07VKG8w/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/nhJyOGl45z/a6MhjZnLL
v4obve9UI+a/KMrqpgfN6D8s9vjsHlvxv1pSpc3IJOK/pz3bxYOH/D/mn+Tq
5Ijpv6tibrDepvE/iqNe6UWw/D/ISIAI5hizP64vSUayDe4/5Ktm9KZnAkCi
gmIs3hDev9as07g/rt0/3tM4SQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8693305022540899, -1.1333463402619013`, 
                 3.0633626215101613`}], 297->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/J6mzhscH/T9002YSIXjcv2yK3jMdvuY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/wpYPtuPC6D9c1N9kiDPIP/iJDooL+fC/yI5VuAEH
6z+YhdNB1uT4v3V9NrW92Oq/JwM15kH7+z+1JPaZO2Lzv5CB0DCs0/c/95nS
1nh//D+KAauyFzvhP5BJeuTPBfM/wkYyhQhPBkAA2T+cS1nhv+SYBHTwQsw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/PMfo6FGP5z+maGV5+bTK
v9Ipal287+W/P8ML6mCx6D8mbWTWQkzxv5Te9q0PY+K/J1Z0toSB/D+S2Y/e
Q4Dqv2PjX2VdmfE/jyHDLqDD/D+AvrxLOfinP8aOaX7eZO4/qw1GJHZpAkC6
QnMlXJXfv6Ww31DZzt0/AHg1Nw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8832054757128789, -1.1519810236748762`, 
                 3.0524232682843597`}], 298->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/sR6pUx0M/T8O5BNbzQTev9hz3Tuk0eY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/5PzjBV/x6D8421uscabJPwa1rJqzxPC/7rS4KiLQ
6j9z1+rN7sX4vxtGFeRTVOu/5/a38i3p+z+ia/nM4fXzv4plrAb1qvc/Z5Iu
bDmg/D+WFgD4+DbgP4BjKdKTT/M/Itxjw8tPBkAEfPynAxjivxqWACNsXsw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/TfrSkI+m5z84ZafVhPvJ
v+BUCG5ku+W/UlY9I/GV6D8UFnAczzzxv+dCZsXaoOK/zIowo6V6/D+mZL4j
FXfrv7uPTZLjifE/jNjrXyvW/D/wSGKnJEmTP2wdGPBluO4/vTWcNu1qAkAG
N8MqNY3gv16ZnUQ/6d0/4Uc01w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.896959618062425, -1.1704645861570915`, 
                 3.0413608954080766`}], 299->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/QGkeKb8P/T+ytg4XKZLfv6xiiJ0A4uY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/z5i2pIAg6T/oCxZ6TRHLP9iOKWOgj/C/5faq0LSZ
6j+AGDJ82qX4v6XYCd7ozuu/3spZAQ/W+z/LUHs1u4j0vzqijYnkf/c/FrYz
7AzA/D9MooRhJmDeP4wZFclBl/M/kArEhzhQBkC682fa1dbivzTEIp67bcw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Qkg8YCC+5z/gTMruFkbJ
v7IuhTZRhuW/TXc2drp66D+atpPzxCzxvyyMYEIl3uK/Dxo8Fedy/D94/j57
RW3sv8jpKGxyePE/qw+pCubn/D9gRqFYKyCDv+JK2RdCCO8/mJ8pDgxsAkCK
p/cy9U/hv7kTEYVv/d0/erUt1w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.9105928176475063, -1.1887960726557925`, 
                 3.0301789745965406`}], 300->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/w1qRvqwS/T+UQfWkCpDgv6AYQxIx7+Y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/EqOm5URQ6T8okliC/3PMP1RZDQfWWfC/AHKy6L1j
6j/W/g7Nm4T4vznm/BNzSOy/x8DPj+bB+z/IXPJfvBr1vyD9JBV+Uvc/WUmK
2/De/D80yUi69UzcP8DnTjLU3PM/jIPXyU5QBkCmoSpSs5Xjv8TtxrPdcMw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ZE20gALW5z/ACanqvZTI
vy75aNqGUOW/2zQ6Ar9f6D/GKQKcJRzxv/YSWl3qGuO/xY0wp0lq/D+S/Wyy
wWLtv7hEI08LZfE/DtINzc74/D/Q54Y+fkyjvxB0cLtsVO8/dxiQlNJsAkCd
8Y/73hLivxHUNH9oC94/jnY1Vg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9240973037656707, 
                 1.2069373065776297`, -3.01889822802362}], 301->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/aRWO2eUU/T/HSft1OVfhv/G6wZI0+eY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/jrIkD6iA6T9Mf2McbM7NP/RmKLhYI/C/2r4YqEEu
6j8geytYNWL4v32KpAvpwOy/N0SDMLas+z8067Hp2av1v2JexDPFIvc/5/qI
0eL8/D/gumRmiTTaP6RX+6BFIPQ/+vDhhw5QBkBm5wstjVTkv7gjYSXSZ8w/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/IlVzFTTu5z8uk6Odh+fH
v84GhIsJGuW/SFvt4QBF6D/qZ5Bh8grxvxjlLVklV+O/0KwIBc5g/D8YkK+k
dlfuv+2dkr6vT/E/KIiLVeQI/T9csSML0/Owvxw1XOrfnO8/131UukBtAkCW
mINR49Xiv98DGhwpE94/TsIw4A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6301813101377853, 3.0021223727382615`, 
                 1.4193423742907894`}], 302->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/f5qzTWoW/T/f21R2kR7iv4paHVcKAOc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Phg9W6ax6T8E85REeCDPP5W8fmxZ2O+/iu+WOkT5
6T/590HMqT74v2V/QWBBOO2/RYlyin+W+z81dM2BCDz2v+wjGJ698PY/K/pk
eOAZ/T+0WWg6CxfYP+BNvtKQYfQ/vhfmxndPBkAIRhuJVBPlvwqegqeZUsw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/+od/O7MG6D9S2YqJgT7H
vyT+mond4uS/oHMsK4Iq6D9XppubLPnwv4xffIPRkuO/4hET7HRW/D8k4vc8
UUvvv5ho02RhOPE/VUoMYyUY/T8UvIJkL0y4vyX7TP6V4e8/f/LfdlZtAkD0
ELj/8pjjvwwC/sCwFN4/kxMuIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.64079228376302, 2.9884610561823894`, 
                 1.4432206223412307`}], 303->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/b0C3/DkX/T9UNIcaA+biv6aK49axA+c/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/fjLj9zvj6T98MULPBDXQPxjObJ2saO+/ykwCwsnE
6T/azOfu+xn4v+CiWsNyru2/aZAPWUR/+z9Nc/rpPMv2v2rX3DprvPY/9ZRg
jec1/T/+QxhwpfTVP3oHJLCwoPQ/unOlkopOBkA6d9mF+tHlvxyny+E1Mcw/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/GpXSCX4f6D9YIZPcuJnG
v+YGEiIHq+S/QCLi7kQQ6D/IkO6s1ebwv0rxCDXqzeO/bGjjKj9L/D+8Bp87
Hx/wv15OJxMiH/E/suoLxZAm/T9USeyJwa6/v2bmys1EEfA/+YmAyBNtAkDH
VTDQ/lvkv210Vk//D94/sJs04w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6513518115921652, 2.974568699038859, 
                 1.4669975706298477`}], 304->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/bQ9n1lQX/T9GthfVfq3jv6wEIckqBOc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/prE9B2UV6j9ubIg7g9XQPyWOdriz9+6/kNj5VdaQ
6T+96FWcLvT3v/W/dv1zI+6/AZIdbAZn+z+O2nD3a1n3v4hMkR7ShfY/1Vj4
4PVQ/T8S4SKjgs3TP4i+Bk2g3fQ/KE2f/UZNBkAoamFFcJDmv/iSym6pA8w/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/rtR/kZI46D9m5kxwOvnF
v+zmlq+KcuS/I+jdOEv25z+5nqUD79Pwv9T/FtJqCOS/t1BCoS0//D/YWv6w
FZjwv2/nkMHzA/E/IbSvWyU0/T96iwwHe43Dv2+gy9jaL/A/b2pptHhsAkA3
kDyN9x7lv2qp0yQVBd4//Ig0UA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.6618612090132514, 2.9604491279818106`, 
                 1.4906645164607804`}], 305->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/uQSr2LoW/T82ZcIX9XTkv3pYZyR1Aec/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Ysjznx1I6j9c/jDjqnHRP1Hs3Ix3he6/hpyUA25d
6T/XuC/HRM33v6mM1O47l+6/TdSMp8dN+z8EAMqTiub3v9QtJYv2TPY/l7QO
Vwlr/T/szM3NzaHRP1zu8OhaGPU/SkcPIa1LBkD8C5Htpk7nv8TEx9v3ycs/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/DODa3e5R6D94VKTIEl3F
vwIWyplsOeS/HkqrD5fc5z/GhhIZesDwvy7mxcpOQuS/g+wbQEEy/D9QmdWP
ghDxvwhtrI7Y5vA/qNzcF+JA/T+A/bZhHEjHv0xNkr2KTPA/02SyRoVrAkCZ
uKkCzuHlv6tJWRvz890/iIw3GA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.672320009023035, 2.946103853690368, 
                 1.5142185736339473`}], 306->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/gDyFD2wV/T+3brBUVjzlv7iozR6R++Y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/dUF7zWF76j804u2YbwnSP6FeFgMBEu6/q8oQzZQq
6T/PT0h4QaX3v3/OIJDBCe+/lu5UA4oz+z+V9N29jXL4v27+o+/cEfY/khYW
5x+E/T/0xDeLZOPOP5YvfO/bUPU/umjrHL1JBkCgxTGpjwzov/bGfqglhMs/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/lZye9JBr6D+gcOcSTsXE
vyrP5lSx/+O/MGFpdCrD5z9C0p5xeKzwvxkHbJuRe+S/ixVtCXsk/D/4FRt0
XIjxv2Vphb/Sx/A/ialN+8VM/T/0+sRj+gbLv/mBcT9SZ/A/fQNXkjlqAkAs
GvH+cqTmv3Za7Yia3N0/ZWY0EQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6827275164546426, 2.9315341009533378`, 
                 1.5376576189852489`}], 307->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/EwIRlWgT/T9wq67/kgPmv/xy7C1/8uY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/6nRnkC2v6j8iUAKHxZzSP+UMHRxZne2/graDqU74
6D8U0mXOJ3z3vyeXKvP7eu+/iXxNi08Y+z+BMp+Kav34vz6X3OeJ1PU/W4Q5
nDec/T8UUthvt3rKP6qkrPgeh/U/XJ3hF3dHBkAVlyCpG8rov1x7xEY4Mss/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ULYU1naF6D+yAtMk+DHE
v0wmamFdxeO/HNeiYgeq5z9kk62c65fwv23r8MwutOS/Tj8vENwV/D8cRDsF
mv/xv15oab/kpvA/N0OlGNBX/T/WLXFHysnOvxRv0UcvgPA/Mw81sZVoAkBC
oWdU12bnv9ORnT8Nv90/7LMuAw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6930829799835176, 2.9167410331945325`, 
                 1.5609797334163114`}], 308->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/z8aAkbAQ/T9p/2OPm8rmv0pk1AZA5uY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/qha53nzj6j/i/y4woSvTP70Su/CIJ+2/MK2KhJ/G
6D8NLAP++lH3v4+LlUPi6u+/10QFXxr8+j/AkvQlFof5v5wmBTwClfU/4aiD
lU6z/T/wzyNN7AnGP6rvSMkfu/U/PrJUP9tEBkB+uXUlPIfpvy5qGho21Mo/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/MIc9fZ6f6D/yUqZ7HKPD
vzgpuUt1iuO/c1Im0C+R5z9hQHw01YLwv6FlJvUh7OS/0wVDeGUG/D86SdP2
MXbyv2Cstx8RhPA/2DeCk/9h/T9tCxt8IEjRv+iQWeYfl/A/04oKxJlmAkB0
3Gza6yjov9b+Wo1Nm90/m4wxBg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7033856309521246, 2.9017258030252218`, 
                 1.5841830759819755`}], 309->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/j/8aO0QN/T95gYd+YJHnv3I6AJ7U1uY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/+NcupEsY6z+ghJdw97XTPynm1LCZsOy/VLL8PYuV
6D/jFhBRvib3v5gTxeO1LPC/MdaXseze+j8neJHThQ/6v265W+BKU/U/sVUE
BmPJ/T/QR8zIW5HBP5aqLlPa7PU/hMtYx+lBBkDfsKte4kPqv6w4L3cmaso/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/12f43wW66D8yzj07xhjD
v+4Sxqv9TuO/BVXfrKV45z/MtQLeNm3wv3KzILdmI+W/4GpZdhj2+z9ynGoJ
G+zyv1TrrZdaX/A/oKqPoFNr/T+Fb1SMCS3Tv+hjF1EirPA/piVz8kVkAkAs
mZluoerov50IzDtecd0/oZs0PQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.713634695602177, 2.886489568058543, 
                 1.607265844445777}], 310->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9rqerVXmfjv2Z/
bk3D2tO/Sek11iMJ/T+dURZN0lfov5WzQSc+xOY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/9NWWwpVN6z9ssKB+vTvUP/HwsaKUOOy/AiidqRVl
6D8Ica8mdfr2vwz3MfBHY/C//Z2BycjA+j92H8zvrpb6v2hVw/RoD/U/sXT0
NHPe/T+AKktHviK6P4xbo7VKHPY/0FSv6qI+BkCOtsWe///qvxpRTKMR9Mk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/1WYs76rU6D9qojQtAJPC
v1KYtCT7EuO/3I+v4mpg5z/fYtJIElfwv+aWjcP4WeW/o8PbT/bk+z8ipCsL
TGHzv5kXMgTEOPA//S6Vhctz/T9N7CyEehPVv6saouQ0v/A/uiTlapphAkAW
BO716Kvpv9zHFJBCQd0/gBc2fQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.723829399813108, 2.8710334969341216`, 
                 1.6302262602008417`}], 311->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/0zQytU8E/T/sBYmB4R3pvyaNqRV+ruY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Qs4gEleD6z/c7cfr6LzUPyFrQyKDv+u/9GfPjkI1
6D+B7/PyIs32v+q/rgUjmfC/UXxyALGh+j+GA3Lwhhz7v/SrXcRhyfQ/T2fY
fX3y/T+AS19loBSxP4DeoT1tSfY/TGzC6gY7BkAZZXU6hbvrv1DHsNMAcsk/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs//GLxlovv6D/4ZA3A1BHC
v2pVfWRy1uK/1a9IVYFI5z8bovQuaUDwv8RfCtnTj+W/kljSWgDT+z8+Q5vY
u9Xzv0Q5mWdQEPA/EU6FmWZ7/T98HN10TfvWv4pSOyRW0PA/W8OtYpdeAkCC
Nf9ds2zqv/q+lUr+Ct0/6eIzVA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.733968971228043, 2.855358771929155, 
                 1.6530625616841224`}], 312->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv13F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/UJp0OMj+/D8ulgiqfuPpv26UahuWleY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5v8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/5ROxYYu56z8of3OlbznVPyyFaaBuReu/jVNLqBUG
6D8/LZs+y572vwI/HfFCzvC/aNgew6eB+j8XRZplA6H7v+BtIcU6gfQ/fNCg
UIAF/j8AUKnASuSfP4g+JGY+dPY/zsifDxY3BkAsjz+SZHbsv8aH2Sz+48g/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/62
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/zoW5vqUK6T+s02EGTpXB
v3BikCNomeK/oqUG4uow5z/6QMhUPSnwv9zeeMTzxOW/XLnJ/TfA+z8XSE9d
YUn0vxe41tIFzO8/ZrWKRCSC/T+uSwNUXOTYv2DE7LmE3/A/+wrtFT1bAkCt
EiSe8Szrv2D2oKaVztw/J8UxBA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7440526403238638, 2.8394665901893568`, 
                 1.6757730012222758`}], 313->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/DVVezo34/D8KrqJdmqjqv5bKtymIeeY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/nj00dy7w6z94krv1R7HVP/XvNqJgyuq/BOHSo5LX
5z/lHcemcW/2v7Sc942jAvG/tTkPka9g+j/7BXb6GST8v+hHbZf5NvQ/J8fJ
MXoX/j8Adxd8UPNyv9T4adi6nPY/dBvzp9AyBkBGKqATjzDtv4bdtsEUSsg/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/qhp7Sfcl6T9awBm2dR3B
v9QXdyThW+K/XWzKX6kZ5z9NOd6IkBHwv448U2FU+eW/Yce2r56s+z+ArqOU
M7z0vzMtSay9c+8/Gg4UAASI/T/43Jr+gM7avxDvona/7PA//SKRx4tXAkAo
bKG4lOzrv/iBJVoNjNw/WoM1AA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7540796410050647, 2.8233581643369607`, 
                 1.6983558434243111`}], 314->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/0IdE86Dx/D+aTX09JW3rvzWfnXBWWuY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/P4fzDzwn7D/8GyyEaCTWP9XRMsBiTuq/BavoIb2p
5z9i6bXcGT/2vwAMo8ZANvG/zGhu/Mo++j8Npx52wKX8v8qQlwWk6vM/YG54
umko/j9g9YTn/8akvxqkOmzfwvY/Iu3/CDcuBkCqNi069untvwhhz5JQpMc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/er/aFX5B6T/YNqknVarA
v8QIdTPiHeK/XVHVnr4C5z8XPqtHyfLvv9qr/pnxLOa/TnjZ9zWY+z/tpm6K
KS71v2Rg5j3PF+8/GHveVgWN/T/wnPU7lbncv9q5RFIF+PA/hRhRwYNTAkAi
QtW7javsv3d3UZVqQ9w/zAYzIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7640492109637591, 2.807034722772435, 
                 1.720809364332822}], 315->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/94pmMQLq/D9ZoAn2DzHsvxVE1l4DOOY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/iN/p4K9e7D/mZX9WyJLWPyc3maV+0em/IImHtZh8
5z86Nnilxw32v9RTwZQWafG/lxzWqfwb+j8g2WG87CX9v4axegNAnPM/JfGW
mE04/j8wHmlVFqOzv/D2JCip5vY/bPiajkkpBkC4jbiQi6Luv4BfUI2+8sY/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/n+tV/jdd6T/s7FVV9TvA
v207KCZw3+G/a8CkaCzs5j/uim0Qd8Hvv67zHGjHX+a/x1Oebf+C+z+mVLNb
Op/1v5DT5bJBuO4/Dr7+5CeR/T8fxLbAcqXev30MyGtVAfE/9B6nUyVPAkAI
F2HDzWntv/VbKgKz9Ns/4Cw0+w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7739605919166892, 2.790497509814721, 
                 1.7431318509733584`}], 316->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/kCTjILLh/D/f8jVAS/Tsv74dmaGREuY/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/tZsZl4WW7D/kSFHRXvzWP3cNmg++U+m//zXb4yhQ
5z8A6KXZftv1vzAogQEhm/G/XDcaUEf4+T/rcIvOlKT9v9RQ/q3TS/M/nN/u
jiRH/j8I38uMP+28v3AoukEVCPc/VAAjmwgkBkBEgHCyQFrvvyjOC4psNcY/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/tslt2SJ56T/cEwi1vaS/
v5WmKNuPoOG/25bOf/TV5j+0PJtELo/vvwrI3NTRkea/9q1+uPxs+z8tNVM3
XQ/2v7Pfyn4cVe4/FgLpV2uU/T9gt+eY+Ujgv6hbQwmvCPE/TknK1XBKAkCS
OVP5RSfuv0gRHMTsn9s/f2My1Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7838130297737097, 2.773747785751098, 
                 1.7653216011248034`}], 317->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/n6usZ7HY/D8er57ix7btv5tUZSQE6uU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Usri17jO7D8I/sq4I2HXPzG4lswq1ei/cgn6I3Ek
5z/7VxFlQ6j1v+JM7SVczPG/95cSuK3T+T877izMriH+vxZLnUpl+fI/cetB
de1U/j8ienYToSDDv1qmxR0hJ/c/lCR5l3QeBkAhl/+lgwjwv0bdY0xpbMU/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/BGHSeTyV6T+UqRTmM9u+
v/L7pjlGYeG/lADenxjA5j+wrAbQ8lvvv7zsSPkMw+a/y6Hfjy9W+z/lIr5e
iX72v2T1z1xn7u0/iEt3bs+W/T/TJr4TeD/hv1Qo/JcRDvE/Mr2npWZFAkCw
7k6X5+Puv+xLfnceRds/FbA2Aw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7936057747663136, 2.7567868268341003`, 
                 1.7873769232178007`}], 318->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Uxd8uQDP/D+SR76ydnjuv7KKxxBevuU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Vh5aQUUH7T92fUcxD8HXPy9OXrvOVei/nsuf3nT5
5j/5DXlGGXT1v5Z7OivE/PG/dYNjvDKu+T+3puLzMJ3+v1GA6Eb7pPI/2QFh
OKdh/j9qNBj2Mc/Hv24cgVDKQ/c/6LP48o0YBkC6QFSOaGPwv8NAJIHEl8Q/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/BguOroKx6T+8qhv1XBu+
v/HGCjGYIeG/quEwfZqq5j+uYm6xyCfvv3Ablv508+a/ZM3vupk++z9A5aAm
tuz2v6pFTE8qhO0/lozu+FOY/T9WKiKYITbiv+Rwcqx8EfE/yV/bJwdAAkCD
ZLPno5/vv+OaEDFP5No/d1MzQw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8033380815517982, 2.7396159252458077`, 
                 1.809296136310536}], 319->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/Q/vC16DE/D+e+RuWSDnvv7+6Gs6ij+U/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/5mugaiZA7T+eXPC/GRzYP1OPaMqz1ee/vqbpbTfP
5j9d/zePBD/1v0AHFEtVLPK/WatESdmH+T8FhRakERf/v/CBBjicTvI/58BB
2lBt/j9sxXD39IHMv/DIxJ0OXvc/DH1uI1USBkBVWrP7x73wvxZFSb2Ot8M/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/zjExQ/PN6T9o7MnXR2W9
v4Pnj7iK4eC/Os/VxHuV5j8SVC36s/Luvxqnbx4GI+e/TtODED0m+z/qQJL3
2ln3v1DfE59tFu0/FV4C2fiY/T98Ffzp4izjvygTaQLwEvE/V/2nx1I6AkCS
q2AjNi3wvwQMbX2Gfdo/tCExTg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8130092093020019, 2.722236389041201, 
                 1.8310775701127602`}], 320->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/r3GckZK5/D+OT3mDLvnvv2pFRAHWXeU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/3K865Fd57T/aH1NLPHLYP3qhD/fjVOe/kjwTHbyl
5j+qWvRiCQn1v+Q2588LW/K//dRGXKRg+T8NTcBbR4//vzwqMNpO9vE/D0cS
cul3/j+co3EmRpzQv4YaNPnrdfc/Gp8PpcoLBkDMqALimhfxvy7JtHzZy8I/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/yVP+/4vq6T/0ZQTBArm8
v5Zw484ioeC/JJpqHL6A5j9fr+nNuLzuv77WQqO8Uee/VqPxdhsN+z9qer5O
78X3v/FM0to5pew/X1zXAb6Y/T+uEFnLqCPkv54e63xrEvE/+evu9kk0AkBK
qN8RGYrwv7Z3cWDMENo/4+E2Tg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8226184217820275, 2.7046495420777004`, 
                 1.8527195650404658`}], 321->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/BlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tPfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/JPW8w9at/D9aJf/BDFzwv/Yxa4z7KOU/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/sXRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/UptqONWy7T8i9O4bcMPYP0KkyExp0+a/FuU0KAZ9
5j/P5Uz3K9L0v9ZRLRXkiPK/rCYYBJc4+T8xq5Fd5AIAwOInKhAanPE/0FpL
LHCB/j9yULDvTPnSv/yTZoZgi/c/Atpv+u4EBkCXRx1A2nDxv6w20SC31ME/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/62
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/g0kWqkoH6j9gvcwfmxa8
v/rxv3llYOC/ZW77IWNs5j+EOkJi24Xuv7DxiOiUf+e/6I3q4zbz+j/ePZG+
6jD4v93AX9aXMOw/+icEeKOX/T92Oev9Xxrlv3wWTibvD/E/SionLu0tAkB4
Ng6Bc+bwv6F/n1Qpntk/sXgzGw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.832164987422129, 2.6868567239349987`, 
                 1.874220472290817}], 322->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/hyphWG6h/D8TDzJa/brwvxKoqo4X8eQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/HpyH65ns7T8sxbrcrg/ZP1srW+RNUea/VhsDvBhV
5j+/9YSTcJr0v6BXtIfatfK/IR9HYLQP+T/31kRCRj0AwAKIu+IEQPE/f+nA
SuSJ/j/R6l6p31fVv87yDJlqnvc/3F93rML9BUAWfV8gf8nxvzOUIu860sA/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/6smkAy0k6j9QGzWeHX67
v4c1icVXH+C/honia2xY5j90Snr+H07uv3r3D1uLrOe/1CRUXJHY+j+A3l3v
xJr4vwvcEKqQuOs/AwqRUamV/T/HyYlE9RDmv2wjMTB7C/E/kPpT7DwnAkAU
xkg9PkLxvx9Nc0qmJdk/6TMt0g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8416481793848994, 2.6688592898280543`, 
                 1.895578653930397}], 323->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9rqerVXmfjv2R/
bk3D2tO/AJ07R1qU/D9kMQ+jYRnxv+mov2MutuQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/X1tYfKEm7j8MpqOb8lbZP9iuF+ObzuW/Zx2P9fYt
5j/VBS+Q22H0v/Zd5qXr4fK/8DsEof/l+D8wSH7OxHYAwG5JIYAW4vA/ltuw
JEWR/j/U24cGz7fXv2SVErUIr/c/xCdYSkb2BUBIqTGZgiHyv5icix/yiL8/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/iikNzDBB6j+YWWMglu+6
v4ruzon9u9+/joqoiNtE5j+KWiT7ihXuv8/9QXmc2Oe/eOwf9Cy9+j/i4AWg
dQP5v+IdAbItPes/Szz2tc+S/T9ZKLFkVQfnv+w0efMPBfE/Ivv6tjkgAkBW
bSAecp3xv3wcsadMp9g/8wQzLg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8510672756290605, 2.6506586105148946`, 
                 1.916792482992506}], 324->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8kdherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8vOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/UW1hlZuG/D/mVkFAMnfxv7kNsqNEeOQ/kkxZ4ZoX+r831qoispzj
P+7gKiFikvO/qytNXGePBMCje3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4798
cz4vHITjv1mBce6ydfY/PqtsZOdg7j86ggPKNZnZPzEBDXpdS+W/vsQI4qMH
5j+i9dVWcSj0vy6PDwAUDfO/IVTiBny7+D+GF32GW68AwBoEfztWgvA/rz3Q
JpKX/j9htgWf6xjav6Qeu445vfc/YMOCaXruBUAERJLN3Xjyv4aovBcNV70/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD72SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8LHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9WVvOAvXXjv7EypsVjbOs/elEXwFNe6j8woaPDD2u6
v+RAxCC/ON+/Ol7l/rEx5j9WSsvBINztvwgva9PEA+i/ueAhzguh+j/5wp2m
9Gr5v/YKWI14vuo/gNUY3haP/T9+xAIobf3nv8ASSvCt/PA/BL0ZGuQYAkB1
zekGCPjxv8qiqUYmI9g/T3Uraw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8604215589707792, 2.6322560722005046`, 
                 1.9378603435804822`}], 325->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/w/U1VTN4/D8IOffgZ9Txv9TSeCJfN+Q/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/stx3GGeb7j+0DRA9c9bZP+vaPOWcx+S/UpuBfiLi
5T/586RhNu7zv47DojhQN/O/g6uV4iyQ+D9qWJQABucAwNqvTIzLIPA/17xW
08qc/j++lzXzBXvcv1BUvAr8yPc/iLeapV/mBUDe357tic/yv6pS5JfyDrs/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/NOocmpN76j84iordlPC5
v54a9Iv+tN6/hMkhTfEe5j+uSJrM5aHtv2hj/gsBLui/o9DlGzCE+j/u9A/x
OdH5v0QZiR17POo/TVlGFH+K/T/4nsRdKfPov91e/M1V8vA/NdkaqDwRAkBz
DEvn+FHyvylddXU9mdc/4E85HA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.869710317143046, 2.6136530764374797`, 
                 1.9587806309752613`}], 326->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/pWRVpiJp/D/0inVA+zDyv0e2me+C8+M/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/UnarCBzW7j/M60Eupg7aP7aLz2pkQ+S/rjKxt3W9
5T8iHg47L7Pzv3qwfASdYPO/LcSxlBVk+D+wMIPlvx0BwAYsgxv8eu8/lXUI
wu6g/j/lXKtv7t3ev1Y2VD5P0vc/UFlqoPbdBUArJxw3gCXzv/AUaSzQsLg/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/BLc2Eu6Y6j8Izib7LoC5
v2jLhhHGMN6/MpW56ZoM5j/WcgOm3mbtv1NQ2NdNV+i/aZSDHZxm+j8q9r2F
PTb6vyZxjoU/t+k/He0utAiF/T8tYmDcdujpv72IEFsI5vA/0YXK+UMJAkAQ
2ci7Pavyv+XYJvWcCdc/eaEwEw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8789328428535911, 2.594851040024089, 
                 1.9795517517456325`}], 327->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/vU5+tWpZ/D8oE6gm5Yzyv1YxxFW1rOM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/JkUSoQER7z9cBLQ7ykHaP9TgRlq+vuO/XsG6aaCZ
5T8G2m99YHfzv9qnJSv3iPO/9fJljTk3+D9jgMvwhFMBwIzyePzqsO4/vRQ+
oP2j/j+zsXO4uqDgvz5NW28y2fc/PjDWAUDVBUBwyPz1uXrzv6KUfhnVPLY/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/bh5q3mC26j/onELg5hm5
v4Yg/gAgrN2/ily+QrD65T+6LmXoDyvtv7RHgf6nf+i/2SByIVJI+j/3iR+E
95n6v/GRHinQLuk/vTHeKrR+/T8C7OGCQt3qv/SyHo3G1/A/zqtKrvoAAkDM
bVKOzwPzv+oD9PhPdNY/+Uo4Tg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8880884338416108, 2.575851394900135, 
                 2.0001721238602905`}], 328->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/iTt6vAxJ/D9+yLFoHujyvyLVZ9r7YuM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/XMDrSRNM7z/0/3po22/aP9JQsAu1OeO/WAv0X6V2
5T+G8rjSzjrzv+jiEYdbsPO/abw4TJwJ+D8iEwfxUIgBwKr/UX1z4+0/X0nr
MPel/j97xYajtdLhv1wuUxSl3fc/nN7PdzzMBUDFR+eEMM/zv6gPdlcys7M/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/CdzWsunT6j/ApbSGxL24
v4WQZ7IWJ92/hwHbvTLp5T87R649fu7sv8KCbVoMp+i/+XtZhFQp+j9h918l
YPz6v2bq3Ks3o+g/dMKy9oF3/T88K3U6edHrv3aMw4CRx/A/MH4Ga2H4AUAi
iMx2p1vzvxeXViVi2dU/Yik3iA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8971763929334552, 2.5566555880407624`, 
                 2.020640176801119}], 329->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/KS0FAgo4/D9X53vpn0Lzv1ISRj1cFuM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/orgHaEyH7z+M5PQc1pjaP8h81t5StOK/0JmtVIdU
5T8efQv0fv3yvzJT4AXH1vO/j//BX0Hb9z9AVDvIH7wBwKLXxKOlEu0/i4ej
TNum/j/Lls4c0ATjv5Q0cdSm3/c/HJFItuzCBUC0qrpN3SL0vzrH7I4aFLE/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/LNjkQYbx6j+Q3MAdz2u4
v3q8jYW0ody/w8g3uCPY5T/T0QBfLrHsvwzzO9l3zei/XJbjsKUJ+j/sR/m8
b137v/p0hfCAFOg/WlpUp3Jv/T+8MuP3B8Xsv94einlqtfA/2JOl23jvAUAG
SZubvrLzvzmrI4/fONU/Vx85qg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{0.906196028097486, 2.537265081348603, 
                 2.0409543516770303`}], 330->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/0SW02WMm/D/Y80OaYpzzv5h0/3fcxuI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/OkwiXajC7z/cyxAnt7zaPxQXcjqiLuK/4Eb88Egz
5T8kkF6pdb/yvwr1l6g2/PO/y/NjZSys9z86fyts7e4BwIpcJ7iRPuw/Uxud
4amm/j8m4pRF8jbkv+JspYc33/c/oPYid1G5BUA89BHKuXX0v7hpsSmEv6w/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/+CFyPDQP6z/wDYkJDSS4
v8ZWKeEDHNy/Sx9fhoTH5T/Z5FMUJXPsv+SU83vn8ui/zgyMH0jp+T8meU25
Hr37v5FoExi3guc/kqCo3YZm/T/rZA6927ftv5eT0uFSofA/xIT+sUHmAUAK
9CoyDgn0vzSLmrrUktQ/vxM1eg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9151466524982058, 2.5176813515442906`, 
                 2.061113101338071}], 331->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/s6zaoxsU/D8Wnih7X/Xzv+hanL2CdOI/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/ZhhAiCL+7z+Aro66e9vaP54/WoutqOG/FiGEzOwS
5T/N0B7Jt4Dyv4Ce44OnIPS/g/8CCWF89z8mRqnmtSACwCDCKURIZ+s/34uy
82Kl/j9G94k+BGnlvyC2nTZX3Pc/dMEkemuvBUDAZsaDv8f0v4Cv58y9LKc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/DggBUvEs6z+oSI3ig+a3
v1B/ETIPltu/ZgwjdFa35T+CJRQ0ZzTsv1o+P1dYF+m/G9ZuVj7I+T8xlT2k
ZRv8v4QO44Dl7eY/SZzGS79c/T+5mW2a4anuv8rxtUpMi/A/5wsJprzcAUBr
gnd/j170v+DVappO59M/BAMxlw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9240275845496837, 2.497905890055474, 
                 2.0811148904895784`}], 332->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/mlRvzTIB/D8qfbWbj030v601EXpVH+I/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/ilAFI9sc8D88PjdxIfXaPyBmtEN/IuG/W6tEbXXz
5D+54M03SkHyv0xGTMAWRPS/MG28BONL9z+i5+NVdVECwD5pjBHajOo/gk5i
nAaj/j9oSKEp7prmv8YTxRoG1/c/8LLnhDulBUCngXAV6Bj1v2DbDEpRcKE/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/ZEzmMLtK6z8wKTx1OLO3
v9Kla+rgD9u/iFGDxJqn5T9uNcOi+fTrvyXmp5PHOum/5eAV6Yqm+T83pr4j
PXj8v3bPzsUXVuY/jtHotBxS/T9eIYawBpvvv07X5mtYc/A/nq7PderSAUBo
/5LYO7P0v2MDso5aNtM/L2gv+A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9328381479683764, 2.4779402029044375`, 
                 2.100958195806105}], 333->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/IUbvz6rt+z9xlm0b7KT0v6pUvlFbx+E/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/yXOWeK868D+sywtLpgnbP2PCI9ohnOC/4nxmR+XU
5D81sqDnMQHyvyy+cZqBZvS/awScILYa9z9OrrXsJ4ECwAq80ChYr+k/w8nM
CpWf/j/I4O0rmMznv54zP55Ez/c/0jLKYsKaBUDAsOcqLWn1vyCjQUZiFZc/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/pG93ho9o6z9IDpPBLoq3
vxYC24CDidq/TDqUsVKY5T/qBpZS4bTrvwZezW0yXem/RqVFeDCE+T+GeWz6
ndP8v1qIR71Zu+U/8gde7Z9G/T9qQ7IYnEXwv/oujyN5WfA/8epg5cvIAUCY
oyqjDAf1v8Nh8GMGgNI/+Gkx9A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9415776718254075, 2.4577858105944186`, 
                 2.1206415060449473`}], 334->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/BlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tPfBG8Bb5j9rqerVXmfjv2V/
bk3D2tO//s9AMYXZ+z/zpVQqbvv0v5ZO6yCbbOE/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/sXRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/ixRY8YtY8D8EM26uCBnbP+5y+MifFeC/VkUKvT63
5D8myxzYc8DxvxbcQWPlh/S/+IxQMt7o9j+i0+/yya8CwOol5c/Tzug/qKiw
gw6b/j9unH5v6v3ovwQn4FsTxfc/YnPf5ACQBUBJo8CBiLj1v2Djk0JM8YU/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/62
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/ZRA5/2uG6z+oP876aWu3
v6Cyr28BA9q/hR5mbH+J5T/cHxJDI3Trv/B7nTaWfum/e67IsTFh+T+cJhoI
gS39v0A6aHi3HeU/U7x42kk6/T8V+gmxMb3wvyjnKnawPfA/sO2/vmG+AUCe
pApW+1n1vySe9VFgxNE/GSc1Lw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9502454905982368, 2.4374442479945757`, 
                 2.1401633221592866`}], 335->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/Zf+Ug8PE+z9tHXcJD1H1v5gMPvsbD+E/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/614sOW528D9ozUBoRyPbP2OkvBoHHt+/5DgZHoSa
5D/+fbQVFX/xvzoOLoA/qPS/iUHfHF+29j86wKTFV90CwKZAzIhe6+c/R35l
YXOV/j+6/DklzS7qv/xPIB9zuPc/viPf4feEBUDcQMrp8wb2vwB2OvIASle/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/xloNR06k6z/YCimH7Fa3
v+SRFTRlfNm/TZjtHCJ75T+y0qmAxDLrvxSuiVPwnum/dyA6UJE9+T/wTmBK
34X9v58mBUI9feQ/1j59chst/T/lDQrOOjTxvySrX44AIPA/uNHU0ayzAUAk
r6B5Aaz1v13vxPp2A9E/nbQrxQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9588409442218919, 2.4169170642238202`, 
                 2.159522157410611}], 336->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/NENIZWev+z9Ez3ALyKX1v5iELSvlruA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/voiB+1OU8D+kY/6rYSjbP4UlF02vEN6//+cWqLd+
5D/RIGK5Gj3xv1hVX2uNx/S/OjhW0DyD9j/so3DXzQkDwLBSPxAKBec/WLrU
E8SO/j9GdLmGKF/rv2qDDORkqfc/aLEUNqh5BUCOMolFaVT2v6DvIm/wYoy/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/mIRiCTTC6z9Y3q3/t0y3
v3XSQk259di/2m/s4Ttt5T+GdVckyvDqvzL1uj4+vum/tz3PGlIZ+T+OCynd
sdz9v6Rrtp332eM/xn6OvBUf/T+0xGYnrqrxv9ui0bxrAPA/gWlc9K2oAUDp
AH2oGP31v9r4cGlZPdA/+wc0jA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9673633781396359, 2.396205822533362, 
                 2.1787165374806072`}], 337->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/DxzCgHKZ+z/rOvKUkvn1vy4tcDH+S+A/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/yVaA4zqy8D8kIcoTVyjbP8Bl3ilNA92/ZIb0hdtj
5D8qSkLoifrwv6Sh6LPM5fS/3cZ9SXtP9j/IX8CwKDUDwAo5TFzoG+Y/Ge9w
IAGH/j8BBSTY5I7sv1phMtfpl/c/ohpOwxJuBUBo9rGK4qD2v2AmFhDkPJu/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/pFJh8Rrg6z9YYxYwzUy3
v5NypjsIb9i/DT/b0M1f5T/enjdTOa7qv35BRId93Om/dvEf5Xb0+D8+fTn7
8TH+vxwz3kbzM+M/lIWZ0DkQ/T+2HoKAgiDyv/F36u/ove8/VZTXAWadAUCq
GNKPOk32v/b33iEu5M4/3woyDA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9758121433531843, 2.3753121001881494`, 
                 2.19774500058224}], 338->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/BlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tPfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/HtxTjOaC+z9YcEQdaEz2v19tzIjdzN8/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/sXRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/d6c6nCDQ8D9ghXegJyPbP9muvrL19du/yKTlz/FJ
5D+wGy3TZ7fwvxiO9/36AvW/NumIkR4b9j+wvBbwZF8DwODY7poLMOU/Tmkr
Iit+/j/ICwhq6r3tvybliFUDhPc/nFLKcDhiBUAAdKHCWez2v3hvFJjvSqS/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/62
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/UaMbqgD+6z/omrsWLFe3
vx+XFoBc6Ne/Ps7T9dhS5T9kcCI+F2vqv/ItU9Gr+em/qmLujgLP+D/c9Lj+
mIX+v8iHqi89i+I/tqI/14gA/T8eOySprpXyv34AvLc6d+8/ViB629WRAUAs
8vLvYJz2v3DfyZV/Q80/Ltg3Cg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9841865964724228, 2.3542374883471426`, 
                 2.2166060975701045`}], 339->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/9ngWSsVr+z9KgMsuQp72v4Qp/559/N4/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/Uv/Z0ALu8D9cU4q50xjbPwc+j+i96Nq/02A2i/ww
5D+Eok62uXPwv3R2AwMWH/W/XK/EvSrm9T8F6U9Kf4gDwEo0pjCGQeQ/Jhto
yUJ0/j9kFDSbIezuvwovVeyybfc/PjknKxpWBUCNCNQKyTb3v3Dsd5GvHau/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/LPu63uIb7D/w/pXk02u3
v7be/prAYde/RCx8U15G5T8590MhaSfqv04WX9bGFeq/KZTtA/io+D8qqbVh
oNf+v4bkEoDi3+E/Dkq/CQTw/D8+xTJ+KQrzv2v5FFTSLO8/3DoZaP6FAUBs
xM+cher2v/Yr0KzHmMs/G0EyDg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9924860997646437, 2.332983591942443, 
                 2.2352983920499967`}], 340->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/VnLHhxBU+z8Yb4dnGu/2v/7JO+XsJt4/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/mhPOLN8L8T80fy4tXAnbP3z6rsm629m/Nw4jqv0Y
5D+aVb7YhC/wv2Dk+pEbOvW/YrpG76Ow9T8qOOOKdLADwEw/BbdqUOM/Atvv
20hp/j9ySEdtuQzwv5CJC1n6VPc/fCdP5LhJBUBPAVuVKoD3v9TjAd8UC7G/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/dA+vOr857D9Ap039woq3
v/C8jgs/29a/9oLy4l465T9PqrNDNOPpvzmEVmXMMOq/XBaHO1qC+D+276a+
ASj/vyaS0ZTwMeE/rKbbsaze/D/FW2fq6X3zvxB8WpK13u4/VHAZlOB5AUA0
OHF+ojf3vwhRe60n5Mk/74QxbQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0007100212033506`, 2.3115520295573937`, 
                 2.253820460487543}], 341->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/d9CkHso7+z8QoJN56j73v9d85AI8TN0/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/YU/7W7Mp8T9cGigwwvTaP4VdYVABz9i/kFyxC/cB
5D/mcysYndXvv+pPb48JVPW/9c2aUo569T/AHiOUQdcDwNqQP/vLXOI///bg
ND5d/j/uJ3ZU46Lwv+ysLInbOfc/EhJmkxU9BUASe1CpeMj3v2hIMHvpmbS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/PEvcaZNX7D/ocFr39rO3
v3Xu507iVNa/I6q5k9su5T+oDgv3fZ7pv8TvymK6Suq/Ns+fOCxb+D/I7uzQ
tnb/v6PnWP50geA/u+PCKYTM/D//4wTn5vDzvyLM5YnqjO4/Jz1cUX1tAUCR
DXKRsYP3v75qGKTBJcg/hmk5FA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.008857734516554, 2.289944433303525, 
                 2.2721708923160526`}], 342->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPbtDAWLr+L8ldherbDDiP+xlZrmh
5sC/BAMXR8Bb5r8uOajSXmfjv1/F0lzD2tM/uPfBG8Bb5j9qqerVXmfjv2d/
bk3D2tO/2DxI8/Mi+z92r6QrrI33v3/trQV8bNw/k0xZ4ZoX+r841qoispzj
P+7gKiFikvO/rCtNXGePBMCle3QCO9bdPxv7PQbPX9E/5v8KFBxw8r/25FB/
o034P55rgfrGE80/s3RlqEhL879+Hxok7JL4vzAaDzsW5Zk/ECJhX4rj4797
cz4vHITjv1mBce6ydfY/qU/pCn1H8T+0P7tdB9vaP22sK3Gmwte/xPyKe+rr
4z9jagxYOEvvvyowv/XdbPW/GH1vH+5D9T+fZntf4/wDwIYNsvy8ZuE/5B6e
xCNQ/j9AxnLNgjjxv1BDH5pYHPc/3kO2NDEwBUDInUmjrQ/4v9iIdZYOO7i/
6INOcX6B+b8uJuFmj+biP6utV1g2r+W/pYR3LoyCAMD82SgWxY3gP0qQFVP8
2LE/kl2nCr+t9b8EUG7q7LLwP2QLNoJKWqg/Nfbwyyh57r8KHrfGTSPxvwK3
g8AUecU/ihI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/hUvKGF117D9AJjScbOe3
v+oVTd+0ztW/PnqmS9Uj5T/mifuWS1npvwTQGsmOY+q/+NxbCXEz+D9avk11
ucP/v0YEif/6nN8/3i3z24u5/D/buot8F2P0v7C+ipt3N+4/JTEtl9VgAUCf
JnfnrM73v0qLEGC4XcY/rIEzvg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0169286192346183`, 2.268162448696473, 
                 2.2903482900434136`}], 343->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9qqerVXmfjv2R/
bk3D2tO/EjiB9Y8J+z9LsYRZWdv3v5TUSmC+h9s/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/oFLx5jll8T+EAYy3LbzaPyylMhm/tta/p8jZsdnW
4z8yLdw75r/uv6pYPtWWhPW/evhBmMcM9T+ola39ViEEwI2oZ+tQbuA/JqW7
kPpB/j8wulQtjM3xv/KwBdlz/PY/YrGcyQwjBUBYK8f1w1X4vygNZLw77ru/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/ek7S9BmT7D+gopLoHyW4
v0iSUDPBSNW/LuDN5kwZ5T9Oa+OIohPpv4P4mahHe+q/RpjhxisL+D8n9zfV
gQcAwNcSjRswMt4/nG4eQ8Wl/D++tWzDctT0vxdmGHFj3u0/tqYuYupTAUBS
7qWnjhj4v0rRMXEvjMQ/KlI0Aw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.024922060737666, 2.2462077345308566`, 
                 2.3083512693580697`}], 344->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/J3AuIKDv+j8uy4306yf4v5mnD+kUnto/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/p5ZsnueC8T+8W3alN5jaPxe+mCxgq9W/KnAlU8bC
4z/UvdmgsTPuv36gXFQym/W/NQUJCh/V9D/PgguXmUQEwHSyNE02594/Mxnr
s8My/j8W/+fU82HyvzIjkMIv2vY/Iud0WKkVBUDWWKQptpr4vxipmBAns7+/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/gpJNrMew7D8w7r0MDG24
v76eA70Rw9S/8LNzN0MP5T+fM2I7iM3ov1hAuCfjkeq/rroblV/i9z8zNKnI
RywAwAYtIpulwtw/rcQM6jGR/D8i5brk70T1vxgN1Py0ge0/mw9GtLxGAUAC
EhkPUWH4v1J96SRLscI/7GUt+Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0328374503024813`, 2.224081962754089, 
                 2.3261784592340686`}], 345->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/3zkWeSbV+j/SHyMEXnP4v+aDjtiRr9k/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/SqXi4IOg8T+ELV71J2/aP8YZ3YSeoNS/Uq4y8LGv
4z8an+11pabtv+zPyq+usPW/UyLfy/ic9D+2FLBrqGYEwMHEYHZe7dw/7zvl
XYAi/j+C9pQxrvXyv4DqygKPtfY/JJSE7AcIBUB06YPeft74vyyLPqrCxMG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/JaHD7mPO7D+YSu5sK7+4
v5XMJemwPdS/BFP6BbkF5T9CJOwlAofov8VvJoNfp+q/Ga56og+59z9Q0uC2
K1AAwFSkdyd4Tts/57p9a9N7/D8qC9wahrT1v3mL7nhzIe0/itiHlE05AUCj
hFNx7qj4v1A+b4MwzcA/NRE30A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.040674185148953, 2.20178681833916, 
                 2.3438285020351812`}], 346->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv17F0lzD2tM/t/fBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/ejC+ECW6+j94Aiimqb34vz9wK8hHvNg/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5v8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/roY3Xwy+8T88PvfaAUHaPyxPO++OltO/vQjkBZ6d
4z/Uks+6zBjtv+TRnToKxfW/AOSrPllk9D9uJbbTgIcEwEwUbMRB79o/mlBS
0zER/j8dbke+r4jzv8gi6XSUjvY/fLLmlSn6BEDAgjvLGCH5v4QGk/aEuMO/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/NPbwyyh57r8KHrfGTSPxvwC3
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/ioIYbezr7D8oKbyhdxu5
v0nnVB6puNO/OgDTEK/85D8eHl3IFUDov71x+Q27u+q/PQq1Jz+P9z9VE2XT
KnMAwEbCS8bE1dk/ikAIcqtl/D9KuDeyLCP2v9j+82amvew/XOUiD54rAUCc
wrE4Ye/4v/zZw5kKwL0/BX8vKw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.048431668486114, 2.1793239991565025`, 
                 2.3613000536179074`}], 347->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/4v5BAp6e+j9haXUPyQb5v4QRqbBJxNc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/3NnZy37b8T+sUYXvyA3aP1QmDCtGjdK/+Rsc/YuM
4z/QByt/Morsv3AmcF5D2PW/AIvMzEQr9D8wh20/IKcEwE3Ap/4H7dg/tMuw
bdn+/T/0l1QE7Rr0v4SuCyNDZfY/NE92aQ/sBEC+MT2+fmL5v9BDpnSztMW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/ttW62V4J7T9IAqB46YG5
v9xSPbwENNO/1wlvDCb05D+c2IqqyPjnv0nGyzH0zuq/8USHZ/Fk9z/wHZRj
QpUAwOhoqNeoWNg/S2X5t7tO/D+qAOUJ25D2v+XyNY9VVuw/UqdLNa8dAUCQ
TdnmozT5vzjfq+zf07k/IhA1uA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0561093095575993`, 2.156695215844695, 
                 2.378591783433713}], 348->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AwMXR8Bb5r8uOajSXmfjv13F0lzD2tM/t/fBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/gFUpc5OC+j/ClU2Mtk75vwDwreiqx9Y/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5v8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DyJhX4rj4797
cz4vHITjv1mBce6ydfY/Ls7w2tj48T8EUZQxgdXZP7dqJ+jYhNG/W3ehKn18
4z+qScLh4frrv5KTgZtY6vW/VN+76b/x8z/CJY43hMUEwOZigz7Z5tY/6GE6
m3jr/T/J4l+cWqz0vyKJBEaeOfY/ivO4gLrdBECiGP+dq6L5v2jbsIMmuce/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kV2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/NPbwyyh57r8KHrfGTSPxv/62
g8AUecU/iRI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/CsrR6Lgm7T+gA4L0ePK5
vw71yhrOr9K/ibcxox7s5D+KedZbILHnv2wz3W4J4eq/appyrik69z9SeNq+
b7YAwHOpmBNC19Y/tNsxBwY3/D9GvFaUiP32vyIFMACJ6+s/Jc8mHYIPAUAy
VyYVsXj5v5gEq00v1rU/DFU4Mw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.063706523686761, 2.13390219168037, 
                 2.395702374630025}], 349->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/BhA9kwdm+j+C6M2AbJX5v65pQiN/xtU/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/fvqJQhgW8j/QjagEL5jZP6HyRsVbfdC/AwoEz3Jt
4z8Sg5AP5mrrvwoS1YhI+/W/9FS5Ec+38z+8QGldquIEwL6QbOzd3NQ/JHnH
3hDX/T8qoT4v7Tz1vxh1FkWpC/Y/3LDI+SvPBEA7PWFpmuH5v8qY3t21xcm/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/WPZqUPhD7T8IillOHW26
vwO5WokPLNK/3ABjdZnk5D8+lr1yImnnv+SxMFz58eq/fTJ7UusO9z9+GuhO
sNYAwDZ914euUdU/lUQCOYwe/D/WRAbYLGn3v4MP5w1Jfes/cJyz4RcBAUDe
khd1g7v5v5A6pmhIx7E/WF8uiw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0712227323211945`, 2.11094666244696, 
                 2.412630524150424}], 350->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/g45bnPxI+j+P2l5p5dr5v/ZwR27awNQ/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/Ug7Hujoz8j9gJecw11XZP3D51ZzG7c6/hiOEFm5f
4z98pOpCStrqv7TzTNQRC/a/boFvyXZ98z+UuhhrkP4EwKIwqLw+z9I/D/6w
z6PB/T/lbNp2mcz1vxwLsbVn2/U/WtE992TABEDTbxE4Rh/6v/Bvcps42su/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/LQqoyBph7T/oWtz1zPG6
vw++7E3TqNG/ng0jGZfd5D/zpmqM1CDnv42TqKfCAeu/+Iflsjnj9j/uE+SP
AfYAwMzQd5UMyNM/SUYGNlAF/D+6oxxwv9P3v1nnQlGeC+s/Tsy1onHyAEAx
JbjQFf35v/jjOIL4Tqs/cdw55w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.0786573630768865`, 2.087830376302654, 
                 2.4293749428336366`}], 351->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/IUVM0nQr+j90ECLbGx/6v1w15jDRttM/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5f8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1iBce6ydfY/kVkL/j1Q8j86i7bifg7ZP+QFgPYH48y/Dgr7GHBS
4z/2P5/CGUnqv1JBxUKzGfa/aOmZnbtC8z8geawzNBkFwG3oJawkvtA/JaCw
GTOr/T/fNRI/VFv2v2IvKVvdqPU/wi4YoGaxBEAUQ+06qlv6vygU9zWF9s2/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/y2
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/bFXsCx5+7T8wjz2SfYC7
vytBV6QjJtG/4oBeGhjX5D+w9ERMPNjmvyvhIBZkEOu/RBfzNxi39j+twJ4Q
YRQBwOQOhu56OtI/o3L+9VPr+z8qIxoNOD34v7m8YqeRluo/qSifhJDjAEDE
qQcLYz36vyCtqlc67qI/k3gmGg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.086009849781836, 2.0645550936472814`, 
                 2.4459343555115893`}], 352->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/iDF4sCMG7D8svKW0rurbP46zPmgTdPa/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/stwy1Oex7T+HKUzB6Zf5vwqEw+p/1ea/qjb22GPl
9j+eTneYuy7av0Lp1w/U1N4/NAiOHRIW5D/nsUNwyP32P6WfLM8Fk/C/Zz3T
yqpgzz8Y2/p+nA3MP6GFPuXjKQLAPQAkFQCn/j/MNmqLi73cP77uZxF46/u/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/Mmr699MG6j8evyCWzKXx
v95hvchwYeC/Qplr86EJ8T9cKBNRXj/gv7zT0oQh9LU/3hwD5xoO6D/yIG0d
dPjtP5qptZuMg/O/cYCWMSfv4T/clBF6vvjUP2jfXZntY/2/gAyw9ghV9j98
+QcgHVTcPyZR07zFL/m/oktCIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.093280415351542, -2.0411225869882954`, \
-2.4623071535238994`}], 353->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9qqerVXmfjv2V/
bk3D2tO/W4k/BPju+T8woeosrKP6v3k+bG7kldE/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/T+eO292J8j9kzHR743DYP0Z/9F7E1Mi/YtGtR4w7
4z8bwGr7JyXpvxJ8mQ96M/a/+Zts9C7M8j8SC5G/rEoFwGwvkmlKJMk/ORTz
zE17/T9AptjfyHX3v2bluTX+PPU/RHl3pciSBECp6cogiND6v18a73DpItG/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/KuNv6b237T/gDMFgtLu8
v4RfdL6SItC/jOS3MabL5D/CtKpoQ0bmv+wb9eIqKuu/qhJWfJNd9j/VLQNr
QU4BwC9WNaMJKM4/yk6Z6CK1+z+4o2GGugz5vwT1VFF3ouk/+Z7LUyLFAEBs
xdomGrr6v4AGSV+/vmw/opA0mw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.100466157669949, 2.0175346408058656`, 
                 2.478493132726312}], 354->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/U7XDtwfQ+T/rnZS2++P6v99Km2crf9A/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5f8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/GCV093Wm8j8s2q6srBrYP17egWSQ0ca/rqbcPKgx
4z82eJB4fZLov5w4YmudPva/QTKstWaQ8j/myUynfWEFwEEwiSwm78Q/jwFZ
8txh/T8DXMWxbAH4v4LhQNSxA/U/3DExZSuDBEBbuMzm+Aj7v77uDvU+PNK/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/M/bwyyh57r8KHrfGTSPxvwC3
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/8yBVBVbU7T9M8Uz+IWi9
v5Vur3+LQ8+/Mk9PLLTG5D/QkD0n7vzlv3XYvT5ONeu/yvO3Njcw9j9ujEvB
vWkBwADj332+9so/cVsOVfKY+z/3/Cw0tHL5vzq0J658I+k/Q4aJoJe1AEAj
q7BOevb6v+A9Otc40Yu/xyc0kw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                ViewPoint->{1.107568877955127, 1.9937930514169917`, 
                 2.494490017760452}], 355->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPu/AeURK7r+GjOkmlX/8v8G9p3zJ
5vM//wIXR8Bb5r8uOajSXmfjv1vF0lzD2tM/s/fBG8Bb5j9qqerVXmfjv2N/
bk3D2tO/LeQeqMC/7D9wuE0ZVe7eP2ZUKRIOo/W/3qk9937Yx79wWIDjtzX9
v+eWm7l8PQBAt+j8c5XM/r87gqiP7dz6v9aJCWTSlvs/G92MCXQf7r9inJQo
gdoFwGU2pq2BeuY/eTZbYrB66r+gGr9INa7UP8ZkAqHEFOw/H0X81k5U97+7
n3p0oUrjv4wjwFB5vt6/mKB4olsG7T9xCX1UQlf5v+TgXNvcV+i/joJ2hjn0
9j+EdtLJo57dv8sz2+N4Wt8/EUQ2Q7p85T9VWbdPqob3P5EoSnBF/u2/ba0k
tZfh0D/QQR2IUJLUPyy29I7z0wHAVTlgJ60E/z9sMqI4w2LfP1GmX2p9GPu/
2yzIGzIg4r978jSFptr8v8h173fhMPo/K7Bu2Nv49r9gB0lbQa77v8yjWPDN
vvc/LOamQdw07r9SsQTeJQ0CwPTYelMKJO8/vBy5VDhr6L+8V5FciCDCv7rj
tScTAeM/T+NDfRdB8b90bJEjAFnjv2S82udrx7W/Jkwd3w2x6T8TL7nfeIXx
v0sQCkGfIuG/NL8rygwR8T9W8mldWBvhv9Bo2Sxr/7Y/H5SqdT0e6T9xxwqW
P0LvP1c0J2UYUfK/cp1YQUaY4j8gfbXQUsDZP19gCZh6pfy/ttW3vUay9j9u
9fcojCjfP1x9RL7FXfi/jEU40Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1145880236041759`, 1.9698996268387259`, 
                 2.5102965955876173`}], 356->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/JlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv1zF0lzD2tM/tffBG8Bb5j9pqerVXmfjv2R/
bk3D2tO/PqXRY8+Q+T9sSbR4kGD7vy3NZHNBi8w/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxj7PQbPX9E/5P8KFBxw8r/25FB/
o034P5hrgfrGE80/snRlqEhL879+Hxok7JL4vwAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1iBce6ydfY/OgmVYyvf8j8QSr11jl/XP1QI3e/M08K/e1gUvv8g
4z802t1i/mvnv+5XA7ZfUfa/vGScsukX8j/+qxvVP4sFwPht1jVw6Lg/zu3j
vwgs/T+LRnTnUBX5v14JqMp1ivQ/hhsodVpjBEA1B7kXyHX7v2DbGICAedS/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gPz6QFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/y2
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv68ypsVjbOs/FAV2cQsN7j+EETBsXt6+
v44DXcWpRM2/GCjr7F++5D/OQWScrmnlv8f3XokQSOu//QQ3i1zU9T9a6LoI
xJ0BwBQCKMe8f8Q/hsnaEWxe+z/8RxSw8Dr6vwOjFPndG+g/EneIE+GVAEBQ
qDZILGv7vyTTmRl/z6i/CWYt7w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1215207467626171`, 1.9458561866505621`, 
                 2.5259126895945463`}], 357->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AgMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tvfBG8Bb5j9pqerVXmfjv2V/
bk3D2tO/v4lpSoxw+T+ZAir6y5z7v72rnfj2Rco/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5f8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DiJhX4rj4797
cz4vHITjv1mBce6ydfY/9dO+R0T78j+s0PyktfrWP/bBByON2cC/quaoljwa
4z+WPAbHQNjmv9APYC79WPa/POiYUz7b8T/e1I/ZLZ4FwGh+yiAvXrA/r6Cd
mqkP/T/Fj57He535v+CIuZaPSvQ/5uCJQClTBEAPH30GHqr7v+uTKNM/ndW/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/M/bwyyh57r8KHrfGTSPxv/62
g8AUecU/iBI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/0M+fVSQp7j9MBLENEKi/
v2Bg8t6JR8y/MG81Wf665D8Ac3jOzx/lv6qvuwGuT+u//jgBT+Wl9T8Va1Lr
SbYBwHh1gUSHOsE/N5WD8hpA+z8vSeTgI536v1c+zXVOk+c/41LfsreFAEDU
kFMAdaP7vxp8s62I9LC/+yI2rw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1283688327999422`, 1.9216645618558266`, 
                 2.5413360834161924`}], 358->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP/BlZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv13F0lzD2tM/tffBG8Bb5j9rqerVXmfjv2V/
bk3D2tO/yG2SPt1P+T8ZnH/vodf7v1QZMocT+cc/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxn7PQbPX9E/5P8KFBxw8r/25FB/
o034P5prgfrGE80/snRlqEhL879+Hxok7JL4vxAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/jKycXS4X8z/w2QtiC5HWP9DStVgxxb2/YRWBj4UU
4z84AjZ6PkTmv8YzPrZsX/a/RNHurVCe8T/YkYcmza8FwBDZUgZnKp8/CkBf
r1Ty/D8td/T6aCT6vzn/q9l/CPQ/arjtO8lCBEDLujZfDd37vwWj7ppKxNa/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0KQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1QLNoJKWqg/Mvbwyyh57r8KHrfGTSPxv/62
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7AypsVjbOs/Zqh9aw5F7j/meMlJsj3A
vxn0m6MPTMu/i4ah1SK45D/SVRCoztXkv6DTmYkdVuu/hp9A9hZ39T/yryMP
z80BwHZ0/Gdg3rs/6db49hgh+z+jCTp1Bf76v2NCkkqiB+c/p3eb7Vt1AEBy
K1unV9r7v7gsq66Bj7W/YUAyDw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1351309890826538`, 1.897326594742322, 
                 2.5565659448775695`}], 359->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP+5lZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tPfBG8Bb5j9pqerVXmfjv2Z/
bk3D2tO/RtTCzMQu+T/ntSzCDRH8v0X9DQvFpMU/kUxZ4ZoX+r841qoispzj
P+7gKiFikvO/qitNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/sXRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DCJhX4rj4797
cz4vHITjv1mBce6ydfY/dfvtd+cy8z9cE0zqlyLWP8TrjYgt3rm/piyzGtsP
4z/odB0HA7Dlv9pFJM2tZPa/uWbsgSVh8T+QPThcHMAFwADHfzKWNGq/5Ji0
RwzU/D96cO/7Dar6v4jGRrpLxPM/oHg4rjsyBEDarBYpkg78v2yVhdWJ7te/
5oNOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mfbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/T/fOhcdg7j92P4nBJazA
v1f6ka9OUsq/LZI6m8215D8oD4TusIvkv7Plf6BeW+u/gJ1XJ/VH9T9CTKee
UeQBwCn+Q7LyO7U/lbY7imgB+z8wEw7fjV37vzCGqFvkeOY/YvFMCs9kAEBg
saH1zw/8v5It/Z9OOLq/n6kyNA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.141806700647572, 1.8728441387419903`, 
                 2.5716011141574966`}], 360->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAO7tDAWLr+L8ldherbDDiP/RlZrmh
5sC/AAMXR8Bb5r8uOajSXmfjv1vF0lzD2tM/tPfBG8Bb5j9pqerVXmfjv2N/
bk3D2tO/jE6piUUN+T/LNeb3Ckn8vz6hMwQ6ScM/kUxZ4ZoX+r841qoispzj
P+/gKiFikvO/qitNXGePBMCle3QCO9bdPxf7PQbPX9E/5P8KFBxw8r/25FB/
o034P5ZrgfrGE80/sXRlqEhL879+Hxok7JL4v/AZDzsW5Zk/DCJhX4rj4797
cz4vHITjv1iBce6ydfY/8/5DbW1O8z8w1qnaY6/VP9jx07xc/rW/OPxjlT0M
4z9gveH8mRvlvwVjLgrAaPa/GiaslMEj8T8yjAw1Gs8FwKjHKqvA66K/QCgm
wNK0/D9zsaBeYC77v4mPFIr4ffM/nP3b4YEhBEBQfZOHqD78v69vDUHmG9m/
5oNOcX6B+b8uJuFmj+biP62tV1g2r+W/pIR3LoyCAMD82SgWxY3gPzqQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP0QLNoJKWqg/Mfbwyyh57r8KHrfGTSPxv/q2
g8AUecU/hhI8U6Uf5b9UVvOAvXXjv64ypsVjbOs/zfoke0187j+ifCvRWR/B
v9l7o3xaWsm/9vmS2P6z5D9kM2ZpfEHkv94Cit1wX+u/U7oqj4MY9T+M03/Y
z/kBwKje0bKTHK0/ZrvnJAzh+j+fc0Ortbv7v7ADm8of5+U/cVJYUxJUAECO
2by/2UP8vyA+532S7r6/ScI2ow==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.14839545911437, 1.8482190582898341`, 
                 2.586440446261954}], 361->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBUQKu/SFib1JlAgAAABgAAAADAAAAPLtDAWLr+L8ldherbDDiP+5lZrmh
5sC/AQMXR8Bb5r8uOajSXmfjv17F0lzD2tM/tffBG8Bb5j9qqerVXmfjv2Z/
bk3D2tO/Pvf4EWLr+D+tqvcylX/8v51qG4Oh5sA/kkxZ4ZoX+r841qoispzj
P+7gKiFikvO/qytNXGePBMCle3QCO9bdPxr7PQbPX9E/5P8KFBxw8r/25FB/
o034P5xrgfrGE80/snRlqEhL879+Hxok7JL4vyAaDzsW5Zk/DSJhX4rj4797
cz4vHITjv1mBce6ydfY/LPMsGL5p8z+6NvAueDfVP5QPDE0MJrK/M5i/R60J
4z8aIjbuDofkvypxFhyja/a/toq1rynm8D8K772FxdwFwOhO2adsIbK/4PYJ
iKqU/D+VPYHRVbH7vzA1+cSLNfM/UmS9JJ0QBEDuf7a6TG38v/z2e11ITNq/
54NOcX6B+b8uJuFmj+biP6ytV1g2r+W/pIR3LoyCAMD82SgWxY3gP0aQFVP8
2LE/kF2nCr+t9b8EUG7q7LLwP1wLNoJKWqg/Mvbwyyh57r8KHrfGTSPxvwC3
g8AUecU/hxI8U6Uf5b9UVvOAvXXjv7EypsVjbOs/Bu8NJp6X7j8aHOV8RZfB
v0uDsWBGZMi/9MfAsbay5D/CZRDiNvfjvwMRcu9TYuu/+kDX4MXo9D8w4pwP
SA4CwKQMu7ysV58/D3cBTQbA+j8hdDyCdRj8v4OiXPVfUuU/+O/cFidDAEBO
Fdf2cHb8v61B7pv32MG/pyExCA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], 
                    SphereBox[{1, 2, 3, 4}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    SphereBox[{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}, 0.24]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 15}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{15, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 7}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 8}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 19}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{19, 9}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 20}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 10}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 21}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 11}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 22}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 12}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 23}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 13}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 14}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1548967627242617`, 1.8234532286818776`, 
                 2.6010828111112985`}]}, Dynamic[$CellContext`i9476$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.9197994530681467`*^9, 3.919799608762884*^9, 
  3.919799687030052*^9, 3.919799972254601*^9, 3.919800536186047*^9, 
  3.9198006964642277`*^9, 3.91980114380646*^9, 3.919801369325227*^9, 
  3.919801493327729*^9, 3.919801805418309*^9, 3.919801865660822*^9, 
  3.919801941081646*^9, 3.919802004482244*^9},
 CellLabel->
  "Out[1465]=",ExpressionUUID->"69e97325-31f0-4cf5-8da4-ca4739665d2c"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["CH3NO2", "Section",
 CellChangeTimes->{{3.9198515927996264`*^9, 3.919851593762348*^9}, {
  3.91985266458792*^9, 
  3.919852666455021*^9}},ExpressionUUID->"f41b4822-9f9b-4fc9-ba0c-\
0f3e6e4e7ed2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<Nitromethane\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919852683441238*^9, 3.919852714474255*^9}},
 CellLabel->
  "In[1525]:=",ExpressionUUID->"893e0de6-b95f-4f82-b357-d043f418abf4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.8660254037844386, -0.4999999999999998}, \
{-0.5021194001350998, -0.28989877083333315`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False], 
                StyleBox[{
                  
                  LineBox[{{-0.5021194001350998, -0.28989877083333315`}, \
{-0.1382133964857611, -0.0797975416666666}}], 
                  
                  LineBox[{{{-0.05999999999999994, 
                   0.1823733333333334}, {-0.05999999999999994, 
                   0.498132375}}, {{0.06000000000000005, 
                   0.1823733333333334}, {0.06000000000000005, 0.498132375}}}], 
                  
                  LineBox[{{0.13821339648576117`, -0.07979754166666665}, {
                   0.4251792386989288, -0.24547734791666675`}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{-0.05999999999999994, 
                   0.498132375}, {-0.05999999999999994, 
                   0.8138914166666666}}, {{0.06000000000000005, 
                   0.498132375}, {0.06000000000000005, 0.8138914166666666}}}], 
                  
                  LineBox[{{0.4251792386989288, -0.24547734791666675`}, {
                   0.7121450809120964, -0.41115715416666687`}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.8660254037844386, -0.4999999999999998}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.291989, 0.437977, 0.888609], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.08459508333333327, -0.10737333333333328`}, \
{-0.08459508333333327, 0.10737333333333338`}, {-0.055444583333333276`, 
                    0.10737333333333338`}, {
                    0.05734841666666671, -0.061230833333333276`}, {
                    0.05734841666666671, 0.10737333333333338`}, {
                    0.08459508333333338, 0.10737333333333338`}, {
                    0.08459508333333338, -0.10737333333333328`}, {
                    0.055444083333333366`, -0.10737333333333328`}, \
{-0.05734891666666661, 
                    0.06137666666666672}, {-0.05734891666666661, \
-0.10737333333333328`}}}]}, {
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.22115175000000004`, 
                    0.07883500000000004}, {0.17970675000000003`, 
                    0.07883500000000004}, {0.17970675000000003`, 
                    0.03739000000000006}, {0.16234341666666668`, 
                    0.03739000000000006}, {0.16234341666666668`, 
                    0.07883500000000004}, {0.12089841666666673`, 
                    0.07883500000000004}, {0.12089841666666673`, 
                    0.09619833333333339}, {0.16234341666666668`, 
                    0.09619833333333339}, {0.16234341666666668`, 
                    0.13764333333333334`}, {0.17970675000000003`, 
                    0.13764333333333334`}, {0.17970675000000003`, 
                    0.09619833333333339}, {0.22115175000000004`, 
                    0.09619833333333339}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3},
                     {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQPW1HJfscz137nZb/WjHzxXt7GP/alMAg37YP9p1F
PEvSr23f7/Js+9WZPz7YWzK0hjF/2LT/lfuGOCPvj/bTrIOrLITX7F8sz7v8
zNyP9hXzdjgsuzlvf0O39WnJ4x/tGe4safqhp2wP40docdqrF0+B8zfkulT8
iV9sL7v3C+fmzR/tdc5W9fi2rbaPUEhvf9rz0Z7HPEA84dpG++U/bY9Ipn20
X/NUe2n3xy32/w44Xf6v/9F+xWXxtKMi2+0L3twsnvnqg/2ig8zq/8132j8S
LxQxXvrBfh7EP/YNQj0FDWEIfvGZnon//7yH89/w7jOY6fXe3mupqdYUzZ32
ru1rj/1f9c7+zP0vqQtebrOv2PXgp5HcO3ulnTmrJ6zcYr/6rbBu2sS39hUv
p4Usqdxovyvx9qIzam/tH8ScfOm2eZX9ohl7GNPuvbG/kXr0tF7xIvseX4ld
/6cC+WxXUvolJ9szvOzIPFP4xp6BoUJ3IXPzPhj/xVk+JpvNU/bD+De+rO2b
PXPx/gMWO0rOzHxj7321mZH5wOr9jjfEus+8fGN/75aOlennjfsPlZcuPGP5
1n7PUvvrszi37n9iv33V/2Vv7WOtzymbKm/fv3JdGEOa4Tv7fxdiCs7b7Nxf
PLtg/Znd7+Dx/V2q6bGRHyL+YekBAG9kIY0=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfUJ+/ePZJzft11E4/vLfk/f2MH7o5oeH/wu8t+fk
t2Wdw7hxf/a2T5P+Z76zl7i9cYLF41X7axSf7Pn//q293IyXYpaHF+/v67n6
7H/pW/sXszhXZS2bul+UWfD8f4u39gwzrIOrLJThfAHm758+7p9qD+Pn2Jwu
MXi82J5v6ePwmWVv7WVK/swI/7bKnuFlR+aZj2/tlbbZfTvCstH+26oVV/7n
vLM/ssSpbf7JTfaFMZubzki/h/Orfs5VM/6H4CuGiqzf5PbB/tiEZze/sW+y
v3Fnn4lR6wf7PydLyw+2bLD/wrn58cxdH+xT2Li0JJjX2f874HT5//sP9kuy
P0elTFtp/2Th+7xUyY/2CYySU/UPL7bfqSRXdsbso72FXu28r/dn2/ct9qk1
DvloH+CzQLdnZq/9+xWGis+SPtozdJ76FmFoDOenlF85f8lnyn4YX0EspcCS
efF+iQdTzWe5fbQ/ZGlgwVSwan/4jZ9LGPg+2l+Qu+Sd8W7D/qkXYoXSr36A
x8dVXsa1z8oQfFh8AQDa7PFO
                    "]}]}}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.800498, 0.201504, 0.192061], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQPU00M90994X9gQjW8DTxB/th/FVrdm479ezu/oh9
1z6v3f3C/kuawsoZsnf2L1rTXlsV8dI++oFdq9nlW/s/SGxOcP/60r688XTy
2Y6b+7e2B21bu/+VPeslwcszHt/Y/73swfW121/D+X+mBiiJRL2B81sm31lf
9eaNfR+37g1jw5v7a37KH7yf99Z+QV3yo8wzN/d3BTu9dvv41j5NkuP9jPRb
++NO/o1ZE/LOnufPl00MDrf3y7lLTxWe+c7exW+GwazQO/vvHrE4W3X3nX3N
Aut1xtl39+9tds9c9/+dPeO287b/lt6D8/uNi/MYmB/A+aKfHM+nbX2wP4hx
fu7a2+/s91QEWTKEPty/6IXY13WT39l3usqznX34cP/Zx0f/rvF+Zx8m9ObS
zLxH+29ovi5a//Stvfs8lVjjm4/2lz/6ErY+8a19Qrrzv5mKj/ezLRa5uvbu
G/vSTc9dGbIe73/wpi7Z3f+NPaN4+TTjvsf7Px/3nFO17TWcb3XNneOhAIIf
k5ur/7Dmlb3jcfdu47TH+0P4HXZU/Xppf0D9ZYmx2OP9vhuFHEUqXtrbd3TF
GR97tP9TeEGvu+hLe7kDHqEMkY/227becxa59MI+InDl/5nnHu7v3OTz60Hf
C/u+lP4AY5eH8Pjmelorc3YjIv5h6QEAdoQpIw==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvSHjUbZ77Ev7a/ctxBilH+yH8df4yNkwvH+w/8Sq
Denu017aT/fkzWWY9nD/Dz3feHeOV/at96SdGQQe7Vff/DLMveqVfXGxliRD
16P9l/6zT3bnfG3/5s87A4bjj/Z/kNic4L4VwT/E8qG8KuUNnF/AsPT92i9v
7D9HyaxI63y0/7Xwi8QHqW/tGcXLpxnzPdqfq6zQLnz9rT1PaLg2w+SH+50W
Ktxcx//OfsJin1rjJw/g/A62pJtnGBH8utXrnE2f3tt/SG7q4crvb+0X9bDo
mr++u/8Fq7u48PG39kY3jAtniN7dz//2R9aaaUDz/3zZxOBwZ39yM7veQ/+3
9qUVji5Zs27v339n5cO1n97YK5S2q59Tub1f2sxnatXUN/anC89yGa2/tf/W
WT7Jhzpv7N1iLKvTS27t/6VaLvxwx2s4/92Km4EiIgi+O3dQoHvbK/vF9SsU
pz+9tZ/X8+qRKv5X9ivmSeT8PX57/3mOe/fWznhpv3Zvx7bkVXfg8bHuxG/v
VJV7+9HjCwApXOvy
                    "]}]}, {
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1.094102762117772, -0.42103141666666694`}, {
                    0.9938494287844386, -0.42103141666666694`}, {
                    0.9938494287844386, -0.4036680833333336}, {
                    1.094102762117772, -0.4036680833333336}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"H\"", "3"], "\"N\"", 
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["7", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["6", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.8660254037844386, -0.4999999999999998}, \
{-0.5021194001350998, -0.28989877083333315`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False], 
                StyleBox[{
                  
                  LineBox[{{-0.5021194001350998, -0.28989877083333315`}, \
{-0.1382133964857611, -0.0797975416666666}}], 
                  
                  LineBox[{{{-0.05999999999999994, 
                   0.1823733333333334}, {-0.05999999999999994, 
                   0.498132375}}, {{0.06000000000000005, 
                   0.1823733333333334}, {0.06000000000000005, 0.498132375}}}], 
                  
                  LineBox[{{0.13821339648576117`, -0.07979754166666665}, {
                   0.4251792386989288, -0.24547734791666675`}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{-0.05999999999999994, 
                   0.498132375}, {-0.05999999999999994, 
                   0.8138914166666666}}, {{0.06000000000000005, 
                   0.498132375}, {0.06000000000000005, 0.8138914166666666}}}], 
                  
                  LineBox[{{0.4251792386989288, -0.24547734791666675`}, {
                   0.7121450809120964, -0.41115715416666687`}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.8660254037844386, -0.4999999999999998}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.291989, 0.437977, 0.888609], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.08459508333333327, -0.10737333333333328`}, \
{-0.08459508333333327, 0.10737333333333338`}, {-0.055444583333333276`, 
                    0.10737333333333338`}, {
                    0.05734841666666671, -0.061230833333333276`}, {
                    0.05734841666666671, 0.10737333333333338`}, {
                    0.08459508333333338, 0.10737333333333338`}, {
                    0.08459508333333338, -0.10737333333333328`}, {
                    0.055444083333333366`, -0.10737333333333328`}, \
{-0.05734891666666661, 
                    0.06137666666666672}, {-0.05734891666666661, \
-0.10737333333333328`}}}]}, {
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.22115175000000004`, 
                    0.07883500000000004}, {0.17970675000000003`, 
                    0.07883500000000004}, {0.17970675000000003`, 
                    0.03739000000000006}, {0.16234341666666668`, 
                    0.03739000000000006}, {0.16234341666666668`, 
                    0.07883500000000004}, {0.12089841666666673`, 
                    0.07883500000000004}, {0.12089841666666673`, 
                    0.09619833333333339}, {0.16234341666666668`, 
                    0.09619833333333339}, {0.16234341666666668`, 
                    0.13764333333333334`}, {0.17970675000000003`, 
                    0.13764333333333334`}, {0.17970675000000003`, 
                    0.09619833333333339}, {0.22115175000000004`, 
                    0.09619833333333339}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQPW1HJfscz137nZb/WjHzxXt7GP/alMAg37YP9p1F
PEvSr23f7/Js+9WZPz7YWzK0hjF/2LT/lfuGOCPvj/bTrIOrLITX7F8sz7v8
zNyP9hXzdjgsuzlvf0O39WnJ4x/tGe4safqhp2wP40docdqrF0+B8zfkulT8
iV9sL7v3C+fmzR/tdc5W9fi2rbaPUEhvf9rz0Z7HPEA84dpG++U/bY9Ipn20
X/NUe2n3xy32/w44Xf6v/9F+xWXxtKMi2+0L3twsnvnqg/2ig8zq/8132j8S
LxQxXvrBfh7EP/YNQj0FDWEIfvGZnon//7yH89/w7jOY6fXe3mupqdYUzZ32
ru1rj/1f9c7+zP0vqQtebrOv2PXgp5HcO3ulnTmrJ6zcYr/6rbBu2sS39hUv
p4Usqdxovyvx9qIzam/tH8ScfOm2eZX9ohl7GNPuvbG/kXr0tF7xIvseX4ld
/6cC+WxXUvolJ9szvOzIPFP4xp6BoUJ3IXPzPhj/xVk+JpvNU/bD+De+rO2b
PXPx/gMWO0rOzHxj7321mZH5wOr9jjfEus+8fGN/75aOlennjfsPlZcuPGP5
1n7PUvvrszi37n9iv33V/2Vv7WOtzymbKm/fv3JdGEOa4Tv7fxdiCs7b7Nxf
PLtg/Znd7+Dx/V2q6bGRHyL+YekBAG9kIY0=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQfUJ+/ePZJzft11E4/vLfk/f2MH7o5oeH/wu8t+fk
t2Wdw7hxf/a2T5P+Z76zl7i9cYLF41X7axSf7Pn//q293IyXYpaHF+/v67n6
7H/pW/sXszhXZS2bul+UWfD8f4u39gwzrIOrLJThfAHm758+7p9qD+Pn2Jwu
MXi82J5v6ePwmWVv7WVK/swI/7bKnuFlR+aZj2/tlbbZfTvCstH+26oVV/7n
vLM/ssSpbf7JTfaFMZubzki/h/Orfs5VM/6H4CuGiqzf5PbB/tiEZze/sW+y
v3Fnn4lR6wf7PydLyw+2bLD/wrn58cxdH+xT2Li0JJjX2f874HT5//sP9kuy
P0elTFtp/2Th+7xUyY/2CYySU/UPL7bfqSRXdsbso72FXu28r/dn2/ct9qk1
DvloH+CzQLdnZq/9+xWGis+SPtozdJ76FmFoDOenlF85f8lnyn4YX0EspcCS
efF+iQdTzWe5fbQ/ZGlgwVSwan/4jZ9LGPg+2l+Qu+Sd8W7D/qkXYoXSr36A
x8dVXsa1z8oQfFh8AQDa7PFO
                    "]}]}}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.800498, 0.201504, 0.192061], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQPU00M90994X9gQjW8DTxB/th/FVrdm479ezu/oh9
1z6v3f3C/kuawsoZsnf2L1rTXlsV8dI++oFdq9nlW/s/SGxOcP/60r688XTy
2Y6b+7e2B21bu/+VPeslwcszHt/Y/73swfW121/D+X+mBiiJRL2B81sm31lf
9eaNfR+37g1jw5v7a37KH7yf99Z+QV3yo8wzN/d3BTu9dvv41j5NkuP9jPRb
++NO/o1ZE/LOnufPl00MDrf3y7lLTxWe+c7exW+GwazQO/vvHrE4W3X3nX3N
Aut1xtl39+9tds9c9/+dPeO287b/lt6D8/uNi/MYmB/A+aKfHM+nbX2wP4hx
fu7a2+/s91QEWTKEPty/6IXY13WT39l3usqznX34cP/Zx0f/rvF+Zx8m9ObS
zLxH+29ovi5a//Stvfs8lVjjm4/2lz/6ErY+8a19Qrrzv5mKj/ezLRa5uvbu
G/vSTc9dGbIe73/wpi7Z3f+NPaN4+TTjvsf7Px/3nFO17TWcb3XNneOhAIIf
k5ur/7Dmlb3jcfdu47TH+0P4HXZU/Xppf0D9ZYmx2OP9vhuFHEUqXtrbd3TF
GR97tP9TeEGvu+hLe7kDHqEMkY/227becxa59MI+InDl/5nnHu7v3OTz60Hf
C/u+lP4AY5eH8Pjmelorc3YjIv5h6QEAdoQpIw==
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvSHjUbZ77Ev7a/ctxBilH+yH8df4yNkwvH+w/8Sq
Denu017aT/fkzWWY9nD/Dz3feHeOV/at96SdGQQe7Vff/DLMveqVfXGxliRD
16P9l/6zT3bnfG3/5s87A4bjj/Z/kNic4L4VwT/E8qG8KuUNnF/AsPT92i9v
7D9HyaxI63y0/7Xwi8QHqW/tGcXLpxnzPdqfq6zQLnz9rT1PaLg2w+SH+50W
Ktxcx//OfsJin1rjJw/g/A62pJtnGBH8utXrnE2f3tt/SG7q4crvb+0X9bDo
mr++u/8Fq7u48PG39kY3jAtniN7dz//2R9aaaUDz/3zZxOBwZ39yM7veQ/+3
9qUVji5Zs27v339n5cO1n97YK5S2q59Tub1f2sxnatXUN/anC89yGa2/tf/W
WT7Jhzpv7N1iLKvTS27t/6VaLvxwx2s4/92Km4EiIgi+O3dQoHvbK/vF9SsU
pz+9tZ/X8+qRKv5X9ivmSeT8PX57/3mOe/fWznhpv3Zvx7bkVXfg8bHuxG/v
VJV7+9HjCwApXOvy
                    "]}]}, {
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1.094102762117772, -0.42103141666666694`}, {
                    0.9938494287844386, -0.42103141666666694`}, {
                    0.9938494287844386, -0.4036680833333336}, {
                    1.094102762117772, -0.4036680833333336}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"H\"", "3"], "\"N\"", 
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["7", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["6", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C([N+](=O)[O-])([H])([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"LYGJENNIWJXYER-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"C", 
    Atom["N", "FormalCharge" -> 1], "O", 
    Atom["O", "FormalCharge" -> -1], "H", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{2, 3}, "Double"], 
    Bond[{2, 4}, "Single"], 
    Bond[{1, 5}, "Single"], 
    Bond[{1, 6}, "Single"], 
    Bond[{1, 7}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{{3.919852685886633*^9, 3.9198527158188553`*^9}},
 CellLabel->
  "Out[1525]=",ExpressionUUID->"d5dcc0ee-d18f-4572-b2de-bbf62d43447a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"AtomList", "[", "molecule", "]"}], "\[IndentingNewLine]", 
 RowBox[{"BondList", "[", "molecule", "]"}], "\[IndentingNewLine]", 
 RowBox[{"torsionIndices", "=", 
  RowBox[{"{", 
   RowBox[{"3", ",", "2", ",", "1", ",", "5"}], "}"}]}]}], "Input",
 CellChangeTimes->{{3.919852870296233*^9, 3.919852872621789*^9}},
 CellLabel->
  "In[1530]:=",ExpressionUUID->"8a5f4ff8-3564-4d31-8c00-6d82a12428a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Atom", "[", "\<\"C\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", 
    RowBox[{"\<\"N\"\>", ",", 
     RowBox[{"\<\"FormalCharge\"\>", "\[Rule]", "1"}]}], "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"O\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", 
    RowBox[{"\<\"O\"\>", ",", 
     RowBox[{"\<\"FormalCharge\"\>", "\[Rule]", 
      RowBox[{"-", "1"}]}]}], "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}], ",", 
   RowBox[{"Atom", "[", "\<\"H\"\>", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.919852738557907*^9, 3.919852901497491*^9},
 CellLabel->
  "Out[1530]=",ExpressionUUID->"c026eaf9-6a6a-445b-ac96-2d3722836754"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "3"}], "}"}], ",", "\<\"Double\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "5"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], ",", "\<\"Single\"\>"}], "]"}], ",", 
   RowBox[{"Bond", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "7"}], "}"}], ",", "\<\"Single\"\>"}], "]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.919852738557907*^9, 3.919852901574236*^9},
 CellLabel->
  "Out[1531]=",ExpressionUUID->"16d3d05e-6eb8-44f1-b3f4-56dc0ee183a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "2", ",", "1", ",", "5"}], "}"}]], "Output",
 CellChangeTimes->{3.919852738557907*^9, 3.9198529016245832`*^9},
 CellLabel->
  "Out[1532]=",ExpressionUUID->"9272fdc0-dd46-4641-a9f4-eb18af9f5870"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.919852785317449*^9, 3.9198527901564817`*^9}},
 CellLabel->
  "In[1529]:=",ExpressionUUID->"50af2393-9ad9-4499-8790-895ef70f3f14"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA2kDKbRti9j8AALB5WO5wvgB0ujhl
G10/nju9K9qktr8AABQ4zUpsPhmtWvdzyXe/tKnsIn/Q5L9L8WqrO6DxP4DL
T4UUoFc/4zw5S3/Q5L9LI/aoO6DxvwBfAAYboFc/NKmOCpfu+z96JQd7/rHs
P96goyUiheC/7ufUiUN1+z8AgId9LDnQvrMrWnSAvfA/JwWDCZfu+z/EKhGi
9rHsv1/dt2MwheC/IG0Oy8335D8AADDtjkc2vhkQLKmagmC/k7/85U+g37+S
OzrjPS7fPxw6FjfO32u/eMWX1clTz78EkoOBWKnjP1jp3NM9jE+/pnoPEdhI
y78nZ0Nd5Uiwvwpt4qejyHy/6uC44RnO6L88VHFHrZvwP9BdhhmuGi0/HvxI
lfePoj+pOvAh50iwPyjt0kZEynK/fnIgZOTS4L9ajmQPyqTyP6Nlt6NpzmU/
VuSwkBql17+vvNCaO6Dhv1mV2jVt4WG/B3UsPFko+T+GdCpZ/rHcP6RDB3OU
dtC/ZJTPe6/r+D8AQG7f5XzAvlBaqE3HxOA/AKOmO1ko+T+42+3D9rHcvyWA
G7GidtC/sqjikw==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], 
       SphereBox[{2}, 0.32000000000000006`]}, 
      {RGBColor[0.800498, 0.201504, 0.192061], 
       SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
       {RGBColor[0.291989, 0.437977, 0.888609], 
        CylinderBox[{8, 2}, 0.15]}}, {
       {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{11, 9}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{9, 12}, 0.08]}, 
       {RGBColor[0.291989, 0.437977, 0.888609], 
        CylinderBox[{13, 10}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], 
        CylinderBox[{10, 14}, 0.08]}}, {
       {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{2, 15}, 0.15]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{15, 4}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{16, 5}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{17, 6}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{18, 7}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{2.2480967411395474`, -1.7830317826560438`, 1.786409444812737},
  ViewVertical->{0.5757882488620218, -0.4773348557802354, 
   0.6637916299032915}]], "Output",
 CellChangeTimes->{3.919852790675887*^9},
 CellLabel->
  "Out[1529]=",ExpressionUUID->"de8b76a3-91bc-4d50-86c0-22cef92c80be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"relaxedScan", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"molecule", "=", 
        RowBox[{"MoleculeModify", "[", 
         RowBox[{"molecule", ",", 
          RowBox[{"{", 
           RowBox[{"\"\<EnergyMinimizeAtomCoordinates\>\"", ",", 
            RowBox[{"torsionIndices", "->", "ang"}]}], "}"}]}], "]"}]}], ",", 
       
       RowBox[{"{", 
        RowBox[{"ang", ",", 
         RowBox[{"-", "180"}], ",", "180", ",", "5"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"torsionList", "=", 
     RowBox[{"MoleculePlot3D", "/@", "relaxedScan"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"ListAnimate", "[", "torsionList", "]"}], "\[IndentingNewLine]", 
   RowBox[{"ListLinePlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"MoleculeValue", "[", 
       RowBox[{"relaxedScan", ",", "\"\<MMFFEnergy\>\""}], "]"}], "-", 
      RowBox[{"MoleculeValue", "[", 
       RowBox[{
        RowBox[{"relaxedScan", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<MMFFEnergy\>\""}], "]"}]}],
      ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Axes", "->", "False"}], ",", 
       RowBox[{"Frame", "->", "True"}], ",", 
       RowBox[{"BaseStyle", "->", "15"}], ",", 
       RowBox[{"FrameLabel", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Torsion angle\[ThinSpace](\>\"", ",", 
             RowBox[{"Quantity", "[", 
              RowBox[{"\"\<\>\"", ",", "\"\<Degrees\>\""}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}], ",", 
          RowBox[{"Row", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<Energy\[ThinSpace](\>\"", ",", 
             RowBox[{"Quantity", "[", 
              RowBox[{"\"\<\>\"", ",", 
               RowBox[{
               "\"\<KilocaloriesThermochemical\>\"", "/", "\"\<Moles\>\""}]}],
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "}"}]}], ",", 
       RowBox[{"DataRange", "->", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "180"}], ",", "180"}], "}"}]}]}], "}"}]}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.919850108985312*^9, 3.919850158932712*^9}, {
  3.91985020674454*^9, 3.919850337520555*^9}, {3.919850387647703*^9, 
  3.919850402048278*^9}, {3.9198504438656063`*^9, 3.919850474571083*^9}, {
  3.919852670646165*^9, 3.919852672511868*^9}, {3.919852722131147*^9, 
  3.9198527352148*^9}, {3.919852835159801*^9, 3.919852840529209*^9}},
 CellLabel->
  "In[1533]:=",ExpressionUUID->"a2a0031b-d9d4-4700-a717-345b47be7da9"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i9557$$ = 70, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i9557$$ = 1}, 
     "\"max\"" :> {$CellContext`i9557$$ = 73}}, Typeset`bookmarkMode$$ = 
    "Menu", Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i9557$$], 1, ""}, 1, 73, 1, ControlType -> 
      Animator}}, Typeset`size$$ = Automatic, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    PaneBox[
     PanelBox[GridBox[{
        {
         ItemBox[
          ItemBox[
           TagBox[
            StyleBox[GridBox[{
               {"\<\"\"\>", 
                AnimatorBox[Dynamic[$CellContext`i9557$$], {1, 73, 1},
                 AnimationRate->1.959578828800001,
                 AnimationRunTime->365.7990052356071,
                 AnimationRunning->False,
                 AnimationTimeIndex->35.115702029673,
                 
                 AppearanceElements->{
                  "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons", 
                   "DirectionButton"},
                 AutoAction->False,
                 DisplayAllSteps->True]}
              },
              AutoDelete->False,
              
              GridBoxAlignment->{
               "Columns" -> {Right, {Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
             "ListAnimateLabel",
             StripOnInput->False],
            {"ControlArea", Top}],
           Alignment->{Automatic, Inherited},
           StripOnInput->False],
          Background->None,
          StripOnInput->False]},
        {
         ItemBox[
          TagBox[
           StyleBox[
            PaneBox[
             TagBox[
              PaneSelectorBox[{1->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAnlC9ayTt8j/DwLVcwuzWP8k3Q9jq
3NS/tboE/5aFxz9oFv7NRRrdv+EW3B3pvdo/HJ3Tj8oU5D+DI2Z7EMH0v8jk
/uzCUPM/u+GR+JQt8L9MmH6zNVbNvyyo8S/Ms8g/bphvdVv65D8PD1lLcuHw
P+Jykq8aZO+/bja1nv5+/D/zJ5BrPL3sP53NEXjBS9o/sheCPezC/D+9THBU
YiPVv9y4b9N0Ge2/9OedS9fd5T+YViHFDbaov2B8Yxb5g6c/WBdst0SZ0T8W
0JLfnjvtv+wEpNFaEes/HsDe840p4T8kgjj+pNPqvxTQR5cf7+g/REfNOv8u
qz9aZFivP4Lfv7hLOFgk4Nw/xoV+h6nM3z8At7zzDlv1v/7xlbtR2fM/zBGr
F7cf1D92yKPsS7Lavwrif+Otm9g/VffnW0BD6D8GkA8DEif0v5LXZx40yPI/
ypRiMcR52r9Hsd5TsOLVv3x16prni9M/1Rx1JlJq7T9Af4biopzmP2QH2g1I
6eS/hkM5hRG29z8qhPXMzhnkP1BXOn9au6U/KLSfVAjY9z9gQFeEAJaMP2Cq
yB/1w+O/tIPuIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.031081826509871423`, -2.3022983434503197`, \
-2.474440594923774}], 2->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAiJr4S1rs8j+mrF0I6GjXP/4Rnt9e
VtS/g9wbHjmNxz/ExKTUUKXdv/LK5lYNKNo/D9bQuB384z8wPFizFy30v+ay
AfTj6vM/se2uaQwd8L8l2ZeKSBHTvz/h4bO6yb4/Eml8jMny5D/DjZsHrEnx
P6gZseDEe+6/OZiZIGOS/D/+KU3fR1/sP29WUTq3cds/746XaPSu/D84m1RB
MOPTv7IxzvSjbe2/GBa8bwHe5T94YBwxo/Gov9DjIt25Rqc/AtIrc/mF0T9w
Tn2uD+3svytfSbUKYes/L+TBRm8c4T9SjIUiyD/qvxpsLd7DiOk/mJgPD1Bp
qz9xQ04wTCngvwS+Ai5UANw/8LB15Mie3z+4LFaWadj0v6qvyKn1YPQ/cOk5
HA8g1D+lAq1ICfjav+DXyn/GT9g/ptNm/9Yo6D+oS1rQxYHzvyK2Oj7SdPM/
QOTWi8pW2r/0Tp6vTFvYv6Gh7wE+7dA/Ec82Er9l7T/s+LIJ5iPnP1QRQCh6
U+S/YBlJtl6/9z8oAL7x3QnkP8ARzWphbaw/vBRIWqfN9z9wi0g4vi2cP1id
TrJpzOO/25bnzA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.24410230781658981`, 2.3769264775071455`, 
                 2.390613850843353}], 3->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAPE5lAxay8j8vzXocGDXZP0Qh6RDa
Z9O/CWu+wbPVyT8VYMUpP+Pfv+uf3IacCNk/nDDY8fa05D+Xxb2XLBzzv3hk
lLhj+/Q/0DTaMOv87r+lyOphSBDfv4EwyY0FToG/uHtve0234z9xWgGGbx7x
P2hFll4ks+6/eOmVtSVZ+z9XPThk9KHuP4l5vg2ucd0/Ow17YiF8/T+qBao1
Cx3Pv98lZ/xZIOy/nRude8zs5T+YSyo1nLiqv6D6zdcJg6Y/JIaJ5ggD0z8I
dTsuhNHsv/SYMsNA5us/TAgDb9+o4T8wxiKWdFjpv/J/ZPHUlOo/LMGDlPsN
sz93B+9gJ67hv+24qlgIWto//w35c0mh4D9N8cN9cPrzv7jqB62+T/U/vnqd
3DQS1T87sayRL2rcv+mGDrUwt9c/OVO3b6TI6D/hmbex6D3yvzjeIMQIp/Q/
DppqQH6H2L9dFNjFw3nfv2dWblosfsg/GAwdwbyN7D+8DSCNtWvnPwVrhbOI
M+S/2pt93J0F9z/40To5QJ7lP4iwqvmnE7Q/vC3wshsX+D+0lEsDJU2zP0Db
bYIj6uK/dqDkeQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.7144532041746777, -2.464693404313506, \
-2.1998279573134893`}], 4->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAi5HcT9ha8j8tYec2LH7bP4XkzBNT
H9K/t4Ol30RHzT/j3asjvWHhvxPk/aPPe9c/FSfPuxwX5j9Vf8CRZVTzvwbY
Jgky1fQ/H9gzL0xv7b/FPk6Djf3jv5gtroA7hrW/pL5MzmrM4T8oMoNacunx
P9k1RLmldey/u3xk8KrR+j8/QnJoVArvP+YKj90iJuA/YQg7qDZq/T8aD9zK
5lDCv74JzswO8ey/AkLR68AD5j9oasFBOBWtvzj+w0DycaU/RWhswi6E1T/k
ra+40xXuv2Zyio0KL+s/4FOCktam4j+oLn2OtPTpv7AvwlZBOeo/dYga+oz7
uj+AHcW4THLjv8kmxtqYcdg/NhcpI70k4j8kH01crVz0v7Po2FakEvU/muEe
oWGI1j+LPCUdW6Lev12hNW0GhtY/9DZ1VHwJ6j+G3zPHHUzyv1nHdLu/l/Q/
MHdK93od1r9UDn1Tpa/iv61Y0sNAGsI/3fACtw1B6z90Cj1o/cjoPw5UlaGn
wuK/I4cgoEGW9j9q+fJBtWTmP4xiok7lWbw/9swLfIfi9z+gWXnRuFXCPwA+
WitcAOO/6MLivA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0100938442835348`, 2.380388809384844, 
                 2.1766624777158072`}], 5->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAlDm2qWoK8j8Ge2E/sfvcP5cIJjne
iNG/XtOXDvk60D9E5GSRMVLiv1th31gQzdY/2O8TVKPq5j8gCZrbZ+TyvyER
O/17QvU/Bds1Ye6K67/EjHBR+BDov2WbaMBtFsO/DPPJNwwV4D+MJvZgyizy
P4zxNMvSTeu/rbWAvP5S+j+eRmL1oL/vP5ATgY9dteA/guWz8jdT/T/2qtwJ
qFizv+KVtxy3Ye2/bC5c7SgZ5j8QNqGNx6KuvxBj5X7IEKU/C/cpPqJt1z/C
hmhI6WXuv5ak40QjTes/At5KvE5R4z/CbzAAGLXpv1ouAuJcnuo/xOHD4vZA
wT/E74A1mqrkv5jXwLvWe9c/mv54hWQd4z/gDqgtnBD0v7Bu85UtbvU/2rXN
q3bV1z+IsZHakfPfvx7r/fVJHtY/FuGuIuK36j9gA4yJM7jxv5KzgmTKFvU/
VvHp2XFt07+EuGrxlDHlv1AnVvGyg7o/GjObxfAU6j9Ohc6wtmvpP+z64/Mg
CeK/oHcbs7Qu9j8QgonKvB7nPxQ9uMu5w78/iw81TtGu9z9IUOo8hyXIPxZN
pRwTE+O/mnbsPA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.2967465784518941`, 2.341520830110012, 
                 2.064007876301403}], 6->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAdM2U1xml8T87F20ACkjeP35KlZxx
etG//ajrX0ZA0j/h0fO/lyXjvyG/JDJsydY/r3QJ/1086D+pBsx1QmLyv9CV
N7MtufU/R6ZEA1Fx6b/ur8APpN7rv/nuYZ2nIse/EE19BBDT2z+T7BZozVTy
P/t5EC3/F+q/Vjk68V8D+j9e2abaVjbwP94mZIzBm+A//SIZUurm/D/mr9Oq
Q2OMvzbhZOenbe6/s7ePbys15j8MGfX+Sgawv5DSPVbqO6U/tL3z4EoY2j+h
kyDaNZDuvxagZAk9s+s/VGqFvltQ5D+SS2vR5lnpvxvrHHbUI+s/BjvAIyD4
xT/odU5Ev8Dlvxx0bMXUWNc/8q4D2EKa5D+tWPk31q/zvw+DCdgH3fU/dzT3
rXyE2T/aLZk7cIrgvyYK3Z4DOtY/bDoPJnne6z+ltJ6zrhTxv5GoZY5TlfU/
ydFO0y1R0L/oQNrnHYLnv0iP58YwcLY/uCC02N2Z6D9iMjLoz+bpP52Prf2b
auG/ZYNn5DzU9T8sH8JaWcjnP3wGZvgier8/OPjWFAJG9z+8eRbj72TNPzrD
11pwleO/ayfpRg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.532930258828593, 2.2868420720372407`, 
                 1.9608360867569028`}], 7->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAz5802Tel8T9ngGIwYj3ePyVV/Akm
jNG/GaJEjR9G0j/7aDLnjx7jv/+fmdCy6NY/HFbPeC0e5z/TdtCxxYfxv//Q
vtJOb/Y/99lppqVJ6L+IKnjL437tv0h5V2VGFMy/NWZqRSiK2z9rSCs7b3Xy
P9hFKxJMmem/E7hEA3tK+j/U/WwFlA3wP1RGV9IcZ+A/bvaMd7er/D8IfQTX
Me6Nv8sz1e1Z7u6/VciFvL825j84Rgl49v6vv2grdRozcqU/rrVtm9cc2T9w
Hmc0h8ntv/++nGOUXuw/Ucy6cdGy4z8wOGwWlGTov/+yLapi9Os/P2GB0nND
xj8b3C92CdHlvwCsCIrkUtc/X13NpvqL4z9jME95AuHyv/+TGkHbifY/kpNI
MYVq2T/b9TRYFmzgv/6TKheBftY/2U7RSmCw6j9DvVHqiC7wv/8NY2TCVPY/
1hGPvytNzr/CSVXZuU7ov7TG2zsfvbE/XDmP6sGH6D+E6EPHxwTqPza4lIuv
L+G/8as8btn39T/unYWR7JznPwRvZDUnhL4/HstgqHco9z9/XKqh8E3NPy6v
aXk22uO/fdjnRQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.6900011021029075`, -2.314428438109522, \
-1.7921264686848621`}], 8->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA1yG/TJD48T8VYYF5Zw/bP+ipd+mx
sNS/ldACVAfL0D+d7qX2mhnhv4Am/Rnc/9o/dxrXZVdQ6T8BKP8bZrHyvyd2
70noe/U/al8ra0027b+Hsohdl2Xkv2ScsFToCKo/sOW0Lj1j4D86ILNERYf0
P7N0m4jjW+O/B1liAcAP/z92QaIdmYHnP9qvJbUWF9U/LSQSegoA+D+81w/f
yK65v/S/y2ApRPO//NW/IVIr5j+Y8CnPOY+sv2DyFcKoPKk/9eW0Af7s2T+K
LAD2bU7tv9VmwgNHDO0/xg/+Dly/5D8WEqQ4+S3pv7kYG513a+s/kme+i1QE
wj/X+1NV1Snjv5x0pICroNw/EUzF3uhr5T+eLlZLg7nzv65JmSMc5PU/YW0m
YuST2D/Gwu8vwRLev2TYVbMMX9k/3ejo7MU07T9kIajsSKnxv6CiRXC0E/U/
H/cpwcnQ1L+SUBcqmb/ivww6kyT5QM4/r5QZ5C4q6j+AeBMjH0vrP6dJV308
tN2/b70QJyiE+D8AeTFtpoTiP4B8gesymWk/AqNoY0389D8ma71BtaPEP26q
KdtVcOi/puXh2w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8818820592886141, 2.440923623508832, 
                 2.1653119631363493`}], 9->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAP6JBeGTE8j/mSvSTiEbZP46IgCG9
6dK/kTZHqvWEyT8qixbCWPXfvx7ceK2kuNg//e5+cMzX4j9SYSGAdmnxv4UN
6HPVbPY/3jh56uOC7b9G/E1zKinjv34ljcNPCsC/7o8c3OZy5D+nxJ4GGKT0
P+1EeO8P5OO/pcXXDxlh/z8lrrvD7w/lP802vHSVb9o/rZhxQ7w/+T9ZyG8q
ghLEv2EzASN+VfK/EYmKLQP15T8QAYm4QLuqv0BO4S+eO6c/Vw0paPku0T9W
SG6+llXrvwy/vsa+Bu0/9jX8Jo2h4D/iv9+iAnjnvw3KzXc+L+w/+K/viKnh
sj/OidJudunhvxzRafwkkNk/sC4Wboil3T9vAwWH22Dyv8VKpIe1ovY/k0oL
SIvM1D+3AoimxBfcvyDnh14k4dc/osbyqdTc5j81vz15EXLwv0XQK2D1NvY/
Omvnf6Yh17/uoCxq65Hhv2BJsst8s8A/NupP5tf97D9g15sruvXqPzSJOIDu
WN2/8rMMxL4S+T/M6doGmtngPwC57kxhF64/dp3ZXRAC9j90zXj9jnq+P4RV
YWvtD+e/ug/tDQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0789547406555722`, 2.582903133883816, 
                 1.8944308033259027`}], 10->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAQURSSulO8j/eXU1OaFLbP4pY7atR
otK/jwf/bLVMzj8JVI1ER1Lhv/KnAaP4XNg/PmYKGc8+5T8ZfzTgD7nxvzfC
QtIZTPY/Cz/oMcj1679vGOQGdOrmvzJGDF7zR8G/zZWDggcG4j+KO1zIKx31
Pyl2pPyiBuG/rbZP0lde/z8ofpDmDJjlP/+/N7q8Adk/6FDQMmFb+D+dQp1t
3cusv0TPmzM+G/O/MyXy938Y5j/QKDXrmEitv6A9Udyb6qY/8nzvCscU1T/5
mZTPipvsvy+pHrrHxuw/qWnS7phH4j9CuGE13Cjovzev5zvo/+s/X2KTNJWk
vT/kxKaRnovjv+qhOCHYI9k/phBdZDRg4T+HN8GGu9Xyv7WA0LHRffY/9y7a
H5Dj1j9cxufu3zHev/qtyiQZltc/1ru3zWkd6T+rxqc5ZJzwv7kDtfJhGvY/
Jn2o1ppi1L88trilXR7kv7AJ9+f9cb8/KA+UC+1R6z8Ck+/bxfHrP24im9LL
V9q/d/1QjqDW+D+MltuGoKDhP9CdKTmsfak/lEqRPiVV9T+KtZmg7LjHP2Yl
l57Sw+e/EabusQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.2666098244653683`, -2.48502234929855, \
-1.9091263646114487`}], 11->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAbwq9RKYC8j/ra1Ikdb3dP3J1r/EQ
aNC/ztpKAhrF0D+cpYGcOO7iv0kqbnXUgNU/DpBaqLyR6D/tnDsrhhj1v6C5
6d+zL/M/LG8ikWiz7L9XGNgGR17lvweHC+bG0ra/hyh8qBN24j9YAMjX5IX2
P601QGK58Mq/c7+FhNVlAEBpjuh8U/ngP8nJTDo1m9Q/j6Cvg/RP9T/4L6rb
z2bGP4Sv3dPJnfS/IsFPxewz5j+cvmEp+D2wv2DT+g4OY6Q/V1gAJvE22T8R
GbtNQWTwv+qpIfhO9eg/StF/FtFY5D9UrYJXwlbsv3reaAKDKug/YGuW/YIP
wj8DaHu+GCflv7n1JmugS9Y/f72aZhCz5D8gfjg89jT2v3zsV91mYvM/7H/K
hXKC2D8144d6WLXgv9letX8IttQ/nWIa6mhw7D+6uz4aFvzzv8SGe+IA/fI/
xgH9j9tQ1L/63qzRPybkvw6R1ndFmL8/sh77GLA96z9Sm9wgQvXtP0iQz6Jt
4M2/qkTkpihn+T9exBEPDtjfP2BRdSKRzKA/f1U2ZE2p8z/0wROJbnjUP+GM
SRDOt+i/h27ocw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.0138797966545057`, 2.1560399706203404`, 
                 2.3974860589841307`}], 12->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAcUJSrGDf8T9OIpLZPtLdP8OFNDPT
DNG/kDYZd32F0T8Je/4GtQPjv1bg6KreQ9Y/U8vvj6jm6D+Tl2MIojj0v5H5
FRCCHPQ/jtAJvKjW678vYCGGHUrnvzBl28Vsfbq/20G225Ur4j8e5pTdf4P2
PxdlmL2mG8m/jFo90UB7AEBeCss+xe7gP/FrrheO9NE/1qGDrbOk9D++7ZHL
x4DHPyy99y546PS/FZAYCsBA5j+Ip9VoVmqwv0hq0d4t3KQ/BWplDtIP2j+k
TBWQ+wjwvwxWFfqiD+o/mLFJRH6h5D/nEJv3AWPrv0ANi3tQS+k/8nMEdNDX
wz86P0abL1vlvyEpcykxCNc/CE1k8d0Z5T+reYdSX2T1v8SLuK+WTfQ/JzMw
tBIf2T/YtrZyOqzgv4uXXiyMf9U/nkl7LnOz7D97tT++5Azzv15nc3Bt6/M/
RjV9AOoT07+c7Y9G6SblvxQO5PIGSb8/XmMtmiv16j+ybvmTD/jtP064AJKm
ms2/xHtmJ/Fq+T+FG5Sr5NffP8DFPI9c93w/JPLqLApC8z+WjK1fUcnUP5ze
xPusK+m/F03jJQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.1519821883835053`, 2.223031440050626, 
                 2.270565624286951}], 13->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAyn3Ia5ro8T/FvYh2bNrdP3VntdTJ
ytC//SMK1rdg0T+7iLxTxxHjv3/kaypc4NU/89f4qNOl5z8tiwnXrXDzv//B
elOa4PQ/qApuwTDk6r/jS9LVVerov14DEkAEhcW/c7YAuqtc4j/z8uTn34n2
P2LkzJ549ca/f4bgsuyDAEBnjRbd9pLgP2srPaNxEtI/ui8TGveh9D/ixuGs
LibJPxqk9RSn5/S/yQZLYchA5j9kp+BhRJKwvyj02VZJVqQ/BroRp9bX2D+6
pnv6GWvvv7aEt6AomOo/7wx1QETq4z9b+FMHCYjqv4fxcxs6Geo/Iug70r3E
wz/qX1DNT4Plv653r69KX9Y//b+CMqfm4z/FdtMTcqn0v8umy/RVAPU/6VP2
whDf2D+MsSjaPqDgv1BRKKVtYdU/6e9uHwBl6z+Vnz+a6TfyvzPdKbLewPQ/
qfho1tQz0r9PaseUDv7lv6DFxRS0O7Y/BNnISPAW6z9kIocFewDuP6bZGySG
Rcy/ZMXE6Dl4+T9K7FoYLYDfP2A/fOh8eoQ/wtbtwkhF8z+b0HzmwTbVP/j9
IopZGum/2wL0sg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.3419922382079006`, -2.272109664075821, \
-2.112101916812494}], 14->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAADnCa7YLL8T/yDUsx06rdPzOroOYU
u9G/8r4rXYYA0j/aD2mQkPziv36gvTOU/9Y/in4cjAoo6D/kuxhcf7XyvzO/
HZiGiPU/C6G6tzVu6r/+8CZrt/npv/5nuxf5xMK/rlkWXJzN4j9HIup+o5n2
P1GtLdMnHMO/cQ26Wy2zAED+tIl+Z2DfPxvy0qC5V8s/vm9PXQiE8z9hrPhm
iKHKP+EMPOHUVPW/yl/lhKRL5j+IIw7fm5ywvyjVczT9EaU/5gKkJp3B2T+1
L6SrM7Xuv1aPbkq6mOs/kFxgJ39H5D/tV/acW7Lpv06/q/8c+Oo/qcc6kqsz
xT+++7+X/H3lv4ZwgH4xoNc/+1AVQrJ05D/WMcRfNfbzvzVzzuqtsPU/EBo6
8TZn2T/2IxKJJHvgv3bQ+uj2XtY/Gawj1mLb6z/yRW1YyXTxvzELbUVfYPU/
ksEkifJt0b9sAMj9I3vmvwDZv08vOrs/5ZylG1Ey6z/E5TxLWATuP9yBN9Ao
Scu/eEWH0u6Y+T94YepXnYXeP5jI3FjgPKC/5u90pcWn8j8RsmOyy33VP643
5Bqaw+m/o5ru0Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.3881537822206131`, -2.321069965113503, \
-2.027329103513934}], 15->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAASl8SCmWn8T+PnHulsY/dP9IJbsVN
ntK/d2lq4q7B0j/uOcFR2fLivzjiOicBEdg/iPxisS8H6D/cpXq4nmXxvygz
vGH/mfY/g73PVtMc6b9lRQ2/+1vsv4tzWB/cxcO/NqXmRBJq4j8gPmlg1on2
P6TTj+aMoMS/xaAMugW3AEBmarEUB+PfP4GAoN4SsMY/b9dhq6wJ8z/WlVh+
JDTJP+BDYNQ8jPW/qPmswtBX5j+crg38Aaywv5hhM4fNyqU/BJxX4QE12j/B
ID5Ms4Ttv15ftoKG8ew/QmPsMYZN5D/lZHh2Yznovw54X9T4Suw/cKhTQlMd
xz/cF6Q8gZjlv4jJkdWOt9g/6LHCEK1t5D/TFOytcrjyv/zsUc2iw/Y/tv6q
I7T02T8AXN5mMU3gv+j643hzatc/KEcDUrKg6z/lNgnDyhLwv1R5JvZbcPY/
jhE1y/d3z7+qP2eIaqfnv+RQHS8mXLw/5bGFLG7c6j9EJcjJwu3tP6TztTiU
7sy/atAVP7iK+T96gxZdXLneP0gmd1gRGa2/XBu62ohY8j+981Py4RTVP1XG
u0XQM+q/5l/rdA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.5577758206015169`, -2.3746293612417233`, \
-1.8327219891401951`}], 16->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAy+m+hWiy8T9xnaaYBqndP8RcDHJQ
P9K/zqr/AYeP0j8kjQhpcQrjvxIViq3th9c/XRDXcpqN5j89/BjlHcLwv/Ie
yqZoD/c/jmnyaR0I6L+u2ntVgtftv5VrbR+Mscq/H6pru3PS4j8LsnGUipj2
P/lC7z6p78C/nUoO7ezDAEAB7xe4QKreP19PMRQdmcY/lXJhr6Pv8j9mQLzM
2S3MP7T0fUvojPW/ftQ+RkpW5j+s+dRyuNewvzjh9u10IqU/7qXqLLDC2D99
NjoxUgXtv3wS0W1gJ+0/zZJh3QV04z8hTwACW4nnv/A1iLZnu+w/7tUmdrL5
xj/SgKUAbcjlv5/x0mTm89c/cvBgj0ME4z8UduewGyHyvxVWnNRmKvc/perr
yDSi2T92mWvRdUzgv4U4Qfb0G9c/SDBNVvEW6j/MBJUyQMbuv8/n93hq9PY/
TCjl0bOAzb/pM0Lf+XDov5C+pjtPXrQ/2r50Y6Ib6z9oWZs6zALuP0D+gxEl
t8q/gr/tLyGd+T85Rl+ooyneP1DUzp8Hy6u/MC6QGgZR8j/SXoK/+d/VP+UL
AWi8HOq/az/qpw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.713253384414897, -2.381081565344533, \
-1.6791704558999754`}], 17->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAzSm+HdOD8T/1GcRDafzdP8Lp9Ame
ndK/wuJtBsl+0z+ddP4LpkXjv/+D6Tx36tc/m5Q1zued5z8EGWSEvqfwv6Sr
+Bc3Ifc/05s7ZW6R57/pOMZ3673uv7RrQkPpQci/s0TbcGJ44z+E8AgdjLL2
P6JtnoDafK+/UJAvIJXpAEBmPLdWD3bcP8+QJ/O5r7k/BKBBpaKA8T+2ZfGB
c2nRP0DdlGag1/W/fqJZX4Vj5j+MnnGoxR2xv/Bo0stkM6U/TkGOVHln2j/w
vJqLyBntv/KI15+0Xe0/VWUlp48p5D+16SuJWnvnv1aQji712ew/KjwfE+wR
yT863jUN3RTmv5l8Mq42btg/RHLGT/4i5D/Tzf8EWg/yv8vpSvQmQvc/bydM
A5x02j8AC8cKb3bgv2WLoMu3Ztc/8rakTNEY6z9qyJAHRoDuv31tpjtHAPc/
5FQJxBOky7/DVuLByAHpv0yckDYFk7c/JswrVgRA6z8C9/ltpjHuP3a3CFo5
jca/NqUOr36r+T8uqz1NPDndPxwLVhpfY7i/6OR/4TqC8T/Wv9pi7rLXP7EX
EukHf+q/OcnmYA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.7385017516929953`, -2.358517109233903, \
-1.6850545109317208`}], 18->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAVOEN1xSG8T9XIfdv2vvdP5fD+2fH
k9K/Tk40LL9x0z9DmEGSUEnjv7pJp9clz9c/XKgMxEmT5j+APoDBLQjwvzUi
RnbPivc/rqB454ij5r+HytAGOfvvv33DxiV+DMy/YuFFVnom5D+MIQqtvrz2
P5NpFbqyTZ+/7D9pDrD6AEBla6zgWNDaP5I+z4Xd0rM/qZiK2b0W8T+Wa9Cq
m+rSP2+cBrpp5PW/6PQaooRi5j9cHhhpjS2xv4gYrr557aQ/3uQBQf1z2T+X
gvv8Jo/svybs7EOFsu0/FN2luSqS4z+skkYYhcrmvyL9cpSsSu0/UcceJiYz
yT84EJyEoSvmv784IYf+Ntg/CTN6tzMn4z97eq06Vnnxv/adJKLFpPc/9DhZ
RetJ2j9OIOef/2bgv7VaLShNZ9c/rx2f0F//6T8KBaaQCi7tv3SmZ0rZcPc/
DPO8olLVyb9lMYnMRKLpv/jPh4nNkbM/BdIwAlKZ6z/i6QdJtTvuPzAanZOi
iMS/ljDwebq9+T9exlGoGWbcP+TnDw0gPru//jxMWGlO8T92xmMNO3PYP1SN
BZRbieq/nmzl4g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.8525253572390252`, -2.362452903118145, \
-1.552857392465602}], 19->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAuVsD1ROO8T+H50Z9/EneP8HAQTB9
7NG/+QxRHG1F0z8EByodgHzjvzp0Pkd97tY/jRdSR2LF5D8gRgxYoRDvv49t
/wkU0fc/aPvkJqwj5b+SNklo59DwvyJ76YeTAdK/9ZktIA1t5D8BFTaeScD2
P5y7XsrSnHI/zvQiqbT+AECz+aWnjAHaP2Top104ubU/1B46I4YV8T/r/0Jl
MBHVP4jrguW6y/W/954XHG9f5j8ETRp6B16xv+jN8lsACKQ/jZcIR5K81z/o
U6hBJETsv2I28W54nu0/Q1L2sc+J4j89+Y0z/Ujmv9rerEjueu0/+Ay+G80z
yT9ZNDekE3rmv8PLgm0HEtc/TxQZAJ9v4T+7uYxvGgfxv3GDkJP22fc/dhPD
qvPw2T+v2RyW7H7gv7Ec+iDzytY/yxqLjiUb6D/LGP/QDRPsv61XboAxyPc/
1ul4MesBx78UOt52J4/qv2DkU/2ms6M/tCgaZZrE6z/izoe9yFLuP9NFGOUJ
osG/qqKkk77F+T+dcHaSxCXcP1CNrzFe/Li/Rr0e/MxR8T+580Rxlq3ZP7hb
kzHaRuq/17Llig==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.0146596456049357`, -2.3338737178341793`, \
-1.385128146264404}], 20->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAJoSFqKuU8T/UNlNDqxjeP3kMLFXB
HdK/PQjs1RgZ0z/+GNQu0lzjv//hGuSzItc/LDX12WzX4z/CSvZ/k9Dtv0yD
lDGDKfg/nIVXmFd35L+1QxBrrjzxv+9QLwltqtK/AOHJtw2W5T+cDpzyP8j2
P4vH/YqcvaI/4SDz4AkVAUCq6r3k+JHXPy2YnTQbXac/D5FKFal58D+9ZsuO
4IHWPxn5GrBV3fW/NYYA3vFa5j9Q9qk08kGxvxhWuzvKE6Q/u8cbX53L1j9m
2zDl357rv8tVOsDbAe4/bVVdlSr+4T9biJnJhY7lv8wh/JSE4u0/XC054HkB
yT+Dwp88/2Tmv/4VWQ8LQtc/ZHwN5z6L4D8k+uBGYGzwv0wQZPxYMfg/zHm7
u3Sx2T95bwghpVTgvwCu3LhcA9c/9O3czJoj5z89oSpyZsjqv0z2xGatIfg/
+gLDWpbVxb80UHqCF+vqv0BErmsb4aE/pnRqhLJf7D9R3HDDak7uPxCnmIcb
jL+/9OI1tV/f+T+/kAgUUtXaP+ayMN07ZL6/mgroXioH8T/ITg/pRU3aPzj8
ZQXGZOq/8jXm7Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.0821061493585296`, -2.3425542325821276`, \
-1.2655724594881765`}], 21->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAtpQIox+z8T97poRJigHeP40G+O+i
qdG/zDcTcPhq0j8mb5/llUrjv3Zd28/DgtY/zsm4E4lI4z/Fi77Yf2Luv3Kn
K3xI8fc/g97uq8z15L9UBxIM+9rwv1Kxl0uW0dO/TcUx+mMl6D//zrBflLz2
P7bzvhisFMA/eowVzt43AUCMeGXPgKrSP1DR9i+jbJG/nq1dSykA7z96rs2M
uifbP3tTsHZpvPW/qWINv91N5j+kb3QDQyexv6hbjX+DZKM/jrLiIHHO1T/g
XjtbDNLrv4d8Dpgdlu0/bQxRu8yW4T8MnCJjCdvlvxeBNkjVje0/TAlnish2
xz+Q0KthF0bmv+ZYsx8Mi9Y/duCR/H3h3z+YdmWqAK/wv06mIZBa8/c/8ury
mowa2T+8DZNpFE/gvwZiA4B7etY/YaMoKVOg5j9bKrJc/mbrv5aoNWg27/c/
OoXK56CAx7/nvuH+RYDqvyBhHSJsiZU/XHchoNHF7T+e+BHy9jzuP2QZMceZ
PrO/1daZn24R+j+ED3WMBVbYP6Jz9yJtwMK/wrVbJJqZ8D96KilropTcPx5V
rjLSJuq/1l3nuQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.0518637991239177`, -2.354816909322381, -1.29193354063363}],
                22->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA8Aa3M6CG8T+bUDRbXlvePzrPJig1
9NG/y8n62Ys80z+f0Wam7X3jv3ousFRG3tY/WZq79Rds4z9fb0nEMGvtv3VN
yH4zPPg/SiRacqCk479jnyTCO7fxvxNza2FH09O/K4EmcYGW6D9ya8zXtLD2
P7lYNo5eecQ/RPEdvfEzAUBjwWhdXyrSP4I99G/VjLK/7SVfJjoa7T+DNps9
mmbdPygPccuftPW/Y7k1KsNV5j9EpTLj+UCxvwB9JbJEqKM/wBi7kv6M1j9O
sz9cRovrv87HqHy6++0/3nJbmd7D4T+vjXAO2F3lv1rqP6vP6+0/msb5E1l+
yT9vZE7NpJTmv+0LGSYx7tY/Gqe8TWgt4D8XgZj180Dwv9KEIjMuQPg/SbD4
Keu52T/PPn9/NmfgvwdRR4NbztY/mI26nceq5j+P3GGdeVTqvxgWbso4OPg/
yn65CrUMxL8yCFiVMnbrv0DbJZr3V5g/hkdK7ODR7T+Yf5lujEfuP3iLLoQX
3q6/vHT51kH3+T//iE7c3kLYP5reI4Rql8a/80xzo94J8D+Pw2dM/ODdP/fC
ehWtMeq/L9vouA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.1531926730436393`, -2.312032926506105, \
-1.2011099281509583`}], 23->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAfGXCY8PY8T/Ny993awTdP7txWBJd
gtK/6lqosTt+0T+uV6V4L5viv4IFq006k9c/KvitCyaU4j9KDdKm48Xsvy+0
gnQ1YPg/VWUInouR5b9T6EE2JJvwv+b1lyQtEtK/SD1GK80w7T+sMwFqbHL2
PzRvEh292Mo/hya+L3dHAUCS59WY2TLEP4N8tmaixsW/D/OMa5cx6z9S6o5R
liPgPzSZFjCAjvW/NnwsUFI45j8cx9Xy5mOwvxhPSu10Q6Q/dBgPtGWE1D8S
Fw9Qqpnqv5OsWrrdX+4/ZJl6ChER4T/mTWjPaMfkv4s+gFUqKu4/f5tqArte
xT9EvPg4UITlv4pzhbLtyNc/KuPo5m1Z3j/gcSVnBK/vv7FPuU2ibfg/FGgb
4hlN2D8x5qNwHWTfv3qX0OiGXdc/v37nI5X75T+0qH7mwtzpv60YTJvIUvg/
wG9oitukyb8qlJTyu+jpv3A+TKQ0BKY/EMKy/JQ48D+gJvlHh7PtP4ToPA/6
V6S/RVmf4dgz+j/LXyUi7I7TP/yvs0WuZc2/BN+IGY9x7z840H4NzKXeP6K1
rHQXL+q/xYPi+g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.014669883559567, -2.4283840388750964`, \
-1.2117987539252353`}], 24->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAp3ldBh588j/N+BhUkbzXP2DSzy9p
M9a/VHnEPtgXzD/TKa3Ysk/evxNJFXk3Vdw/OHG6U+Qv5j+kr7Rdohbxv5om
m4pmsfY/mhw+g8Sv7r/zf+wgbHXgvzGyFD9Z8bE/BZhWFS/F9z+UIexIcPfy
P/zva1amP9M/AL0nfGbk/z9GIBTFK6DQvzbOXupQ1OS/M2ffUwMi5D8UFger
dk3oP3PFYjAMi/O/0gg2Dhn/5T8YxFAShkyqv9DaFSU5h6g/MHg9Os8p1T/O
o8dPxG3qvzip8gAYqO4/ddNMxvKg4j9jUPjXWefmv4VIztBQ5ew/NJXQ2IP/
tz+fPj6oDuvgv8apOan+F94/imUjv94p4j9/hKj7PPjxv8c+pFYYIvc/B1SQ
SPcX1j9o1t1gSMnav2Do8Ehwkto/5nxR6Ok16j/J2sC/BzXwv20Okr60QPY/
Rv6Mc86p17/cFEONRZ3fv9A6beTGaNA/1gjajaYg9T/IX/KdlOboPyATH8sW
npe/VJtCQUIw+T8YYhM8lnGsP2a3RoIF7t+/QC1NsB+N7D89yYmq3xXiPwu6
VnzmF+m/xLLi3A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.719563651045178, -2.650957255852882, \
-1.9695313604346325`}], 25->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA8dmeRqkW8z9E/PxfUrPVP0TrYUXw
SNW/Spy7pUPtxT/ULr2puqfbvwrQtAM8Mds/AcT1b6CJ3z8XKU2FxWLqvzmX
o86E2Pg/dg53l7ln7b9V84PD4O7jv256rjAlN8C/QvRqHZr69j+0BN54haHz
PxaYpvYeS9A/k2b5LnyFAECug6WHHpPTv2MA5OKBSN2/9QDfVaHi6D/mO4J7
XtLjPz33NLy12PS/ek1Wu1HU5T9AygAnodGnvxiTS/kuoac/j+ba5jNdyj8h
x2O/vf3lv3iiRdWoEfA/3h5mT6hR3T9g+cca5Tjiv4dRlvRVJu8/zMILJ9Uo
pz+V/FhOk2zfv3LDqbk3Ltw/Nm75QRl41z/4D5vXMUXsvxPUILzDF/k/8CPa
ACkI0z8TYSEF4uLXv6Lcv01ANNo/5gz5zpPN4z82Qv8yWYDov19aJuFFmfg/
YycIrmjs179gRTEMX+Hgv9SSXWupFcM/GucEsqEI9T/FQ90QWg7pP7hM7TpF
96O/jNNI0tAQ+j+wxLvCngGRP9T1IhS5SNm/bFqO8fmH7z8IuoCrB6zePw5y
jc3xKuq/T+bqIw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.1783457202351546`, -2.872770142543171, \
-1.335325080913252}], 26->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAl4mwtWf18j+8cunZuavWP3DM2GxU
99S/Ssm0vdQrxz8Mxm8mXcrcvwjC8/QH2No/uGNXFNwY4D8o/we91prqvy60
jKHc0Pg/FyoeYQie7L9HOh5xxMnlv2xZvq6OqsK/2lW7xJBg9z9h1vWRpEPz
P/iyCTMLNNM/DtwJTRlYAECDbNrhjbnSv/3Nq1AyquC/VlclWGGh5z/oOSVd
aknmP3X8SbH8N/S/wCJnTeLa5T9ATRkyjXqov2DWayDOgqc/gGHw27Dgyz+2
0/p37YPmvzKUMdaG+u8/VPuQGUrX3T94DkXYF3zivy61YWc2E+8/1vpvSIwT
rT+lxRJjGWngvwuhw2NYv9s/JmLiUj8+2D/H4eKMwZ7sv++rQL2wCvk/78mm
NGOJ0z/OALqGh8LYvwXjI4a38Nk/XZY9f5gS5D+JHC3t65bov2282IUIl/g/
xfewMRPT1r+mDiuCeRfiv1KVlJ3AgsE/uO81Pfwq9T8QM3AIk+7oP4CX8ZyT
NIy/2iDiJ83S+T/AMXjAX5GfPzU0GIfcJdu/QjXDYRjG7j+j+Qylo8/gP5Ev
gMzRdem/EDntPw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.2954649833189185`, -2.8297451656756247`, \
-1.3186025839235822`}], 27->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAxBUfTbcH8z93R6InqmzYP/5OfSEQ
etK/2++/xMlgxj/025GxOfvevxrWeWm8qtc/Pih8iLdl1D8rHty8BhPmv9C4
iGAiS/k/wEg4yBlJ5796qeKW1Rjuv5BBgswq4NW/q3PCWGCo9D/BzkNvKqL0
P6D8T0tpzdM/Gh2AqdT/AEB5zObithDHvwASoLjTfNS/d4fRBAoS6z+uIqOu
/PLjP4H1NIPDv/S/vxO3hdDT5T/4Ub4nPjqqv3Ac8h+xwqQ/bH4sop7WwD+U
1RSJzlPlvwJp9yVHN+8/9uDFGc0q1z+QNpAM1Tzgv6rz1s9bNO8/bDhB8C+F
rj98PQuXGQniv3FLmr+nrdc/vK5ISPELyj+tbR57g57ovybWEDbdS/k/zsi3
xiOQ0j/wPA01QOTZv8NgWRPRp9c/HvnTbHbF2z+pzpn+iYfjv3qbAItnSvk/
ykwIV+ew0b+6y9U3Ocvmv6BIec8ZqYw/uMTw0gvY8z+eYCz5VL3qPyDaKp2S
NYU//KcPULCD+j90wl1snci5P3+wDu1xe9O/wOzDJ15I8D81IzrhqBTgP0FJ
lItHXum/L67qYQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.8954830685416195`, -2.7149400363283376`, \
-0.678707990238461}], 28->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAUqxbv6zt8j+OAKhKr5/YP1Ay6BkX
1NK/BPt/3MlVxz/uFGQxBirfvzAGFdd3KNg/h8CJqDYn0z+l28MOaTvkvx33
CXEFmvk/FoOcTTDG5b9IOvLuzi7wv3i3qEJoitW/lguc2rrb9D8daI/xFJL0
P70oSCUb6dM/SxA3zBDsAEDw1yMYagnHv5qDuzACv9a/8sc2gZAN6j8M/Kq+
YnzkP/XX7ytlo/S/sqvr+mXY5T+AUfCaWymqv4BPs/SCUaU/oW+KmipzwD/m
odeXUpXkv+FPmpyyqu8/OIaESYaY1j9siDwfM3bev3EhBDGUne8/OVmBwLHt
sT9Puc6cH0Liv540q0KWNdg/pjLUVHzvxz99iuCShejmv7mC7wtNnfk/tqRf
bF3a0j8+tyopzc/Zv8LXfmtZG9g/u2epJq9W2j/NLKeKTI7hv4FrJNa9lvk/
qgj5rHvhz7+EP0t7UPnnv8B1YqN88JQ/9Nv7zLPk8z9AaDnEALrqP8Bm/7VA
UIE/dObkK+di+j8sKSx99DW6P/XaUaWMydS/SxD3/3T07z8qfv8xHWbgP4nk
afJqWOm/5njrjw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.0157682207831495`, -2.6668824837079703`, \
-0.4988148936953886}], 29->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAaQHBKkms8j9o1RhSgI7aP65A+J1V
qtG/WPsmOhjgyT+Tld3fisngv86pxQfdvdY/pUaIym2I0z9W2TNuwEfmv0LT
SL5qNvk/Si0FhtfC479S+u4rdTfxv/9RuwoA3ti/0jJOcM/O9D+5Uqi5tD/0
P4yvB5qxVNk/xg2FhIDSAEDW5WUn7IvAv7Dg4E9wsNq/U4XPrec56D9VXCbP
htznP1TTuEc4ufO/1OAFMkzo5T/4Vom2VRKsv4CkNacdTqQ/NY+oG1ytwj9u
6OTXPWTmvxctbtSFye4/tnzH2csh1z98hix2Da3gv1ROBiw+Au8/eYxn3PQp
uD+MxrkQI6Xjv5CILbAkhdY/Llgdyb1FyT9PChCfWCPpv/PKYqg8KPk/OhgN
A5vV0z81yQJe5dvbvwzLXV+V9tY/M+GBsPxt2j9dqFc9KGzjv5HbLtSYRPk/
6Nz27qKVyr8cxd2bOpzpv4BBrRcYAZG/HpqHTYy98z8TiC7OVOPqP3i7PfBv
qa4/eo7lGaUo+j984mU+ikjCP6+Q7PZiLda/EsSoAT3J7j+EYxl845HiP4Dj
Nq/NI+i/6I3oZg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 2.164970574442072, -2.5416586126470624`, \
-0.526568047413604}], 30->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAgOaZjOQS8z/yRhO12NzZP7T6uL9p
HdC/l+yzu/y/xT/T0ji34FjgvyQCmAZgrNQ/nlP5qpb8pb/licAkDvnav3la
CM+2m/g/uVWMJ8kF2L+6gOIocd/0v7vsqsX1/Ny/NNiJpZo08j82LDAdua/1
P9W4JblVCtI/8YNxCqVRAUDGrhXYi1qyv/6eg9fJOr2/Qp5RpZwQ7z9Y2Ta9
vJHhPw/5Sh97+/S/E2QQJOTK5T/QennlolOrv8AdfBvZO6I/FOJzGmF8oL94
L7/nbCziv560b5rReu0/NZCSV+9fxD+b0LPD9VHXv2YB7QbMEu4/dFA42fEA
sz9odiu6mZrjv121GpplFNQ/RBnWeam+wb+I6FIVQL7gv0cH6TO4dfg/ethl
RcD/0D98XoxoTy7av+tOFXNaRNU/1r1lkXgBqz+6QtsenHXUv6utJ2q1wfg/
2r5kk5VLur8k6n6E4QvtvzDVJX4robC/Wt8Rmb+j8j/y/XRK7ybsPwDiy5a/
zo4/MXe+UBfb+j9A2w2/NUbFP3TimTUcbMe/0Fqhb5lN8T/RfMAXKYDeP7w3
OY/VAum/1mzt+Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.419253196094968, -2.2809605758678404`, 
                 0.6073160828768911}], 31->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAFJnFWTmm8j99Dt2XNdzaPw9EOoS3
WdG/qDy1lGYNyj97tri6Dfngv2SpXKD4UdY/GuBGt8oYlz90ruogl5/bv5Sw
TCMpF/k/CPzFwafz1L+ml5ATPMP1v/co5izZiNm/1eRxIS9s8j/oh6umnZL1
P818L8CObdM/WhXHFaEzAUDYMrgmzcSpv93xYkQHXc6/QZFG/N496z/bLjXn
R1jjP/iov0Uhz/S/qUBcLObn5T/oeVF2l1esv1iViXAE4aM/LLPlwHxdlj8K
x3gKm8nivzLmTyYug+4/RmKBU9Akyj9VjWqBfP7Xv6jPd3Ag1O4/cM0FbqzB
vD+rdpofPF7kv++/NFYGAdY/2vOSDe6Ssb9qF1f1+TThvze2wpDsAvk/TMkz
efvc0j+W7K2rvifbv9mShOrqotY/5mM2aVMfvT8ULidXOtXUv/Gq1rVlK/k/
0Hat3dGzr7/k8uzwwj/uv6D8S2QEt5m/9L6bPTSJ8j+Iy6IMq0nsP/DFqd+5
npA/5OGpwr2G+j8iCAbzm6PHP3/eNZMdRNC/2nD0a5Qi8D8N25FZMWPgP/w5
ziaPJem//g/vWA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{2.537573361417284, -2.159300213703386, 
                 0.5679295929302312}], 32->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAkcPFZWFP8z9q47PzAAfWP0YX4nT5
r9O/JXwVfoldwz8YkU+Fq9rbv/7z/LQCJdk/FjysJkAM2b+paxpdUpO5Pybz
IC553vU/y5ADQ/ASt79DoKYGNBb5v83/qRZb+6S/1YZFPZN08D8YTkqjW4P2
P6+T3p+ExsC/2yEzpGVWAUB0lX58aHugP1dXYTgUcbs/UhySJI5R8j+nq9q+
J6u+P3wYIbR8/vW/FnOIlRK75T+4tm5Gqk6nv+ByawAl1KU//CvmIYKgyb+/
AmqYAP3Rv9L8N7Y/uOw/KEBztdJppL9wm/esssarv3pjiAA0l+s/WZyhhwU1
sj9gjFpTYI7hv1WNrGoORto/EpPOg8Mt3r/Yl91DEaiLv3zZjBu8JvY/Hipa
OJCgzT9vCepjlpjUv6daTf/2A9g/GuWJybzq078mRVhx003LP9AMtUA2lvU/
AM9OckVQnz9EQv1zbwbwvwS0J1KXhcY/M6WFUfrh8T/zRjfgGwXsPx5h0cQ7
E8y/pAMWVxb++j8YtkMDbhbIP+CCk81op7m/8u8rxXfQ8j9UjmrjyrHNP02e
WRF76uq/TpbduQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-2.353671537087772, 
                 1.3019204486099072`, -2.04685940919113}], 33->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAKRIEkCk69T+iMZEWdHPIPzEdA7st
Ks2/CxYPJJTFQT8kcz//FrPOv1pn0GYLjtI/Bz8Ql8C25b83JIzSu3/jP7Tc
ixbmIOw/v4ze1Twl1L8eg670db72vwQnVOY6H7s/jkvHuk1U9T9/zCkmNHv0
P2BVWwozzdO/hA26T+ihAEA6s0LzuKDDvyhWfbhY/d4/6cwmFu+J9z+PE40F
QwLRv3Xgq6YIWfO/DJSIQmI85T8IBrmii/6YvwjGdkqkx58/OjgMh5Mm3L+o
meZ1+P+2Pzx59+ZZXOM/knwEuhV8zr9y6P4H7uXRPySX/OKRC+I/t9XLK4at
ub+WWuJ0g2zVv3JJy2rT3tM/g72SweLw6L+10+rXP3bgP8BNiRhKyew/DxJc
fJz0uT8cMboUJ43Cv0KF1WJDPdE/i8CNbJ584r+5dC3NN4nmP6hrjhSCeOs/
NIXMC1ocxL+DcZbU2JTqvxtxZSDaVck/3K5lpTtH9T+08vuooonnP/xx7vMk
MdG/mBa8F/0++z+g+TmN7EqTP4/H+9pBaMA/iW8VUwxi9j/46hHpIyKjvxtE
DF5O/ua/+7Hg6g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.4469903529082724`, -0.8560825621535318, 
                 2.9321905745307615`}], 34->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAHds4QO8f9T/8Ml10y+HIP/CCYUKz
0c6/XhmTSGRPgj8tb7On/znPv97271kirtM/iShe7rFn5r906USZp9fjP4WL
oXISxeo/OMtfGHEJ0b/xB9IQ5R/3vxq89yV2GMo/yJ4SiWAt9T9YIJVFC4v0
PwEtUzLCL9S/EpZkL528AEAnSomykoDDv0o127kvvdw/nT2MfswE9z/vhSYb
hW/Qv68HRu2gpvO/UAHKCI5E5T/A8FjN0GCZv5jV/OIiFaE/xovMnA9c3L8E
bWh2dmO3Pxu2siUgLeM/A1lWO7LBz78RABbBcTnSP9nQ5nkDb+E/WlswdYCs
tr/+qZflSc3VvyDcuwU/bNU/WoAmjn+G6b9A8GWQgr/gPyZ+h8ggpOs/siFV
h1lAuz9eijeEa9nCv5wRJK4F8NE/uNCVTuRI47+o4iOizO/mP+SYuxwE5uk/
bTIb9vV2wL/WdcgFJQfrv3bqdbYuXdA/8ryl5Kcm9T+3xiC0RKfnPzz3welN
zNG/oAOBz5RM+z9Qo08H44SVP6TnVDGsqLo/XYxi310S9j+IY78H+/Sfvw04
klXXgOe/wMPi7g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.4690501246282126`, -0.6042962740172109, 
                 2.9834741065641492`}], 35->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAUYyGfYTa9D+f059n+/zMP4i4zzLS
JNC/JCLnjhmWnz/K1UBGKDbSv+yWY/Ftu9Q/w8yBE2NO5r+FbL+xxv/gP6p8
Nsk12+w/YdQEl/E/yb/BZCu5guH3v7gh/KCuHcg/QQzysSe89D+swMFruRX1
PzWeztqsHsu/rJ0svXLzAEBjsanlhgPHv+Xr48SqWdY/u/R+3gXN9T9bhk3E
6lu+v2RoYx3olfS/2ijC49xY5T/YX4eTVL2dv5B5T/puWqI/QuPHd5Q527+Q
JNYGCyyWPy622y4qfOQ/Q4iaLKDTzr/uQaHZSM3MP/KRDJPCvOI/cOt2vgR0
r78hdXIkGrjYvyi7Mo3VetY/i3TgK1RC6b+zOU2Fm33bP8gOHpfpuu0/ygav
Jg+Fvz/mbB7QbGjHv7BylFUG/NI/+yQj+3Fa478wPNigv0DkP4zqTvuB++s/
HfAnZS5Ntb8zmrvKDG/sv+TT8KAiZdA/SUy8F1bL9D8gu7XYWLXoP6IHN6Ao
tM2/1OPv+7Rg+z/wiNgH0uWXP3DNUEhi06g/hsACLsVT9T/kIPIKDJ6rP4ZW
F6ocn+i/qubvgA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.5888783512876774`, -0.6342863228752982, 
                 2.9150551359147023`}], 36->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAANg62B0HS9D83BwZxgf/MP92/nM+A
a9C/ZLhZoHFvoT/PNj3sBjjSvyYWxBm/LNU/3FyQ68Yz57//Fbk9z1/hP6pz
4yoqJ+s/YQMK3A6YxL9AoFh8PhD4v4YCNNCvpdA/RSi8gDfY9D/sRNsqOhP1
P9webvoBo8m/PgHen8P9AECSP+vLZrDIvyuesBen3tQ/TkwDLip19T/PJzeR
UOy6v956y4H1vPS/+du4lLxd5T+YmdGdMcKdvyhZnSj5BKM/DGxjKofd279Q
PtXpmFKbP6hTNZDL5OM/oBayeBhc0L+SQi8B3KTNPxQrkCe+2OE/Rp1rJkmW
rL+BXTolqcbYv7o+aYLMONc/N7L8lyIU6r9MBXVC/DDcP/QHNt8wLew/B4eP
M5a6vz86IIBmyVLHv5LtHrGxINM/gQckP2tT5L9YqTdaIKfkP2DfkHYjIeo/
SJXzczI8sL/07Wc3QJ7sv1YM/HQ36dI/Phs5RDzV9D/TBfxYKrPoP0vP08wB
Pc2/WQi5I+Rm+z+YHmuUajyRPzh5TyCZzKE/Qq3cmrUj9T+g5tRQshKvP9aq
srXV1+i/VvPcWg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.5556081185280857`, -0.42470131527096094`, 
                 2.9705407208750096`}], 37->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAACF2eJ1ZF9T8YC03haLLMP9PH0GcL
+8e/4E3jgjSQXb93/aVqAhXSv/XzW/yM184/PKklfrHX779LFiC2aT7XP2w9
01FbD72/aZr7LgPxiL8QZA3L/gr1v/xjqZNjfe0/mPFFXPAI8z8RoOjVXyLy
P885zlH01Oi/kgGwRVSD/j9zp95maL3bPxmrUVSV4+Y/NwLoOkTN/D8cunZr
xM7hv9YtXk/wOem/NaR9GvI95T9gv/vPb96dv4iwLFIGcps/o8g1MwKb4r9o
Gw08jCOqv3qxUMavnMA/gaRiyu6W2r+DePelsdvAP8AOl7ccNGO/wmYdCmy0
tb9OreSXJ+7Xv2i9eYwmptM/N/KTcrs/8b90ZuGIRGXRP3BfSDG2S6i/VEwG
ZurHtD8/m856unfIvxttxN/MYsY/C24jF+wv7b8ixl7jjhfdP5AlgcVt/Ma/
JQRYvwmjfL9u47ZlP5Dpv30wYGmjmeI/UCfyQSMn9D90QRLyrLjlP8Rrwiu3
096/TS+nNlXk+T+AlsJrTgvVPyR5XXrS5NA/oC9DMU0J+T+s7kZmVETFv8pf
UimzON+/aGfkCQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.20044989664815754`, 1.8553645109365318`, 
                 2.8181274581698728`}], 38->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAA9TBpS1E9T/EoJqrm+7LP/CZRE+P
98i/AJxFg8OBVb80tstE1onRv6MVBHKoItA/vsF8TPbs77+Q27uk/hzVPwuZ
ZGPIxcS/+ir/RdvxgL+/GGnKSxv0v57qYqb/DPA/L8nYcFsO8z8GawcKchry
P0yviJDB4+i/V1epq+7L/j9BOeghZ8HaP01nZOdCVuY/zQlSvQd5/D9iG1Bv
OyTiv1JAQq41x+m/nALhNM0+5T+QLvN3Q5Scv1hFDlMGN50/4D1+kJCh4r94
ZU4YnHGuv0TXiPeS0L0/Vk2AO02s2r8syOeLb4W9PzDLBtkHRpu/R3MF2a6D
tb+Rlc33nSHXv+VmvQ/rttQ/rObtolVJ8b9m+HPjbQrPPw7t40+GOre/Z0br
vKDXtD+urZMjHeTHv8KIlajLHMc/I7YdU0FH7b/tur1XxrTaP487155N7s2/
et5nthOic79MBpxbwX3ovwbw48KpFeQ/mU5Ni0Qp9D8ev3p/RZjlP8jVWWSl
Id+/rZW1KA4I+j/SxNp7WlzUP9FAkxNfGNA/6O6JsZre+D9i5tIIKVHGv2ez
CcGMAuC/VJ/qUQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.13461330735816307`, 2.053174679646252, 
                 2.6815579412613126`}], 39->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAey/Fz9hM9T/Dn4ESCsHLP8cEOCIf
Wsi/d15SeoG4aL/ze6dGtGbRv7zV0PHe6s8/wVgtESFw7r9lpiqQNI/gP9xq
kBerI8U/G+SZ5ycnsL/KGqAGDwH3v0sR3IydDOU/hKJoNwVi9D/eoLXxHbT0
P7yC6KgRG9e/ubc0/bJeAEDcJ43SDVuAvy+2TF9fU+M/MEgfeFtU+T/kID6p
neHTv2Ra5ccizPG/TAYIj3xA5T+IYDXreTGcv9hDYz7/Qp4/fsaxwbgE4r9w
f6AEPJ2ZP/y26QesjtA/Q8nroUEI2b+/kccywjvMP6HSjfkx8cM/ZBrCziPI
tr9oXDTzuqjXv7TRef54QNM/2KTFhDaY8L9WbMhzYtzaP4c4syK+ucs/fPQc
t5s8tT/9NjU0W0nGvxEIrubLVMk/02fPGNWv67+fFnHmN7DjP2I62xgwG70/
D3ds8+vsoL/G+UkYvFrrv7pGUElVB90/AOmWA2/X9D/X1AU0PyzoP5BCAp0Q
pNG/dk8XZR8F+z9FzVg1Wbu6P/tpfS2veco/1jvyI5pQ9z8MRPV/YgSov/1a
LKxm1+S/in/hGA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6275967875137751, 1.0758881332883226`, 
                 3.1421309643221043`}], 40->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAPGLfvgRL9T/kMk8Gq/7IP6/mzdBJ
T8u/0eEepb8xWb+U7nn++kvPv3wq5xfc8tE/WIWLFUmF7b8SolSwR4riP0w7
j0hXy80/99obiafVtr8R5qES94j2v617nyhDD+Y/k658N7xR9T/LfZXZqov0
PxPRcAK0EtO/X9dxr2+mAECFeluJfAvBv8C45ngbSOA/fB3qT2vG9z9WVULE
+HLRv2rLPmSW//K/hBr2TrhE5T/A7qrgPzWZv5TcAL7cLKE/6h1FauWU4b+k
tpVIPauyP4AQEMQJ8tM/vO0xFvn5178x30aPwsPQP0RvPfD7zMk/uBdFe2rE
tr8OsM0dd7LVv+vW3/2heNU/b8yQwp4o8L9gixjCFQjfPxVKQIpxa9I/qiAc
ftz6tT8MfVjBBzPDvxr83GMs2sw/0nH1pVS56r90/px/hJDlP27inXzLv8Y/
f1awh246p7/jI3FydnLqv+sQkzSxCN8/aAgue2BO9T8nZF86gKvnPzXia3Us
XdC/fYjhDvJL+z+A4c7zucyfPyl+ZgmS6MI/3L9kB7iI9j+Q72oEjc6jv0CI
WJ5/aea/YJDr4w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7901259625135354, 1.045842255121036, 
                 3.115495938171868}], 41->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAYIMNSsIU9T/9qJAldojIP40/sPuL
58+/0BuEz5V5kD8pHfq/4LXOv1vo98Do8NQ/RpxnaQmm7b/CNjIOrtPhP/2M
tGy9KNA/9lZujFnNnL88yfOh5fP1v0HPZ5cKV+o/nIpB7hIc9T9hCdOzlX30
Pz6Xn9udPNW/CL+uHwTlAEA5/uPAgxLCv0FG7T1PB9s/7P7jfTaD9j/YfMi+
Ja7Rv2lUYg8FtPO/z5NLoahW5T+w0KVpqrWYv1QifwyL9KM/MFgMwHk44b/M
WMK5hg6xPzmDVA4Vu9Y/b0a+9YXT17+8yPYNygjQPz7krz4ivcw/68zToHUc
sb/ZJ8CPhD3Vv+gwdrgqH9k/YRv/ZbIm8L9AVKHsx8TdP4rVMmT/VtQ/09qV
iEBZuT+g6nNguPDCv86fecmmwtA/ygHRBq7+6r9kwxMm+MTkP+CIbOr29Mc/
THbUeYeneL/hDPO5ocrpv7fh8Xu/Z+I//oYnnGoY9T+AHoV4pI7nP4Lbu+wx
mNK/uIC1RGVv+z8Qq7KSydeZP/ZMKoASJ7Y/JsH4Y/zL9T9koQCwqqelv1tc
2I72sOe/1qj0pQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8745389456609513, 1.2931039805186264`, 
                 2.997909893257153}], 42->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA5QrddkYS9T81sUXrDLrIP8/tqf3z
7s+/oy2Awvy+kT9vGXgSwv/OvwaN5kAnA9U/+n61hkAd7r/IpqHaqPHgPw5D
f/CjKMo/PmiUaYAnhb+lAUxOY6P1v3VoRFsF7Os/sc9ENCw+9T9wWAFoKIz0
P9hotr60AtO/eWJa5J/vAECHjTwKn2/Fv7l0RoMKo9k/xls2DwE89j9B6t0X
eVfPv9hwgExz8vO/nAvnaUJZ5T/ooMmc1BaZv3xYRgi1LqQ/l1rYSXlm4b+g
JzREtxirPy7jTPROatU/60WSrZ5R2L/KdwGHswDOP7+WsolUWsk/HdOcm+iG
sL8wKLl2gk7Vv+1YoJi5Ydk/ZY0ewApe8L8YMsZHsBTcP25t+U/kctE/7+nc
/GZmuT9+4n03f2LDvx/BLOmUpNA/KeMtjWt+67+ENGCR+djjP0CrC0F/a8E/
EObXNvKsbD/TBJuQW4Ppv3zX233MNuM/S+2QVTko9T+WDmoFaqPnP+CvxV4X
fdG/7OfIH8N4+z9wHUkIb1OKP6L74gghV7M/VrMJwyOn9T8w5GCysHWav5Ku
NcxR8Oe/mynjUA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8005278920687399, -1.4427276058003353`, \
-2.9499308719835478`}], 43->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAzuCqgOgV9T+UkjxL1z3JP5eUtji4
RM+/catbSNX5kD+IoE61x7zPv6yLa+nYn9Q/Ws7hU9uA7r+TwgwdGhHgP6y9
TBSEdsQ/B3YmYLf2U7/SQ3vq2X/1v4RwbV7Opuw/fVEih9d19T8m4WgK9p/0
P8nZvQUAWM6/WiOU8wL1AEDaJZPCsDLKvzpdGRwoQNg/ZxybRX4F9j9WVxZY
qZPIvwTqeEr8MvS/fE/M1c9Z5T/QN0iowfuZv4QFQTTz9aM/PY9tmgWY4b+Q
JUWlAMuiP+yN3VcU3NM/gsNiHg7C2L9iIJOV4NTLPyy5aDcN/sU/EsvZ2oSd
sL8Dxrf166bVv1ckgMdfDtk/jPK/TC2O8L9nDwkfrFnaPwLvddCRU80/yqAH
f28auT8KtS1/tyvEvwHzVgtSMdA/nLdDDlzl679z/ZQqXvXiP6sYR7DsMrc/
IoiypNN0fz/jFyXhcnfpvy2bkWlde+M/JpnmA+BF9T95c9DzsMfnPzA3Oh9c
zs6/wZPpM/d/+z/AaNLqLptuv94lfP+XO7E/mv4iY7ON9T/AZ8dkvkVlP5e8
j1GTG+i/wFXk5g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7186964656349923, 1.5357098157461126`, 
                 2.9239478025616}], 44->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAArLq4sYIk9T+o2wBCyWzIP6engQUj
2M6/FlLL4WX4iD+qIoxJCsHOv5OOKNJaW9Q/cWEu9Xz77r/VKCsS+vjdPxGD
0/eHEa8/TlyhISauR7/sMjoA9Iv0v5zo0D6RZO8/Tl9G9CSb9T+H4OVcVoX0
P7VxhWvYwM6/DYilk4nvAEBeObK7NQ7LvwsbIoRm9dg/e7422Mgp9j99rJFX
kVrKv5XFviVBGPS/UFF8fXNW5T8IHC0eBFGZv/zqnj0lvaM/lWbfgtrp4b/Q
aTGZ6VqcP/Khldzy2NA/J5uPtYFb2b/GAaSnjKXJPwp0NdJjkr0/wfkk5FnR
sb94huUBEefUvwuxLMaHFdk/+Rad5MTM8L+ysws1bnLYP7Ql/eW7OME/R86X
XHMPuD9kOE2P8rPDvzbYSLxbQs8/8JQiIXBd7L/8TqX3wr/hP7xCNqF+/4q/
UTyxf4N9dz9Ct2tJFWTov/KX8lMfyeQ//Yz/0tNf9T/8+yWF75LnP66Mg7h9
zM6/Y+WB7MqB+z+w7YrNYwuFv26OwgKqErM/lLz3xCWn9T9ADQ1Zgdx+v4r6
boZF8+e/HpvtSw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.5792283198978196, 1.7937368956239388`, 
                 2.8056019857965846`}], 45->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAArmSYwJCF9T/tTzdnlkG6P6LoiQzw
Uc6/VLDTWm/Pkb+L28QlBpbAv+2mCoqXBNQ/+c7iBVC667+mn7e1DLznP5E8
GCn+Ibc/IpvgWe8Fyr+JTDgHD+vyv+4OcNVP5u0/YlWLUWpi+T+49m1fz47y
Px0TRSgYwru/YKKiLd5uAECROZgvtqHgv/c9jpkpDtQ/9jgZcCwZ9T+7/Rv5
IhLGvzlbQPHzr/S/7RUtA1M+5T+onEmR16mLv3DKFg9+bqM/0ilV8e4u4b92
OatAX6LNP+pu2KZZbtE/VIXIHrkz1r/LNDe45lvYP0+O8Np6vcA/uIh4XiXI
vL+cc6Y9vSDKv866uqZljNg/jULbNtnE7r+iOb/vXlnlPwpG7E2boMQ/jrAO
sW3gsz/mDY03PC2svxgmtdqS+c4/ZVvq1Mav6L+qBbB7uh7qPzS0X9kWC5Q/
LRE7Rd0/vL/75/DLz/3kvzKxOs1N9OM/CN0Rif1z9z+3a+HF6DLkPxg5VhB+
Gca/t9TujaYx+z8on2LFBrPKv5gmJU3GlKM/0s5YmF5P9T+KqwCLr+Khv06Y
0fIxeui/y3Po5A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.8678092246580842, -1.5592746751954039`, \
-2.8705347301317583`}], 46->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAASdtTv7Ro9T+fhAuFXHizP4fjCTxo
1NC/nZpRfXH2gL+8U4fRWa64vzM9KD3iGdY/73cTT/ja67/R+BWpBornP5nO
oiNc1KM/IfddmNeYxb9Oh+5Vxgbxv3LJN4PCkvE/OPK5Sxy4+T9/AdkNnhvy
Pwm/YmgeIci/94FKNcBsAECxNRpXUEnhv7N1fqKBUtI/I7rWufJB9D91OR9y
mQ7Pv4TgVd+b3/S/FDhZ3MdG5T94PO8x9deEv7BmeQToFaU/9mKaMjkG4b+i
yM2cDT3QP97sqPhvhdE/x7bcxDEx1r8SVPxAaavYP6CoziP3O7w/oFFacE/V
ub9NNfKMiMXEv47eAlUbVds/uHspd8jR7r/1VQrAb27lP7rsO3ES174/+OoF
EbOXtT9486gkikafv9ibTSWp3tA/JnT9Jijk6L+tmyGSnaXpP0M8MptsBaa/
yxAzsD6otr+K/Abzq5Hiv77YgRI7Gec/wOaGhWiQ9z/JuSnWI1PjPwxDO3D3
5My/nG/0lBoh+z86ivGMibTNv8AiSWeW4Yc/tkqVvFPV9D8ld5kva1K1v2ZZ
WO61FOm/gVXoYw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.9235007757211134, 1.910388106476355, 
                 2.6309624854558815`}], 47->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAs68kxrxl9T9zxg+B3BGzP6LPsP8H
9tC/lST8S7n1fr84s2Azhny4v8GHH0IqN9Y/6fklPTNL7L9VgjCOIYnmPzXz
fAsN51S/2dJXDvJkw7+AVdj/im7wv3yggGB0XfI/oQLzxQHz+T9ACRP7GPnx
PwfssnqEMMS/DXaLnz9gAECsN1lcfUDiv41kLhVCftA/f8JkALAR9D9nliTZ
rMHKv93P9IJeDvW/jrPYDMdG5T8Ys0PJpqqFv4DgugmJBKU/4sSyF64z4b9C
4saDH8zOP+jM+Pc4edA/oVoWMOGq1r+7ZqXNEY3XP5b3bPQopLY/jiBek1Fo
ub82T3IlRWXEv0JPjp9Bn9s/ssX5/FE677/uBEALYX/kPzkqjUHBTLU//Jve
aZqJtT8GkLk3BF2gv0DAsOQSz9A/IC5SfRRc6b+8/yAR4pLoP9MR6an587W/
/bO32J9ctL+0YA5jU/bhv2yCCPE+6+c/KtkLRl+s9z+nBSTDNirjP6ZFCj1K
Dsu/5s2dAh4T+z+6fW6Yg7zPvwDFmqB68W2/GblEY7a79D8ts5yYvjixv8UD
4YLgS+m/c3/l2Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8790709429614205, 2.0557721596340497`, 
                 2.534844197364894}], 48->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAz1VHCp129T8Q7Wsp1eGwPxd6/2v9
gtC/KTHy/nUMi7+S7uz/hQ62vxtAu7YWk9U/z7uq+UhJ7L+rpGHV5HXmP1uv
/Y6IBKq/KCgtVuOnxb+y8ojQu6Pvv2GfcC66r/I/KBoQJgKL+j+omq52w5Lx
P+4VJ3dq/Li/1Z9j1w0zAEC2TUlMOxfkv8yktqZ6O84/SrJjJr8h9D9HHYs9
e+vEvw0bMkmgJ/W/bXFJHoRA5T8IBgRaw7KEvxAY7yplQKQ/N4lIGkJV4b8K
/Hn4g5fPPxTeK4+TMM0/ufa7bnHA1r+tD4suZpzXPzDZLOre0a0/kX2IS7Q1
u7/yiEQy59fCvw1q46sdAts/vAIgq81D779BIM7Iu4HkPzWgQxqvc6E/R/HL
y5ZytD8ELUNt9rSZvykWk8EPJNA/4nQ1SMRO6b8VKfXhDWroP7u/Dw4wX8G/
OksctqpYt79CSENIxjLhv2hvH9x/FOg//LcrmM8A+D95WUXJ4KDiP5I/yQkY
wsa/vEqHXFzu+j8U0BunAPvRvxB7QooBVIa/DIRVGC7M9D9+TapRIfWov5L5
MaRfSOm/nWjcqg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.8400306178789628, 2.1412538133904575`, 
                 2.4766470615868372`}], 49->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAzNFrpql09T+mnWps1k2vP/34NSP0
p9C/1g6hWRZ1ir9k3kGJYr+0v2Mg86KOstU/HCPRoHBG7b8/AYpDhHPjP+oq
Zy+whsO/ihCqaIxnwb/Aoi3cgPbrv76fXFsTe/Q/Df5PoYJF+j/fgHhtoqzx
P/eU4g9+5cK/i24wAAVDAEAkluWMCi/jv7zvjJZwEtE/+d39850+9D+PCTI9
vBDMvxoCLLgrAfW/ro+4eb8/5T9IPjJM3WGEv5id9P5pKqQ/kzJWR3jD4b/x
SWIk+MLKPyIxupoyncc/ienCZZnZ17/sZZLSs1XUP4AuOfGeTmA/FRkHHVGp
ur8nMAIF6VPBv31zsKqMids/AsGFNeMY8L8CsXFTdrbhP9oSsn/QYq+/X9We
hgsMtD/ocf0hzFubv5KaazYht88/NcSW1hpb6r98UaIzkjDlPx7R4T6sNM+/
dyFEzt0Os7+N3lUtbY7ev9ZnGQS35+k/7OfdIxbd9z/M1dsgEafiP3hDJyuz
Gsq/cVdm01n9+j9J7B4mLTrRv4CvvdUcn2o/4tc0zaPZ9D8lYheiRj20v1qA
+cAoK+m/borjpA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.7057405343247267, 2.481886532797174, 
                 2.183247474871108}], 50->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAetnut8eA9T9caW/KG5arPzF4UtLK
UtC/E7e+QMmCkb993M2CyrKyv/a2+ZmlNNU/LHCxTfKV7b95K+itfNDhP1rH
0YO00My/zbJlzdDJwb/1KA5x+1Hpv+B2NQQfSvU/AhU/c2x++j+2L8Nsp33x
P2CAwQsLMMG/9aI0RGgsAED7WQh6Qc3jvxNEfKm5l9E/Jana4/lr9D+EMK4z
XT7Mv6oCso3H9PS/nt7rkrw65T9An1h28p6Dvxj7nB5rh6M/XF19b9v/4b/m
6tF996LIP0gZc7THx8I/ERF0UFpE2L9f6jP8yqLSP9TKRRHEvKS/EwE9bWvX
u79UxmP9aFW/v/bZKshjMts/S42puGRC8L8+bpXeKDzgP1uBbyc41cC/iaXd
zAYWsz+ayt8gsECYv+0nkdfObc4/wsUPKhun6r+06Dp90GTjP6wGGnAYZtS/
r4l99Sn6s7+E5GfBVKjbv57ks2pIl+o/PveWFZr/9z8BqxZLWFriP2E4M1jQ
6si/sg8sIMzs+j9mY2G93xPSvyC+nHLtToQ/UMHkzWD29D8uVhJB1li1v7ag
RkJ6Cem/P3XuiA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.6181178807502792, -2.6591512464410476`, \
-1.992798267273385}], 51->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAKERwAfKA9T997X3wqySoP36Tg1Dy
ZtC/oBBEgJYBkr9KIOK9Pc2wv/ZiVHzyO9U/WfkP+RrP7b+iIlODoaHgP/4x
zf23uNC/6+IyYVHywL+cDa8UIjPnv5yVu2g68vU/VHV7gY/T+j92/PSeMjrx
P4CKRcz6ULy/Qu8nqLYQAECwewECWubkvwVbtuAQTtA/aUVdYa9R9D9p2HnY
t5TJvynPy14cFPW/5jNvp+s45T8spowWn+uCv+A9Q68AVKM/UhGTBZsb4r+s
gYunKUHHP9CwdqrNysA/GBH+ThmH2L9b/GfDXm/RP3w7obViEa+/QSdhGJ/g
u79Tlyad0Wq8v+IiTBK8X9s/3v4MFJFd8L+CJ9UO3lvePyXkqs/cKcW/8R4/
2NPfsj8EpXZ6p76UvxVGucxRMM4/9vQFyhPj6r+DsTv/UxXiP+rxxJOB3Na/
/2Q7MYQys7+mUWvMyUzZv1mu0Ac3Qes/vtx1wUAq+D/i63j+V/vhPx72lAMx
e8e/VhHgqC/R+j/YnPlCD2TTvwB4OM1v4Ui/yMRmsVDp9D8KXVrcjIuzvwm0
7PLYLem/iRLrhA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5774887459601881, -2.778127854607702, \
-1.8365490387523382`}], 52->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAGjjfBL+B9T9C3epu2QSrPxXV7ni5
TdC/ec2dyCXMkr+bxXqPodyyv+YwROCqAtU/ehRkD7nZ7b9YCnB9eKngP3E/
NpQrUNC/r6wdWZzxwL9VLmmkqPvnv2YxnbTuuPU/EjXUuwFb+z/u8TxPhNTw
PxXEzOsfhIS/PqVfm3/E/z9uiHV46Ovmv87lXyAQL8c//KPOf8Au9D+ej4ZC
Tf21v9F6v0xVW/W/5MC8bY425T/oWxVg02iFv0hvVZ3F06I/W4Pps1Ak4r9T
cm10rYrGP14DACLv2MA/Fv9+E5OX2L8fqsrccVbRP9iBkCfCz62/oYLPGiYV
vL+Gp6LU1/6+v9s5PcviFds/MYs8Uv5i8L81HJZpY0reP/hselLnecS/5ZuA
NhOvsj++jkspremav+JPlurl3s0/khJPenXt6r+VBhVGvy3iP2ZIL39jY9a/
XmYxEiFLs78Jh1jWPFfav589rmyZ+eo/lrZZYGBu+D/YSLQaq6zhPzY7TXja
8cC/rG4fUB+j+j+a2obhmjvVv7iI+6LF2KK/C+5Wwj/Y9D/8QSIWwfWQvxYw
+6rDbum/vrPt8w==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.5708855034859884, -2.748211794344747, \
-1.8830352294457935`}], 53->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA1cXCKXqG9T/5eU43L26rPwxkVOWc
HtC/DoorsiCzlL8zyyCD2UCzv9CLX6xAtdQ/K9ct2oAi7r9hK0qKkCfeP3vJ
3jay19K/hmcyuhWCwL/Eo5I+jnrmv/ygWdX3I/Y/os4rzTuN+z/MX+AKLKHw
P+K/atioHZw/Rt3/O72V/z8XskOh3KHnvyfXF0PZisQ/TPQgppxE9D/ZLmkm
2Ieov4d9T2ThYfW/rRf6pq0z5T/cOOadByeGvxCfLByPWqI/nX5E+ydP4r8U
rlPvoZXDPzDI94iPXbw/u2n1yOPx2L8VQ7BjEhnPP+C+9LJV57S/ggmyh6CF
vL80YH33ScS+v7Ic3VPd3do/BV7J8s2G8L8hBjNttEbbPzJxwh4rXsm/fESc
LhAssj/G2BA7pPWev9z1wwlIGc0/S/LIzmU3679RqLBTNoTgP11aXN5OANm/
yNh30HkYs78rvfZuqeLYv/CDcQBIUes/PEp3+9qJ+D+c05qEnXzhPxxwm6+E
uby/jlHhshuO+j94ys6t+erVv+DhIQ/BZKe/EN3xZ4vl9D8AWSqHuDJnP4qW
pJ2Iaem/s37s5Q==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.49461268494329336`, -2.8472158883050134`, \
-1.753031653244367}], 54->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA1qY3yQuD9T9keJCyrxLFP2WEF3jN
ucm/KBayxK5Yk78leUrRaaXLv5mdvyKLYNA/yQWPuAUS77/6WL77IBTYP7Z0
mYdkBtG/GW6s/CnCuL8ksCyxAkzxv7qkg24ALvI/cvSMFg1l+j+c4uhbmozw
P7cSKuuhkdg/6xkeBNAfAECiQQaulcLlv+mPAspqTp+/mtANgY+09D/v8yw8
CLjZP48gE5XaQPS/fd4kDqk15T8AA+h66EqavzjbnjUjHZw/dYYc9K6w4r+A
xrxxBdV3Pxhx6+I5wLI/CyAwdTj42b+bUqT6L8TDP5DNUnafV7W/SV8+l3ao
u7+s12rcFpTSv25l502GY9U/gKCoiif28L/gvfgHv1LTP8JZ47jSBsi/NVTl
NB/8sT/xQr/ppSLCv4irL+8fu8Y/kcrMW7w37L8U9IPvgtXcP4s8wbJfCda/
o/PYrVWYrb9J/1Xrr8DkvyCMMzcjRuY/pE3ibwz09z+o8TpS8C7jPwqhPF52
abc/Vu256FXh+j+JI2LB6X3Qv2LWV9Gao72/uLsipc0b9T8QmLoKsCDSPxsR
FkQUeOe/XS3nFw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.159137780863101, -2.389624344391729, \
-2.38511439125933}], 55->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAeF5DKsxx9T85aF1alO3FP5pBpxcj
l8q/2a8NlpZvjL8iitE+UK3Mv/qK2IVL4tA/tnMPkexe77/akpHNP9nUP/Y+
9LBxxNG/AwgruLbysb895mw/D+3wv0MFjOOAzvI/7YjJGUGa+j9kF+3jNTjw
PweqB5NEDdo/PyFMC9MSAECXNY9NzeDlv8qoFrynmba/x+Z6uI1P9D/tvDil
nRvdP+4X9/0kKfS/GEMX/ew45T+oh9CR7/6av2hRJ9DPtZw/xuHzjTiz4r+w
mlNjkjeXv/BIAQTB/rI/X5HnuuQ62r/SHXhRQ9i/P+AYcLBZh7a/VRrClAvl
ub+gZbIcbQvTvzS3ZtwOE9Y/IcCn1OcU8b9K8kfQeiTQP3glzLRcJ8m/X64+
7yXJsj8DST5ExkPDv4C9lF4QY8c/K2fPeAmU7L9qM9vKBI7ZPzBrggc19da/
/r3siqmApb+CF0dHuYLkvwIoAsUTB+c/snMGogYG+D9rxDhv6PXiP3QSaA5m
g7k/e9BtILnL+j+I2/c2aGXQvwBL2Xr78cK/oCJf8azg9D+EuDPpMwnUPyIA
7GAJfOe/tPTmAA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], CylinderBox[{16, 5}, 0.15]}}, {
                    
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.10349200942826295`, 2.4788023913754773`, 
                 2.295479929883011}], 56->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA12Zza1Rt9T91asyx4SvFP3eEwblv
k8u/Q3Ye8ONlir9G7kQtnaHLv03jUfX0ftE/jj1spQZ5779Llmbg5kzSPxhH
TwMyktO/ee/zBDslsL92a3E1H7zvvzvk0bZPw/M/7SJMMG/5+j8qMC5A9cLv
P0IP7lZlCdo/tZ0skyzn/z/ZSa4XZYLmvwCHkUH+oL6/af3izXIf9D8AS6tu
FOXdPy8t40y3MPS/6imTo4g45T9ID+Lt7daZv4gIicPoqZ0/cv1i68e34r9g
144MjJWhv4A4Dx1Tq7E/6nOTk6xV2r9Q6FctJ7u6P67HBFVH+Lm/u9xoBIOA
ub+jYRY9jEHSv1JjlENo89Y/pm8cu78f8b+WV+VzUrjLPyWOGWp9O8y/Kz9h
CArnsj9GGV3gIcDCv4/GHk4DFcg/0Juf1I2y7L/LgNqGpL3WPx7HkVGlBtm/
Qb73gvdxo7+EU2FAQ1Ljvw5dJvQMI+g/4sTfzWEz+D9kpVDW9obiPw6aGvRa
f7g/RgJQf0Cq+j88LzurbDfRv/wjRW33ccW/IDKrnGPG9D8ewMijgj3UP75d
G0Qlo+e/h5Dj8A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.05991599658168934, -2.619544645157931, \
-2.1351337019910566`}], 57->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAgxRoHV7E9T/uF3IALl3BP1LYxLBo
G8a/Dv0bAvWJpL9gXwh/+KLGvwDvTiVp/ss/5bWfNrQl7r+d/x0TiGPVP1UU
+Y84J92/dUkBqHwLyb+XJjtCYC7tv9u0hpajN/M/TfhEAxuB+z8mmtbc5j7t
P5MVcGNNHeA/hfFgkKY2/z9GU2xMyOPov3K/54OiB7O/UoJB2TnW9T+qO0cH
4OXePwoKuGm9VPO/mzRXdQ4g5T/IHVn6KReVv7haKNIBjJc/FBVGjrnH4r8g
Dnedx1CQP9Dlou7kX6O/RsH28DNN2b8UvoSz/hnCPzeA+r4OeMm/JGgcbLxk
wb+ITfNe66rOvzDpe/M5J9M/D4jCACKb8L+JiCijjl/RP6SiJC8z/9e/dKY5
rAd/rD9w4jo+Cza9v58LpmNersE/rVu6ayQV67+xdhODgWfZPwPDZvieJ+G/
uUiI6Pktvr84n/4wj2vhv7uSMLtwt+Y/aIZWkLyi+D8QkHkuGcvgP/6+fW7m
LMU/BIPkVoJ9+j9LzU/MfIzUvwu4uPI5n7+/astU+0vN9T/QI8CDO8rTPxSl
0H8qGOa//vvg4A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.010961095545488873`, 2.6994649257444627`, 
                 2.0340031880653195`}], 58->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAH2cQWaDC9T/Wy3xjgpnAP/9URK6s
3ca/A5YWHed1pL9R+glcmnjFv+ntpzjE+Mw/LYslirQy7r/vTW5hIjrWPzwh
TdwRUdy/wXOfC0KtyL8JKRzrC8Hsv0ml8qK2ZfM/X9Gsj10x/D9tLhjt6fHq
PzMtEecna+E/SGsKQT+2/j9xqDp9r9vpv5Rke5+FHcW/b0qWxzSi9T/yBWcE
hsXhPyTd6bsT8/K/b7InIPEe5T/wuTTiX3yTv6hjjilebJg/QKA8d93L4r+g
/fUTpP6cP0CvxAIU45q/m6h0CWtc2b/a4VPk1VvDP6e+mf/8TMi/ZT1KrMlY
wb9ki/QMm1bNvyRBJLyIuNM/k1izQcSg8L9mBfkIIkvSPw3XfDzrFNe/j8n7
dlh3rD980j5WMzW7v4tZB/l2gMI/NGXkkOAj6794luO5IinaP7a1Dj6cxuC/
Qhnl0rvKvb/PUw9BmQ/hvwajByrPBOc/P5xe9P75+D9jYfeFShjfP+cvAHd5
Z8c/NGkNzW88+j97dVvkTrXVv8rc3yaZ/cW/x1hTkGqy9T/oOEad5uvVP8Rn
slHJzuW/q7Lpfg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.02881123590456482, -2.7072220912063547`, \
-2.0234916509760903`}], 59->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA7sXEeQTJ9T9CwctZa7XAPyYkCpSQ
F8a/Ov9CxdyLpb97fikYtGzFv0Yhsu8ECsw/u78Qy94T7r+07Vkt4SDUPzFG
mdo70t6/K/xeDr4Nyr88HkGipc3rvyqk6JrOmPM/v0iTa2Jj/D+yu6gVD6zp
P5Nc5wfypOI/q1h9Z8CA/j8uLOwfNRfqv/jkRYqu/8m/G3WX8p7E9T+KRSsB
LVbjP48nh8FsgfK/9K2ak6Uc5T/g9Hb5It2Sv4D0n27RyZc/btTQMtTK4r/w
GfsAm4GMP1jVI2tXDqm/gTYoyZBD2b9Oq3qS9AzBP8Z1t+rcVsu/LDLKzQ61
wb9S+16JIQ/Nv7+w1DvUSdM/KY4XWTKU8L9IL790qk/QPxWmnRZqjdm/Osqi
rIG8qz9IA+hNjZS7vw7humdhgME/JGPy41j/6r8grPTlF/LXPydzSs+GC+K/
+buvP7Vwv7/tviVUaZTgv1Lo3jgPGuc/VgescjMW+T8DrBvsadndPxKnycUb
Pso/TA+hcOIk+j/dO3lJ2unVv48EKI+fC8i/hB0uttHG9T/aNZ7Xh4PXPxRs
CNReROW//+TpAA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.03502215779457445, 2.770869562215184, 
                 1.9353178854267963`}], 60->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAARl8T9rSc9T/UX9hTDzvHP5YGqoaH
FcW/IyA90zY0nb8w50JAOoHNvzkEyoL42co/ydCwI+W27r8AUFTfgvbNP6sx
lCMYUd2/Q7bVIKqnwb++jCyI/xXwv2oHoAE8rvI/81ZlbJEf/D/zYX8DjjTo
P+YNd3hcbOU/i/pkI/ri/j8Q9XunYkLnvwTSLlzi2tW/XOxQXbjf9D9Vi1dz
vU3pP5W2kxxVHvG/xWrGGuQn5T9wHaqxqxiZv5D2f/DDEZc/bgdsw3C/4r94
5e1Uo6exv1BbczDBS6e/uGS9LSzC2b8YtxCTNJKyP0qIQXhH9cm/UZwEZ3jG
vr8qRyEd2EfTv3oubgySddI/qb37PAnT8L/cqFTlDOjEP04Fi1iCSNi/Pwxm
/VwssD8MQENGxHLEv36rt+zMyMA/QCZqzbfH67+S+6lsfILTPwSvTvfWLOG/
R1o9+zBOtb+k6TTQJsbjv/FH+RF7CeY/HFs8MSPe+D/oeXXYUQPeP0GMzJb6
JtA/6Cy8jNc/+j8b3YXSnnPRv6jqwQ/TMtC/0SWyqTY+9T9Ko01IgRzfP2j3
aA0GweO/tTPkng==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.20633468180088832`, -2.6321234316869293`, \
-2.110391489617684}], 61->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAwduDRZbQ9T/otLZegiDCP2Ye6/Tg
DcS/N8Da1I/Zpr84poP+FMHGv4AF6Y40s8k/4IHcFmfv7b8auoeXQqjZPyLC
cjAcqtu/ovVzUaapy786FdUvmQTwvwsHdJ7buPE/FQys7oyD/T+RLGSo9Ibh
P7cbFo0GiOc/tT6imhVv/T+wLpZs2zDpv8dkr3Vaid6/PftfNzza9T+11sc7
HAfsP/dpthsO4u6/vwXdxskZ5T9AxTN/SoKSv2ic92dOlZY/4Mnpa+3J4r9s
w8tBpX+mP2hI0zAQ8qS/CMiAUCUm2b8h3Rjghu/GP6qsx8V/ZMi/xHuJfBkk
wr9bnFbG42jPv2Q52TWZo9E/Z5pYPGqF8L8IP54zW1TVP34LDkId4Na/oW5w
SEbdqj8qYGFtjDK8vziYH7I2H8A/8s4HtfnT6r8sNXH7KfzdP2O8a48NOuC/
2FJVIwWwwL8BiqXPu9ziv7snUTBC7+Q/6/MXmhGq+T/L2RFAFQ/WPx1U20+O
hNI/Ow0T8NWf+T92gejUuqjUv/15EnglSNS/f+txPmnV9T/4wbppnkfgP8iY
eCzD8uG/CP3qHA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.009650441953481378, -2.501519605034684, \
-2.2730390525895543`}], 62->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAQdLzDtjP9T/oEKhoMinCP/aUo+5X
HcS/1qCOF3G2pr8YIKpBcqTGv5lcFBhj78k/a58EZd7x7b/EHDS7K6TXPzVS
U3iZTN2/1j6N+EWDy7+YrR2DhRLvv82PuudZKvI/LGL4xKTI/T+18tVnuhDg
P7Nc8ltT2ec/6RWJKOUp/T+K/+MN++Pov24dIhOfyeC/Y67Jr2nW9T+meo79
fzLtPz3BweRUy+2/Ol03hiQa5T/APAhk/+yRv5Aew6UsSJc/507BlHbJ4r9I
3OmaZFWfP4jt6cNBFKq/I3V4w50n2b/n3WChOLnEP2/Ml2e/JMq/4dDtq+sY
wr9H8atIuAvPv5CCsUmd39E/y5RDH1mG8L8sNLO3iHDTP/L9q7qtZNi/2AGa
gMz2qj/SnVB1WHq8vxO0xZyLH8A/QBWCiwrX6r9cBbW+ztfbPzxT/ZpCGuG/
hnM4H3GYwL/PGsQJ0V3iv2AbvUpGaOU/Nhr2aT7M+T/v9v8BB5vUP3V3SWD9
0dI/FXS+m958+T9Q+7lzrlnUv6wCyw710NW/UsBe3yDT9T9wP9xLZt7gPz5T
NXBVaeG/+cDxEw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.03225951055394394, -2.578639433380267, \
-2.1849434767506257`}], 63->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAyIo9NBre9T/GD9vYwR7BP+wJRhhS
Q8O/dfR2IKXqqL+bKrBahi7Fv09XdaXU/cg/djcL/RKU7b/xFBgOuWHVP8nB
KAZHq+C/s9eLYTnWzr8XyHUhy9nsv0zVcAfTufI/F2UIlB3j/T8+3TNJawTe
P4QU0k0vUeg/AmGu/7v2/D+nromxmDjpv4YScLoBA+G/1wm1PfIt9j/gDouD
QmPtP2yXsP3jHe2/JNM5C8UW5T9Qa1QHEj+Qv5A1vTQK6pY/UWreZKm64r+4
GPpCMg2YPxw+qQA3n7W/2nho1CfQ2L8wvCB5RZPCP8gQ2fKr386/5RhyPdTf
wr8o5xDzVffMvxbIW2/ugtE/NCcw3a5e8L+rtudBUX3RPyRnsO+JUty/qXra
tAaqqT8c3J6Ebcu6v+U8ZtiY670/hCC2P8hq6r83c0jaIEbZPwBQeRRJLeO/
aMrUVHGIwr9f6RBcthLhvzaAH5yN2eU/8Pci5Jvg+T+QstAa5knTPwmSwMda
gNM/5fX1GWtq+T+16lI76PDUvwGVgUDW09W/UEr5OAYG9j9o6eB8edXgP/QM
4UFc9+C/EwPnqQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.0927868727253236, 2.7095784936063554`, 
                 2.0184090227790223`}], 64->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA+O4ksoLi9T/Puief/gzBP72c+wx+
wcK/CgBbuiGNqb/X2Nd0iPvEvzy1oSmdgcg/tYv0S85o7b9S1P3h0pvTP7Xk
J2y1qeG/422BiakG0L/BbLkcDOnrv+QBF9ca9/I/7twWNXIV/j8Y7EkdJJ7a
P0G3rdmT0Og/nyHxdO+6/D8oWsrd48nov9Mc4oIlb+K/3Rfva1ZJ9j8ROQis
lpHuP8kYRR6truu/+BZSpBkW5T9A8ICtTnSPv/hhmHJ8AJc/7mkEVIGv4r/Q
Qz7eIWaJP6ybWOeL6Lm/kqMrJz6k2L+R6z8xu6XAP+HHqEl5mNC/TPBz7wwe
w7+B3IX+NIPMvxkrurz5T9E/5OsVtr9L8L/6pE06+a/PP+94ZrA/RN6/HMEZ
SfBdqT9aqlPWt+e6v40onrONxrw/oz+9Kx066r8n1tQmqV/XP/KMHABLMeS/
5M3MwE04w797sfcc95Pgv4w4S3xOB+Y/8+Wdc/r7+T/A5G62UZLRPxLQblY0
INQ/TAiLE7lO+T90awA2pIbUvwIEIQaFH9e/agMKj+wV9j/iE+kpa2rhP/z/
wVCGL+C/6OHu2A==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 0.13796338365520466`, -2.7691977864443964`, \
-1.9331088237142413`}], 65->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAASDcPPE7i9T/ZU1mBGFrAP+l5O4Rh
Y8O/2DnzVVFxqb/6ojw1OgLEv+n5LKlEbck/Cpa0xW1T7b8KvTy1ATDPP7bf
CmM5zeK/n3ZI+KUm0L81dHH+Ry/pv8fJN0Ju4/M/EDkx/7pM/j8u6UrXxtLZ
PxFU0ygZe+g/YVOU/HuC/D9wM/pyhBHpv9lutJuLy+K/+cq15SVH9j8sIizB
cHXuP2fSCTZgxOu/eZ1fscMW5T8QeRqfDUGNvwAAxpOMJ5g/Be6ANTml4r/w
QG8iB7GDv7D/RlSem7y/RrclS5OK2L8+HE7kr9G4P4yCbdzovNG/O/NYdTMc
w78RpGNnLtTKv0ReRPiiAdI/ns/VxrJB8L/zuxWDDV7IPw7vMxG5J+C/PFl9
KSuOqT/GQysGjGC6v5JuosOGrr0/2Yy9/XUj6r8R37Hz+gDTP17Q4bS5cuW/
2t0GI9BUw7/znMCL1i/evwRpXdcWEec/LDignYQX+j+OyfuL6f/QP5Z1xMdA
otM/VMVRHGUy+T963qNS/vrUv1RNw/xjpNe/IIHiELoU9j+RO8Fw+0XhP3FY
jEucTuC/rYTmbA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-0.18447982336188412`, 2.911319843620279, 
                 1.7072152655465445`}], 66->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAO3ih+DEX9T8jE7Tw2dHTPzFQGTwY
za0/tCx/+u2/hj+++Sdopd3Yvw+2iCYzBbK/OTKqLkfm3b8j4m/kJ/nev8Vx
ROA6T/O/Uyw6CCZM37/tUNHaZc7qv3yGCp1y9+4/amNX3vYi9T+LMfdTgWrr
Py9ji/r8DfA/ojziR6fEAEC1osny0i7dvzD82zw7ZaU/hVT1PGTV9j92He1p
x/3vP72EoGIsAOm/lHaW1LFE5T9oms/dLS+kv7hv4EM49Xi/OC8AaF+q1b8g
zW3FKCXgv82Fg/Wlw+K/aiZYW6EXvr+iQbzBe4zXv3901i92G+a/pGUEY/Bw
ub8NprdMkDzdvxbt8/TIl5K/hKKfW0F84r85x39kCazhvxi2r9FGefK/0jCk
4esgvz9vTZiDun7Uv9hw1A90ZL+/ah8VpgvU1r/UNeD/PJrav3It2e4uJfS/
7TJmmCaWzr/mpnJHnJ7jv7pvOTjMttw/0m18axQd9T+OnSgmt6niP7EtbLxl
/OA/wPgyREBQ+z8kHysE8rmyvzCmerwpmak/YGbLGkv29T+EkyMxWvPkP7rv
3t5aI9e/xoDsjQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{-1.634197150219645, 2.9227682537551845`, 
                 0.45959265557106055`}], 67->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAuCj9k8kP9T/5O125of7TP0SDc11s
bq8/vTIAS+MTiz/4Vh3F4hPZv8/Zo9hv6rK/qZJdSYuW2r8zWhDfJBjiv3Oe
1oWviPO/25yIpxoP4b+kcZgTNJTov1RcJncxCe8/3qPcIfsU9T8FH2gOVFbr
P3x4QJBYJ/A/KTOkKgXJAECCHeIhN77cv0wsM99z5KQ/0Q9Shvm59j9zCGdb
4B/wPxre+VIax+i/HSmTWvFF5T/4awAvBFWkv2DBUE/NmXm/2hPROVUZ1L9y
BAEtg2Dhvwpe8BK7DeO/5vTR1FuStr97AjwpJoPavxVa0fPxYOa/6SbZHwCH
ub8sWoDd0jLdv46mf1RRdpa//e7VNXXo4L/N20HrnCfkv3Bfns3hs/K/zJlM
efwlwD/EU7qs8vTUv/3kE66lG8C/WUcPJyxc07+Z2N7SrAjgv3bdDj59XfS/
EJxcGsui0L+QjhO7Eo/ivxrhEXzjq9w/S+bsWmIS9T+AXot10qriP5YULPPL
IuE/hcei9OlQ+z8UwwnRKn+xv8hXUx5wKao/RJwnjeHk9T9yV77JiB/lP+al
Io0z0Na/CNnmdA==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.641712301390327, -2.9487439741949295`, \
-0.1846339462633317}], 68->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAArRv0U1Us9T/p2D6v3g/TP1ChLu6r
grE/rUHNwmlpcj+elZuz/+TXv++eh98n/bS/6Wqvu35Z2b//pD28JELiv5F3
t03Ww/O/H2fJRrmi4r/iwE/43Gzmv6RC8D37mO4/Zg+GCzmY9T9mcd3HfX7p
P5nMo20movA/gUAFY4m2AEDGTr0CIIzev3LcavIN/mg/spH39HHd9j8ppfwV
knDwP08P2ssAmOe/7+i2vb4+5T/Y8nIRhFSjvwDtx4rf03u/Mr1wB8j3078N
Y9v77AHhvyldUzaldeO/wuLNNERgtL+CGWA0b2Xav9aFDGGssea/6LRNWNeY
vL/p60YVNbTbv3P4RWkWGqC/lQZnHK1k4L8lUBNtvynkv2YtCYPU9PK/Hl2n
kATmvj9TP/BRyhXUv9IgNkWi9sC/qMiQPqPp0b/Z+WcLilrgv7zBZRjYkvS/
m8xDc+Z90r/YxQ5pri/hv8ZO/0FW+ds/ihW9L0di9T/tbr6PNoPhP662hixR
uuE/WE7/DLRM+z+86/ymgvi2vzT4wV2cSqI/sNZ1pOME9j9kW8zBiTTlPyU7
FE6rZ9W/HTD1Gw==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{
                 1.5590751980803, -2.998606493224566, \
-0.045206476553108055`}], 69->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAtAH3+Mhk9T8KAVWoQ9XQP2U/g65f
Irc/BXEY7/rIib/xLhwtSxPVvw/JX6B+ALy/yHTW0xXr1r847ahqI7rhv5P4
FxVEaPS/Ea5XmqS+5b/Rdhp2wzHiv3Y3KHTz7uw/zefz0Mfx9T/dsWC6ZE7n
PxMjdna3PvE/ejaTU4V9AEBVujCOwJvhv9P6o8VAXI0/c+TceM719z/WnVkZ
IyzwP9w9CRo+Dua/0tAYAzcx5T+gtxwTHvigv6gmcsd7eIO/8rn6S4G107+Y
KJJHonDfv+y9Df5hsOS/ePlRfXEPsL/I4Nu67xbZv1wsLgA2oOe/pcKXmzRO
wb/ZUndzJEDYv0wP3pcuQbC/kpIpSujD3r8sf9YNkFDjv/fcjxRPrPO/CGlp
eyoqvD8JC8HmcebRv2nBcFTn38O//K0Gu4Ykzr9EW3vHtiPgvy8UoBU5JPW/
1Q8Uhsgl1r9KjqgMabvcv1Q+HKDjbtk/wHT1ZEir9T9iMouOBrnfPwlXXnHd
sOI/VLcO0Okv+z+gcwx0PWLCv7++N8fnzao/FPPpuEut9j8Y3m4DdGHkP/DV
OCTyKdO/k/ToeQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3546222988360135`, -3.0914484836934224`, 
                 0.17984632374856366`}], 70->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA3xkKTUVU9T+jUAOX2nrRP61ZPsOE
JrY/vVqaRX6Efb8Y4cw4j/fVv7rP/DpUiLq/p91ey6fS1b+9D+gHvWzjv8Ey
Ho49PfS/DIte08y/5b/2OMyYi+Dhv+Qnpl+kK+0/b4ON0ogz9j+vn2707x/m
P+TXfa6WgPE/5CyHoiuZAEAjzDJ2vYTgv/RcFkrWd6m/FDYVqK8x9z/duowX
OPjwPwrwFQtWJ+W/hH/EzsA25T/YQSaH0vKhvzjY+d49h4G/2EgMl5P30r+5
Ofz1Gc3gv2UsoI4EaeS/zvFHazGJqr8gjaRc1TbbvxTT+xSBYue/dB3QW5GS
wL9B1HaAPinZvwFqHEPERK2/9oIwgN6l3b9RCb2rlAXlvxVJh2zefvO/ke/s
7pJ0vT/v7SLx38XSvzq1NSojN8O/sHAaLeL+y78pFhNk5dPhv20cta+c+/S/
wr/pz9X61b+CqTI1U9zcv+6NRtiZ2tk/p87LD+fD9T8ASPA/Xd3eP3+9sfr+
4uI/1DkMSU5D+z9Ej8SqQB2/v2RWZjwz1ZI/+qePevpC9j8Gj0297lblP9Uk
rnKFYtK/Fu/0EQ==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.3904576296293956`, -3.0674989939054433`, 
                 0.28544264326567353`}], 71->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAA88HSwwdK9T95bdV3SUzSP1Od/m1M
yaw/fobboUPkbL8wtnapNxTXv+iG73VJibC/cRrvIB4J1b91CZVSf2nov2sg
5kMyAvO/a2LokHTO5b98ehyJyTzdvyEwFf2S4u4/t/RfI42V9j/6LQuQr+Dn
P1w2q7dNsfA/82k96LCpAEBetqTfA6rfvy2Vxc2Ug7K/Lu7BbL1+9j/3mrul
FrDwPwpaUqF5ROe/MNQBopU75T/YIoXGuB+jv/jBgfcZJXG/vFn4Tslx0r8R
K4D82Gvjv6i4L6nMZOK/EL7TyeqIpr98OdAqwofgvwt5Wg3BsOW/FFBFBD0U
wL/FpyZ7TvjZv6wqJCq/y4q/bgvOG3TZ3L8/Am27itvpv1Jw2yo1L/K/wOds
zjVavj+bxMbXIDDUv3qImgYbub2/6FIgTJBxyr+rEL3pc/fmv4TQ8Fwv1fO/
8j2K1Fjr1b9WmEmZgCjav0Q/V85p0dw/VVuZc8rv9T9b8volaoPgP0crGxuY
l+E/7MomyrRO+z/MkZ7PdLu6vwwaGVu6e4C/EFhKmGLk9T9W9rADKUPlPzVw
ctrkd9W/ou3t0g==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.4091429495057646`, -3.0009145901722003`, 
                 0.6582004028787968}], 72->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAADZecp2rc8z8WDy/yNH/ZP+/P51hl
bsM/bV+ffWwGvD+RuakFLCjgv+9rOiL0DMi/ZpvzlbiW0z9IX5vSn0n1v+NK
lpzQZvG/VwNbZnsC7r+b5VnWUInXv5cQ2BR0It0//dd0hSPk7D+iwDCVswfy
P7QMkKSyiOw/iMbtxUxZAECtDOySnFzMv1/cGUQf0eE/2gyUAdPT+D+xzwxT
OcjsP7hd3MV9jui/BI12b9Gc5T8wkJFkjESrvwBwSiU7epK/l8M0xzLEsz+k
GQfNhefuv+F5L8fJ6OO/XEKOA0en1T99Xtnd5dPrv+G2i3oU6OS//A2LlyCY
lb8kl0D9+7Hhv+3xgbteDsa/ViUm2jZ3xj8SzmbOhw72v6M7v+/9JvG/LMGQ
kHC5zj/8tyUcuDzdv/Hl8oiJC8q/ISTUvtXx2z9+8M/Wt4T0vyNabUmjpvG/
aRen1q2B2r9erNZw1Ozbv5/augP6G8E/hoErNT4n8T9ohLzRgGfoP1gAZf0l
suA/DhK8GYJH+j+AEXJRzaG2P1rQU5q4rNY/9FGY1B5Y9j+eKxLm6cPkP7xp
om/kstO/HUTvQg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{1.1049300091926688`, -2.2325479259149335`, 
                 2.284569857386379}], 73->
               Graphics3DBox[
                {EdgeForm[None], Specularity[
                  GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBwQE+/iFib1JlAgAAABIAAAADAAAAt9gs1XF+9D+y/377wcPQP3BNfAB0
Q9E/8o4vbyuTrj/JVhhAOU3Vvzn3oBeOh9W/AKveI8y7yD+4d2Y4GQbsvz25
Sxy8CPe/GFiPewHN778HGGOjhdbOv3BUKNjWftM/0g6hsUlN8D+xFrBBqX/m
P+AKYpCwvfM/TBfymOMRAEC5JYNmXlbhv25JiR5sddk/QT8QV6tk+j+LOg6S
lWvwPyCEdSxotdq/L1WmMAtz5T9gXGUS3SWivyCnklxoEKG/mG7ohXY/hL9Q
YCYpDlrkv3ZmijEDcuy/04oENEfS0D/NQkyvp1Liv6CH3RI8Y+y/F9XPGPCe
s79MdPK5n1TXvw/WTTZVltW/4HKr7iQerT95hlN1zAntv/Lw9uNtDPe/BLL/
ww0ZyT9GOT7G0kXTv2MY9PjGeNW/pDwJhgcY1T/3aHn7ZQLrv4iBoFQKBfe/
Kl+cxM7j3b9m8eQIPlzSv1AWxfu5RZC/xPNmw91l8j+Klm8/iuHePzwegZCN
Dug/qIOIgxxR+j/AS4fR+ujBv2/Lgg9wXNU//Iselo5x9z94+u0QhpzkP2Bt
8lfo47K/DmHhvg==
                  "], {{
                    {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
                    {RGBColor[0.65, 0.7, 0.7], SphereBox[{5, 6, 7}, 0.24]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    SphereBox[{2}, 0.32000000000000006`]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    SphereBox[{3, 4}, 0.31000000000000005`]}}, {{
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{8, 2}, 0.15]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{11, 9}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{9, 12}, 0.08]}, 
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{13, 10}, 0.08]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{10, 14}, 0.08]}}, {
                    {RGBColor[0.291989, 0.437977, 0.888609], 
                    CylinderBox[{2, 15}, 0.15]}, 
                    {RGBColor[0.800498, 0.201504, 0.192061], 
                    CylinderBox[{15, 4}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 16}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{16, 5}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 17}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{17, 6}, 0.15]}}, {
                    {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
                    {RGBColor[0.65, 0.7, 0.7], 
                    CylinderBox[{18, 7}, 0.15]}}}, 
                   {Opacity[0.7]}}]},
                Boxed->False,
                Lighting->"Neutral",
                
                Method->{
                 "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
                  "DefaultGraphicsInteraction" -> {
                   "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
                    "Effects" -> {
                    "Highlight" -> {"ratio" -> 2}, 
                    "HighlightPoint" -> {"ratio" -> 2}, 
                    "Droplines" -> {
                    "freeformCursorMode" -> True, 
                    "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
                  "DefaultPlotStyle" -> Automatic},
                
                ViewPoint->{0.6731506775593791, -2.938932037409044, 
                 1.5277259717606664`}]}, Dynamic[$CellContext`i9557$$],
               Alignment->Automatic,
               BaseStyle->"ListAnimateCore",
               ImageSize->All,
               TransitionDirection->Horizontal,
               TransitionDuration->0.5,
               TransitionEffect->Automatic],
              Identity,
              Editable->True,
              Selectable->True],
             ImageMargins->10],
            Deployed->False,
            StripOnInput->False,
            ScriptLevel->0,
            GraphicsBoxOptions->{PreserveImageOptions->True},
            Graphics3DBoxOptions->{PreserveImageOptions->True}],
           Identity,
           Editable->False,
           Selectable->False],
          Alignment->{Left, Center},
          Background->GrayLevel[1],
          Frame->1,
          FrameStyle->GrayLevel[0, 0.2],
          ItemSize->Automatic,
          StripOnInput->False]}
       },
       AutoDelete->False,
       GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Top}}},
       GridBoxDividers->{"Columns" -> {{False}}, "Rows" -> {{False}}},
       GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
       
       GridBoxSpacings->{"Columns" -> {
           Offset[0.7], {
            Offset[0.5599999999999999]}, 
           Offset[0.7]}, "Rows" -> {
           Offset[0.4], {
            Offset[0.8]}, 
           Offset[0.4]}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484207`*^9, 3.9198503896300077`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919852929298945*^9},
 CellLabel->
  "Out[1535]=",ExpressionUUID->"910c9108-c699-40ad-9881-4e90ffb41a79"],

Cell[BoxData[
 GraphicsBox[{{}, 
   InterpretationBox[{
     TagBox[{{}, {}, 
       TagBox[
        {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
          NCache[
           Rational[1, 60], 0.016666666666666666`]], AbsoluteThickness[2], 
         LineBox[CompressedData["
1:eJxNlG1Ik1EUx48po2LRi4Z9CNKQKJK1cOVL0x1t2UoyHTq3OXNTt1oICbkP
JuQTGIVErLcPldiQPvgSKGIWlNtNJaWiT0ZIMFYpRS8UlqGV2r33uXvWhTF+
z+Ge8z9vN7XmlNm9AgAO0R/750fyEPj/RNwEUloTYTYvxBkpb1cd7Rt2yByo
I6A1jT2/WC8zUE57WdCX4ZPZWUtgzGm9lHxGZlJDYEOmL3i3WeYUysHNOeaz
TTJLLgK/769uMzbKHHESWHdwceTJSRGf8vymc70X7IKrCZCxSd0evYh/jOkn
DePpQTmeg4DUPeE9LexSJYFA1mShP3rfTtlVmz0k/IONQGvnTNNeEZ9UEDBO
dagbovosBJLGG+c6hX4sJzD7p1e1U+QHZQSuPn0/YxP5EzOB9tGNj8KiPlIp
AXyc48quEvdLKL8pWNVlCMk9KGb6MTFeK+uXiiirdHFuQ2hpmR0TgYeftkKG
uC8VEpjob3/2tT6UwD8YCWwz7TJ6fTJL+QRGdh+fy4zqyyNw3X9gMCD0Qzbt
T233ZavID3S0HpLHurYxtJKzhkBEfcvujtYnjcaPr/yZag9953oSaX19b/2v
9oX+HxvtnRe5EdmOQBbexexpCP2fLey+zBoER/rNmH8dwtK0l8UX+hASbFzf
PPeXi+D/Uqjol/IReh54WH5/uX0/gn2NhuUv6oMw2MHrI9tNCF3hHbH6FSGk
NGtYfbl5+Qiyz3aVNsjrbShBCNwwsf6I/lH7FT3rH7eHzAj6cJLSXyhDqL/2
gfWfuzOUI4TL7inzIVkQhvJ8yvyQCoSBH+1svhb5BStC58K0Mn9oR8gKO9h8
cntLJdVz+7Uyv8SBEGn6xuZb1l/F9ONAsZh/rKasH1X2A50IJ/rPK/sTofwx
LrZfkov6W1Kz/eP5balByAnE9pNQVlva2P5ye3UtQut6m7LfUIfwK92o7H+A
svpw7H1AN+1/T6nyfkQoO73JyvsieXj9nS1Tw/8AMvKfrQ==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ]},
      {"WolframDynamicHighlight", <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
     StyleBox[
      DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
        Slot["HighlightElements"], 
        Slot["LayoutOptions"], 
        Slot["Meta"], 
        Charting`HighlightActionFunction["DynamicHighlight", {{{}, {}, 
           Annotation[{
             Hue[0.67, 0.6, 0.6], 
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]], 
             Line[CompressedData["
1:eJxNlG1Ik1EUx48po2LRi4Z9CNKQKJK1cOVL0x1t2UoyHTq3OXNTt1oICbkP
JuQTGIVErLcPldiQPvgSKGIWlNtNJaWiT0ZIMFYpRS8UlqGV2r33uXvWhTF+
z+Ge8z9vN7XmlNm9AgAO0R/750fyEPj/RNwEUloTYTYvxBkpb1cd7Rt2yByo
I6A1jT2/WC8zUE57WdCX4ZPZWUtgzGm9lHxGZlJDYEOmL3i3WeYUysHNOeaz
TTJLLgK/769uMzbKHHESWHdwceTJSRGf8vymc70X7IKrCZCxSd0evYh/jOkn
DePpQTmeg4DUPeE9LexSJYFA1mShP3rfTtlVmz0k/IONQGvnTNNeEZ9UEDBO
dagbovosBJLGG+c6hX4sJzD7p1e1U+QHZQSuPn0/YxP5EzOB9tGNj8KiPlIp
AXyc48quEvdLKL8pWNVlCMk9KGb6MTFeK+uXiiirdHFuQ2hpmR0TgYeftkKG
uC8VEpjob3/2tT6UwD8YCWwz7TJ6fTJL+QRGdh+fy4zqyyNw3X9gMCD0Qzbt
T233ZavID3S0HpLHurYxtJKzhkBEfcvujtYnjcaPr/yZag9953oSaX19b/2v
9oX+HxvtnRe5EdmOQBbexexpCP2fLey+zBoER/rNmH8dwtK0l8UX+hASbFzf
PPeXi+D/Uqjol/IReh54WH5/uX0/gn2NhuUv6oMw2MHrI9tNCF3hHbH6FSGk
NGtYfbl5+Qiyz3aVNsjrbShBCNwwsf6I/lH7FT3rH7eHzAj6cJLSXyhDqL/2
gfWfuzOUI4TL7inzIVkQhvJ8yvyQCoSBH+1svhb5BStC58K0Mn9oR8gKO9h8
cntLJdVz+7Uyv8SBEGn6xuZb1l/F9ONAsZh/rKasH1X2A50IJ/rPK/sTofwx
LrZfkov6W1Kz/eP5balByAnE9pNQVlva2P5ye3UtQut6m7LfUIfwK92o7H+A
svpw7H1AN+1/T6nyfkQoO73JyvsieXj9nS1Tw/8AMvKfrQ==
              "]]}, "Charting`Private`Tag#1"]}}, <|
         "HighlightElements" -> <|
           "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
          "LayoutOptions" -> <|
           "PanelPlotLayout" -> <||>, 
            "PlotRange" -> {{-180., 180.}, {-0.006748909281102833, 
             5.206279851677209*^-11}}, 
            "Frame" -> {{True, True}, {True, True}}, "AxesOrigin" -> {0, 0}, 
            "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {False, False}, 
            "LabelStyle" -> {}, "AspectRatio" -> GoldenRatio^(-1), 
            "DefaultStyle" -> {
              Directive[
               PointSize[
                Rational[1, 60]], 
               RGBColor[0.368417, 0.506779, 0.709798], 
               AbsoluteThickness[2]]}, 
            "HighlightLabelingFunctions" -> <|
             "CoordinatesToolOptions" -> Identity, 
              "ScalingFunctions" -> {{Identity, Identity}, {
                Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
            False|>, 
          "Meta" -> <|
           "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
            ListLinePlot, "GroupHighlight" -> False|>|>]]& )[<|
        "HighlightElements" -> <|
          "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
         "LayoutOptions" -> <|
          "PanelPlotLayout" -> <||>, 
           "PlotRange" -> {{-180., 180.}, {-0.006748909281102833, 
            5.206279851677209*^-11}}, "Frame" -> {{True, True}, {True, True}},
            "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
           "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
           GoldenRatio^(-1), "DefaultStyle" -> {
             Directive[
              PointSize[
               Rational[1, 60]], 
              RGBColor[0.368417, 0.506779, 0.709798], 
              AbsoluteThickness[2]]}, 
           "HighlightLabelingFunctions" -> <|
            "CoordinatesToolOptions" -> Identity, 
             "ScalingFunctions" -> {{Identity, Identity}, {
               Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> 
           False|>, 
         "Meta" -> <|
          "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
           ListLinePlot, "GroupHighlight" -> False|>|>],
       ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
        4.503599627370496*^15, -4.503599627370496*^15}}],
      Selectable->False]},
    Annotation[{{{}, {}, 
       Annotation[{
         Hue[0.67, 0.6, 0.6], 
         Directive[
          PointSize[
           Rational[1, 60]], 
          RGBColor[0.368417, 0.506779, 0.709798], 
          AbsoluteThickness[2]], 
         Line[CompressedData["
1:eJxNlG1Ik1EUx48po2LRi4Z9CNKQKJK1cOVL0x1t2UoyHTq3OXNTt1oICbkP
JuQTGIVErLcPldiQPvgSKGIWlNtNJaWiT0ZIMFYpRS8UlqGV2r33uXvWhTF+
z+Ge8z9vN7XmlNm9AgAO0R/750fyEPj/RNwEUloTYTYvxBkpb1cd7Rt2yByo
I6A1jT2/WC8zUE57WdCX4ZPZWUtgzGm9lHxGZlJDYEOmL3i3WeYUysHNOeaz
TTJLLgK/769uMzbKHHESWHdwceTJSRGf8vymc70X7IKrCZCxSd0evYh/jOkn
DePpQTmeg4DUPeE9LexSJYFA1mShP3rfTtlVmz0k/IONQGvnTNNeEZ9UEDBO
dagbovosBJLGG+c6hX4sJzD7p1e1U+QHZQSuPn0/YxP5EzOB9tGNj8KiPlIp
AXyc48quEvdLKL8pWNVlCMk9KGb6MTFeK+uXiiirdHFuQ2hpmR0TgYeftkKG
uC8VEpjob3/2tT6UwD8YCWwz7TJ6fTJL+QRGdh+fy4zqyyNw3X9gMCD0Qzbt
T233ZavID3S0HpLHurYxtJKzhkBEfcvujtYnjcaPr/yZag9953oSaX19b/2v
9oX+HxvtnRe5EdmOQBbexexpCP2fLey+zBoER/rNmH8dwtK0l8UX+hASbFzf
PPeXi+D/Uqjol/IReh54WH5/uX0/gn2NhuUv6oMw2MHrI9tNCF3hHbH6FSGk
NGtYfbl5+Qiyz3aVNsjrbShBCNwwsf6I/lH7FT3rH7eHzAj6cJLSXyhDqL/2
gfWfuzOUI4TL7inzIVkQhvJ8yvyQCoSBH+1svhb5BStC58K0Mn9oR8gKO9h8
cntLJdVz+7Uyv8SBEGn6xuZb1l/F9ONAsZh/rKasH1X2A50IJ/rPK/sTofwx
LrZfkov6W1Kz/eP5balByAnE9pNQVlva2P5ye3UtQut6m7LfUIfwK92o7H+A
svpw7H1AN+1/T6nyfkQoO73JyvsieXj9nS1Tw/8AMvKfrQ==
          "]]}, "Charting`Private`Tag#1"]}}, <|
     "HighlightElements" -> <|
       "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
      "LayoutOptions" -> <|
       "PanelPlotLayout" -> <||>, 
        "PlotRange" -> {{-180., 180.}, {-0.006748909281102833, 
         5.206279851677209*^-11}}, "Frame" -> {{True, True}, {True, True}}, 
        "AxesOrigin" -> {0, 0}, "ImageSize" -> {360, 360/GoldenRatio}, 
        "Axes" -> {False, False}, "LabelStyle" -> {}, "AspectRatio" -> 
        GoldenRatio^(-1), "DefaultStyle" -> {
          Directive[
           PointSize[
            Rational[1, 60]], 
           RGBColor[0.368417, 0.506779, 0.709798], 
           AbsoluteThickness[2]]}, 
        "HighlightLabelingFunctions" -> <|
         "CoordinatesToolOptions" -> Identity, 
          "ScalingFunctions" -> {{Identity, Identity}, {
            Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
      "Meta" -> <|
       "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
        ListLinePlot, "GroupHighlight" -> False|>|>, 
     "DynamicHighlight"]], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  BaseStyle->15,
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       TemplateBox[{"\"Energy\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{
             SubscriptBox["\"kcal\"", "\"th\""], "\[InvisibleSpace]", "\"/\"",
              "\[InvisibleSpace]", "\"mol\""}], 
           "thermochemical kilocalories per mole", 
           FractionBox["\"ThermochemicalKilocalories\"", "\"Moles\""]}, 
          "QuantityTF", SyntaxForm -> Mod], "\")\""}, "RowDefault"], 
       HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox[
       TemplateBox[{"\"Torsion angle\[ThinSpace](\"", 
         TemplateBox[{"\"\"", 
           RowBox[{"\[InvisibleSpace]", "\"\[Degree]\""}], "degrees", 
           "\"AngularDegrees\""}, "QuantityPostfixTF", SyntaxForm -> Mod], 
         "\")\""}, "RowDefault"], HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[2]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[2]]}, "DomainPadding" -> Scaled[0.02], 
    "RangePadding" -> Scaled[0.05], "OptimizePlotMarkers" -> True, 
    "IncludeHighlighting" -> "CurrentSet", "HighlightStyle" -> Automatic, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-180., 180.}, {-0.006748909281102833, 5.206279851677209*^-11}},
  
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.91985011326657*^9, 3.919850159308919*^9}, 
   3.9198503457484207`*^9, 3.9198503896300077`*^9, {3.919850460922832*^9, 
   3.919850475345052*^9}, 3.919852931432691*^9},
 CellLabel->
  "Out[1536]=",ExpressionUUID->"1aa6ce4e-4fe2-4400-84c3-67cf7271ad73"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["torsionList"], "Input",
 CellChangeTimes->{{3.919799366343082*^9, 3.919799368657453*^9}, {
  3.919847337711438*^9, 3.919847338687681*^9}},
 CellLabel->
  "In[1512]:=",ExpressionUUID->"aa85e01f-45f1-403c-a934-98777978da19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIH718PStGb3P9sc2Sp7SVTq8X6W8Zrlw6Fl7f6fl
d4Di9so/dxjpKR22zxNL7QGK72fR7V3gWfNtf8fdPwdT9j+y58yxKj2099j+
qxbtCQ0zXuw3lfD8UJK1b/+p7YdFZyt9tT9xsKP4gd2H/ZZGPve3eX/a/+Vs
+P+lprv3l976sBRojr3tzs2rgebsf1B9YCrQHPsjl1fEAc2x7/1k8bs4a599
jvB8XqA5++c0cSUDzbGXVmD+AzTH/vC3jYmLTXfb/+n7ydb98MP+xF9v5m16
e9q+QIfjpEvsLPuE3pVzeSY/37+HTV5xi/bB/evdNnfZnn1hv3fTuwdrWl/v
T03qn/Fn/ZP9IQoL/RtL1tufs1XiAppj//Irlx3QnP0WWZNuOcfO2s/FvQJk
jr3pTi0JoDn2Vtu064Hm7D+iHHcRaI69vX3UIaA59hJmEtubS9bvBwCxd7gd

      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    ImageSize->{180., 172.81871673421526`},
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.9555392341665696`, -1.6249852912505585`, 
     0.22047820418677544`},
    ViewVertical->{0.2608698643397846, -0.02810633580301755, 
     0.9649647391314723}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAve1yWsqU5r8BRGzQmanCvyT4R6X8
S80/teYVOuia5j+gW1YzfRHDP3O+0Q08vMy/xpITvWiL9r/RreVVUwDiPyWx
CGFaBsy/lqdmVSYa6b9xj+NU3Lmzv7qRIc2VFfU/KzHHcXsH8L+x54S31Hjy
v9dxXxanKrO/zuIKq3Jc9j+ZUGwzGI/jv58clmYrZ8M/IdDBl+F56D/Sk6L+
OwHDP2mHhU1NE/W/Jru054SD8D85SQMlsQ7yP2heOx99ksE/0oQm9ebq8L+h
OZXD2avKPwBw9EMkWnQ/qsrsV3jX57+6C976h4a8v7+QymEVv+g/CqgAn+BR
678xcJLxB87kvzg/GBqptrM/FOsKZPPU8D9icy3NcZXNv6hDd04hqqK/a9vr
6GSK5z+5d/yYXAnDPzi/P8/Uqui/gK6/BPnQ6z+tFG7L4HDkPxTALN19U6a/
5xW28g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1174457795537698`, -2.6730343751746757`, 
     1.7408624755827204`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAE/27GroB5r98RtesK129v8W9pu/V
uNI/QHA1on0R5j/IUlfaNjm/P1dmDVPePNK//07IFdvt9r+mYzmjQJ3fP4a6
2KiTMM2/lYdpZCq25r9t5HijkZXAP5x7HFYHvPU/9dVrmGQt778YsSPYGKHy
v3RRp/wHR8Y//tZUCslx9j9jPxOMTXfjv6zqy4Kc47s/Q9oYMtxp5T/LlMLb
FMGJP8K4HlT4+vW/7Rb5oQmx8D+/lf6JehHyP4m0lsGqIqi/xCaTEVz38L8G
kgO49UXIPwiC6WwwgqA/VMKSP/Jb5r/wEtTQvG9+Pw4rBtI8auo/hOmTWY+X
6r+AJfGS63bkv39m+u1Z3M0/j8e37UO98D8UqpBhTSDPv1jXtGTuh7a/QiUn
6qy95T+w0ue6rDixP1gS4ugviuq/Dc8Tc8i56z/rCqT3DQXkP+g8QKszQcW/
AUm68g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2563129404704885`, -2.417097845570353, 
     2.0009287344994457`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvW2tFYH45b/HnorlAX29v0eOjAsX
5NI/iGHXXy0P5j+uiBjd+RPAP+gbADR1MdK/EBYWuu0M978gSxi6TmrdP5Rz
vByzDNC/yVFVd8kA57/baY7xl2zEP9+GtoalpvU/lcvHtoSL7r+0tt6f/cPy
v8pNUn34bso/UPMFa6NS9j+vUmp7+y/kv1+cXnwqVbI/Te8PUBoL5T+l7HP+
URisP1iqfMneBPa/o9blDY7v8D//OTwpY+jxPxKcDdAeOo+/d2Z2IpcE8b9u
o7VADgvGP5DVgHYfu5Y/w1+BRqV85r/caST7W7iWP3CqmUmrX+o/qZw65gJC
6r+hYDe+zZvkv5baGqXJDdA/CtJ4DR2t8D+DMCQE/SrQv6Dp0ClVOLu/aqjz
1yON5T/Xg7VcDhq3P1KxfBY8keq/Z4fRvST36z8US99k4urjP8mIgCpGK8O/
BIOyWg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2664590684090196`, -2.419751180777233, 
     1.9913025011714682`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA2rJbLvUZ5r/wISH9fSi5v1Rfjygg
sNI/RY81vfc15j+vohJLiJu8Px0slpf41tG/sGjnfXQH979tmTr8ambbP86u
QikQsNO/sLw9WX3U579dnOVennPPP/4HeFq6QfU/k122Pitn7r/+dEwhU5by
v/hua7/aQdE/5CvlszYS9j/opTgMDUDlv2/iQ5QSVrM/Fky3y5tP5T9ZJr0/
0YelPzlctv2h7/W/N8yX3UJd8T8mrz4T3IrxP68vOwgVG4G/DqGKijcK8b/w
UPJ8SxzFP0DvaRYA/n+/xbfMQzn35r9kC1VgX9+yP9Pfm2TC7ek/NgiJNpBA
6r8dhx4B2yjkvyZn/XP9+NE/w/k/SZmW8D+SUdYCnKzRvwJnCuXnArq/rm12
xMnC5T/umnh1uK+zP0DnmyNgZeq/2pMyvD547D9R2e+XlFTjP5oF2D/RX8K/
wCa0BA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2248564693583337`, -2.3616303978813065`, 
     2.0849049122859333`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGZS5Ewkg5r8Z157Vi5S4v9Jnq92X
pNI/uHTG4KdA5j9PoG7TFX+8P47b9KR+qdG//NPMFdgR978q6Dop28LZP8yx
z/KQF9W/uQ6Bf5g56L+o+P4XKJHRPyibBfApFvU/kasNSzMU7r+/088UNpny
v434Qpep79I/3Tfn9fPZ9T9k80OCyT3mvzkF+ql1r6I/opHido4l5T+xG3/y
Tg+3PwxrQzBX7PW/s1YZWLO78T//qDycfDPxP4doLyygfKE/BM/UT+4Q8b9k
MtMzuJ3DP9BPIqnIl5O/aVGdydAs57/DhS5FCti2Px11cOdPv+k/1Z9jLx4a
6r8wwSnSfiLkvzAwd7ogytI/HDkl8yN98D9aH9bH5q3Sv841a98fp76/LYPU
Kxuz5T8A3vZiMse5P++hgNm2Vuq/D5F8SAfc7D8Ek3P5bfviP/rc3T7V876/
l9i50A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2121188292765186`, -2.385013887859852, 
     2.0656419579464766`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAwnOeUn4l5r//yG7orBW4v20VBaVV
mtI/wtc+GldI5j/xouy340O8P+EcH5M5jtG/BmEHjW4f97+1+Ymc64nXP7bB
wCeDtta/5eLsdKyu6L+Nl9g4eQrUP2mpaxQf1vQ/p8CyWuui7b9+3D4Qmpvy
v5lMmVBGW9U/KhrWGUWo9T+qVoAHcAXnv46BN/iTx2Q/mflmblUH5T+Hu3f4
uq7APxhOPl5j5fW/g4DhNN4K8j930D04fuDwP6SCTW6JirE/dE0r2xYZ8b92
R25igITBPyix7gq2cKC/VKvFYxVq57+bynn9Gwq8P8TurH20fOk/NJqo1jTk
6b8OycXe9BzkvwMxz/rN+tM/BsN6Uzhm8D9MwoKQ83zTv96tLmuqZMG/ruhS
RNan5T8ADW7UrNC+P1AVBsPxSOq/ZOwAwgkv7T+mmrxzvKTiP3B4F28uV7q/
hG63Og==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.206512472523818, -2.3861714637707556`, 
     2.0675863704161404`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAOeKeseAw5r9pTHC3Fm+3v9EYfSGX
dtI/+YDtXaVT5j99YUtlaJq7P80o67Ila9G/hMcbQhIm97/2KFBPoVnVP+cO
EKCAbNi/rey0IG806b/uljmZQrPWP5Midub+g/Q/wfMV0VdG7b9t0B2QXJLy
v4IFcvti3Nc/nZvx4T9v9T9oTWiGR9Tnv4Mk6dg6Hp+/G9ILXYQF5T9lRs9j
uefFP9qafgzK1fW/73lGSRFg8j+hLnY3m3nwP4490Urw9ro/UJx1TUEf8b+3
K+hCt/u+P1jYS/ql16e/c+cp6aey57/Ug13rfNfAP8ho1a6kIek//WpaQZy7
6b8z1ZT7TQnkvyqPdw59KdU/DS50SIlM8D854b55+mDUvxW7eWAJXcO/iql8
3ZSs5T+SezrLdtrBPw5lOXmTMOq/bDo9+OOJ7T+55Mq9QTPiP9SybUDTWrW/
LMK47w==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1936184260474716`, -2.388363187615591, 2.072533796357167}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAtYJOxMIu5r9er4yVJm24v5/icYk8
cdI/e8AIl1FN5j/C8DP2GVm8P2U7EsXDfdG/rQiQ2oI9978wL4gD5FvRP90z
80QIMdq/8IKIuPrc6b/Zi3ppPN/ZP7rmrnJEEPQ/R4B8nQVf7L+sO+nt/Z3y
vx2GItXFsNs/Z2RKkmVf9T/AIfWV9ATovzURjEOtjqy/Wif/xtjk5D+KcuH2
sBvKP90eb3sK0fW/SYpPm2l68j8cvVruek/wP1NLthtuQ8A/BKVbHnIq8b+y
Bkq8NIG2P/hEBe4u/66/0oJrvt4F6L8BYBfE8sPDP2JfC5WTrOg/foHlMORG
6b+iBkJX0CTkv140Si8BEdc/UmLnLgdD8D+ooy5X0XnUv4y9g22ZD8W/6vMD
LxWZ5T92tf34HiTEP7ats2x7MOq/hurTZhKh7T8o/L2NDBXiP3grbm4ZuLK/
4cKylg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.2169658692823662`, -2.343261476884767, 
     2.1100994583075066`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJ5axwD1B5r9VYJ3Pt863vyNnsab+
KNI/V7e+xdBa5j+gD3jvtRa7Pyf50wlSXdG/su6VxqE497/2IrrItCrOPxQ6
5JCk59u/oAYl2RJ76r/ibTmUgsvcP6BJqfnnlPM/lSn0mQ4d7L9TRJmHHXzy
vxtUq9omed4/HzPAMTMd9T/7JLyDF9jov8gr14TEoba/xvWB5lwK5T8haVbh
xLjPP03WRoBis/W/zt9+TYfV8j8aAY9ls4jvP+Vi/tdXisU/41x3U6As8b/L
cuvgWEOyP+SlZdRLfbO/ZE7rTChe6L/OFVKg1NfGP2ijVaMnH+g/3t9SLSYv
6b9ZGpMECfnjv59drsASUdg/ZcdPyk0l8D8HI83FQHXVvxnECSvDBce/jlYg
1pay5T94OInsD6LGP5bUuwK3Cuq/ejtesO8C7j+HAb8RxXXhP9AeU3eYYKq/
NnO2Mw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1948199591560291`, -2.346426047116679, 
     2.1192192124966174`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAN6WnhERL5r8gXwQuIvu3v4gl0Mxs
99E/Kk0ZNZBd5j8qJipBQlW6Pyb1zaF1ZdG/kekTPwo597+RzWSpkODIP2OH
ES6pRt2/o0INsjMN67+GW/z7y4zfP/6ehmLgEfM/tHS4za+0679Fy08RDF3y
v6HoIEU7wuA/ZJgOFm3h9D8zyvfcjH3pv0WpwkHiMcC/mv+7084W5T8z/VFW
jwPTP3bAi0Odk/W/unC1mwEk8z+Oy+50D2zuPz44dmk/oMo/Ft6zQFYv8b8A
PMUk/8WpP7jDgsJ4nra/7XNaGzys6L++Q3twA47JP2CoupW7j+c/9gwwKfr/
6L83ETA0vtzjv2X7iKvxvdk/fJ9NmBoI8D9uhdKU5DLWv8hJr8Jmfsm/YqZq
hC+65T++hpzm35jJP789/6v67Om/TxdCtslS7j8qCIreW9vgPxxkS7RXVaC/
Jxu14Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1846080806912167`, -2.3474090207781524`, 2.12385841908787}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0p2IsRVd5r9p21sL0jm4v5ekAQoB
m9E/i7U2HFJm5j9P+/IoJXK5P9Y/6InfT9G/b6Jf8acv9787DlSnUfLCP/Te
vaW29N6/2d+uy+TN67/Lo8RmAUXhP1n9DQX0ZvI/OAeV4p5U678huDvC/Szy
vzP1vKv9YeI/xduzlPyp9D/tutUGyw7qvz8ticfTJsS/+U3SbLlU5T/fLmEI
JfzVP6IEVuZaZPW/25/xPPJn8z+MiQweFELtP8frDZw93c8/rPgRZRkv8b8c
gpiGolWbP7x0eDdrs7q/1r6bPn0V6b+8ULJKjnvMP35mjke0zeY/hdIOStrY
6L/XdfHimrDjv37HvTB+L9s/ijbPoiXd7z+DW7dhhuDWv3bWrG1JY8u/woGE
xIXd5T+y7Z1SrljMP5cU0MhSuOm/oPoMSxub7j97dJVhLDjgPyCfFL4LFIa/
kLu86A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    ImageSize->{180., 160.11822278860402`},
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     3.0807994202941056`, -1.3903269628337491`, -0.008115930814439176},
    ViewVertical->{0.6051765441208867, -0.15807100266258575`, 
     0.7802402889899657}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAy0C7PUCC5r90dEzB1BW3v6bUD4TP
89A/YkSnRECC5j9ozkyj1RW3P8w4sJ7P89C/FQsKUMER978kqbCzomq+P1yF
dN3QfOC/GT/SNWGP7L8vAdw5jMziP/Tbn3Q6pvE/wMiaLWd2679yUFQ/Ytnx
vxgTHWD4qOM/Se1FCZBS9D8LsWfUgffqv5nTI/YU88e/F9vYpQT45T9EpiX+
LRHZP626A0tHEfW/oUr8FhPG8z9936fyzofrP2xf6IBuTdM/vdVzt3Ap8b/A
0pDJN1ONPxI22TbSBcC/8r/GudCI6b9C5WRDo9PPPx7Ro1Uu4+U/xgSrtVP8
6L+6F2mLv0rjv2v9JCLgItw/eo+ZK7CT7z8+F/4fxxTYv5giwhla7cy/vA9A
dSI95j/e2fhmo9bOP+DIrzI7Tum/0uxPOTMH7z9KeRGniWrePwA1wRH3zJI/
B6O2jw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.9195192477567636, -2.9110401561774895`, 
     1.4507686108153055`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvZY/uP565r+B8/At0Wa4v1E2roHm
+9A/U6MdI1Ry5j/tO3P+y0K3P9qLuhzIQtG/uXBaCwsX978mXKeQEqSxP5kP
cKkpv+C/4g0z43oI7b8xLX0uBuDjP5FjW7pEE/E/0zxSWNbQ6r/F+T3gC6rx
vwBQmctoVuU/tW7zSmYe9D9+Xm9eSzzrv78Y8BN1OM6/jxtIyS7V5T9j6wqi
3K3cPy8uBbmW2/S/fKv6OAv/8z/E/H8+bUnqPz6+UHLlVdU/DB69M0Uq8b9o
XSZ1+gqLv+LoMdFsgsC/UFK5zbzB6b/BDr8ILNPQPybxxlo+UuU/yOlIiOql
6L/9CB3zeDDjvyhrcAxc1N0/XkCCXJBX7z8B96De8VPYvx1MWVOBL9C/cd8y
dsEj5j8v3dPQRz/RPyXRM8BILOm/Jn2JSjU47z9BZE6+xjHdP5DJWFZ1TKA/
SdiwhQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5675621371263786, 2.3906199476485357`, 
     2.3210362957966537`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAfKihuxJ35r/t0JLbNGO5v7We8KzS
9tA/ISdynlFn5j9P0BN4CE+3P0T8m4X6d9G/WgAT8egT978G36YjG4OUP4T3
LqOfBeG/evV7nXGO7b916B7Ax+bkP0t+7W5wdvA/SG6E3Uo/6r/scngFZGrx
v7i9o/U+7eY/WkZwlnHm8z8Ujr4Sx3nrv+kAIy2IDtK/t8DA4jDL5T91CjFm
uwbgP5PTtTdLl/S/RGQ+qp029D9NrO71eP/oP4/Z/RrcQ9c/TOpxJ7kn8b8s
GakSbkKkv1JQbZlsFMG/+86OLMIC6r9YjqwkYbrRP/ilKRoltOQ/YguTzC5b
6L/7nzFTlwDjvxINHEyoaN8/6lmpZRoa7z8KFLwD5o/Yv5Z+X1lBw9G/7HOZ
QEEZ5j9/hDN1nPDSP6TSHNlJ9ei/1Hd3eUZq7z9XJvEEWunbPzB1h1WGL6c/
RLqzCw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5662382878987149, -2.390926961998522, \
-2.3210433997894246`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKCM8r/h15r9oW3v62eG5v6IRc0Bp
7NA/RGcsnDdh5j/xDwlp8iS3P8BqQDiCltG/+w5XEdcJ979PyRnPi8qav/8m
fT4HSOG/+UpwtzwU7r8z06RU/9/lP0pYUxRxru8/mxw+1yjI6b8X4xwPVBvx
v/LsYL3GZug/SMirwiOo8z8jgXeSi7brv74+CHPQ3dS/zqg6CqLW5T9iL5MW
E5HhP0LGdzfPR/S/+htRj/Vu9D/R3lzhEqrnP64mPrnEDNk/SJB6tGki8b/e
5iB3Pkqwv1w8hzylo8G/EDdWsxpF6r/GZ1UVxKPSP45wRtpSEuQ/4h89wxAf
6L/OmMSucbniv+I6za59buA/6vvBkL/Y7j8lX1ZF7dHYv79UpFUpOtO/CYgz
0+wb5j9gUbRjsXXUP/Lgh8Vvrei/nE9nXZGf7z/PAH4usY7aP7jv9gMK2a0/
B/61UA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5663998131127178, -2.390947054432604, -2.320983290462457}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAISMafXxu5r+RfuysxZm6vw1eMpPY
/NA/75VHGAdX5j9Whyq1voC3P/e5M5xUvdG/oocoZPH+9r/dDbxIIw6zv/mU
BiqUZOG/Rete0i2W7r9uxxMreKjmP6E9JBu0i+4/K1bOg2c56b/3tvcpYs7w
v2GjrEW4y+k/ZSbOzvhs8z+mnteIi8rrv4MvAZ+jzde/EmT7+R3I5T/8rR0q
uRDjP+zoDu+p9fO/Ya7A6m6h9D+y2eEaBHPmP3dKoY0Wf9o/mcxa0Rcb8b83
RtR69NO2v+bL2sBPzMG/M4e8J1WC6r+cN3Z1P1XTP1S2XjIQheM/pjx0APLT
57/gfsaE/nfivzTpokcSJeE/XPHxWnyY7j+8TTKyc9rYv710mh18xdS/AH0h
iZIP5j/m/sIA0QDWP2rXGxb/ZOi/WHnkdvLM7z+cKofxG2PZPwAh2+KDg7E/
+Da76w==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5657891454180122, 2.390849609974954, 2.321232600453855}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAU3IO4DBx5r/m+Q+YNZu6vzqbFwdZ
6NA/MsEAKAhZ5j+5+GL72nC3P/jh/ArCrtG/2NuCaOHp9r+Nx9jS5DS9vzur
5zvFmuG/QbUbQE0X778Eev4mb1/nP5KkbDIocO0/26r9vwzr6L+yjpybBHvw
v8rzieoy5Oo/rmNRwSMm8z8q+Uc+/Orrvwj9NGZGoNq/Xd8U0tbx5T+xKUU7
aX7kP2vhZiv/jPO/1KgejxPY9D+jrWpMFQ/lP5qij+x/J9w/gQpF7DwR8b+6
YHQ1Dei7vzy7t3AxTcK/yhMVED/E6r/IevxzCAzUPxg5/Foq8uI/lw4G0B6u
579Qjh31tyTiv7TgCrcvrOE/R8RR1adS7j8Tmtve4PzYv4DvmDiEJ9a/SNAK
fW8l5j/IiLGahGzXP+kZJq6v+Oe/toSP0UsC8D+6DNerMP3XP0SBJcN78bQ/
x+257g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.567752570592848, -2.380481711754108, \
-2.3313866771922327`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABcVr3xKI5r+2zY2kdzy5vyA1TRsD
idA/uNZZoElx5j+r7QqBTDm2P2IcEg7sRdG/+f4JQLHC9r8KkzZe0CPDv9l6
ypUlF+K/BThSrDaw779qIh7T0lDoPz/4ayE3AOw/ZGnODD0B6b/FwhlM5QLw
v7hMtt9Y4us/VqnFtfHb8j+FD3JE8zjsv7Z2PFCCgdy/t5x7AjyE5j9pP+V4
JH/lP0qaQ+5jGfO/LucD+r8I9T8QstxXIJjjP4bhV7wlDd4/vvDfV10D8b/l
eX0wDMK/v5LARxBIpcO/hf7exSQc67+0aIzeQynVP2hJiVdcIuI/NBcd9qfE
57+gn2LGrJbhv6RzrjZtE+I/spTyhZYU7j/PsVC0yXHZv4xJJy+349a/uLlq
0cJ65j8fnQYJTkbYP2IhyPHeaue/RWkYZbIg8D/GD/7nSV/WP0iKi1xzjrk/
OU+wpA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.5627327340278557, -2.38048703635731, -2.332597980747717}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA0RCY5M7B5r+z1aCxsji1v9WhNWCj
NM8/jiq4EDat5j9Rf2DCE5WyP63X1k6DRNC/eNf0smaK9r/RZhvTxrHDvya7
bpkZE+O/BBNwMb0N8L/8YjqhInnpP55CmuK3fOo/qC9TdYL86b+QRvlWGOnu
v7ZZa0P6Luw/8wBEKPVo8j897k9o2fLsv45jjmBqHN6/wZ2JAtTn5z+pcBN6
CWHmPxjZmOjUY/K/oL1ZVNJD9T8BxOaBq0LhPxjeuw9fkuA/8G+gEqf18L+q
0esrIE6+v2GlwoLhi8a/bBu8o6Ru679FSAZLDNLWP4rVU13wJOE/PKD1rChf
6L+jsJZWF8jgvxZhvI0R/uE/OhagMJC/7T9T3gPwNqDav56dstd2MNe/KOSg
CYVK5z+TgF/yq7PYPwSPTrz1dOa/dOlarjZN8D/r0zL6TZXTP4LkoNA64MA/
/Hq73A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5723108334790381, 2.3465719455767338`, 
     2.3644154487134346`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAWKEWHEsj57+qIdnIlLGjv8HLSF7U
7Ms/7/68VG4R5z9yuYy+/YCeP/n0MYFuAM2/3D/XCyYy9r+JVCWkC5jCv7JZ
DVVEoeS/KFgMcoIR8L8Cv8AyR2rsP2cQiqMRVuc/YIRqelxG7L/OFnM+Iurr
v7gJjWR6B+0/RVkjLfmz8T9Rn5vEUxrvv3N+dBmyD9y/97HYIoSM6j8caLM6
LQzlP3p4JtDm1/G/NxEa1Yl19T/vHPNQLPbcPwqSM05FQOI/REjxzOXh8L/0
nFvWcIS3v4NN9noeTMu/1KgXACij67/oLDPmLS/bP1hDHLtGUd4/3JJAy9O0
6b/oqACLOyXdv1SeD75XAeI/vNiBV7A87T+FOafWSybev3i8Bq30R9W/c9jK
O/nO6D/nzacoNQDWPxm3TKD0d+W/V0i8fyB/8D+G6NssPN7OP5cpzltTAMY/
neiwIw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6002455638212141, 2.3881787992922727`, 2.315320125970462}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKMzEDV0l578zO5lJ1Fagv+SHhJT4
6cs/m0k/bRwX5z92PlyT4iaaPwTTbHYpv8y/FuXQLhEr9r8rnk2dqY/Dv7hG
ZqoGn+S/4Acg21YN8L+c7GvZc9TsP8vrV9+t9+Y/5kQj20hc7L9ZbFGc73Hr
v15rq7kLU+0/zsfRDQND8T9fcsfB3Q7vv5NYFfwYE+C/FzB6lm8B6z+gBfhU
TXvmPzJggJoMMvG/aoia4/Gp9T8QB4ckWpLYP4H8bkbLAOM/laXZ2t/e8L/4
7LOvXqW3v35JigoRScu/9G0CYgWg67/pWNKUBs/bP8QNeQQs8t0/hwh09NLA
6b8MAOvgXHfcv6xGZu/EJuI/nGxxRJHO7D9skCytpj3ev1SNsFnjQte/2bzc
AUYM6T+T55JphEzXP5L6TcnxyeS/nBYdDcCa8D/4yrxNyDTKP4CPp9EBosc/
k3a2bw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6341980435021852, 2.323292359624117, 2.3716039832421867`}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAJUO+CdLI57/xNHbNQWu7P5Ah7WVd
h7Y/BXxJgoC/5z/6XSBeEKi8v/xu97Cfbbe/Bp1DbuyL9L9Slpx9UyvEv1BJ
+zMCauq/+/bwxatc7r+/XViDn5DyP/smRU4kadM/FmFVnqkM8r/FvARCBKff
v1B/xtwRU+0/J3nFqRcE7z8nBHHAQ+Tyv24EW9Vs2cK/5VVFc0ia8T9Sk2Kl
qQ7YP31wnw7VCvC/suQHYECv9D9jm3aKyUvTP6gIhZcrS+g/TF+RuSo48L9k
74VbytaZvx6lPYcWmde/EJ3X574S678OwS+gU0fkP19vwKf7Csk/qII0oxLx
7b+KL6fOM8zIv8ERwsT+EeA/lnoHFsxh6z8GClPGxK7kv+y71q08kL6/6BNq
tAh67T/Te9qNpeTAP2znrgmvgeG/WlGWUIBH8D/KB93likO4P8kaZqF3XdU/
oDGzVA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.6320101800727966, 2.685898531783721, 1.9521557850864262`}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAvv920tDS57/Uc8pBOE+2PyUaJxVp
Rrk/2PLvMaTO5z/5GlMqfOG2v/GoCNhEvrm/FDXDa6ec9L+Y+wnoOG7Gv+TX
cOebCeq/P+2n3Zw+778PJZu72AzyP+WNv7VW/tU/qQTgqCen8b+ZU5HDA37h
vzCcauBVR+0/MwZMsKaX7z8xhrzV9knyv8EnKQIqENG/qgtELT1y8T80fGlv
9FzfP3h9KA4vw+6/TsY0QyOn9D/A3r0Jc97PPwKjO/9ZHek/elp/6gdD8L9c
g0mOOY2mv6D0y8TO4Na/fnYP2LaI679MzLc/zHHjP25UCfvwT8w/iIQbEpCQ
7b8+CrB2OWjNv7q/h4EROOA/hvwdcSWz6z/gt2GYDrjjv/5RKzi7f8e/FgU8
Ro9Z7T92tdRklaTJP0vJlNR7/eC/3V8WrjpH8D9DUZT0tG20P+SNOmSR5dU/
A3C2yA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.5877920305185216, 2.5745166101246175`, 2.10968356704302}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIPYVeSwT8e35fl3X7/Un7261T189PcK5aZ39248O
5kBxe/Pd51Yev7t1f4DAOUeHpnX7pWUE1rw7/Hm/opPk/e7K3fvVXosve3bt
zX6WuXklMXff77f92ChlsPqjfUNl/0v769ft61hPK3G0ftqv9uQy8/GOx/vP
cpRXW/a8tNctUwgCqrc/9CpYDKh+/7EMjutA9ft5Zf6KANXbt9o67TzW8dh+
u/Rmdquel/tXWu3aBLTXPjK6raSvcre9k4nCYaC99k7LGndJ7X+//8Ln9hrO
/Lb9+QV9BYfe3dq/4sYKj1svX++fkNq4iYfzsf3bvEUhHctP2y/ptzE0aXi3
v/H3lcu8Zy/sb2lm2Bhbctued8sGF6B6+7JrHyYA1e+/oOV0v3356f0sU+ca
ANXby6VxHAGqt9/z5zx3XMnt/Qs2R50D2mvf0XBPSzq/zd42mHk/0F57AKdj
tnA=
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.36390375882917525`, 
     3.352315980148783, -0.23227488790031783`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/qEMakXZ578ytZA8Tda4PyH6sU8+
CrU/03SIJrPc5z+pv3xJdke4vwD6X8CFt7S/h0JDtZyY9L+wTYVEyAPZvzwl
haCAeOe/W0XGe0EB8L8XFsoijJLyP3CHumO5zLU/W40nxjJg8b+P8vdtbt7V
v6pUbbJHZvA/z0jZEFSs7z+EPYhEyYfyvy/z9hwD8sS/TNI34uSR8T9UxjLr
ienZP/SBzsXSoO+/c2MyI0uQ9D/Wqfkn7KnUP8HU0FVWxeg/w8kktZ9C8L9j
IGH1NM7Cv/jljtY419S/WpbMMOTt679qIZP28B/kP8hAttl7a7U/Wt4te9VM
7b+Giqc9tlG/v0x0aJfrtuE/0d6wm4PE6z9+CSCpQAzkvy/wJv3FTb+/tgx8
dT6A7T9qltNYrNfDP5pA7b7hG+G/7k47W1I/8D/X8zQrHTC9P4HVxJ1lLtY/
pbW+DA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.1073138557885786, -1.7084774888329732`, 
     2.9144447852904616`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAAPk2zNzY579mJPrbl+e9P3hGfptP
XKo/ABwNyhff5z8F9uMnTuS8vyZwv0byNqm/fZXnpfVU9L/KeU6XjDXav1FE
7HTEB+i/4NVLye1Z77/m//vzHO/yP6Q+odLXr4O/lshMClf/8b/2a6Nqtf3Q
v3KUXanoEPA/r1ILrHHi7j9LdGN7IuLyv8LmTkG4/sK/kePT14lj8j+ZPmbp
oiLZP7kiMUMS1O2/q1j5XGMp9D+If59f45vRP/03MMsctuo//ogBBrIg8L+x
8E+gprvCv+lfNHv/Yda/cGfBSmWZ678tortxls3kP8/21aZZcJU/FkVocMXr
7b+6xUnnngezv6aGOSbL4+A/WDcMu8Rg6z+ss+FdZ7Dkv8zC/tJ0TLm/kXHa
vBVT7j8YQW1fj+nBP7wZnWeBZ9+/VvP/oHcM8D8NBE2rn8W0P/pAxKatItk/
0qPCdA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.03977244140280435, -1.6583709165937601`, 
     2.9449319272100047`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHoNGZzTN57/XoEdMfgLBPwm0z12q
vZ0/si+tQZjV5z8+0GwbA1fAv5nzvFj1v5q/NaSx+HQy9L/MVMPNDVnbv8vu
Fv6bJ+i/B8lPRGiy7r+TkNlzIi7zP1qy3NcfQ7a/j7loSM5l8r+WNVLazFfJ
v+IXVfKlr+8//HXlPzE67j+UbLfLNyPzvydUG2rPXcO/wHKkts//8j9RCGU/
jffYPyfg9E0wQey/qmxbFF3Q8z8bBRqy/hfNPxc0jFIQQew/4nIqlocM8L9h
hJ+nztfCvypxKKuuOde/EibLVc4/67+uhGI9ck7lP6+K0YBqp52/HvsLfGhM
7r98KRUcnaqgv8HKoaLJTuA/11LJwOQH6z+cBiUvGC7lv5ryMhXOtba/mQp7
15vq7j8yoK6xC8zAP8THuvgvF92/gwQyNSm77z+4aVot94GpP3pMxqcQa9s/
Rs+z+g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.14957163507466617`, -1.623380344457142, 
     2.960855380326993}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAZsQByUuk579Xs3AZjI3EP0MJlBbU
z4+/FRXdkfWt5z+Gp4n3BszDv/cAjid7Y5M/ZBmac8DM879TfTzAKHfav2MG
uBkjrOm/2Hsaxf8e7b+zM5fSeabzP2gwGD2558a/U+GPF65K87/nHHi3Kxm/
v3NLPiVy4O0/T/rIApMi7T942DVHBJTzv/lmrx05/sG/o4DlDOYb9D+G2ICz
9SPYP/rdZkMKKum/0j/j7+n08j97nTily93CP8kFLBFbE+8/l/saWOae77+n
I4SzYjDAv4hWEmpiK9q/HyAOx6Vh6r8eSsVVKzjmP/xwgX625Li/hsMQ/NMc
77+Qk9L22AOUP07749QyYd0/sgdTSkRo6j9oDScmhQ3mv7RNe3GTI6+/LgvU
1eDy7z+ECXhv5Hu8P/NtKmrujti/XMrRuOTL7j+AQSFKasdtv9B1aOp2rt8/
7lm1hA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.3812366236282519, -1.6185284782456857`, 
     2.9426899602085563`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAnDgEas1x5r90NHAKsPjRPwHB+++F
vKG/jzt2Au155j8X5NzIGcLRv5AGjMra6KQ/AIfsXMRw8b8sjhq02DrLPxDw
Fus24vC/Adpqrkpt579H5sN2jSH1P0Vres9qUtM/o1CXzH/39b+U6ERXXpTT
v8eu1E6ROOM/jP4EekIx6j8wlQFdfP/xv/LJSlrQh+S/X0KNq2TP9j9e9K95
euneP08WrH5bXNG/CRWkgadl7j/WJGJHsdjiv7DMf9vv8vA/TqPuEaup7L+K
e31kHJbPPxjOlhobcOG/Tok3DIzv5r9k8195uZ/pPyXzehHaGsE/eLbMQDOY
8L8AQkvN5LqJv7fy1O/IHNI/Dp09vpdV6D82zjjPAnDmv4kJoq1COdO/EzBk
li0G8T+MIKZhwU66P/oqtUqAfr2/TCgNQspv6j/iltArvrnbv+Us1LE2muE/
6e24Mg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.1321505430373722`, 
     2.726056777995848, -1.6465872558243244`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATVhE+3Vo4r/AzkWqGGvTP7hqFnJv
uNi/9f4kTBRS4j8kwZFcy0fTv0b/KQfhFdk//w9VhEEk1b8YrxFXjHbXP5Im
6n2sNve/QuvVJyim6r9v4YV2Trz0Px+XGeBJy3u/voY+kU9f97+lRHus2HjV
v04/mE6MfNO/Xi15I5kt8j/hfexKhgjwvxFUGHnonM2/KXQUsm1f9D80U8AA
Iu/eP0f/1XtgROY/SHBB6u/Myz+tyHuIoe/pv6ifIS2rq/Q/TOBuvZb63L/s
vquA0nDVP0DBb1rIZO2/yCGNEU+H5r8fVRehFJfpPxTRlpmcJ8m/cllwR8VJ
8L8gr6sRAG6QvwNVV+B9Gta/2KyLSaNW6z8q7hAiedrkv3yqO5XZjrQ/pPMm
2HeI7T8gJF1IrU63P3V/tX+oZ+E/B1u1RlBF2T+gVGKbw8nhv3of7G4j8eo/
Z0ix3A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.6822183917042866`, 2.916663387316241, -0.2959999454405246}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/Xn3UtW44L8zd81Jd5DYP39hGLPl
8ti/MGG1aRas4D9UK0W4LGPYv96a3+j4QNk/CDNL85Wp178A3FdeYl3QP6If
MWy2c/e/ihy2xwFE4L9d+8+xWCr3P6cQFYHbuMG/cw9KHjxU+L9ZX9wWf85+
v3yuM8FYRsW/Amw0wLMo7T9NgVMtF3zzvyDlUJN2rMi/FrHie0D49T8zpE+1
uD/RP+3k/A5oxeM/6tg2ynimvT8wvyaSGATovwBDstfycvU/gROdTKCN3L+a
qRLU7HbUPwI499hvsO2/RMtWjWt+4L8qWUOEdk7tP+l00bmp59C/OebiY1NY
8L+2BXJNPRXIP14c2QkJy9G/meb0FGXq5j8izGRb4pTpv5xQbj571bk/rmG9
sEtO7j+AHNYL0I2svy5ZtkHyMuA/TTz8guVg1D9tqiR31xriv7gp6hExw+s/
y121BQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.238332650245279, 2.4385790057092698`, -0.6838123863750435}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAqlh78u944L/+2+iP/QjZP8lDYyj3
KNm/OHhSxQZv4D8aYVE9nebYv1yjdqW5ZNk/nWODU0tF2L+M5XQVHwbOP08U
G61ge/e/7GuNdQCc3b+41XZIe1v3P1XH+q7LbsW/7zg/bulb+L+pTWoVkfGj
P5vSqWw4DcO/hqHoL3nq7T/cMysxzCvzvwPT19poksq/5RDDNhiS9T+fw0m7
l9nQP3KKVmZ/k+U/7YV+1sEdtT/0Xf/A+p3pv8mJON99BPU/eAo9nJWb3L9i
p1GNBgbUP0LlM3eexe2/oA5CLfBG37+3DHGsup3tP7pT8H8u8NG/onK+szBM
8L+zJZayL4fLP4sWXK/JV9G/34yd+r8s5z8ijH+Ac2Xpv7RzFXAKN7g/AU1s
mZvJ7T/4Og8ECxqwvxDuiBzuIuE/9kgiAL8S0z9AB9SvpAjjv6AylkisXes/
RzO07g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.268477816287621, 2.422308536287064, -0.6409600237470113}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzky4yR4g4L8CtL+PcrfZP6E9zDng
Ytm/U81FGq0Z4D+EWWeRCKHZvzWYaybJidk/+8+vHaTx2L81SSkyym7LP753
dSnVf/e/QuWaLX6y2b8/Ma1GMJH3P+x0d1xVw8m/YobSO1hb+L+7vx/zLQ+6
P3UbCFGVdcC/q1J5VkBb7j/5+RQD8/ryv1/Z//Dz+8u/MOlnxOUp9T/RmpXA
LWXPP46MZRtGZec/gsEpeHUCpj9B6TP2ki7rvx3NKJoTivQ/zDSQ2PCY3L9O
LGrUa7fTPyaH6DeN2O2/b7+F4F353L8/Hp3qDP/tPwz8A3RFItO/ZFZX0LM1
8L/40UMGnx3QP64lKHHVztC//49fuHY65z9a0G4nNWPpvwxX11ueF7c/2s+K
Ubw27T84GDli49yzv1SsTVcVFeI/a2nIcdR50T8Cy3Ofi//jvyqzw+OF7Oo/
RUC2ow==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.320003137206787, 2.38267231651475, -0.6040348296786365}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAFTbyaS0P4L+oKMXtes7ZP4rAfXrj
edm/1sWQfhMM4D+f5QIvIcPZv6mUMu4pjdk/AGuhHDMr27+W2iOoGivGP6UE
PtYmcfe/AamJA6KK1r/Iw0aA1KD3P0GjAf2EFtC/Hb5Xmgda+L+8Y6ehIOrD
Px1mrItzUba/h8ideEsA7z/8ImrvA7Xyvzz69OI4+cy/4UjWQNjX9D9W3yKJ
DHPPP6l3U9bjmOg/lKxe/fNCnD+0iZmqXz/sv5HnPsjCKfQ/letC+Mak3b/6
iusgBHLSP8d03bSfz+2/lgq3a35U27/yDbg7cxTuP+axvzs0yNS/lGyoJ88w
8L9DbUyfxeHRPxHaaF1ADs+/LkeXey+G5z9k3Co7zCXpvxQvcPkaIbY/zKse
AOLd7D/o6+LUNRO0v/9gtma8r+I/Ort7Hivu0D9Cfg0heJDkv7yMy0MNjeo/
plK3VA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.345903034788885, 2.3505784331770303`, -0.6292217263026727}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAR+vXuXxb3b8uelLWYnLRP4aI28GH
LuG/CXZZT1hY3T+vRBQsLG/Rv4YUrPivMOE/DvN9LjlIw78JLt/woGy0v1UV
t9Pmavi/1Mdcj6MS3b+i4RnWxN31PypBGYWEOOG/MJxxkwnL97+/C1VMLk6w
v/XTwt0rv9e/6pwtNTfq8j/Ht+M2Kynvv+Dl1YfPU7w/UO9YfjRa8D+qvOPj
wDzhP1qZu5SKJfA/ByD6apCuvL+0AKp7YDnpv+/JeEoYC/U/Z3KLqMx/079Y
XTU0da64P8xsUloVgfC/jlmaJBA33b8tgK6LXTrqP9hkeiOGM+G/Apfnwegh
7798bnqGrr26P4DyvLAdDt2/bPoDSU1A6j8Q7XamYPDjv0LRpukpu9Q/0kwv
kkqw5z+mNLObVQrBP52jEZHiveg/CO6aNLQsxj+GEdpIe/jgvzLUzkZwo+0/
Dz+1kg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.0697684925130178`, 
     2.6336182666891386`, -0.45223137082878667`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAB04WrM4l3b/bOzNP4MDRP5nB4w+b
MeG/r4u+lc4l3T/vpe864MDRv5ELgPSaMeE/fmB6ePJMx7//OjLNdkG+v2KT
l1s5U/i/p0/LfGDL2L+eCfQGuOb1P1e2TIZMg+K/RHqE+1D297+WJO/2WS6B
P4d860Dkv9W/fu2usOYi8z+znF9JK6Tuv5s3MMAdALs/5Rl5rFmz7z/FaoSz
c/HgP7XAc86UwfA/TPYCJ8Kcvr81xmHFQpfqvzqBmfdBk/Q/I78p9CNm1L82
Ws03BWG0Pxe6xHEDdvC/185wlJf42r+U2MAa8FbqP/g7GMtz2uG/xg2KpsQ/
778AteoeU0rCP9x/WTCNEdy/apAeVlps6j/Wt2uzTcLjv4QShqyekdQ/3i+s
eyAj5z+aLxksByLAP37Gs0hiWuk/HM79C55+xT+WzGxx2bvhvwKH2XEPLO0/
zH+4ww==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.6674233470295085, 2.6795414804749638`, 1.949103263106899}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAavT96pKw3b/sa+bjZxHRP1L6F4NQ
IuG/Mm8SH4Ct3T/27W8+HA7RvyF//Al3JOE/jT4uS9HPzL/dG1cvYvnFv+Hx
tB75Jfi/qQZ3k2Ae17+TXxD3SKT1P0oIN2z/D+S/684vjxkg+L8nfcGbKKOl
PwmfffnrBNO/ZMtmOTu88z8T1x049RntvwLj6RF5D7k/5gV5SEuJ7j+jsGXB
yqPhP+d5KlLsJvE/oFplgQXnt7/uygf95q/rv6Qe2pE8NvQ/2IlKyD0M1r/4
d+sw21KoP4V3ILCQW/C/in06v3ln2r+O+gnwoujpP06Bp/cnmeK/BUzvST6M
77+Rm173zMXDP9bJ1n/GpNq/MGcrQZsn6z8H56qrgdDiv4G7OSxmRtQ/wB4B
rAWw5j9Qc1tEeTnCP3i5KNcnuek/ihi5vr6zxz/04B+OehvivzRe2BZ4yOw/
S/q2PQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.0960075536491747`, 
     2.6045330798082444`, -0.4975537872734799}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAIzi2PkG83r/FJpU4rz3QP6CBdwBV
3uC/kzspbDmv3j8H3WYR6jPQvyCbZUWa5uA/bp6NuWPSyb+A8yrKDMq+vyE5
6TMZRvi/Up/A8T7Y3L/AeFKq8o31PyhBdWPkY+K/wgtZF1Ae+L/UpaF/Ooyp
vyZxdPxUjdO/ylMG18mF9T/YELKnypTnv8m+EhP5xLA/OfqUgQlq6j+FuHw0
zvThP/hdV7d6vfI/tXrziTFwhL8KbWL0Ygfwv+UAJ59zjfI/rYO+jbnS1b/K
0xQMWBaxP/h8EtqhWvC/ums7GEDK3b9ywnd4Xp3pP2Rh9rEcoeG/ypkGZ2DN
778U5EHRTxi6PzO6sX7/pNq/rqIQMpgx7T9cf2Wwv67fv/nyx2c5/9I/AczU
G9Pg5D8ClJJXsrXDP4grCtrHMOs/vZ/Z37cLzj9MJLx4XRTkv3XO2cHAAOs/
3gS5SQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8156403561119783`, 
     2.8402183067071003`, -0.24700216092864502`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAaL+hWzKs3r9ppMb7fGTQP67u+yfz
2uC/fXrvhPeR3j9gF6n+1lDQv6sVILeY6+A/aEQD9Bf9zL+YvJAB+27Dv9gX
tPOjKfi/GllXs8QB2r/6uo0AL4j1P2ZHBaVpauO/VAqnPjI5+L/w8dVNHzFK
P5jvNzI6A9K/R44zyLDS9T+iaOXpm2fmv3YDi7qM/7A/MGLTi8QY6T/Z2M5w
wHbhP7fNPKJ2UvM/s/3Ra9VAKD+cQ4BhEarwv4fHsgLl9PE/zrDRKl+V1r90
GPnr/bOqP5gH2cOOS/C/QYx8h/tW3L8UZH8/TqHpPwqbgGauIuK/LnqP1T7k
779ij22LlXHAP3rmF0GQ3Nm/5mxvqS537T9S9DlpB5Devxp2cU6KC9M/t48l
J+Aw5D9SmvTiqZzCP4zYzP1CyOs/vfScn/+Uzj90iSohR77kv1zSQl6xauo/
JoC9Kw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.827785325827179, 
     2.8336739761174465`, -0.23214779724471674`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAGLGh1IXO3r9F8ChVlEDQPzqOOfx/
0uC/CZQVIlWm3j8raKmQTSLQv3eX2yQQ7OA/gSaxI7Z80L8rgQeS3HzIv5yY
qVe0//e/vitmlzvn178YThDrtWX1P/uk3iMOlOS/MrxvOpFN+L/5SeDxd1ul
P5wtwAgTOtC/K0tvBdwl9j+DK+65XQnlvz4Zw7zeFLE/r9+2PJDw5z8fAybA
Hj/hP0XgtvTxvvM/GCsoy2mdlD+o+BgnaCPxv6mBWhw4e/E/zGsp/J2l17/A
vpQwmAigP9wv4yp6NPC/a+4DtuBa278qiloA23XpP5oZDBBHs+K/PBTMV5kA
8L+E+WRTA+zCPwilmYCJ79i/LrD0TXHP7T+Y30KChBrdv5/6c/yrDtM/2tTg
Zt2h4z8SnqLv71vCPwCsJAf6NOw/uhbIvivwzz+yUkOL+yvlv2RNyC5A8ek/
YD+zTA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.826095351531008, 
     2.8338825902130154`, -0.24266279484999417`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAATFV84Mzd3r9bbk5uhS/QP/HxzyAZ
zuC/znBvADGp3j/Z/ACd/wfQv6CnV/OD7+A/JwcDWXdJ0r8o3DkLDu3MvwGx
BzPd0/e/Uyyx1PL91b9ddNWIU0L1P3k7c0muneW/V2w4/qBW+L9xQAgL1W+0
P96kKMa3m82/o7phMdtz9j+wbU7oXqLjv5cLfwIEyLE/SkGQKKDB5j+Bg+Ue
AuvgP3BM9l6BKvQ/PmWzI+YepD+ebjwC4pnxv+rsiS10/vA/Oq6/HKKT2L9w
BBiL5o+LP/3Ut+F0HfC/0MCW2t9t2r/0D2nkNE7pP7WWIbXjNeO/1cArGwoH
8L93fhCxekvFPygbWhIHNdi/1pZ9cSce7j8c7M62XqbbvxOJp3OEKNM/2Pxj
VBwL4z8qCsqgBM7BP0AgolhDouw/u+5y4oaW0D/UrXzp4Zvlv7rANSc2duk/
1X60GQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8213127223170156`, 
     2.8368523025521375`, -0.2439036306224676}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAHfRSlcsc37+ZDMqXR4bPPyhyGfRf
yeC/H0XeJXLf3j8bt+sOlynPvxmZudZU8OA/y+PNA1tr1L+X7dJwo1nRv659
VRM7lve/tCRwHa7M1L/UuMJtSwD1P1DKVdX53ea/XVp43ppd+L9fcufwcaW7
P+ACSWCAWcq/bB0olWvG9j83ckpVkgXiv7NzbAJLVLI/VDvmGpS75T8+AJjJ
ffDgP3XQeYcVcPQ/LA+JUt1rsT9i0V1WReXxv0x4fkaTp/A/9GuQTBPE2b+w
dN5O+meJv8I2Yg3r+u+/aIxh2bz02b9n+rtgFPHoPzyet+Ss0+O/sovm4WYS
8L/k4h5IgKzGP+CyKwzAX9e/tK6fHkh+7j/+XwUZ+M/Zv5AnBzfeOtM/8q7q
lqaV4j/vJLoLMEzCPwKd1vI/6Ow/dURAvTSd0T9FSDs4eMrlv9hE27G9H+k/
KPe5tw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.8023645037145133`, 
     2.8462118013761573`, -0.2737892939050491}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAS6N/2lFV378qkbYJBNbOP57/lwBA
wuC/tDTHZi0U3z9AqHYmG3POv8y0CWat6+A/bVdqRGmU1r9WGAIUsADUv7AH
tYaTUve/sSJi7PK107+EOLrAlL70PyOMIsNDBei/l5tFR0de+L9lfByJiG7B
P8E1CS/cUse/+MgAzd0P9z8Lp382WHHgv9MyFXbNtrI/uGxyO7jK5D9v4zfK
KNvgP5uk90fhr/Q/A6K5rNe+uD8zKKANfy3yv7ZCewGMT/A/XP10j9302r8I
P5s8uFaiv38HAYezs++//uJwY6KF2b+qCvFBVZnoP+BF3eHBY+S/NcLy3s0Z
8L/IhmlJRiLIPw5NWgz3lta/JZayJunU7j8bUR0AHw7YvyZbzBSHQtM/iQNr
d2cq4j++cjQBxHzCPwF//Pq3Je0/ms76qPGh0j87/W5y4vvlvxwdgLRixeg/
c4WySg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.7845630313499794`, 2.854689789140926, -0.3008005899487306}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAyOB9lzqx3786ELwZPK3NP+biDC9l
t+C/glA4Bqlx3z/n+hmOpk3Nv/zPJE/B3+A/JLBqXqCu2L+8ryhTR7/Wv3PY
G4R2Bve/VZg2chxy07+O4ZMEfG/0P/VMWgXmIOm/raJLfFtf+L/VFMtMAWfD
P3Xkl6KUTcS/gqoHoEBh9z9hcV0lbwHdv6lyI6bJwrI/p6Q2qJPT4z/rtJ6t
A+TgP5P4GawA5vQ/b/0IriRjwT9+I87yImryv+3r8lOB9O8/dkj0eu0v3L94
nioZpaKvv+ZJohspYu+/jjzahKuR2b+WY8uHIyXoP+6XM5ol7OS/cI0VEdUl
8L+IkkOzHorIPwPcslfKytW/or6V4ao97z9qNzU2IdTVv1E+6YMaONM/dGap
FTTG4T9jbDAUNCHDP5FgrFPhVe0/nWeerp0R1D/bYpHE1xPmv/Tdi1Ehaug/
Xou1Eg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.7435135179845498`, 
     2.876726345905426, -0.33016078413214167`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAmY23v9Iu4b95vFgRwWTNPwRgLyUD
vd6/3X3r0qQQ4T88GQArBzzNvz5r+D2ZCd8/Da8LKPM92L9sm5De0h3Lv0rO
ULFUgPe/tI33vTju379ukzxTRhP1P6SQ/5PWJOO/pQ1Jgn2F+L8Od7S6cdul
v1GPPPgQdb6/FL50xINY+D9DqHhzrDvGv9Xp3DZBL5M/KG2bfQfr4D9ksE4O
SGjYP7P4vvjbSPY/LW4okF9G1z86fv31Y1j0v/+XlNikoug/IGW9U8xN3b9w
CEGWcTeCP0umnHqVL++/OqpZj/eS4L/9qmd13r/oP1OgSxOsQeG/OWoScXOO
8L+2nqui5O23P+xBn7EjLdO/gT71Fmtw8D/AYDzP2bvJv+4cs6hGHtA/gnVD
KNb94D+MR53xiJSzP4ITPUhCC+4/9LT/mtSz3D9hgV3b5P/nv89myLu4E+Q/
ZmW3fQ==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.245328058769693, 3.1387849531603607`, 0.1469253002549984}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAegeWUkk24b/Vg028xvjMP5KnZatx
xN6//Aa0Ndwg4T9ApMvhSMzMvyq+ni2A/t4/InwaYkXB3b9eQOGSH9DUv0cR
CIf/w/a/1GmAzw3s2r8nn2XZYKX0P7y8/KUrrOa/j7YTrLaJ+L+B54A/PKuy
P3K5X83GK6y/+GLdy/1A+D/QGHq23jTMv6zyFVa5MFC/LbXx1qk44j9x8OzE
/l3bP2v+07kOyPU/w3DHEr2J1T8wjdoogPLzvxiCTpPaUeo/xqLRAXYL4L/M
+enS8E6pvyx74fEbde6/ZDxWOlCs3r+hT++weUToP0LI1z0yB+O/Jl2vqm2S
8L/L+wZuMifDP2DPiEL1JNG/O7Nb87Vo8D+I3iLMk4DMvzeoSHRP7s4/FN5S
BsOs4T+gPA6otO+5P/atO8Wuh+0/Xr8Xv7rl2z+4ARRFCYznv5bwDlWN6OQ/
Hdy/2Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.4227949974249705`, 
     3.0634569121063864`, -0.12363714235649467`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAdbknwWJN4b8MaJCY3vjLP8/z1EHk
yt6/23m1mINB4T+mtu3hPeDLv2rmPTsO694/3hl1TxqT379huYcvlpvXv1Yb
JZuIcva/X38PXh2A2r8WQDwTDF70P8YZuR/Y1ee/MlBZ1TyB+L9vFJINgGq3
P6G+sMvYHaK/zFEfWWBf+D8jCSS5DCfFv4tXR7P6tH8/MQ8k7ENx4T+dhrZP
QOPaP11cZw+i8vU/rJh769/P1z8q5En20AT0vya/WZwDqOk/MiNx9HeL4L+4
Cn/GTT6zv0pYmqtBJe6/JHkvcHGN3r8XTU7mJ93nP9fJUSClneO/dpb2GveT
8L8iuaxPD9fDP9KFpa1Ph9C/XQe9EhGA8D/k34hNpYPIv8gDCybiac8/hsRs
wmNZ4T+UVn+9Qua5P/jVNp5lre0/MUZzjnMp3T/+moey2IDnvy5Z/FzFjuQ/
oe6z+Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{1.390202550062198, 3.077125614920644, -0.15177226294620422`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmII6UuLflZMGj/Xpaky0W/zlgH74tsWyG6r39Nj9W
bAWK2/d23WMDiu/vnlxpDxS3j3p661u/2aP95qFlFyeufLRfqH5LssCxL/vn
VZxwd7d+sL8wrOfZc5dP9vHb5q/Mzn6zf9sib7/Uhh/7tXVletPLltpLmOyx
eCy5xp7r5PN4oLj9+YSzqUDx/TvYBHY/kVyz/+aN9G1A8+1nsbXITVr5yJ6r
Py4UaL69+OZCP6D59k+s/74Dmr8/iyvrCNB8+1t1d66uCX60P0x0MdulK2f2
r3jj01jm/2Z/jUdwHUfYw/3bds/zrUl5Yn/UI+OT9P6n+wvDY0VS73zYX2l6
S9o2apv9FX0v/phFp/ZPUYqTBYrbH3wU+MAmatv+LZPEV0QvOmXflcGxDWi+
/dvjM3YCzbd/89kmFWi+/apQ3iag+famvDf9gebvl8gSBplvDwCFobPC
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-0.8969838528865911, 2.680938979738597, 1.85267000693024}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAjAqZC5HY4b8ItJgJZJXDPwDBwScl
K9+/jgyzFIjm4T8FVVq4K7HDv+vftkWnBt8/P5SEgU7X4L9PSZ1hHxXhv8C7
hfKwaPW/FzNOLddi3r9Xl5GARNjyPxulICn1ieu/Ss5Qgcx8+L9QfJ9+762l
P8perWMVjVw/iTPTHQ6I+D+PB14aU+qgP2D+P0GN/5Y/kaWAYYuh3j9sxNBx
R8XePzXS5Ff69fU/q+yaD3qT4D9cFJWlTzDzv3rWTCVeu+k/Zs+Oxu9X4b+a
OG6+jF/IvwAsdjx6M+2/DBIgUf6E4L/YrcQB8UrlP87CgN7Dj+W/yKmOg4q0
8L8ck0Dp3wC5P6ETXhKYDs+/6FwWFKm98D9CpoXjLe2uv+hv5QxQO9A/q6+5
4qab4D/pmaOVsezEPzCKUimkt+0/nPwmEgE94T/8XqAcdablvzgjFORYn+Q/
/h2zxA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9664480244747824`, -0.9779941318188181, -2.5692430101427113`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA+qwIc8WF4b9ETdZrOa7HPylRj6EM
Mt+/sME/jc2i4T81EEU8+uTHvwAZVMrO5d4/zrP0JIir4b8DT3FKFNDfv/7x
iWJTfPW/ieTBmaOz2r9fg4fLf1fzP8QN9iWYLuu/bPwHKzRm+L9grN6+0UO9
PzFaMWpp+Ne+/IgIRICI+D8b0NmYWaWhPzcG6fTQ7as/vF96clwC3T8z9Bms
8AXZP00faULog/Y/tXyvVosi4D/ixQaNhv/zvxuZXAm8huc/ZLD+y6aY4b9g
KIaU9/jDv0jG7YrWSO2/Pp/pP5ff3r8HTQL5Rk3mPyzbXjvPY+W/dClGcouU
8L+60aIlESjDP1q7+JkkMs+/6jRUhfOs8D8unA7Wo3uzv+SceHTEMdE/x3g+
4/0R4D8y2O4b5ya6P40l/vRbPe4/Mp/3cazi4D/oZ4/UJfzmv85SQ7fRfOM/
7VW79A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9690884101162824`, -0.9284328550772332, -2.585556664774312}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkeNIktNi4b/d2ygyT3/IP5Oq1hBv
Wd+/3Np4LhuP4T8PORmuS9PIv7zPEQZc5d4/KfYAOHeN4r9ZrvLgpmngv/pr
Mm2IOPW/x8ome16f2L9K2qC5ETzzPxXmkxk1Cey/4uXgFWRN+L8o9WRWnb/E
P2MMLOnHmHc/CenAuhCF+D9IaY7NqkyvPxO686us3LM/AI6f4Ht42z+SY1o5
3rHWP9UzxpJbwvY/WtSjiUeF4D9nXacjjzv0v3YcH/nQhOY/3ewkZSX44b/D
7tAoppPEv54WaDHkDu2/9Ejcz4Ky3b/F9eWf+0vmP6+d/1D22uW/1auC72Z/
8L+C6EZEdp/GP2H6MfEL+86/PKv+KE+m8D++nrX6IACxvyBfh5hD7tE/3KHI
HllL3z8WjpvEcJC0P8SnSpSye+4/m1cOXDEK4T+JhGqZ+FXnvyoCFH6/++I/
hRu8Dw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9703328171418877`, -0.9343041568932107, -2.5824918842284443`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAt1uda7I34r+8vu6wJD2+P3w3WgC6
8t6/Z34e9ZRy4j8TQC3evxG/v05+BQeKWN4/XGMqc8Tw4r/aFkbKx/Dkv1S5
973UIPS/ltFbUcdl37+OVwiMdaTxP1ia16mXfu6/tQP2NSth+L92I4Jq/F+x
P/gwyZDsz6k/ZGUMnQVI+D/g8AMjM0nOP9IAww0Gl6c/5ibVGzNv2j+w2m1c
4bzbPyZRkGOndfY/TnuNIHdj5T8kvaJQJu3yv5kXCfyaC+c/it9jbzuU4r8D
Pyg0IynRvzNHDj6D3eu/QaIlCkv14L96QxfXR4jjPwtbAlX6++a/yFjiNYK+
8L8ZcbiNkM63P1wRQW68uMu/TNLNC6jA8D+uodpnpoCtPzTvXmS1pdA/2hEJ
gy6q3z+qiuJkcfjDP7qwUeXJC+4/2vzVCgbr4z8lkYVOQt7kv2Drxf/vG+M/
IJ6yyw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.978752901382878, 0.8930537541357196, 2.5906354331501253`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAzLdYMocl4r+++W1h6LW/P2gHJaGd
CN+/U4DaPrFs4j9uKP/qYFvAv1yh70IJTt4/+pYTAind478bAc1H1mPlv5yb
Gi4FzfO/oNe08WeS3b/zt1w6Nn/xP/s9PdC0Ve+/68pTPx9Q+L9kHiZMSKi9
P/kzaGVUNaw/UbaDz/wz+D+qSRUDnwbRP0sGqaMqfLE/HAjYm8M72T+OMS5g
zRPZP/cW2rCEuPY/QAdu6pX55T/ktC33XB7zv6dprikl6eU/Yyc2GlgB47/k
QZ87GW3Rv3bdY5Ysj+u/zpGZlV134L+Pl3PAlHrjP9jgZ9ABbee/aBNAbHGx
8L8RDMpWGK++P+gAeBTzgcu/PXt4tyq18D/maisb3bGxP3jx7PWJVtE/YYTG
DJMK3z9Wna7qHObAP07/lQEHTO4/ykOklCMz5D/ymY0UySnlvyodk+UUiOI/
YuWvSw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.977315781861854, 0.8920812559872141, 2.5920673856048415`}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAKQGnIEw24r9hGjqk+oy9P/0kN8OY
Bt+/rSx5pluG4j8rv2noOK6+v7wnQc+tNN4/GXp9Yjqr5L9Yren6FI7mv8fR
qzLiRvO/NYhP7OkI3b/PK8objgTxP/wwP7h9RfC/S0oL10FC+L/ZZTpt5nLC
P/4M/IZzbrA/MEwUxZ0K+D932uHTXlnUP6sPK0S36bQ/SgChGNwY2D800J/s
E7fXP3TqWOzd4PY/wja+1HlC5z91VEcS6f3yvwtfW+jzFOU/oT2SQcNw478M
amKmddzSvwabeWOICOu/omJni2Bd4L91zQ3GXd3iPzz6DOkjB+i/cGWv87Ou
8L+FuavfsZzAP74heOH76sq/Q3EozOWm8D9Z1Y4zoVu5P9T1JdCNt9E/0qzJ
ssmS3j9qYIWyhQvAP2M0KWAJbu4/uLGbvWrk5D9n8M2gzOjkv3T5/WelF+I/
yVe5hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9770970439290763`, 0.8928765902800303, 
     2.5919603919459906`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA08w+9M084r8Temr245+8P0dYluyN
CN+/HzC7bPiQ4j9ioehof8+9v9tPkb/+K94/WnxC3QWC5b+NmTS9rGfnv7Pm
xLOAy/K/7HKIBYn9279dMVsZspnwP/QdDMw70/C/SQzQNdUw+L93Y4/epUjH
P+2T3xTkr7E/Ay7EEore9z/tsSQnlifXP0GGMQFDxLk/w2+qAwDt1j8940lT
6qbVPxMKOVTAFPc/EX8aFrZa6D8v1nO4lu/yvzlqkdW6E+Q/lqTA6Gnf479K
Smc+sNPTv8R86i6kjeq/JIOBO8kd4L/+2MFYsGPiPwa0MUdflei/Wbn3F56n
8L9AUOLsS8zCP0xzXueUnMq/CeOQJIOT8D8qE9WZbGe/P7bY7r+HTtI/AGiQ
bngH3j/KdR/yFGa8PwpeHQTAn+4/mNdqQdd15T9FYAKvjszkvxMJrRrdlOE/
PVC2Hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9779606819850422`, 0.8918818119571635, 
     2.5916439520160313`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQWfGy0Q44r+lZQx8CFy9PwxcbY2G
C9+/5KR+U0eK4j/DKR9GeYO+v1MezWmYNN4/DscPLA9z5r+N1yckl9vnvw/e
klF2X/K/MBfy0lpP2r/UKHqgfUXwP3hqWkXoUPG/VX/5FmgX+L9keVIK0L/N
P6K8Rg9LBLI/36tjGNm09z9hY1VodDvZP2SGdIdxI8A/AKsYbDK61T9B96Se
orzSP3zPURomU/c/HZA9v74w6T8LOjufOvvyv0gr4hGC3OI/KBfr+6lV5L/Z
SqYUFjDUvxI17vRXIuq/2XI/NfJf378u7zooPhviP3vBtejJE+m/e1luPsWZ
8L8bViwk6jbGP+Ssm8lzisq/KH8RYf588D/wmM0WlprBP8Kww5YoI9M/ZPqK
iWBn3T+hWTqaiDe2PxAXxTRM4O4/gBpeCYPd5T+nLJ0zcuPkvzldZCNn++A/
Qc+pJA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.9780309537088736`, 0.8908182918033151, 2.591956079326613}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQgQFdyI84r89W6aDWC6+P2MdpD/F
+N6/wbrEwuCE4j/O9sbr7yi/v7GTICRTOt4/u46t81E9579DgSIy8Bvov/tU
E0AOCfK/PvUtygj82L+tISAR7/3vP+G5EHOVr/G/9aWXBBUA+L/wM9e3/J7R
P8GAZN5YZrI/Bmt8Mtx49z+uDhTyoM3bP0Fkiq7VKcQ/w0RJXHFh1D/jKlJc
WuLNP/UNCzrkmPc/EVZk7VBQ6j+UIW+JyPjyv6WrJUN3R+E/fklZNbq85L/c
ta0hJVbUv1Rc/I8/x+m/4f4b3Ca63r+KdsoQ3eHhPzrB+cLGbem/CxQNIBOP
8L/AysDYkirJPzL9CggvX8q/M2TvSaZd8D/7UCL3ZAPEP+nisv2eJ9Q/Il3p
cJm13D/4Xt3MxJusP+IyEwN5J+8/aYgU2Jhq5j8BkSuIV+vkv7/6mmpQMuA/
PBq1Cw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9851613028017856`, -0.8548328303463973, -2.598614137193186}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAkfeIFqxc4r+bGhK/b/G7P9ALzXe1
z96/2/c4otmT4j9/ix/FmbC8v8swricZP94/Vk6HrQsb6L9mXZiAvh3pv1L7
UxrjYfG/czzSdHpI2L81OCpvZJjuP6AREKoJVfK/ZIhIunLp979XtT6dPi7U
PxNKFH677bI/eOFFFZwu9z8+XF8mIPTePyOJ24hrY8Y/iwZ0o+WA0z8KqHvx
55bJP4wew0sKw/c/82bZvlW96z/jVGzg1Kzyv9Ts+JGAOeA/9CII4ts75b8S
GraIkJ/Vv0Y+R3jQFem/yhXyUOmA3r/EPYYzSQvhP5RUAwj3COq/FoLGYuSL
8L/+OwONmirLP0z5R5hGFMq/sy4xc0Q88D9eeRe1+cfHP676DXZnuNQ/IPvy
c0xU3D+WxNcdNn2mP76qrpXQUu8/Zy+JsJco5z+bTb583nfkvzoF0CUNWd8/
C/uxkw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{
     1.9831952277478089`, -0.8588529176922721, -2.598789786498667}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAABDvAp0JW4r9F/9JFff26P55E4c0C
7t6/W/Qw6hh14j8Pz3Kb0167v0Sff57mnt4/dRkmk/xa6L+xNd7gQJfpv5HT
Vgf2GfG/uzvO1L4U1780BTgS07ftP73ABSfMv/K/bLSYytTd9793R9BEWBTW
P/2OYIORhK8/aPlj7hnA9j+gc/+STT/hP6xXVahrUcw/nAnFDdx40T+u+sMN
E2TBP2+cMbaiBvg/mUnyVo1F7T/gASzKclvyvxKutqBRgt0/PCpznZ9Y5b/J
1SM4kTfWv7gkz7p21ei/4lgnEqLg3b+OMnldwYvgP+QRftpMe+q/92g8D3uE
8L9IB0WWt9PMP74ydZ1w/cq/lnN8Y6b67z98MyI/5qbLP40lVTnOY9Y/KXkT
8YYx2z84mVQASqWNP0CE0V1cru8/+p6RIFPd5z/RLuMDYBHkv6smmx+cEN4/
kXC05g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-2.0195637418032493`, 0.7968861559336123, 
     2.5905085885352714`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA7JcadUdq4r8AF9EVVL+6P8+ffnIx
wt6/hPSRdEdq4j9FD64rU7+6v+G2u1Ixwt4/Kq02LwJW6b8zBtr8sRTqv1p6
HZOph/C/XwlrcsCp1b/MSBytb3bsP80ojUXwSPO/Z2tkcPm097/vFNHIDpbZ
P83U/V2iPK0/gX7fAddx9j9PTDH5lljiP30rPNVB3M8/fQkrpjad0D968nkc
dmm1P+bU/ZNdLvg/HgQ43Yti7j9hqMRRRRnyv6I2WJE789o/i6Io0iTg5b9T
4x96x7zWv04ive81OOi/nBxQric/3b+sa9YvWs7fP8DQLKJ8+eq/rtt4lQ51
8L9YrSLn8SLQPzblviadGsu/w3govPqm7z/OFHcnWQHOP1DmrB4pWNc/Qnmn
x+K42j8oc9A8dFeFv57CrOjp3u8/UfzkqGlm6D9WiX+EOsXjv8L2CXK22tw/
Ic62cg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{-1.6069546013452312`, 1.8516290067288985`, 2.32670731521082}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA4djBez2B4r9hhhAZafe5P19jw54q
ld6/MVoWnWhg4j+1yw7dOo+5v+ep9YNi6d4//cUroqlE6r8H9Y2YNqDqv3ox
uLKm1e+/77kwANl11L+SQZwWkwjrP2ayI4El0fO/QZdHYUKI97+fI2C1L93c
P9/TuGVRZ6k/D0WA4GQZ9j85cvjWlIPjP6098NDGrNE/MtXKPTa/zz/llcYO
KWehPyR9vpt0TPg/dGpaXViO7z+8hH6eAL/xv9p+a60nkNg/b8/2jvNi5r87
5Gt1SWHXv5TxDAEekOe/2DXa+ym83L9eUr45gEfePz6L1Chwduu/2UGUj3Bk
8L+cItL9hK3RP+RIDHJAaMu/KHILL5lJ7z/DmFZ7rVHQP8rzcqoUS9g/fg+J
LDZQ2j/CgKtVptugv8/zXZ5mA/A/UmI4fWD36D94cU9M9Ffjv2CUsBjFvNs/
CPa2yA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8578347510111645, 3.25193264328275, -0.3368287747649862}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAANB4Z+p+S4r+nlZQhSL+5PxOdiDmA
bN6/cejIfQhT4j+7mb50gvW4v/GPHByMD98/hneafQY567/qdj/Hxvzqv87u
p8fvq+6/HqEK2SU707/k7Hdg86zpPzYwhpGCSPS/Ikb9VIxR978lCyOEzRTg
P/F/hIsIh6Q/tSp0B6LA9T/O0vHVkIfkP1XKlbWqmNM/DdbrG6drzj+6oEBR
NDaTvzhbOaGrYPg/WQxr0o1O8D8505vdCGbxv3nJKDyjKtY/3crZO9Pl5r81
5AzD3cTXv6weNvIX8ea/w26e5jIw3L+Zf6pk3OTcP3pX6J+i4+u/nuoEKW5N
8L/anVWItkzTPxQNGCif28u/7p5YRibq7j+W/1mH4GjRPyMt2WgbVNk/9N3D
RPLt2T/qwQ6JD8Otv5o/IFRHEvA/koBPERJ46T/VvOcEYfXiv7WsIqwXndo/
6ey5rA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8563633964399463, 3.252180336897317, -0.3381786355408894}], 
   ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA6fyktVGh4r82+jCAhq+5P3VE6b0x
R96/7LXo0KdI4j+x1cJA8JS4vwR8tQK1Kt8/gfGkFfk07L/NVZzKlkLrvw92
J2Sgfe2/282N1DQh0r/slriK1FHoPy74p6LUtfS/C5aA5j8S978W4sxxtqvh
Pzz//TaxNp4/tmPJAqZo9T/Uk7VreXDlP3BvX5iBfdU/kxHUH09tzT9iFAja
E8Cxv/64pHDCaPg/tyw4pw7L8D9xiJLPXgvxv/JGADUZ69M/NfekZSVr57+G
Npb6pQzYvyUMjqGcUOa/1uPrH+yx278ytr5axYfbP0xJIhKhR+y/QIqpYHQx
8L9cAdNBp+HUP4JkearGY8y/rL496/mM7j8eOZ1j213SP7p1ik0bVNo/Ubrd
mPuj2T8KdWUNgiq1vwAMqdi3GfA/rYesj2Lv6T/MtZ7TrZTiv3vh2hvnitk/
WMu8sw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8573893152780458, 
     3.2515740099543757`, -0.34139422935407027`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAQxD4ITCv4r/TOs6YPFi5P0Cg+1bZ
Jt6/55waO0VF4j91o1VhHAe4v40PGH/vNt8/XSGcmiEh7b/28Viq9IXrvw9D
enlMTuy/SVF47whT0b8uVshwv/nmP8+Jra95GPW/dbm5EuXS9r+AvJyYOAnj
P1sPuTGXCJM/W8x1A8cJ9T/q04VzRl/mPxSbSBVRWtc/pclNX/nJzD8CD42K
oue9vwn43MteZfg/h38cVSdK8T/MfoSevKTwv9IW9mYTztE/0BhK3ijo57+b
Kj8X7VrYv5gJfJLcsOW/6Di0mbRY27+JHeIDxyTaP99xbAUwouy/y+DakT4V
8L/ag7YrQDTWP0oP4ONP9sy/zhoDoWks7j98H1vnYl7TP1BVMEqgSNs/UA/u
ksN32T88WfF1X/e6v/Z90VWNGfA/+s2p8sls6j8D2ZlkLiXivzATB3OBgtg/
MAaxKg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8506908284373658, 
     3.2529201527482576`, -0.34530507418338874`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA5ltyqhqs4r+nzDYXZz+6P84LlNEG
H96/QPY5GYQ54j+5bXNeU9K4vyyo5e55Rd8/fHOWTWQg7r/DdI4xJnfrv4pn
BJR7Seu/hdY9BJs/0L9Xp24iDt3lP3UDX5QUa/W/cT8i4AmC9r+4dfft4oXk
P/iJZ57DwXk/jmAcql229D8DLblqSvfmP1awGQCyitk/fM8ZqnDdyz/9YZP/
ynrFvwH5SsrGV/g/8fNgRmKp8T9NAM9aAlnwvyzmZ3MDkM8/sWcEfD9m6L8u
m6dOOS/Yv7g2Z35/LOW/KEeRLOjL2r/sgFUF+yTZP2gGxEjW8uy/ZG1bNRfY
779NT97Qz83XP6ZtGsP/t82/rlu5th/T7T9Mv+r+/9zTP0Gsf/cVaNw/H2rA
Q+Aw2T9tjGZX+vHAv4YxAqOSFPA/Ee/9UiTG6j8pN7aQJ+bhv6HNTNS9htc/
6Eu0/A==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8620063386076958, 
     3.2508408174898213`, -0.3367180594240052}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAifVlLxSs4r/NaTZMaue5P/Owh0WL
IN6/MEPY7Rw54j9HO3scJ3m4v+VDprmfR98/1Cn5Ks/87r/lYk/3XZvrv8od
VQMmJuq/EVSsLKg1z79A8YdYs5TkPwknjnTzwPW/JxNCkA879r8HeJceParl
P+Ax+kcAuH+/Z9EOMSBU9D8SGaGWk8HnP4lhGiKgets/kFVvaZleyz9FBufL
dLzKvzqxd11OQ/g/b7wFY7QZ8j+iW0j+0OPvv+vXVcYWQMw/ro8vrXHU6L+s
lcitcF7YvyJ7DNM1m+S/jQqROn552r95vg6ioNHXP0YT8EUWSe2/7A31pxmR
779ARR5oKufYP7qZp0Zrn86///L6p65w7T+psRGzbrLUP7dS4O0fYd0/lBg0
SMMQ2T/0URIthHzDvxqh8CWbCvA/B97x2UI26z+F4evwennhv+2XaI7Vs9Y/
tZyy8g==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8561107099923615, 3.2518503448217984`, -0.341970447727183}],
    ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAn1o8kVKt4r+uvUa8Nhi6P5i4kj2H
F96/+mxsLg5C4j+dxmrS0ry4v6lPS8Y3LN8/s4Jylbn/77/HQ3eusZHrv52J
rOiL8Oi/BTVyBGw3zr+/UoVeyFfjPx1gvCerD/a/EWN8wy3m9b/M3oFeg+Pm
P795txxhDZS/hpPhCncB9D9Vku+UVVPoPwtdDVwcNt0/aVyTD6tUyz9YKYIR
qbLPv+mz2umqJvg/vU9/yI128j+tDDSRsTvvvwRZShZD9sg/qW5XE4ZW6b8S
bO7Wqk7Yv/TyusMn/uO/4OdYki072r90Kg42z5rWP0MOIfeMle2/YJAaDNc8
77+Ctgo2iibaPzQwXk9dWM+/A8oXIn4i7T+COaI6uzvVP1pWLBEqMd4/FERR
8jgX2T9Uxls9iQjGv9SHbdu48e8/Ooa135SX6z/AssD1pSnhvxY+uKis09U/
j4Ovkg==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8627315647954185, 
     3.249147591359287, -0.35090479715984535`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAAl/mIGPyo4r9UaRSR7o+5P1a3EnmE
Jt6/WXZAr2NL4j+EiPKc4WC4vxTSdXPdF98/iJvp1Wpo8L8dvNBQyJ3rv9+A
K0GvzOe/7CmTa6SEzb/QliiaIRviPzihKgAdWva/8alwcCmd9b+F0VuIMNHn
PyZEBhq6d6G/drfRIeKb8z+n9DzRcwbpPx6i5hMsF98/EK8nQTw+yz8/A0BU
6SfSv1qARjK6Bfg/DKyhU0vh8j90cy5M6mbuv8HrPAi3IsY/VBgu4ui86b/z
Lq5+ymvYv0Vu2r74b+O/EsRtMyUK2r/6I0tsH03VPw5Pbx6+4+2/vCa1fKfx
7r+vXn5aLgPbP+6/Kd69KtC/ovJx+ZPB7D+Xo56dV/rVPxk6rsOEF98/HWKK
v/Ia2T9gpXy7IUDIv9/0I4+xy+8/OOdBK/0G7D9CYuY/g7ngv/ojynucFNU/
oc6z/Q==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8543751323953123, 
     3.2506085930163584`, -0.35775257951928957`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAA/VAPTpKd4r8TasXr9KC5P03Tg0wq
P96/9FrM2NhS4j+y46OuLK+4vxnz6fHZ/94/LAVxOqbV8L9bOm8oz3jrvx4R
l4zCwOa/2DqQPPCxzL+7pfzG1QHhP4Vcf928m/a/ffGOwctK9b9AJNyytcno
P7iBslrDzKi/ld9wAZ078z/2i3hGL4jpP0CiSqmUkeA/fcfcAy0Pyz9o2BuI
H5rUvyRfDh7E3fc/qW1uEYo+8z9j+FGQFKztv6zRGT9OXsM/qq14YW8k6r8Y
jfaKsETYv2J9bNkr8OK/s18zXQ7K2b/9UnVk9DXUP1hRoHCHK+6//JmW6JSZ
7r+D0VRQ1P3bP8IR7VthrNC/Dw3XbQll7D+AD6SwSXLWP+bNH9HACOA/04zD
GaQW2T9U0cSz6sXKv+rbiJq6ne8/I5vUffZn7D9tOhMT/WDgv/htu4iAV9Q/
Zna/GA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8545639675230023, 
     3.2506529836807347`, -0.35689719121741786`}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAALCahbC904r9FRkUOwgW5P8vCgn37
qd6/2b+7WZY/4j98o2wibV+4v9AtIv4iL98/WnyvMZkb8b9W/sj4rGrrv9lY
N/1U/uW/m25SLnzSyr/35Vke6MffP6Tim5H+4Pa/3q5fiBMC9b/sCZOqt4bp
P1bZrxn98LK/JvouxZK58j/I83YNZiPqP9Vj6CRV5uE/eDbTGVKjyT8yuMmV
GufWv69MYdgIuPc/cjgKtkuk8z+8wt3VocTsvyRmKeHbFcI/cA8A6LBV6r+O
VQC39EnYvx9d/F2pqeK/08E1eM4o2b/Em/VQrATTP1aT/HB9i+6/9EGwPis8
7r+0slvsb6fcP5Bc92Eds9G/EtoM8l3Z6z9ZXylpeBfXP169/FHzvuA/d40w
4Gqo2D8R4WTe9f7MvyPY6ZfRg+8/Xhjo4hbE7D8rVyt6j9Dfv3FwW3cIHdQ/
0N2+Hw==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8441854156182759, 
     3.2541894864267378`, -0.3492875183671529}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAAA4AAAADAAAARnOd5vV44r832CvwHVm5P9yG+B7w
mN6/mYZoGCFe4j+OUR17Ewa5v7BzQ+SE3d4/nyvfrw+J8b9EKeVbIiHrv5CE
8ycZ++S/D8OZh4E7y7+s4e/OWCHeP++8OaeODPe/ix4moie29L/KneDl+k7q
Pw1jQ1psNbS/apzCawpX8j/ZGVOOwoHqPzXbTRSY7OI/pgxPmu2kyj/oJ4pd
YrjZv9S8vOIOevc/VugtwGkI9D841HxUd+7rvw+iFH8cv7w/QuUto4rF6r89
rt+d/vXXv//jt5vII+K/CuSDSNZH2b/da30l0DvSP6be967Ksu6/Lth0laLy
7b/RGOajHnrdP9CvxJol09G/tt/29xqG6z+ob+8eAGHXP4bKN0OtLeE/wkn8
flwH2T9LfFE85/nPv8CZzRtwMe8/oitiTHo37T9qfuDDOQ/fvxpOBAKmBtM/
mSG6hA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{0.8352358537043255, 
     3.2582084115098247`, -0.3329549757150812}], ",", 
   Graphics3DBox[
    {EdgeForm[None], Specularity[
      GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgA2JmIGZjtOF/nfVo/9/F+cVTA3baz+JTW7531739WRUl
TEBx+6/GwflA8f0dJw9NAorbF8+/XT3j08f9TJZlgpWXXu2PLqt+xP718X7+
kM9SDTdO7a/VWKW54cdte+8g29/tLt/3t0pLeSXEfdmfkdJS9UT9tb2LnOfp
WK8d+5la38cBzbHfo3PMCGiO/cVnyquB5tgnci+qBppj/+yHMxfQnP3t8/f8
A5pjf3NCdRjQHHuDaU8SgObsd2ic+wVojv23+ZXMfBqv9ze7cCSnrbi+/4od
e7Txyof7ua79EOVWvLl/H4fz4Sy1i/afrrKlmn9+t59DZsfFq5Pf7n8e8Unj
e+A9ezHtPz2r0i7tNz+o+YBX47W93bHbLUBz7E8tdbICmmPv9DtGEWiO/ack
ns1Ac/a/DMxNBppjz3d263WgOfbr/pzjA5qz/43I13agOfYAm7a2CA==
      "], {{
        {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2}, 0.34]}, 
        {RGBColor[0.65, 0.7, 0.7], SphereBox[{3, 4, 5, 6, 7, 8}, 0.24]}}, {
        {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 3}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 10}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{10, 4}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 11}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{11, 5}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 12}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{12, 6}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 13}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{13, 7}, 0.15]}}, {
         {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 14}, 0.15]}, 
         {RGBColor[0.65, 0.7, 0.7], CylinderBox[{14, 8}, 0.15]}}}, 
       {Opacity[0.7]}}]},
    Boxed->False,
    Lighting->"Neutral",
    Method->{
     "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
      "DefaultGraphicsInteraction" -> {
       "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
        "Effects" -> {
         "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
          "Droplines" -> {
           "freeformCursorMode" -> True, 
            "placement" -> {"x" -> "All", "y" -> "None"}}}}, 
      "DefaultPlotStyle" -> Automatic},
    ViewPoint->{2.018782305109029, 1.7668172111438032`, -2.05603379033145}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.919851379301186*^9},
 CellLabel->
  "Out[1512]=",ExpressionUUID->"dfc42955-626d-4cb1-b3f7-dc5692a1588c"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculeValue", "[", 
  RowBox[{"molecule", ",", "\"\<MetaInformation\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.919853535243842*^9, 3.919853549988922*^9}},
 CellLabel->
  "In[1537]:=",ExpressionUUID->"16fff5fb-e1cf-48c6-9013-61a5b180317f"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{3.919853550582275*^9},
 CellLabel->
  "Out[1537]=",ExpressionUUID->"b275f093-33b7-4c36-8d32-e532eeb26a8d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cyclobutanone", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 
  3.919856227119166*^9}},ExpressionUUID->"288da12a-b000-4974-9ccc-\
651e94d37ae3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<Cyclobutanone\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}},
 CellLabel->
  "In[1538]:=",ExpressionUUID->"3ce79f01-3c0a-419c-b321-5958bf54e353"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{{1.1879997332825714`, -0.05999999999999995}, {
                   0.7768425791159047, -0.06}}, {{1.1879997332825714`, 
                   0.060000000000000046`}, {0.7768425791159047, 0.06}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{0.7768425791159047, -0.06}, {
                   0.36568542494923806`, -0.06000000000000004}}, {{
                   0.7768425791159047, 0.06}, {0.36568542494923806`, 
                   0.059999999999999956`}}}], 
                  
                  LineBox[{{
                   0.36568542494923806`, -4.4408920985006264`*^-17}, \
{-0.3414213562373096, -0.7071067811865476}}], 
                  
                  LineBox[{{-0.3414213562373096, -0.7071067811865476}, \
{-1.048528137423857, 4.2186684638543077`*^-17}}], 
                  
                  LineBox[{{-1.048528137423857, 
                   4.2186684638543077`*^-17}, {-0.34142135623730946`, 
                   0.7071067811865476}}], 
                  
                  LineBox[{{-0.34142135623730946`, 0.7071067811865476}, {
                   0.36568542494923806`, -4.4408920985006264`*^-17}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQfeJRiKm96Rd7h70RrOFp6fth/CuzjLxWnVxgr7m9
u7oo5ot9y4k/26yE19v76aUcuLHqi/2SOpbXqpu32Jc++Wlo//OLvcmviwWn
7uy0vzH7ZExR3Fd7hh07Ns8p3GNfMXlCbtEtBP/3ohOTlmp/g/P3L+y7eaPk
m/2Ni97zDax32+8OMUji3vbNfgJrUVnEuR32hxodv9t9/2ZfMeu+85zEbfZr
bOQ3fNT4bv+EX8fk7/9N9j2/dX1Uvb/bs/TZVusFr7XP2WXzIiL3u73DH6W+
pGVL7G9Lumwrqvtub7GARVlmwVQ4nyFpzsxiZov9MH6Ak92Lm2um7V92I9+i
KOe7/ZJu9anMAUv3+53R/lPk8d0+L+JL4gWZdfufeDYzFKl8t583KWH6uZLN
+1++EbUu/vjNXvWTystZJ7fttzgppVu8/pv9GyvpT+d5du5vWKmVU5T7zX7q
ZFt9poDd+3PPxRvbq32z/7Ed7P/9362Pnr9x8yucL+V8hJWnHcFfzRcuyWP7
1f6rpV3UHMPd+5fHH7h74/cX+7e2nstnb9yxf8kGzUVLd32xf+oY8mWW4bb9
35ojPOw7v9jfYnBbxXRi0/45s/oXL03/Yh8lOvXX/Jdr9jttPPaP2+2L/QGP
bxymzkvg8f1jwZ7+xZbT9qOnBwBBhx/N
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQHdoz0dx+7Rf7hsv3LcQYs/fD+B5TTzazP5i7P3Ft
hen+k1/s3WZeucCWsHJ/5Xs3w/1MX+1FvtyTYGrYsH+ioajufuuv9m2zg08y
BGzZ/yxcxdu++au93/PydkaLbftLn/w0tL+J4MdFzdh7w+AbnG96o6jyU8U3
+/brjxxMvbfs/5Q4ZVP3xm/2P7bv2DyncMP+LZkGrqqvvtnPCCjdymSwcv+8
FQbviti+2x8onLIyv20OnM8QkKEw7awOnF/gIXp09ZqJ9nHPs5Ijfn2zF5h9
e7rbsgX2H28586o++mY/xy6xzCZ4uX3rOZntH09+sz8hH5Hx6/9a+/WSSyR6
ln2zd5D79S5s2kb7GLfSok/l3+ynaD9KPJ6z2Z6r2O1MhOc3+xcWp66YO2+1
f7VPnY9H9Jv9nz4p4SS9bfa/XkVz89z+CueX6PSuWtqB4C+I9dTa7/jVvoMx
rnJx5hb75j9cTyLYvtoXtc7153qwwT4lhr/w06kv9nuEdnk/WrPKHhYfGaXO
Dqt3zrVHjy8AuYLhqw==
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{0.36568542494923806`, -4.4408920985006264`*^-17}, 
                   0.2]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.3414213562373096, -0.7071067811865476}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-1.048528137423857, 4.2186684638543077`*^-17}, 
                   0.2]}, "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.34142135623730946`, 0.7071067811865476}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "4"], 
                    SubscriptBox["\"H\"", "6"], "\"O\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["11", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["11", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{{1.1879997332825714`, -0.05999999999999995}, {
                   0.7768425791159047, -0.06}}, {{1.1879997332825714`, 
                   0.060000000000000046`}, {0.7768425791159047, 0.06}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{0.7768425791159047, -0.06}, {
                   0.36568542494923806`, -0.06000000000000004}}, {{
                   0.7768425791159047, 0.06}, {0.36568542494923806`, 
                   0.059999999999999956`}}}], 
                  
                  LineBox[{{
                   0.36568542494923806`, -4.4408920985006264`*^-17}, \
{-0.3414213562373096, -0.7071067811865476}}], 
                  
                  LineBox[{{-0.3414213562373096, -0.7071067811865476}, \
{-1.048528137423857, 4.2186684638543077`*^-17}}], 
                  
                  LineBox[{{-1.048528137423857, 
                   4.2186684638543077`*^-17}, {-0.34142135623730946`, 
                   0.7071067811865476}}], 
                  
                  LineBox[{{-0.34142135623730946`, 0.7071067811865476}, {
                   0.36568542494923806`, -4.4408920985006264`*^-17}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQfeJRiKm96Rd7h70RrOFp6fth/CuzjLxWnVxgr7m9
u7oo5ot9y4k/26yE19v76aUcuLHqi/2SOpbXqpu32Jc++Wlo//OLvcmviwWn
7uy0vzH7ZExR3Fd7hh07Ns8p3GNfMXlCbtEtBP/3ohOTlmp/g/P3L+y7eaPk
m/2Ni97zDax32+8OMUji3vbNfgJrUVnEuR32hxodv9t9/2ZfMeu+85zEbfZr
bOQ3fNT4bv+EX8fk7/9N9j2/dX1Uvb/bs/TZVusFr7XP2WXzIiL3u73DH6W+
pGVL7G9Lumwrqvtub7GARVlmwVQ4nyFpzsxiZov9MH6Ak92Lm2um7V92I9+i
KOe7/ZJu9anMAUv3+53R/lPk8d0+L+JL4gWZdfufeDYzFKl8t583KWH6uZLN
+1++EbUu/vjNXvWTystZJ7fttzgppVu8/pv9GyvpT+d5du5vWKmVU5T7zX7q
ZFt9poDd+3PPxRvbq32z/7Ed7P/9362Pnr9x8yucL+V8hJWnHcFfzRcuyWP7
1f6rpV3UHMPd+5fHH7h74/cX+7e2nstnb9yxf8kGzUVLd32xf+oY8mWW4bb9
35ojPOw7v9jfYnBbxXRi0/45s/oXL03/Yh8lOvXX/Jdr9jttPPaP2+2L/QGP
bxymzkvg8f1jwZ7+xZbT9qOnBwBBhx/N
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQHdoz0dx+7Rf7hsv3LcQYs/fD+B5TTzazP5i7P3Ft
hen+k1/s3WZeucCWsHJ/5Xs3w/1MX+1FvtyTYGrYsH+ioajufuuv9m2zg08y
BGzZ/yxcxdu++au93/PydkaLbftLn/w0tL+J4MdFzdh7w+AbnG96o6jyU8U3
+/brjxxMvbfs/5Q4ZVP3xm/2P7bv2DyncMP+LZkGrqqvvtnPCCjdymSwcv+8
FQbviti+2x8onLIyv20OnM8QkKEw7awOnF/gIXp09ZqJ9nHPs5Ijfn2zF5h9
e7rbsgX2H28586o++mY/xy6xzCZ4uX3rOZntH09+sz8hH5Hx6/9a+/WSSyR6
ln2zd5D79S5s2kb7GLfSok/l3+ynaD9KPJ6z2Z6r2O1MhOc3+xcWp66YO2+1
f7VPnY9H9Jv9nz4p4SS9bfa/XkVz89z+CueX6PSuWtqB4C+I9dTa7/jVvoMx
rnJx5hb75j9cTyLYvtoXtc7153qwwT4lhr/w06kv9nuEdnk/WrPKHhYfGaXO
Dqt3zrVHjy8AuYLhqw==
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{0.36568542494923806`, -4.4408920985006264`*^-17}, 
                   0.2]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.3414213562373096, -0.7071067811865476}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-1.048528137423857, 4.2186684638543077`*^-17}, 
                   0.2]}, "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.34142135623730946`, 0.7071067811865476}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "4"], 
                    SubscriptBox["\"H\"", "6"], "\"O\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["11", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["11", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"O=C1C([H])([H])C([H])([H])C1([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"SHQSVMDWKBRBGB-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"O", "C", "C", "C", "C", "H", "H", "H", "H", "H", "H"}, {
    Bond[{1, 2}, "Double"], 
    Bond[{2, 3}, "Single"], 
    Bond[{3, 4}, "Single"], 
    Bond[{4, 5}, "Single"], 
    Bond[{5, 2}, "Single"], 
    Bond[{3, 6}, "Single"], 
    Bond[{3, 7}, "Single"], 
    Bond[{4, 8}, "Single"], 
    Bond[{4, 9}, "Single"], 
    Bond[{5, 10}, "Single"], 
    Bond[{5, 11}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9},
 CellLabel->
  "Out[1538]=",ExpressionUUID->"cbfe5e2a-4df6-4332-8cf5-6f83201f9601"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1539]:=",ExpressionUUID->"5905d160-374c-4b79-86d3-41d3d63bc566"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGAQB2JmIN6mFrn66fk/+xkY/B+7NBTbHVvsnap/fcv++e9v
CN/6/wgoviKlI6nA7oB/lKDD8dn2am3Zuwxa79lPVIr5aL3+o73bTI3Divv2
2lsKmnRNi/5hz8BgUXZ/f8W+ItfTr/s2HN0fmvb7pT5QvdD6e9+A6vf7/N/x
B6R+Xf6d/VLJD+3P12iavHrxw94ztmqax8GP9tMWv7p9IfGm/QR/XoMk4X/2
l7jeCtUeebLfi/1UXYM4swMDw5GT8y3q7WZt/CGnyfvA/pHwMqF6rX9Ae4+U
v22dvO+ZTFn9EafP+0/psKiCzJcJf9gJNH//xH0iVSDzWXbkfToDNP/PwhXW
QPP3L3v/9lkN0Px+j02PJqt/3m9Q0H835/VBe5Xb4vGxO+bs/x46+ZKdxuf9
H1gr92W/PrjfJGWPisLdWfuZFmQYTwCGm1YS2yuQ+iVC03mmC23db/7ou7I+
MNxM6yQugsTdp+iULLw5yz5rraey9YU/+78JM20CmfPChGHf8dlb9rP/3cnc
yvB4/+vv70+BxC25O9bd2zLHPkGys+9m0AP7DecPCQn7fLW/+2zNJq25j+3v
iWifbvh8215g5xYB/4ff7Vd9b7+1g+fi/mf8Tw57u/4HhoOBH+NjT7uqA9wn
uJyO2vcJ5Z7jcv4NFA8Kfbq1c9+U1vcx13483f/rPQMvyHxx5gQHoPn72/we
zASZr8NvmlcHNL99hbMk0Pz9e8+HLQeZDwAH8iLL
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{2, 3, 4, 5}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{6, 7, 8, 9, 10, 11}, 0.24]}, 
      {RGBColor[0.800498, 0.201504, 0.192061], 
       SphereBox[{1}, 0.31000000000000005`]}}, {{
       {RGBColor[0.800498, 0.201504, 0.192061], 
        CylinderBox[{14, 12}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{12, 15}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], 
        CylinderBox[{16, 13}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{13, 17}, 0.08]}}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 5}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 2}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 18}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{18, 6}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 19}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{19, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 20}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 8}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 21}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 9}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 22}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 10}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 23}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 11}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{-2.184208759182957, 1.827184408075144, 1.8207221740824548`},
  ViewVertical->{-0.4697392935619936, 0.4396075671132995, 
   0.7655652702549961}]], "Output",
 CellChangeTimes->{3.91985625493498*^9},
 CellLabel->
  "Out[1539]=",ExpressionUUID->"413d838c-7210-424d-bb60-0750f36cde2c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ammonia", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 
  3.9198585140392227`*^9}},ExpressionUUID->"35c5282c-91c6-47c2-b28d-\
4b0ce10f7540"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<Ammonia\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.920894039132866*^9, 
  3.9208940679024076`*^9}},
 CellLabel->
  "In[2551]:=",ExpressionUUID->"36beec0c-2a93-4e8c-9394-c8bb954f6e11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.08983870771574476, 0.05186840208333324}, {
                   0.2815615045002696, 0.16255961041666656`}}], 
                  
                  LineBox[{{-0.0898387077157447, 
                   0.051868402083333306`}, {-0.2815615045002695, 
                   0.16255961041666678`}}], 
                  
                  LineBox[{{-2.8021955126670646`*^-17, \
-0.11854266666666675`}, {-1.0824674490095277`*^-16, \
-0.32500000000000007`}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.2815615045002696, 0.16255961041666656`}, {
                   0.4732843012847945, 0.27325081874999985`}}], 
                  
                  LineBox[{{-0.2815615045002695, 
                   0.16255961041666678`}, {-0.47328430128479426`, 
                   0.27325081875000024`}}], 
                  
                  LineBox[{{-1.0824674490095277`*^-16, \
-0.32500000000000007`}, {-1.884715346752349*^-16, -0.5314573333333333}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.054986804166666646`, -0.06979266666666675}, \
{-0.054986804166666646`, 0.06979266666666659}, {-0.03603897916666665, 
                    0.06979266666666659}, {
                    0.03727647083333334, -0.03980004166666676}, {
                    0.03727647083333334, 0.06979266666666659}, {
                    0.05498680416666667, 0.06979266666666659}, {
                    0.05498680416666667, -0.06979266666666675}, {
                    0.03603865416666667, -0.06979266666666675}, \
{-0.03727679583333332, 
                    0.03989483333333324}, {-0.03727679583333332, \
-0.06979266666666675}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.5081681499598852, 
                    0.2552073333333332}, {0.5081681499598852, 
                    0.3947926666666665}, {0.5266397416265518, 
                    0.3947926666666665}, {0.5266397416265518, 
                    0.33747349999999987`}, {0.5991934999598851, 
                    0.33747349999999987`}, {0.5991934999598851, 
                    0.3947926666666665}, {0.6176648749598852, 
                    0.3947926666666665}, {0.6176648749598852, 
                    0.2552073333333332}, {0.5991934999598851, 
                    0.2552073333333332}, {0.5991934999598851, 
                    0.32100033333333317`}, {0.5266397416265518, 
                    0.32100033333333317`}, {0.5266397416265518, 
                    0.2552073333333332}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.6176648749598849, 
                    0.2552073333333336}, {-0.6176648749598849, 
                    0.39479266666666696`}, {-0.5991932832932183, 
                    0.39479266666666696`}, {-0.5991932832932183, 
                    0.3374735000000003}, {-0.526639524959885, 
                    0.3374735000000003}, {-0.526639524959885, 
                    0.39479266666666696`}, {-0.5081681499598849, 
                    0.39479266666666696`}, {-0.5081681499598849, 
                    0.2552073333333336}, {-0.526639524959885, 
                    0.2552073333333336}, {-0.526639524959885, 
                    0.3210003333333336}, {-0.5991932832932183, 
                    0.3210003333333336}, {-0.5991932832932183, 
                    0.2552073333333336}}}]}}, "3"], 
                Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.05474836250000023, -0.7197926666666666}, \
{-0.05474836250000023, -0.5802073333333333}, {-0.03627677083333357, \
-0.5802073333333333}, {-0.03627677083333357, -0.6375265}, {
                    0.03627698749999976, -0.6375265}, {
                    0.03627698749999976, -0.5802073333333333}, {
                    0.05474836249999976, -0.5802073333333333}, {
                    0.05474836249999976, -0.7197926666666666}, {
                    0.03627698749999976, -0.7197926666666666}, {
                    0.03627698749999976, -0.6539996666666666}, \
{-0.03627677083333357, -0.6539996666666666}, {-0.03627677083333357, \
-0.7197926666666666}}}]}}, "4"], Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"N\"", 
                    SubscriptBox["\"H\"", "3"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.08983870771574476, 0.05186840208333324}, {
                   0.2815615045002696, 0.16255961041666656`}}], 
                  
                  LineBox[{{-0.0898387077157447, 
                   0.051868402083333306`}, {-0.2815615045002695, 
                   0.16255961041666678`}}], 
                  
                  LineBox[{{-2.8021955126670646`*^-17, \
-0.11854266666666675`}, {-1.0824674490095277`*^-16, \
-0.32500000000000007`}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.2815615045002696, 0.16255961041666656`}, {
                   0.4732843012847945, 0.27325081874999985`}}], 
                  LineBox[{{-0.2815615045002695, 
                   0.16255961041666678`}, {-0.47328430128479426`, 
                   0.27325081875000024`}}], 
                  
                  LineBox[{{-1.0824674490095277`*^-16, \
-0.32500000000000007`}, {-1.884715346752349*^-16, -0.5314573333333333}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.054986804166666646`, -0.06979266666666675}, \
{-0.054986804166666646`, 0.06979266666666659}, {-0.03603897916666665, 
                    0.06979266666666659}, {
                    0.03727647083333334, -0.03980004166666676}, {
                    0.03727647083333334, 0.06979266666666659}, {
                    0.05498680416666667, 0.06979266666666659}, {
                    0.05498680416666667, -0.06979266666666675}, {
                    0.03603865416666667, -0.06979266666666675}, \
{-0.03727679583333332, 
                    0.03989483333333324}, {-0.03727679583333332, \
-0.06979266666666675}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.5081681499598852, 
                    0.2552073333333332}, {0.5081681499598852, 
                    0.3947926666666665}, {0.5266397416265518, 
                    0.3947926666666665}, {0.5266397416265518, 
                    0.33747349999999987`}, {0.5991934999598851, 
                    0.33747349999999987`}, {0.5991934999598851, 
                    0.3947926666666665}, {0.6176648749598852, 
                    0.3947926666666665}, {0.6176648749598852, 
                    0.2552073333333332}, {0.5991934999598851, 
                    0.2552073333333332}, {0.5991934999598851, 
                    0.32100033333333317`}, {0.5266397416265518, 
                    0.32100033333333317`}, {0.5266397416265518, 
                    0.2552073333333332}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.6176648749598849, 
                    0.2552073333333336}, {-0.6176648749598849, 
                    0.39479266666666696`}, {-0.5991932832932183, 
                    0.39479266666666696`}, {-0.5991932832932183, 
                    0.3374735000000003}, {-0.526639524959885, 
                    0.3374735000000003}, {-0.526639524959885, 
                    0.39479266666666696`}, {-0.5081681499598849, 
                    0.39479266666666696`}, {-0.5081681499598849, 
                    0.2552073333333336}, {-0.526639524959885, 
                    0.2552073333333336}, {-0.526639524959885, 
                    0.3210003333333336}, {-0.5991932832932183, 
                    0.3210003333333336}, {-0.5991932832932183, 
                    0.2552073333333336}}}]}}, "3"], 
                Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.05474836250000023, -0.7197926666666666}, \
{-0.05474836250000023, -0.5802073333333333}, {-0.03627677083333357, \
-0.5802073333333333}, {-0.03627677083333357, -0.6375265}, {
                    0.03627698749999976, -0.6375265}, {
                    0.03627698749999976, -0.5802073333333333}, {
                    0.05474836249999976, -0.5802073333333333}, {
                    0.05474836249999976, -0.7197926666666666}, {
                    0.03627698749999976, -0.7197926666666666}, {
                    0.03627698749999976, -0.6539996666666666}, \
{-0.03627677083333357, -0.6539996666666666}, {-0.03627677083333357, \
-0.7197926666666666}}}]}}, "4"], Annotation[#, 4, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"N\"", 
                    SubscriptBox["\"H\"", "3"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"N([H])([H])[H]\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"QGZKDVFQNNGYKY-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"N", "H", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{1, 3}, "Single"], 
    Bond[{1, 4}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.920894082686472*^9},
 CellLabel->
  "Out[2551]=",ExpressionUUID->"a35327e5-f62b-47eb-ab91-2ff09f0beab8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"molecule", ",", 
   RowBox[{"Background", "->", "LightBlue"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}, {
  3.920894075988387*^9, 3.920894079120803*^9}},
 CellLabel->
  "In[2552]:=",ExpressionUUID->"cf1b0b8d-fce1-4042-932d-abc608e50527"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{-6.996416747424221*^-8, -3.4640357086794006`*^-8, \
-0.06998066010461731}, {-0.07551809069877247, 0.9366542102315211, 
    0.3241464174781019}, {-0.7734070816997113, -0.5337276969042443, 
    0.3241468299755509}, {0.848926144608894, -0.4029260319706481, 
    0.3241463419167589}, {-0.03775908033146997, 0.468327087795582, 
    0.1270828786867423}, {-0.3867035758319394, -0.26686386577230065`, 
    0.1270830849354668}, {0.4244630373223633, -0.20146303330550258`, 
    0.12708284090607078`}}, {{
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{2, 3, 4}, 0.24]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], 
       SphereBox[{1}, 0.32000000000000006`]}}, {{
       {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 5}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{5, 2}, 0.15]}}, {
       {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 6}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{6, 3}, 0.15]}}, {
       {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 7}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{7, 4}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Background->RGBColor[0.87, 0.94, 1],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{2.3653465666987725`, 2.388820381201211, 0.35081733960001377`},
  ViewVertical->{-0.6429276238299583, -0.6074114863666551, \
-0.4665783500616098}]], "Output",
 CellChangeTimes->{
  3.91985625493498*^9, 3.919856288982011*^9, {3.9208940798219337`*^9, 
   3.920894084108514*^9}},
 CellLabel->
  "Out[2552]=",ExpressionUUID->"7322ca1b-dffd-4c26-b05e-1e2746a395f7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Benzene", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 
  3.919858523724455*^9}},ExpressionUUID->"5cb6b279-0b3e-4fe6-8741-\
0dc692a8587c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<Benzene\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}},
 CellLabel->
  "In[1542]:=",ExpressionUUID->"b69778dd-2eb2-435a-ad33-1dd1af1aa8a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{{1.0000000000000004`, -3.700743415417188*^-17}, {
                   0.49999999999999956`, -0.8660254037844393}}, {{
                   0.8460769515458678, -0.026602540378443805`}, {
                   0.446076951545867, -0.7194228634059954}}}], 
                  
                  LineBox[{{
                   0.49999999999999956`, -0.8660254037844393}, \
{-0.5000000000000004, -0.8660254037844386}}], 
                  
                  LineBox[{{{-0.5000000000000004, -0.8660254037844386}, {-1., 
                   8.545724576056347*^-17}}, {{-0.4460769515458677, \
-0.7194228634059948}, {-0.8460769515458674, -0.02660254037844384}}}], 
                  
                  LineBox[{{-1., 
                   8.545724576056347*^-17}, {-0.4999999999999997, 
                   0.866025403784439}}], 
                  
                  LineBox[{{{-0.4999999999999997, 0.866025403784439}, {
                   0.5000000000000003, 
                   0.8660254037844388}}, {{-0.39999999999999974`, 
                   0.746025403784439}, {0.40000000000000036`, 
                   0.7460254037844388}}}], 
                  
                  LineBox[{{0.5000000000000003, 0.8660254037844388}, {
                   1.0000000000000004`, -3.700743415417188*^-17}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{1.0000000000000004`, -3.700743415417188*^-17}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.49999999999999956`, -0.8660254037844393}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.5000000000000004, -0.8660254037844386}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1., 8.545724576056347*^-17}, 0.2]}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4999999999999997, 0.866025403784439}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.5000000000000003, 0.8660254037844388}, 0.2]}, 
                 "6"], Annotation[#, 6, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "6"], 
                    SubscriptBox["\"H\"", "6"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["12", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["12", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{{1.0000000000000004`, -3.700743415417188*^-17}, {
                   0.49999999999999956`, -0.8660254037844393}}, {{
                   0.8460769515458678, -0.026602540378443805`}, {
                   0.446076951545867, -0.7194228634059954}}}], 
                  
                  LineBox[{{
                   0.49999999999999956`, -0.8660254037844393}, \
{-0.5000000000000004, -0.8660254037844386}}], 
                  
                  LineBox[{{{-0.5000000000000004, -0.8660254037844386}, {-1., 
                   8.545724576056347*^-17}}, {{-0.4460769515458677, \
-0.7194228634059948}, {-0.8460769515458674, -0.02660254037844384}}}], 
                  
                  LineBox[{{-1., 
                   8.545724576056347*^-17}, {-0.4999999999999997, 
                   0.866025403784439}}], 
                  
                  LineBox[{{{-0.4999999999999997, 0.866025403784439}, {
                   0.5000000000000003, 
                   0.8660254037844388}}, {{-0.39999999999999974`, 
                   0.746025403784439}, {0.40000000000000036`, 
                   0.7460254037844388}}}], 
                  
                  LineBox[{{0.5000000000000003, 0.8660254037844388}, {
                   1.0000000000000004`, -3.700743415417188*^-17}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{1.0000000000000004`, -3.700743415417188*^-17}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.49999999999999956`, -0.8660254037844393}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.5000000000000004, -0.8660254037844386}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1., 8.545724576056347*^-17}, 0.2]}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4999999999999997, 0.866025403784439}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.5000000000000003, 0.8660254037844388}, 0.2]}, 
                 "6"], Annotation[#, 6, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "6"], 
                    SubscriptBox["\"H\"", "6"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["12", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["12", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"c1([H])c([H])c([H])c([H])c([H])c1[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"UHOVQNZJYSORNB-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"C", "C", "C", "C", "C", "C", "H", "H", "H", "H", "H", "H"}, {
    Bond[{1, 2}, "Aromatic"], 
    Bond[{2, 3}, "Aromatic"], 
    Bond[{3, 4}, "Aromatic"], 
    Bond[{4, 5}, "Aromatic"], 
    Bond[{5, 6}, "Aromatic"], 
    Bond[{6, 1}, "Aromatic"], 
    Bond[{1, 7}, "Single"], 
    Bond[{2, 8}, "Single"], 
    Bond[{3, 9}, "Single"], 
    Bond[{4, 10}, "Single"], 
    Bond[{5, 11}, "Single"], 
    Bond[{6, 12}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9},
 CellLabel->
  "Out[1542]=",ExpressionUUID->"5114a5d2-c9d8-4e46-8971-eafa8af108aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1543]:=",ExpressionUUID->"60d418db-de0b-4e26-afab-09c0b3e9ed5a"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwB4QIe/SFib1JlAgAAAB4AAAADAAAAIx7oAiIe9j+lbqnnHdLHvwAAQOQj
ZmG+EUehltn14D/L9VscraT0vwCAXX6QJbk+auim62lG67+XoxrPaarxvwCQ
6mmG2cq+iWxuxyEe9r/TP7xeHtLHPwCAMShMi8E+GFUkTdn14L9Fv7AhraT0
PwAAH/d3/7I+7ruDB2lG6z8DHhGgaarxPwCAzF7FVpy+5/zmO8qsA0Bmetjm
ojDVvwAADzZOjLe+anqGFqws7j8SFNiFBV0CwADgr253l+A+2puulEND+L+/
JN/g4m3/vwDwb8MR4Nm+1q1o2MqsA8BvnZyNkzDVPwAAIUgMwbY+eAH9n6As
7r9hmkytBl0CQAAAEEscwtu+mvsc5z9D+D89pN6n5W3/PwAoSbAxWOC+HxW+
0jZY9D9jcLuglL25v0BUunJZV6a+EGqabAbU2j/9fnKpQkbzv8CrRMgpCq0+
JycSMw3k9z+Mknq/uGLRv0BUMvaUKqQ+Gln19q+B5D+ZbEWPFwP2vxBVTAwG
48E+RymnHUVr778NC8OkT4Tyv/XmQ+vk/tC++IxuYI8w+L8fBHmx7wLBPy6E
KHcRzrQ+jaemuY4h578hPHL5g9DwvxdSTf1CtcO+GkxuLrQL9L+He/8LTaHO
P+m9zpSPr8g+1jcFpNRc4L/2xadJ/dz2P4zGjkwBpbI+MNmisG3f6z+0JAjI
ueLzP9BlDQmgwJ2+WnJD9t2O4b+UuLn5XGzyP3Q5r6HuWbM+rJ5kXmSt6j+l
LjTwMuTuPzCai7Tq7Jq++AtbPdu7/j/cmFbt2IzQvwAAMVV/F6i+vuCT1kKR
5z/4DgYUXK/8vwCQe34pvNM+CAhBRTzz8r8r5PxXJoz4vwCcMnxqptO+GuQf
vNu7/r+sXn1e0YzQPwAAQkzS67w+SKuQ9jyR578E+iQ+Xa/8PwBASE0+Ase+
yGxvNTrz8j8g4fejJ4z4PwCMP9vnOtG+Szd1iw==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2, 3, 4, 5, 6}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{7, 8, 9, 10, 11, 12}, 0.24]}}, {{
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{13, 14}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{15, 16}, 0.08]}}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{17, 18}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{19, 20}, 0.08]}}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 5}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{21, 22}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{23, 24}, 0.08]}}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 1}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 25}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{25, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 26}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{26, 8}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 27}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{27, 9}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 28}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{28, 10}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 29}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{29, 11}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 30}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{30, 12}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{2.884400172246701, -0.17570586370128372`, 1.7532150740294783`},
  ViewVertical->{-0.14829897421102162`, 0.1552951879297127, 
   0.9766733429626479}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9},
 CellLabel->
  "Out[1543]=",ExpressionUUID->"ce808227-359e-411d-a2a1-49433775d82d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["CO2", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331207`*^9}},ExpressionUUID->"6d95e83f-6c95-4f51-a9c5-\
9e974bb85f62"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<Carbon Dioxide\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}},
 CellLabel->
  "In[1578]:=",ExpressionUUID->"ab34c2e5-918a-457b-a88d-8d3b09f1fc35"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.8223143083333333, 
                   0.06000000000000014}, {-0.49611805416666666`, 
                   0.060000000000000095`}}, {{-0.8223143083333333, \
-0.05999999999999986}, {-0.49611805416666666`, -0.0599999999999999}}}], 
                  
                  LineBox[{{{0.49611805416666666`, 0.059999999999999915`}, {
                   0.8223143083333333, 0.05999999999999984}}, {{
                   0.4961180541666666, -0.06000000000000008}, {
                   0.8223143083333333, -0.06000000000000016}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{-0.49611805416666666`, 
                   0.060000000000000095`}, {-0.16992179999999998`, 
                   0.06000000000000006}}, {{-0.49611805416666666`, \
-0.0599999999999999}, {-0.16992179999999998`, -0.059999999999999935`}}}], 
                  
                  LineBox[{{{0.1699218, 0.06}, {0.49611805416666666`, 
                   0.059999999999999915`}}, {{0.16992179999999996`, -0.06}, {
                   0.4961180541666666, -0.06000000000000008}}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ3TW7/MDMJR/3O+yJYA1PS98P4z+ZZeS16uQCe83j
DlVptR/3TznxZ5uV8Hp7loAMUwb9j/vX1LG8Vt28xf7uzEuHZz74sN/m18WC
U3d22lc9YpqZVv1hP8eOHZvnFO6x33y1XODsv/dw/rpt7MfSYhB8tZ3VFgyn
3u1/cNF7voH1bnu9YAv12e7v9s9gLSqLOLfDXuGn6F/jo2/3N8y67zwncZu9
T3NU97nEt/vf8OuY/P2/yb6H1TY4XfbtfpE+22q94LX2Z9vlpRluvtkf8Eep
L2nZEvu3JwTqz2x7sz9iAYuyzIKpcD5D1JyZxcwW+2F8Aye7FzfXTNsf4b2z
6uytN/undKtPZQ5Yup8jxfHzaaW3++MiviRekFm3/27GpFdns97unzYpYfq5
ks37Lynllp6+8Ha/7CeVl7NObttvnJU88XTIu/1PrKQ/nefZuX/JSmfhszfe
7e+dbKvPFLB7/6n4my3G6e/3f9gO9v/+aCd2NQaGD3C+hTXHhzNBCP7y/NI7
Z+Z82P/W0i5qjuHu/avleCQY7n3Y/9TWc/nsjTv2rzu7KNhY/uP+u44hX2YZ
btsf86t47cyAj/svMbitYjqxaf+2xzZBxkUf93uJTv01/+Wa/QJnWb+fmfxx
/waPbxymzkvg8X1jwZ7+xZbT9qOnBwBjGC9V
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/fej1b6ZOh/3N1y6byHGmL0fxteYerKZ/cHc/R8v
BB+QFPi432zmlQtsCSv33+xrPSJ5/cN+ni/3JJgaNuw/6LP9hOS8D/vrZgef
ZAjYsj9HbcWqmWEf9rs9L29ntNi2/+7MS4dnMiD4L9wzChiC3sP5Vj6bf5w5
+G5//fVHDqbeW/bvtyhomxXwbv+H7Ts2zyncsN9W0yIx/f7b/R0BpVuZDFbu
z1htzn9m2dv9CwqnrMxvmwPnMzhkKEw7qwPnT/AQPbp6zUT7F7qHVRj3v92v
MPv2dLdlC+wPuQleTH//dv8au8Qym+Dl9rPj42vPyb/bf0M+IuPX/7X27icD
ds1Me7ffQ+7Xu7BpG+1f569jO3v43f452o8Sj+dstu8X4wlmUHy//4PFqSvm
zlvtL9R5np/Z+X4/S7+UcJLeNvsNag+vzPyL4N8LtPc2DvwA529SaD4tOePD
/gmMcZWLM7fYn288KNhw+cP+qta5/lwPNti/U9zb8ozv4/4zQru8H61ZZQ+L
j45SZ4fVO+fao8cXAP7P8k4=
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   GrayLevel[0.4], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Q0wUYB/AfMFe8TI+Si4GRhCzx4kVHBgt4EArjhMpIy8BD1tiY4gSZ
BF0aiWYSk3UMGAg0EdiEDX/jx16S1dPLgTDHwCWIuDgSxSQ8OqQlaRK9sD96
7r5/fO7563v3PIHcA29muxEE4bIUWIrrUiaFAnomXQt9nmULllwFfrZfU3Yp
xQjG41zfBmYzCppZCft69SBuYCwI6CSmJ9Lef/BYF9QMr/e2yrqwql3yjNyb
hKRfjl4hjAZsei5MKtysgnnixxr29QsoLrx65KpXA4y5iTOtuSYkKxR8fW2R
05H+6pLvyz/HZYtWFbvKhU0YNysJJKK6cduTd7P4I+dwnb4qn281YuFpu6zm
DInuhxu+tfD0qGYMzJvFFKbvzaeypzqR9eu9Y2aeDsV2c3BOqxqbbH4+5rcM
OO/mmbr40dnlfjh6j4xV7Kp0muCWvD2e8y4sW/WO0vx7uRwMJ2JcLJEG5C0w
aYmJrbA+XKs103QYNb3y9fr+DjD2LoRarnRi2V2XgT+UFNxSf/Jg8cB5dHz6
tcp8Uw9qk3+CJUOJ/K1fXYj1/xJ+lmd5b6xsxLZm8YhsezfkbUrtOlF7Esf/
7Q+Ej7Kvgv8BLHvN8A7Wmdp6pwuLLq+1liuh99AXDhG9GxIYKuInr/PAvd8R
Jos2gkQ6+40oiYIw+4rdw7k6GKBtjONM6sAvufvyxQ+1sPs93/u2DAN4uZnm
kn5QQbZctD+GTUL8hhe3bytogaQ+d3vpNc1/1kCAx461QlYb0KYnCjhntXB0
Lj50MKUFrJX7PHiFFNwYe57zQoEC6mIdCkmyDkx7bx58iZKBX2KmIIKthwlG
8mlfosjpnEdZqwcsx9G5/+f+avFgjqH0UbgOvouLGnkY3oQbKIGpLoSC6r6Y
ELNdiRN/PvXb5iAtEFNH2muvtSNvhW00f0QNPfqdPdmsDnyjVPfyFrdW6Ems
mZVHk5jnuikrcE8j3IYgqdlCovxGgqcjRep0Sd5Y8eNDGU7v4aYzBVNSHDWF
8PgBJEaJtxy+VK9AQvP0nYhSDT7UX/cXVisxdeK2e1V/Gx5jWp91kXbgytA7
mf3lraiv6B9kT2rRlSpO67MocBfPJ9laT+FM/upTp5jVOP6qxJG9U4eqrEN1
3SmlGMH+e/QYP221exEiWPa6xlc+HvKSOd0YaAu2zSiA1xJUyafr0Brs+Rq7
shUGT9LSBtSdyPGYYdRFq4EjuvVEZBqJF+fWLBbQSZgpHg0YUp/D///3X8hr
/GY=
                    "]]}}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ/eaEQP2ZbW/sG/ZHsIanpe+H8TfMMvJadXKB/brC
Om5j1rf2CSf+bLMSXm//I15/6v+Fb+0n1bG8Vt28xd7tTFTFGbt39kq/Lhac
urPTntv611kjzvf277bv2DyncI+9muiR8pkMH+D8lSp/5pwJRPBzlQ89/j/r
g/2xi97zDax322deS84xuvPBvo61qCzi3A77AuZSxjTZj/Zps+47z0ncZh+1
L2iXhP9H+0v8OiZ//2+yt6pNDPMp/Gj/oNe2Wi94rb2UTcGn+skf7WX+KPUl
LVti3zm7/MDMJR/tP8xnUZZZMBXOZyiZM7OY2WI/jD/Dye7FzTXT9odELXaa
Oemj/Ylu9anMAUv3//GNZ5uV99F+UsSXxAsy6/ZPOr2Na6bXR/sNkxKmnyvZ
vH96nqfrLPGP9uafVF7OOrlt/zMvP/NZVz/Y/7OS/nSeZ+d+Pe24spmTP9gv
n2yrzxSwe790wGTbNJ8P9lw7wP7f71n9cfP//+/h/Amd7+XTohD8TQqi7mnH
3tmzW9lFzTHcvX/Voefn/zu/s/9v67l89sYd+xen7IqYefCt/XfHkC+zDLft
9+CWWHom7q39Gwa3VUwnNu2fbNEWPVP6rX2d6NRf81+u2X8/9Ytg2o039k88
vnGYOi+Bx7fDwj39iy2n7UdPDwDgTSAT
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQzSbT1Xxm2Vv7A1fvW4gxZu+H8SdMPdnM/mDufrm4
iPoz99/aZ828coEtYeV+v0dfys4EvrNX+3JPgqlhw/7atIl5Zw6/s58xO/gk
Q8CW/Rqb1686E/TePuF5eTujxbb9bmeiKs78Q/B57pw+/j/sA5z/OHJZs+T8
D/Yzrz9yMPXesn/B4+N7Nl3/YM+1Y8fmOYUb9ie9Tvb3EfhovyegdCuTwcr9
PlopP2bqfLTnKJqyMr9tDpzPUJKhMO2sDpyv4SF6dPWaifY8mfNy6xU+2r+Z
dXu627IF9vNjysV9OD7aV9glltkEL7c3Dgg4KPHhg/0S+YiMX//X2sfOvq60
+cwHez25X+/Cpm205zqxokZy3gf7Ju1HicdzNtvv+FJ5rT7/g/01i1NXzJ23
2s9wiJYwtv5g/6pPSjhJb5v9ipx+UWNGBN8lpjFzZux7OH/uvp8ZZ86/sy9j
jKtcnLnFPvlPzZ3/Ee/sE1rn+nM92GCvuqf1m9Gjt/YzhHZ5P1qzyh4WHwql
zg6rd861R48vANjb48I=
                    "]}]}}, "3"], Annotation[#, 3, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.8223143083333333, 
                   0.06000000000000014}, {-0.49611805416666666`, 
                   0.060000000000000095`}}, {{-0.8223143083333333, \
-0.05999999999999986}, {-0.49611805416666666`, -0.0599999999999999}}}], 
                  
                  LineBox[{{{0.49611805416666666`, 0.059999999999999915`}, {
                   0.8223143083333333, 0.05999999999999984}}, {{
                   0.4961180541666666, -0.06000000000000008}, {
                   0.8223143083333333, -0.06000000000000016}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{{-0.49611805416666666`, 
                   0.060000000000000095`}, {-0.16992179999999998`, 
                   0.06000000000000006}}, {{-0.49611805416666666`, \
-0.0599999999999999}, {-0.16992179999999998`, -0.059999999999999935`}}}], 
                  
                  LineBox[{{{0.1699218, 0.06}, {0.49611805416666666`, 
                   0.059999999999999915`}}, {{0.16992179999999996`, -0.06}, {
                   0.4961180541666666, -0.06000000000000008}}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ3TW7/MDMJR/3O+yJYA1PS98P4z+ZZeS16uQCe83j
DlVptR/3TznxZ5uV8Hp7loAMUwb9j/vX1LG8Vt28xf7uzEuHZz74sN/m18WC
U3d22lc9YpqZVv1hP8eOHZvnFO6x33y1XODsv/dw/rpt7MfSYhB8tZ3VFgyn
3u1/cNF7voH1bnu9YAv12e7v9s9gLSqLOLfDXuGn6F/jo2/3N8y67zwncZu9
T3NU97nEt/vf8OuY/P2/yb6H1TY4XfbtfpE+22q94LX2Z9vlpRluvtkf8Eep
L2nZEvu3JwTqz2x7sz9iAYuyzIKpcD5D1JyZxcwW+2F8Aye7FzfXTNsf4b2z
6uytN/undKtPZQ5Yup8jxfHzaaW3++MiviRekFm3/27GpFdns97unzYpYfq5
ks37Lynllp6+8Ha/7CeVl7NObttvnJU88XTIu/1PrKQ/nefZuX/JSmfhszfe
7e+dbKvPFLB7/6n4my3G6e/3f9gO9v/+aCd2NQaGD3C+hTXHhzNBCP7y/NI7
Z+Z82P/W0i5qjuHu/avleCQY7n3Y/9TWc/nsjTv2rzu7KNhY/uP+u44hX2YZ
btsf86t47cyAj/svMbitYjqxaf+2xzZBxkUf93uJTv01/+Wa/QJnWb+fmfxx
/waPbxymzkvg8X1jwZ7+xZbT9qOnBwBjGC9V
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ/fej1b6ZOh/3N1y6byHGmL0fxteYerKZ/cHc/R8v
BB+QFPi432zmlQtsCSv33+xrPSJ5/cN+ni/3JJgaNuw/6LP9hOS8D/vrZgef
ZAjYsj9HbcWqmWEf9rs9L29ntNi2/+7MS4dnMiD4L9wzChiC3sP5Vj6bf5w5
+G5//fVHDqbeW/bvtyhomxXwbv+H7Ts2zyncsN9W0yIx/f7b/R0BpVuZDFbu
z1htzn9m2dv9CwqnrMxvmwPnMzhkKEw7qwPnT/AQPbp6zUT7F7qHVRj3v92v
MPv2dLdlC+wPuQleTH//dv8au8Qym+Dl9rPj42vPyb/bf0M+IuPX/7X27icD
ds1Me7ffQ+7Xu7BpG+1f569jO3v43f452o8Sj+dstu8X4wlmUHy//4PFqSvm
zlvtL9R5np/Z+X4/S7+UcJLeNvsNag+vzPyL4N8LtPc2DvwA529SaD4tOePD
/gmMcZWLM7fYn288KNhw+cP+qta5/lwPNti/U9zb8ozv4/4zQru8H61ZZQ+L
j45SZ4fVO+fao8cXAP7P8k4=
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   GrayLevel[0.4], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Q0wUYB/AfMFe8TI+Si4GRhCzx4kVHBgt4EArjhMpIy8BD1tiY4gSZ
BF0aiWYSk3UMGAg0EdiEDX/jx16S1dPLgTDHwCWIuDgSxSQ8OqQlaRK9sD96
7r5/fO7563v3PIHcA29muxEE4bIUWIrrUiaFAnomXQt9nmULllwFfrZfU3Yp
xQjG41zfBmYzCppZCft69SBuYCwI6CSmJ9Lef/BYF9QMr/e2yrqwql3yjNyb
hKRfjl4hjAZsei5MKtysgnnixxr29QsoLrx65KpXA4y5iTOtuSYkKxR8fW2R
05H+6pLvyz/HZYtWFbvKhU0YNysJJKK6cduTd7P4I+dwnb4qn281YuFpu6zm
DInuhxu+tfD0qGYMzJvFFKbvzaeypzqR9eu9Y2aeDsV2c3BOqxqbbH4+5rcM
OO/mmbr40dnlfjh6j4xV7Kp0muCWvD2e8y4sW/WO0vx7uRwMJ2JcLJEG5C0w
aYmJrbA+XKs103QYNb3y9fr+DjD2LoRarnRi2V2XgT+UFNxSf/Jg8cB5dHz6
tcp8Uw9qk3+CJUOJ/K1fXYj1/xJ+lmd5b6xsxLZm8YhsezfkbUrtOlF7Esf/
7Q+Ej7Kvgv8BLHvN8A7Wmdp6pwuLLq+1liuh99AXDhG9GxIYKuInr/PAvd8R
Jos2gkQ6+40oiYIw+4rdw7k6GKBtjONM6sAvufvyxQ+1sPs93/u2DAN4uZnm
kn5QQbZctD+GTUL8hhe3bytogaQ+d3vpNc1/1kCAx461QlYb0KYnCjhntXB0
Lj50MKUFrJX7PHiFFNwYe57zQoEC6mIdCkmyDkx7bx58iZKBX2KmIIKthwlG
8mlfosjpnEdZqwcsx9G5/+f+avFgjqH0UbgOvouLGnkY3oQbKIGpLoSC6r6Y
ELNdiRN/PvXb5iAtEFNH2muvtSNvhW00f0QNPfqdPdmsDnyjVPfyFrdW6Ems
mZVHk5jnuikrcE8j3IYgqdlCovxGgqcjRep0Sd5Y8eNDGU7v4aYzBVNSHDWF
8PgBJEaJtxy+VK9AQvP0nYhSDT7UX/cXVisxdeK2e1V/Gx5jWp91kXbgytA7
mf3lraiv6B9kT2rRlSpO67MocBfPJ9laT+FM/upTp5jVOP6qxJG9U4eqrEN1
3SmlGMH+e/QYP221exEiWPa6xlc+HvKSOd0YaAu2zSiA1xJUyafr0Brs+Rq7
shUGT9LSBtSdyPGYYdRFq4EjuvVEZBqJF+fWLBbQSZgpHg0YUp/D///3X8hr
/GY=
                    "]]}}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ/eaEQP2ZbW/sG/ZHsIanpe+H8TfMMvJadXKB/brC
Om5j1rf2CSf+bLMSXm//I15/6v+Fb+0n1bG8Vt28xd7tTFTFGbt39kq/Lhac
urPTntv611kjzvf277bv2DyncI+9muiR8pkMH+D8lSp/5pwJRPBzlQ89/j/r
g/2xi97zDax322deS84xuvPBvo61qCzi3A77AuZSxjTZj/Zps+47z0ncZh+1
L2iXhP9H+0v8OiZ//2+yt6pNDPMp/Gj/oNe2Wi94rb2UTcGn+skf7WX+KPUl
LVti3zm7/MDMJR/tP8xnUZZZMBXOZyiZM7OY2WI/jD/Dye7FzTXT9odELXaa
Oemj/Ylu9anMAUv3//GNZ5uV99F+UsSXxAsy6/ZPOr2Na6bXR/sNkxKmnyvZ
vH96nqfrLPGP9uafVF7OOrlt/zMvP/NZVz/Y/7OS/nSeZ+d+Pe24spmTP9gv
n2yrzxSwe790wGTbNJ8P9lw7wP7f71n9cfP//+/h/Amd7+XTohD8TQqi7mnH
3tmzW9lFzTHcvX/Voefn/zu/s/9v67l89sYd+xen7IqYefCt/XfHkC+zDLft
9+CWWHom7q39Gwa3VUwnNu2fbNEWPVP6rX2d6NRf81+u2X8/9Ytg2o039k88
vnGYOi+Bx7fDwj39iy2n7UdPDwDgTSAT
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQzSbT1Xxm2Vv7A1fvW4gxZu+H8SdMPdnM/mDufrm4
iPoz99/aZ828coEtYeV+v0dfys4EvrNX+3JPgqlhw/7atIl5Zw6/s58xO/gk
Q8CW/Rqb1686E/TePuF5eTujxbb9bmeiKs78Q/B57pw+/j/sA5z/OHJZs+T8
D/Yzrz9yMPXesn/B4+N7Nl3/YM+1Y8fmOYUb9ie9Tvb3EfhovyegdCuTwcr9
PlopP2bqfLTnKJqyMr9tDpzPUJKhMO2sDpyv4SF6dPWaifY8mfNy6xU+2r+Z
dXu627IF9vNjysV9OD7aV9glltkEL7c3Dgg4KPHhg/0S+YiMX//X2sfOvq60
+cwHez25X+/Cpm205zqxokZy3gf7Ju1HicdzNtvv+FJ5rT7/g/01i1NXzJ23
2s9wiJYwtv5g/6pPSjhJb5v9ipx+UWNGBN8lpjFzZux7OH/uvp8ZZ86/sy9j
jKtcnLnFPvlPzZ3/Ee/sE1rn+nM92GCvuqf1m9Gjt/YzhHZ5P1qzyh4WHwql
zg6rd861R48vANjb48I=
                    "]}]}}, "3"], Annotation[#, 3, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"O=C=O\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"CURLTUGMZLYLDI-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"O", "C", "O"}, {
    Bond[{1, 2}, "Double"], 
    Bond[{2, 3}, "Double"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.9200410030789967`*^9},
 CellLabel->
  "Out[1578]=",ExpressionUUID->"eca901ac-fec4-4f79-bf91-b315f1d97351"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1579]:=",ExpressionUUID->"ea51686d-1631-4d20-95fa-1dc6cfcfe956"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJxTTMoPSmViYGDgB2JmIE5q2+r5sOrbfgYEMFhdpWknfOl3ltCkpn0wQRVz
09cGPxz2LZ87PRWo3h5J/YJVQPU2TXn5D6uewc35I8Kq0vr64H6TKy55yOJ3
+rIlgeL2Tz7+R7FXYXmkBEj96ayn2h7bEfZeb9qgDxJ/IJWNon7HHzFVkDnR
lkKr7uQg1DMqHuAFiV/053AE2gt3J58oxD0XF96zRxY/BXVPya4vKObA7FXn
fITiXxeoOze9ZEJxJ8xedSNfFPVToO4EALIvf/Y=
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{2}, 0.34]}, 
      {RGBColor[0.800498, 0.201504, 0.192061], 
       SphereBox[{1, 3}, 0.31000000000000005`]}}, {{
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{6, 4}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 7}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{8, 5}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 9}, 0.08]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{12, 10}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], 
        CylinderBox[{10, 13}, 0.08]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{14, 11}, 0.08]}, 
       {RGBColor[0.800498, 0.201504, 0.192061], 
        CylinderBox[{11, 15}, 0.08]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{-0.03747643409372139, 3.2358254475578767`, -0.9759247869710473},
  
  ViewVertical->{0.00014791003220715823`, 0.40639878883816016`, 
   0.9136957932230502}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9},
 CellLabel->
  "Out[1579]=",ExpressionUUID->"f6768dac-dd84-4b0e-9a8d-cd45fa9f8428"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["n-decane", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331207`*^9}, {3.920141903568302*^9, 
  3.920141905404848*^9}},ExpressionUUID->"55819cbf-6fff-4560-993b-\
4ca36935f16e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<n-decane\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725863`*^9, 3.920141914994022*^9}},
 CellLabel->
  "In[1690]:=",ExpressionUUID->"26d830e0-9d08-48fe-ab4c-a62aa721b0e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-3.897114317029973, -0.2499999999999991}, \
{-3.0310889132455343`, 0.2500000000000007}}], 
                  
                  LineBox[{{-3.0310889132455343`, 
                   0.2500000000000007}, {-2.165063509461096, \
-0.2499999999999995}}], 
                  
                  LineBox[{{-2.165063509461096, -0.2499999999999995}, \
{-1.2990381056766573`, 0.25000000000000044`}}], 
                  
                  LineBox[{{-1.2990381056766573`, 
                   0.25000000000000044`}, {-0.4330127018922189, \
-0.2499999999999999}}], 
                  
                  LineBox[{{-0.4330127018922189, -0.2499999999999999}, {
                   0.43301270189221946`, 0.2499999999999999}}], 
                  
                  LineBox[{{0.43301270189221946`, 0.2499999999999999}, {
                   1.2990381056766578`, -0.25000000000000033`}}], 
                  
                  LineBox[{{1.2990381056766578`, -0.25000000000000033`}, {
                   2.1650635094610964`, 0.2499999999999995}}], 
                  
                  LineBox[{{2.1650635094610964`, 0.2499999999999995}, {
                   3.0310889132455348`, -0.2500000000000007}}], 
                  
                  LineBox[{{3.0310889132455348`, -0.2500000000000007}, {
                   3.897114317029973, 0.2499999999999991}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-3.897114317029973, -0.2499999999999991}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-3.0310889132455343`, 0.2500000000000007}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-2.165063509461096, -0.2499999999999995}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1.2990381056766573`, 0.25000000000000044`}, 0.2]},
                  "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4330127018922189, -0.2499999999999999}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.43301270189221946`, 0.2499999999999999}, 0.2]}, 
                 "6"], Annotation[#, 6, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.2990381056766578`, -0.25000000000000033`}, 0.2]},
                  "7"], Annotation[#, 7, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{2.1650635094610964`, 0.2499999999999995}, 0.2]}, 
                 "8"], Annotation[#, 8, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{3.0310889132455348`, -0.2500000000000007}, 0.2]}, 
                 "9"], Annotation[#, 9, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{3.897114317029973, 0.2499999999999991}, 0.2]}, 
                 "10"], Annotation[#, 10, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "10"], 
                    SubscriptBox["\"H\"", "22"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["32", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["31", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-3.897114317029973, -0.2499999999999991}, \
{-3.0310889132455343`, 0.2500000000000007}}], 
                  
                  LineBox[{{-3.0310889132455343`, 
                   0.2500000000000007}, {-2.165063509461096, \
-0.2499999999999995}}], 
                  
                  LineBox[{{-2.165063509461096, -0.2499999999999995}, \
{-1.2990381056766573`, 0.25000000000000044`}}], 
                  
                  LineBox[{{-1.2990381056766573`, 
                   0.25000000000000044`}, {-0.4330127018922189, \
-0.2499999999999999}}], 
                  
                  LineBox[{{-0.4330127018922189, -0.2499999999999999}, {
                   0.43301270189221946`, 0.2499999999999999}}], 
                  
                  LineBox[{{0.43301270189221946`, 0.2499999999999999}, {
                   1.2990381056766578`, -0.25000000000000033`}}], 
                  
                  LineBox[{{1.2990381056766578`, -0.25000000000000033`}, {
                   2.1650635094610964`, 0.2499999999999995}}], 
                  
                  LineBox[{{2.1650635094610964`, 0.2499999999999995}, {
                   3.0310889132455348`, -0.2500000000000007}}], 
                  
                  LineBox[{{3.0310889132455348`, -0.2500000000000007}, {
                   3.897114317029973, 0.2499999999999991}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-3.897114317029973, -0.2499999999999991}, 0.2]}, 
                 "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-3.0310889132455343`, 0.2500000000000007}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-2.165063509461096, -0.2499999999999995}, 0.2]}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-1.2990381056766573`, 0.25000000000000044`}, 0.2]},
                  "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.4330127018922189, -0.2499999999999999}, 0.2]}, 
                 "5"], Annotation[#, 5, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.43301270189221946`, 0.2499999999999999}, 0.2]}, 
                 "6"], Annotation[#, 6, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.2990381056766578`, -0.25000000000000033`}, 0.2]},
                  "7"], Annotation[#, 7, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{2.1650635094610964`, 0.2499999999999995}, 0.2]}, 
                 "8"], Annotation[#, 8, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{3.0310889132455348`, -0.2500000000000007}, 0.2]}, 
                 "9"], Annotation[#, 9, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{3.897114317029973, 0.2499999999999991}, 0.2]}, 
                 "10"], Annotation[#, 10, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "10"], 
                    SubscriptBox["\"H\"", "22"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["32", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["31", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C(C(C(C(C(C(C(C(C(C([H])([H])[H])([H])[H])([H])[H])([H])[\
H])([H])[H])([H])[H])([H])[H])([H])[H])([H])[H])([H])([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"DIOQZVSQGTUSAI-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{
   "C", "C", "C", "C", "C", "C", "C", "C", "C", "C", "H", "H", "H", "H", "H", 
    "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H",
     "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{2, 3}, "Single"], 
    Bond[{3, 4}, "Single"], 
    Bond[{4, 5}, "Single"], 
    Bond[{5, 6}, "Single"], 
    Bond[{6, 7}, "Single"], 
    Bond[{7, 8}, "Single"], 
    Bond[{8, 9}, "Single"], 
    Bond[{9, 10}, "Single"], 
    Bond[{1, 11}, "Single"], 
    Bond[{1, 12}, "Single"], 
    Bond[{1, 13}, "Single"], 
    Bond[{2, 14}, "Single"], 
    Bond[{2, 15}, "Single"], 
    Bond[{3, 16}, "Single"], 
    Bond[{3, 17}, "Single"], 
    Bond[{4, 18}, "Single"], 
    Bond[{4, 19}, "Single"], 
    Bond[{5, 20}, "Single"], 
    Bond[{5, 21}, "Single"], 
    Bond[{6, 22}, "Single"], 
    Bond[{6, 23}, "Single"], 
    Bond[{7, 24}, "Single"], 
    Bond[{7, 25}, "Single"], 
    Bond[{8, 26}, "Single"], 
    Bond[{8, 27}, "Single"], 
    Bond[{9, 28}, "Single"], 
    Bond[{9, 29}, "Single"], 
    Bond[{10, 30}, "Single"], 
    Bond[{10, 31}, "Single"], 
    Bond[{10, 32}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.9200410030789967`*^9, 3.920141916938754*^9},
 CellLabel->
  "Out[1690]=",ExpressionUUID->"7b487ba1-7090-47df-a45d-40aa6e8e200e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1691]:=",ExpressionUUID->"dc0253b7-9280-4c24-acd6-5cb318ee9e94"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwBIQXe+iFib1JlAgAAADYAAAADAAAA9RRs6r05E0D0O8rk/Cj0v4hCEg9q
M76/1nqI+agsDEBc2Iolakbhv44DCQHa8d+/hxQSlm1UCEBjKlSo0AzYPxMr
T0sRE+Q/A0oIKb4E/T8eRoiX/l7zP3gd7JYcGNA/muzYvxPO4T8CUOIY0LXX
P0yhuARkVYU/ZyItAYou5b+LyEfrqTT0P7qwf9+IDM+/qFzhF/fR/r9HVeob
8sfeP+Zod9Bsq+O/cdsOXn+7A8DHLH6a5VHYv3YNqOcG+OA/lvuUVBXhDcDl
TotalnPyvz6ti2eoV8Q/csmAw9rDE8CUnQLRTb3Qv/FNoaphere/fWzCHc+G
FECj8yXkkJj+v5xE7fmV5+2/13fIUEijEkBIyD1NLw7+vzKuKVR8vug/VoQZ
+2NxFkDae/8btXvhv8b2soYcTbY/AJM2xOiPDUCwViRZ0AGoP0GWYVZPifa/
SifDelkQBkDcxGVRcp70v76qkdf/e+e//r7utrbPDkD8XT4COwXxP+44aBe3
yOw/fG03kz6RBkBOJ6DiiTfMv9TFqzvuVvg/UTn60c9JAEBt0cqej/T8P+Ct
J8P1euS/0IqtM7rp+T+AW3fVLrL+P0FrZbGJEvE/4o2ez3ZZ2D+aex3KlyPR
vy/1WaC3Qew/o0Ls1z6K5j/tdLujTl3SvyHljXwlTuu/4rnLCpu/27+jZ6C2
fTr/P0z3zh4/DPG/Z6j3uO9+678gCkt7Hxv+P1oJ2q9cheQ/hw9lcB6BBcB1
60qsllbzP0in56lBUu2/nzJBstmZ+7+U+02FzAjDvw6eVG/j1fe/yG7tbXtN
BcAfxrkENd7PP/3i6NfYgvY/Fwyh+BZU+7/KS2dEK8zxv0ojrrJcgeo/pT7c
EhvOD8Ceg7OoaGf9v0/MEj8UZu8/pyZm0RxkDMCYm247r2H8vwiEI1WpNee/
f9joZwI5E8DDwtzBb+PWP4D4JvwDde+/SCGbGJ6DFMBZ9ZxL1FvZP3wnQkUr
aeg/CwTjDYdWF8CuRKUcbv7rv+kbE8GS2c+/uUAXhEbgE0DMF3jkxmD5v3bG
550B1+C/ZkaaHYPuEkAeAgQZlhv5v+FlRxIP+NQ/pszC8pDVFEDh+cly1+bs
vwgvfSE2mY+/64bf3kjeDEDiJfE/mozPvyTXo9bFhe6/ENElOoEeCUAKMStk
p0Htv0IWC2x2uuO/wmmAJhKSC0CUaFMsbwjnPwCyWzHkbeg/AsGkFNZyB0B4
LQhuF+KzP6+tqXA7MPE/Ul5+5i7M/j/Giykbxyn4P0g+Y+/O3ci/aupaLjx3
+z/P0H+2lgj5P59yINeQGOU/izOoJ8/63T+gURM74UiqP7TXbDANl9w/npfi
Syks5D9QbJvUBWKlP5wCe+zP+Nq/rH9JwyuH4b8XGPTQk7f5P2TtvjrQ7eS/
Z2US3bxW6L9WaUmz5Cf5P1Y69O90hMk/7t4q/gx1AsDGgEUzkwjrPxeILz3X
fui/pEcRZeg1/b9+V0PZi0PFP0ApyOvM1fC/HCX+ZX2EBMBwk0IwlsWwv7jp
vEvc/u4/vrAvbcWyAMD81garpODnv2AYK82xvOU/Hp24M5jXDsBCaZ+Bf+33
v9Dbeiz/PeI/HpH9EpkiDcA+9fzKomr3v7mYQDu/H9K/+NC0lW5+E8DAlGjD
h5ioPx+RvRgoMuG/XfUNbrwjFMCIrzT1DD2xP7797Q/fedU/vuax6DCNFcC8
SZOCii7iv3DhMcthy8W/v9qpYA==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], 
       SphereBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], 
       SphereBox[{11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 
        26, 27, 28, 29, 30, 31, 32}, 0.24]}}, {
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 5}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 6}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 7}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{7, 8}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{8, 9}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{9, 10}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 33}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{33, 11}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 34}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{34, 12}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 35}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{35, 13}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 36}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{36, 14}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 37}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{37, 15}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 38}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{38, 16}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 39}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{39, 17}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 40}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{40, 18}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 41}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{41, 19}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 42}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{42, 20}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 43}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{43, 21}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 44}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{44, 22}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 45}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{45, 23}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{7, 46}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{46, 24}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{7, 47}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{47, 25}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{8, 48}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{48, 26}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{8, 49}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{49, 27}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{9, 50}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{50, 28}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{9, 51}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{51, 29}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{10, 52}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{52, 30}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{10, 53}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{53, 31}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{10, 54}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{54, 32}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{1.9372817973154806`, -0.22926375504912166`, 2.7602132831378943`},
  ViewVertical->{0.19942090832514256`, 0.41877310146525926`, 
   0.88592346780743}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9},
 CellLabel->"Out[1691]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"d262c81c-0e9d-4bd2-99a6-4a9a5568f85a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["CH4", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.9203200052529173`*^9}, {3.92089367949266*^9, 
  3.920893680538644*^9}},ExpressionUUID->"fa25ef36-aac3-4cf8-a852-\
819e123487d8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<methane\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920893684528144*^9, 3.9208936883164577`*^9}},
 CellLabel->
  "In[2525]:=",ExpressionUUID->"46347aef-19a1-4a34-a647-fe1ad886252a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, {
                   0.27325081875000007`, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, \
{-0.27325081874999996`, -1.0945346930348155`*^-17}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, {
                   4.688735803243519*^-17, 0.2657286666666666}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, \
{-1.8197394182570268`*^-17, -0.2657286666666667}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False], 
                StyleBox[{
                  
                  LineBox[{{
                   0.27325081875000007`, -4.4408920985006264`*^-17}, {
                   0.5465016375, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{-0.27325081874999996`, \
-1.0945346930348155`*^-17}, {-0.5465016375, 2.2518227124309954`*^-17}}], 
                  
                  LineBox[{{4.688735803243519*^-17, 0.2657286666666666}, {
                   6.315854608618655*^-17, 0.5314573333333333}}], 
                  
                  LineBox[{{-1.8197394182570268`*^-17, -0.2657286666666667}, \
{-6.701095834382436*^-17, -0.5314573333333333}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.5952516375000001, -0.06979266666666673}, {
                    0.5952516375000001, 0.06979266666666663}, {
                    0.6137232291666668, 0.06979266666666663}, {
                    0.6137232291666668, 0.012473499999999957`}, {
                    0.6862769875000001, 0.012473499999999957`}, {
                    0.6862769875000001, 0.06979266666666663}, {
                    0.7047483625000001, 0.06979266666666663}, {
                    0.7047483625000001, -0.06979266666666673}, {
                    0.6862769875000001, -0.06979266666666673}, {
                    0.6862769875000001, -0.003999666666666721}, {
                    0.6137232291666668, -0.003999666666666721}, {
                    0.6137232291666668, -0.06979266666666673}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.7047483625, -0.06979266666666664}, \
{-0.7047483625, 0.06979266666666671}, {-0.6862767708333333, 
                    0.06979266666666671}, {-0.6862767708333333, 
                    0.01247350000000004}, {-0.6137230124999999, 
                    0.01247350000000004}, {-0.6137230124999999, 
                    0.06979266666666671}, {-0.5952516375, 
                    0.06979266666666671}, {-0.5952516375, \
-0.06979266666666664}, {-0.6137230124999999, -0.06979266666666664}, \
{-0.6137230124999999, -0.0039996666666666375`}, {-0.6862767708333333, \
-0.0039996666666666375`}, {-0.6862767708333333, -0.06979266666666664}}}]}}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.054748362499999925`, 
                    0.5802073333333334}, {-0.054748362499999925`, 
                    0.7197926666666667}, {-0.03627677083333326, 
                    0.7197926666666667}, {-0.03627677083333326, 0.6624735}, {
                    0.036276987500000066`, 0.6624735}, {0.036276987500000066`,
                     0.7197926666666667}, {0.054748362500000064`, 
                    0.7197926666666667}, {0.054748362500000064`, 
                    0.5802073333333334}, {0.036276987500000066`, 
                    0.5802073333333334}, {0.036276987500000066`, 
                    0.6460003333333334}, {-0.03627677083333326, 
                    0.6460003333333334}, {-0.03627677083333326, 
                    0.5802073333333334}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.05474836250000008, -0.7197926666666666}, \
{-0.05474836250000008, -0.5802073333333333}, {-0.036276770833333416`, \
-0.5802073333333333}, {-0.036276770833333416`, -0.6375265}, {
                    0.03627698749999991, -0.6375265}, {
                    0.03627698749999991, -0.5802073333333333}, {
                    0.05474836249999991, -0.5802073333333333}, {
                    0.05474836249999991, -0.7197926666666666}, {
                    0.03627698749999991, -0.7197926666666666}, {
                    0.03627698749999991, -0.6539996666666666}, \
{-0.036276770833333416`, -0.6539996666666666}, {-0.036276770833333416`, \
-0.7197926666666666}}}]}}, "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"H\"", "4"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["5", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, {
                   0.27325081875000007`, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, \
{-0.27325081874999996`, -1.0945346930348155`*^-17}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, {
                   4.688735803243519*^-17, 0.2657286666666666}}], 
                  
                  LineBox[{{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, \
{-1.8197394182570268`*^-17, -0.2657286666666667}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False], 
                StyleBox[{
                  
                  LineBox[{{
                   0.27325081875000007`, -4.4408920985006264`*^-17}, {
                   0.5465016375, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{-0.27325081874999996`, \
-1.0945346930348155`*^-17}, {-0.5465016375, 2.2518227124309954`*^-17}}], 
                  
                  LineBox[{{4.688735803243519*^-17, 0.2657286666666666}, {
                   6.315854608618655*^-17, 0.5314573333333333}}], 
                  
                  LineBox[{{-1.8197394182570268`*^-17, -0.2657286666666667}, \
{-6.701095834382436*^-17, -0.5314573333333333}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{
                   3.0616169978683824`*^-17, -4.4408920985006264`*^-17}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.5952516375000001, -0.06979266666666673}, {
                    0.5952516375000001, 0.06979266666666663}, {
                    0.6137232291666668, 0.06979266666666663}, {
                    0.6137232291666668, 0.012473499999999957`}, {
                    0.6862769875000001, 0.012473499999999957`}, {
                    0.6862769875000001, 0.06979266666666663}, {
                    0.7047483625000001, 0.06979266666666663}, {
                    0.7047483625000001, -0.06979266666666673}, {
                    0.6862769875000001, -0.06979266666666673}, {
                    0.6862769875000001, -0.003999666666666721}, {
                    0.6137232291666668, -0.003999666666666721}, {
                    0.6137232291666668, -0.06979266666666673}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.7047483625, -0.06979266666666664}, \
{-0.7047483625, 0.06979266666666671}, {-0.6862767708333333, 
                    0.06979266666666671}, {-0.6862767708333333, 
                    0.01247350000000004}, {-0.6137230124999999, 
                    0.01247350000000004}, {-0.6137230124999999, 
                    0.06979266666666671}, {-0.5952516375, 
                    0.06979266666666671}, {-0.5952516375, \
-0.06979266666666664}, {-0.6137230124999999, -0.06979266666666664}, \
{-0.6137230124999999, -0.0039996666666666375`}, {-0.6862767708333333, \
-0.0039996666666666375`}, {-0.6862767708333333, -0.06979266666666664}}}]}}, 
                 "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.054748362499999925`, 
                    0.5802073333333334}, {-0.054748362499999925`, 
                    0.7197926666666667}, {-0.03627677083333326, 
                    0.7197926666666667}, {-0.03627677083333326, 0.6624735}, {
                    0.036276987500000066`, 0.6624735}, {0.036276987500000066`,
                     0.7197926666666667}, {0.054748362500000064`, 
                    0.7197926666666667}, {0.054748362500000064`, 
                    0.5802073333333334}, {0.036276987500000066`, 
                    0.5802073333333334}, {0.036276987500000066`, 
                    0.6460003333333334}, {-0.03627677083333326, 
                    0.6460003333333334}, {-0.03627677083333326, 
                    0.5802073333333334}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.05474836250000008, -0.7197926666666666}, \
{-0.05474836250000008, -0.5802073333333333}, {-0.036276770833333416`, \
-0.5802073333333333}, {-0.036276770833333416`, -0.6375265}, {
                    0.03627698749999991, -0.6375265}, {
                    0.03627698749999991, -0.5802073333333333}, {
                    0.05474836249999991, -0.5802073333333333}, {
                    0.05474836249999991, -0.7197926666666666}, {
                    0.03627698749999991, -0.7197926666666666}, {
                    0.03627698749999991, -0.6539996666666666}, \
{-0.036276770833333416`, -0.6539996666666666}, {-0.036276770833333416`, \
-0.7197926666666666}}}]}}, "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"H\"", "4"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["5", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C([H])([H])([H])[H]\"", 
                   ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> 
                   Baseline, ContentPadding -> False, FrameMargins -> 0, 
                   StripOnInput -> True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"VNWKTOKETHGBQD-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"C", "H", "H", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{1, 3}, "Single"], 
    Bond[{1, 4}, "Single"], 
    Bond[{1, 5}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.920893689081354*^9},
 CellLabel->
  "Out[2525]=",ExpressionUUID->"b19fa91e-1556-4e4e-850e-3772b3356066"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"molecule", ",", 
   RowBox[{"Background", "->", "LightBlue"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}, {
  3.920893710306604*^9, 3.920893719195073*^9}},
 CellLabel->
  "In[2528]:=",ExpressionUUID->"337983e7-5aaf-4548-82eb-320dc7c23279"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{6.387486555091083*^-8, 2.6078537992665684`*^-8, 
    9.87211596623761*^-8}, {-0.13065963233326672`, -1.023187587268532, 
    0.35904667304720017`}, {-0.7135511490606314, 0.6562665584700349, 
    0.5030493014605593}, {1.017068057749894, 0.3344876961306995, 
    0.215848608425132}, {-0.17285803746810896`, 
    0.03243302192442482, -1.0779457592621065`}, {-0.06532978422920059, \
-0.511593780594997, 0.17952338588417993`}, {-0.3567755425928829, 
    0.32813329227428645`, 0.2515247000908594}, {0.5085340608123797, 
    0.16724386110461875`, 0.10792435357314584`}, {-0.08642898679662171, 
    0.016216524001481405`, -0.5389728302704734}}, {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{2, 3, 4, 5}, 0.24]}}, {{
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 6}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{6, 2}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 7}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{7, 3}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 8}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{8, 4}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 9}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{9, 5}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Background->RGBColor[0.87, 0.94, 1],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{2.9847364965247474`, 0.9294353643732481, -1.2852618214844571`},
  ViewVertical->{-0.9219968292641001, 
   0.28889250155858276`, -0.25780412985476053`}]], "Output",
 CellChangeTimes->{
  3.91985625493498*^9, 3.919856288982011*^9, 3.91985852984485*^9, 
   3.920041005584078*^9, 3.920141919249895*^9, 3.9203199577265787`*^9, {
   3.920893691198462*^9, 3.9208937198935204`*^9}},
 CellLabel->
  "Out[2528]=",ExpressionUUID->"f90abd00-4361-489c-b613-9df8e7d7aa5a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["CCl4", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.9203200052529173`*^9}, {3.92089367949266*^9, 
  3.920893680538644*^9}, {3.9208937767240334`*^9, 
  3.9208937773841*^9}},ExpressionUUID->"e485ed40-d75b-4312-9bd4-560934ea5179"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<carbon tetrachloride\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920893684528144*^9, 3.9208936883164577`*^9}, {
  3.9208937797061462`*^9, 3.920893789828518*^9}},
 CellLabel->
  "In[2530]:=",ExpressionUUID->"fdd8b27a-d422-45dc-aa2f-34afe99ef27a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.8013673666666666, -4.4408920985006264`*^-17}, {
                   0.4006836833333333, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{-0.40068368333333326`, 
                   4.6606780414675675`*^-18}, {-0.8013673666666666, 
                   5.3730277067941405`*^-17}}], 
                  
                  LineBox[{{6.410918071537218*^-17, 0.40698237499999995`}, {
                   8.902966385802908*^-17, 0.81396475}}], 
                  
                  LineBox[{{-3.5572751855255374`*^-17, \
-0.40698237500000006`}, {-1.1033420128322604`*^-16, -0.81396475}}]}, {
                  RGBColor[0.275132, 0.621793, 0.110932]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.4006836833333333, -4.4408920985006264`*^-17}, {
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, \
{-0.40068368333333326`, 4.6606780414675675`*^-18}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, {
                   6.410918071537218*^-17, 0.40698237499999995`}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, \
{-3.5572751855255374`*^-17, -0.40698237500000006`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Mk1cUB+BbgY7BwOBQrM4pgs4Rw0wvIkzZkUGYVYZTo7LBwnfLsMMw
2AcGpQgjFSR2KYO1AekiFoy1o5QWKMhF3RBr3w6nOIJKyKYN2/q2lzE7wcnW
fViS3eT3x5ObnJybc25o9uG9eV4IIY474M4id4ThVz6wKCnc8q+ZtYhVRFX1
zFa8eBq+/jR7eTOvlQQuL49mXBSONAfMirgdZH7aEmszU2ge3RBkre8iFdL9
3pJaCsm/HL+FerqJz+oJKy+Zwhy614jvmEhCSMcgfuKESa+SDKu4n3zVVF2E
khZsnNNPCaUOjxXmz6qwg4VEZ10oiukjaTXK08KPWYgwfl4ktPaQ0OFVS5SI
hcVHmy9Zco1kvHe1GqvtkFVQpM+zdZLaeyu6cL4dJHfN6/LVGrKVs+wyjrAD
8vZ/88/yM2TiQo4c+9uBznTEqd6WeyzJlBycyH8HnlqW2mb+/eQX8E8/kXZI
neV5JySo4fzmSi0uscPGnwN3N13TQu/auWPYZIcqlsPMtenhEkU+zCoWqHSg
3XzfCN+0NG5HLSxkvnHRFLeyF4ZTIsvwGge0tpbcrt/TB0Prpx4ItQ4Y+/f9
YDq3M1wpcHoc42cPUM4u+GRszowlicLghy2uQm4f8B1ZNcxxCumPtJH1sT1w
Q32okBmgsOGuz7ujYgMsHYD1yikKwYK+G1fLdDCPJ3QYTQPy6v816WY7pDRi
gbKOQlTElj27is+C3x/bvuSXPvUF4B3IuK5IozD/02Txq2d0kG4YemyJojAs
P+SX+5EeWoIjN6JACvVxLlWdwAC2Y29NCk1OCE7IEG3CRjjPOjcziQtuuCka
UVx0eBy/pvo5ZbIDxPndlfOvGKD1+/1bmGkWwvWifuXLeuCeWpeNGlkYfxLy
MDpMB5ve5xTggyyk+nw3VnRbA2E0p13Id+9LpSEx3ksNIcVDNkWA+34RPys0
8zTIZ7o68WP3fH943d+VLPMYHR4v9R1J9/iT7DSeyCYjD8OiYlCQu15J/NHr
TSoyKHnJpdjGgm/3nZXvNbT9t18syHjWtRyZlpBhUyHSsNB/6tq3+EcdyRys
KEe+DsjIXSqwNukJ6tkhQ7kOuL+jzpV3wECerd69THnVAdH472MkRyIaghi+
0+MK6RUpNix49LXa55kgCgVnw+RCroG4uMwLCCiMnvDex2g6yYpAy14sprC9
8MGSqH0d5LeylMtMDYVHpWMvjmjOkf//778Atmb4hQ==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1.0972659666666666`, -0.10737308333333337`}, {
                    1.0972659666666666`, 0.1073735833333333}, {
                    1.1236326333333335`, 0.1073735833333333}, {
                    1.1236326333333335`, -0.10737308333333337`}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, 
                   0.2]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd039Q03UYB/CNwZiR3WmUTroZ7igwj7iN8AdwH3FeQZpl+Ct/hM7tOySy
UNLjkhvBZZks6YYGOnDKj61zcfvBNmLog3X5YxsTNXEBlcnc4WTf7/dDNNsq
v60sdtfn7v3H65/nnuee55Mqfed1OYfFYrGjQdHERZNtr5qncJLQn/RJ2F2u
BQjRh5p/DoLxQ+ncFn47+K6w1fLZJLzbMjOs4Boh4SmiXlxGgvpG+ixPYzc8
INfdZ8ZJWHGv9jtWjx1C5yVSt4ICmvXD5+KRXnhzSjefYNMwxKks8ZT3gd6U
d5HZGnNHXOdhtyPm7nn2fD8PwzJKlcpa4oDrvWbj6pUYnrYdrSA8PUCn4JBZ
iSGhuuW8W2aDx4X0Ir8Bw8ayCovcb4bczybT/C4M5aPOtNJOA0iZKYE/gGGC
k/QKo2yDWRlrcogIhku/GPO1b6inzdpZs/HH0s3oP/ds0jnv1zehf/oZj9YL
8+Mlkk70nPxcuv9bDMsDj72qudyF2sna5f7TGD4NsgciOgs6+ZGyml+BIfLx
Ob3TZ0OCrO6flFkYyl4625uf8hXSeMcL/BQNXe2VQ41rHahlIknl1tNw++H8
SHhmOCjaErMvMiMs4sR8t34pn9hDgfO9k6HdXAfSCPPuySIkEL91ZTYu7UEl
5nShvJYE0WjCthvlVnSzrsbiyiRBUOS4evGACSU0STRNTBCSOX2TL17XI9nV
prddPhIKFy5eu2pvB5pIPHj2+EzqX3+JPMUFu9yFFPACt/YuazOhwqN7eMQx
Cq6p33pEts+Cvh5q0zFjFLTmh7SqIitS9d884l5Ag0BSosgS29DCGTx587aY
X3jSPUd8KuZbVF/Y/D0N+0rtdQ+et6LM5PUyfiKGTIui73iGBVUvCXqU2Rh8
f875NUdoQqVFzMvEuug+Eq55K4YMiEz0nHETGDbVWVcWcDpR5QXNo+IqDDVx
oh2p21vR4oMdzxC1GPS3VySFVjdMu6ZiuIo3uHXar0m38BX+BuCSd8aU+zFk
VRZUuzRa0KKJeMsODFO2kZRdx3QP72sVhgN8zwJ2QxecOnH6EpOBwXzk8hXx
mAkG56N+5nca1sueKPJoLMBqH7EzAzQMF6pC8g1W+CPPOyXS0LBI/PezwTeB
7P3NRMz9ua25RFrMG2rveuWjFGzvEKoJrhWSJ+UXmA8ocB2KLx4wmGFgTLG5
+VkKcnbfmZ1dbIS53J3vywIk+Kq8gkHDF/D///0XJyksYA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.9027340333333334, -0.10737308333333323`}, \
{-0.9027340333333334, 0.10737358333333344`}, {-0.8763673666666666, 
                    0.10737358333333344`}, {-0.8763673666666666, \
-0.10737308333333323`}}}]}}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd021MU3cUBvBLWYCJcSDJhiBkJo4EUQSugor01FpfSroxqhgwSGeLt5tx
MBjDEsPKlJUMHNKQFQoKMlhRKlhttcia/p1mpdOWkinhxQw7GIRpb3vvhiCW
2TE112QneT78vp2TPGeNuFB4xB/DML+lwFJYS7Gezs+uzWmHnSJpAr7ghuXp
Mh3+tw46hsviCbMbBv0mHZrRHsgUjGO4j4ReaNnan3sRBFNjacSnJKwPuVKN
fdYGqu8Lp3xBJOz9qcr4eUA9/C5641t1hwuwiV3yZ4eTUaU8dBNR7IKQo+sd
NDQwbtx/s0RZ1sk4WVv0QFKrQ+HcAa+v0QVru+OC7/IMKJVvT8SnXfDEHFq4
0WtEeR/apAROwrpElkM80IcMvyr5eDsJmrBYkdhsQluE7eXqzW5YM5fhOdxj
RjczNgZjVjcsU07kSzQIfSRb+TzpiIdxuPO7lKYAirH43LqHuJh6tY8Z3XW8
Gx5xlYILwukacZ4JZR6XTQjmKNjyKD4oP74PjUQPXpJvo+GvsqfDDaFGdGam
pktQQMOQ307vP4F6VHpf+0CvpKE4LDLNutiN0tOl76+6RkNTfXmbctUPiM2Z
n7JZaDBZu0p/tKkYY6uHM6wNfMaUeGBku14JufOfeAgdDTxLmuBKznlQeB5x
1adoWD1WYu8e7YRbhwaz7AdoOHtrvp8X1g1KQ2S57R0axmEyKtVfBy/utVBg
+7M4hq9vA+GNbw42aSmoY0HGBUHLSz+mgKMYGi6eVsH5FexOPIKGkJ6Dk+VE
NWy/oeEQKTRw2LG52dgxGJW8Nda4n4aK3c7He4ivUOLsFwG4hIbKdBY3h2hg
3Gg5uSCO6WDs9p5LESVrUVVp6oxPSIOTm7lLVaRDSScsWnUSDXeq7rkX9+jR
uDyzEF9Jg1w1ezl/9zUUV2ep1U9TMPGl03Tn2HUUcem9ZRE6CnhS2y8J9Ub0
prXy64oyCghJ9lFxTC+qDt4wgu947bOl0axNga/tWru53ybzQLYzj/38uBGZ
ZuL24nNu8C3c/iAh8jqq43EL1Ar3q34ZkDT6Hul72w0BfbHVi61XUdBAgEJ9
mwTs2WTgU/llVLLvt2TiNAmz8hLvHLqI/jgQvwPPIuHj1sDmPEU7Uv83W0kw
6LbZD2nUjHUPoxxR+pOMsSF2TZi9CPbVNG/ARSRwTpwiVlScgZ8LWrOILhJk
Cn/9/eXN8KLvT0ioa3Hwe3Pa4GW/3fD///4X3G0IuA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.09726596666666676, 0.8926269166666666}, {
                    0.09726596666666676, 1.1073735833333334`}, {
                    0.12363263333333346`, 1.1073735833333334`}, {
                    0.12363263333333346`, 0.8926269166666666}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd039Qk3UcB/CHoaGnFQPO4IwOruLCvImsw5DJ1x8gG5EQZ8gPYTngwYgO
Qa4ID1mScvFLd9QYoSCpY2LT4VA42vE2uRDbM0YnHnIaISiR7hl7cIc0lkXk
za7v3fuP11+fz+fu/Q2U5Sdmu1MU5bYQshDeQk5XZyXXppwi0gQmhy63wSEp
1gkf6YjAp3eKOWnDd24TZvXIeXJr5FgZTXH4ijSFX9t9lqTWeN2Nk3BY5tle
Se1rIZcE4uflBzhQP1R07n+ujngOlobrtQu2R5c59oQhcvPj+0wfh+TctWaO
1Lts2HmlSPFZq8vicwW3M2t1sI/68uR6DmHaN1cYozqQmeaXM1nNwQP8/HXz
nfh52I+JozmI1vPMsoFuqFdtSKMFHLq8g6WyHgPuJQm2CO/bIJyNn95zvgcB
yXsdfzXa8LJiPCtTDQz2zsrpd/9jMnTMODPtsujHti2qiOmn+/Qg94Mes7HR
iu7EySpZhgHp/BcjaG8rYh8IlmUJupFwVaqmqlgsKZkbrud3Ylww1Ua/yuI3
t23zf3ro4bNLI1bdsUDpvXpTv1OLvI/WZ5u+tqCnrrRF4XcGh8v4b9GFFiy5
3vbJ94zSZer14fj+eonLGtnALZFeQcT8tYGhzRYE9G2Ka085SewBa0pMcxbM
jRSZtCOt5ECUdGd2Ioviq4+vRXlryaiyf2nOIAuGTPhHuOvI4r2FVmh+LwyS
6FtIeo0l1qixQswj8Zq4pn/9hhVzh28OF04qyZXx8naVkYVcmzpRSleSipqL
B4UKFpQoeHcylUd2vH33nYEkFp4xYw9j6M/R9JLPo4bwhXmxvK0pdL3Lhr5D
f8iCTrvs5TyxQRp2DjNeX66jUlnMbH0vWlmgw/Hl+zXMNyzuVNywOmP0iKbS
Axtus1Ao7Reytl9C26+F46pQK+wHxww/5V0G09rx0NhsRVIOcz2krhNs/qz9
ycppFGcm58qCumCZOhOvKn3mfq/e+XrumSs/zj7esM2G3LGMyCefduLbFQ/S
Jr+wge/o3RGy+jK6fhkV6w22p/3qALNv1XK53Qbf7uBKZ/NFOFVOkfAVDq85
Jjzmyi5ge5LiHhPOwVdeND+Ls6gd2iul3+dQ3ezRmHHkFIT/vEwOTt1GU7q6
weXNY/5mf/0hl8duRFZ5mwrIro2hH9IJHHQl5fQL8qPkhDjkJrOGQ8gRd/3Q
ykay2PelHPKazJKulBay2G+TDf//338Dt3QsgA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.09726596666666651, -1.1073730833333333`}, {
                    0.09726596666666651, -0.8926264166666666}, {
                    0.12363263333333321`, -0.8926264166666666}, {
                    0.12363263333333321`, -1.1073730833333333`}}}]}}, "5"], 
                Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"Cl\"", "4"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["5", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.8013673666666666, -4.4408920985006264`*^-17}, {
                   0.4006836833333333, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{-0.40068368333333326`, 
                   4.6606780414675675`*^-18}, {-0.8013673666666666, 
                   5.3730277067941405`*^-17}}], 
                  
                  LineBox[{{6.410918071537218*^-17, 0.40698237499999995`}, {
                   8.902966385802908*^-17, 0.81396475}}], 
                  
                  LineBox[{{-3.5572751855255374`*^-17, \
-0.40698237500000006`}, {-1.1033420128322604`*^-16, -0.81396475}}]}, {
                  RGBColor[0.275132, 0.621793, 0.110932]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.4006836833333333, -4.4408920985006264`*^-17}, {
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, \
{-0.40068368333333326`, 4.6606780414675675`*^-18}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, {
                   6.410918071537218*^-17, 0.40698237499999995`}}], 
                  
                  LineBox[{{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, \
{-3.5572751855255374`*^-17, -0.40698237500000006`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Mk1cUB+BbgY7BwOBQrM4pgs4Rw0wvIkzZkUGYVYZTo7LBwnfLsMMw
2AcGpQgjFSR2KYO1AekiFoy1o5QWKMhF3RBr3w6nOIJKyKYN2/q2lzE7wcnW
fViS3eT3x5ObnJybc25o9uG9eV4IIY474M4id4ThVz6wKCnc8q+ZtYhVRFX1
zFa8eBq+/jR7eTOvlQQuL49mXBSONAfMirgdZH7aEmszU2ge3RBkre8iFdL9
3pJaCsm/HL+FerqJz+oJKy+Zwhy614jvmEhCSMcgfuKESa+SDKu4n3zVVF2E
khZsnNNPCaUOjxXmz6qwg4VEZ10oiukjaTXK08KPWYgwfl4ktPaQ0OFVS5SI
hcVHmy9Zco1kvHe1GqvtkFVQpM+zdZLaeyu6cL4dJHfN6/LVGrKVs+wyjrAD
8vZ/88/yM2TiQo4c+9uBznTEqd6WeyzJlBycyH8HnlqW2mb+/eQX8E8/kXZI
neV5JySo4fzmSi0uscPGnwN3N13TQu/auWPYZIcqlsPMtenhEkU+zCoWqHSg
3XzfCN+0NG5HLSxkvnHRFLeyF4ZTIsvwGge0tpbcrt/TB0Prpx4ItQ4Y+/f9
YDq3M1wpcHoc42cPUM4u+GRszowlicLghy2uQm4f8B1ZNcxxCumPtJH1sT1w
Q32okBmgsOGuz7ujYgMsHYD1yikKwYK+G1fLdDCPJ3QYTQPy6v816WY7pDRi
gbKOQlTElj27is+C3x/bvuSXPvUF4B3IuK5IozD/02Txq2d0kG4YemyJojAs
P+SX+5EeWoIjN6JACvVxLlWdwAC2Y29NCk1OCE7IEG3CRjjPOjcziQtuuCka
UVx0eBy/pvo5ZbIDxPndlfOvGKD1+/1bmGkWwvWifuXLeuCeWpeNGlkYfxLy
MDpMB5ve5xTggyyk+nw3VnRbA2E0p13Id+9LpSEx3ksNIcVDNkWA+34RPys0
8zTIZ7o68WP3fH943d+VLPMYHR4v9R1J9/iT7DSeyCYjD8OiYlCQu15J/NHr
TSoyKHnJpdjGgm/3nZXvNbT9t18syHjWtRyZlpBhUyHSsNB/6tq3+EcdyRys
KEe+DsjIXSqwNukJ6tkhQ7kOuL+jzpV3wECerd69THnVAdH472MkRyIaghi+
0+MK6RUpNix49LXa55kgCgVnw+RCroG4uMwLCCiMnvDex2g6yYpAy14sprC9
8MGSqH0d5LeylMtMDYVHpWMvjmjOkf//778Atmb4hQ==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    1.0972659666666666`, -0.10737308333333337`}, {
                    1.0972659666666666`, 0.1073735833333333}, {
                    1.1236326333333335`, 0.1073735833333333}, {
                    1.1236326333333335`, -0.10737308333333337`}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{
                   3.9188697572715296`*^-17, -4.4408920985006264`*^-17}, 
                   0.2]}, "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd039Q03UYB/CNwZiR3WmUTroZ7igwj7iN8AdwH3FeQZpl+Ct/hM7tOySy
UNLjkhvBZZks6YYGOnDKj61zcfvBNmLog3X5YxsTNXEBlcnc4WTf7/dDNNsq
v60sdtfn7v3H65/nnuee55Mqfed1OYfFYrGjQdHERZNtr5qncJLQn/RJ2F2u
BQjRh5p/DoLxQ+ncFn47+K6w1fLZJLzbMjOs4Boh4SmiXlxGgvpG+ixPYzc8
INfdZ8ZJWHGv9jtWjx1C5yVSt4ICmvXD5+KRXnhzSjefYNMwxKks8ZT3gd6U
d5HZGnNHXOdhtyPm7nn2fD8PwzJKlcpa4oDrvWbj6pUYnrYdrSA8PUCn4JBZ
iSGhuuW8W2aDx4X0Ir8Bw8ayCovcb4bczybT/C4M5aPOtNJOA0iZKYE/gGGC
k/QKo2yDWRlrcogIhku/GPO1b6inzdpZs/HH0s3oP/ds0jnv1zehf/oZj9YL
8+Mlkk70nPxcuv9bDMsDj72qudyF2sna5f7TGD4NsgciOgs6+ZGyml+BIfLx
Ob3TZ0OCrO6flFkYyl4625uf8hXSeMcL/BQNXe2VQ41rHahlIknl1tNw++H8
SHhmOCjaErMvMiMs4sR8t34pn9hDgfO9k6HdXAfSCPPuySIkEL91ZTYu7UEl
5nShvJYE0WjCthvlVnSzrsbiyiRBUOS4evGACSU0STRNTBCSOX2TL17XI9nV
prddPhIKFy5eu2pvB5pIPHj2+EzqX3+JPMUFu9yFFPACt/YuazOhwqN7eMQx
Cq6p33pEts+Cvh5q0zFjFLTmh7SqIitS9d884l5Ag0BSosgS29DCGTx587aY
X3jSPUd8KuZbVF/Y/D0N+0rtdQ+et6LM5PUyfiKGTIui73iGBVUvCXqU2Rh8
f875NUdoQqVFzMvEuug+Eq55K4YMiEz0nHETGDbVWVcWcDpR5QXNo+IqDDVx
oh2p21vR4oMdzxC1GPS3VySFVjdMu6ZiuIo3uHXar0m38BX+BuCSd8aU+zFk
VRZUuzRa0KKJeMsODFO2kZRdx3QP72sVhgN8zwJ2QxecOnH6EpOBwXzk8hXx
mAkG56N+5nca1sueKPJoLMBqH7EzAzQMF6pC8g1W+CPPOyXS0LBI/PezwTeB
7P3NRMz9ua25RFrMG2rveuWjFGzvEKoJrhWSJ+UXmA8ocB2KLx4wmGFgTLG5
+VkKcnbfmZ1dbIS53J3vywIk+Kq8gkHDF/D///0XJyksYA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.9027340333333334, -0.10737308333333323`}, \
{-0.9027340333333334, 0.10737358333333344`}, {-0.8763673666666666, 
                    0.10737358333333344`}, {-0.8763673666666666, \
-0.10737308333333323`}}}]}}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd021MU3cUBvBLWYCJcSDJhiBkJo4EUQSugor01FpfSroxqhgwSGeLt5tx
MBjDEsPKlJUMHNKQFQoKMlhRKlhttcia/p1mpdOWkinhxQw7GIRpb3vvhiCW
2TE112QneT78vp2TPGeNuFB4xB/DML+lwFJYS7Gezs+uzWmHnSJpAr7ghuXp
Mh3+tw46hsviCbMbBv0mHZrRHsgUjGO4j4ReaNnan3sRBFNjacSnJKwPuVKN
fdYGqu8Lp3xBJOz9qcr4eUA9/C5641t1hwuwiV3yZ4eTUaU8dBNR7IKQo+sd
NDQwbtx/s0RZ1sk4WVv0QFKrQ+HcAa+v0QVru+OC7/IMKJVvT8SnXfDEHFq4
0WtEeR/apAROwrpElkM80IcMvyr5eDsJmrBYkdhsQluE7eXqzW5YM5fhOdxj
RjczNgZjVjcsU07kSzQIfSRb+TzpiIdxuPO7lKYAirH43LqHuJh6tY8Z3XW8
Gx5xlYILwukacZ4JZR6XTQjmKNjyKD4oP74PjUQPXpJvo+GvsqfDDaFGdGam
pktQQMOQ307vP4F6VHpf+0CvpKE4LDLNutiN0tOl76+6RkNTfXmbctUPiM2Z
n7JZaDBZu0p/tKkYY6uHM6wNfMaUeGBku14JufOfeAgdDTxLmuBKznlQeB5x
1adoWD1WYu8e7YRbhwaz7AdoOHtrvp8X1g1KQ2S57R0axmEyKtVfBy/utVBg
+7M4hq9vA+GNbw42aSmoY0HGBUHLSz+mgKMYGi6eVsH5FexOPIKGkJ6Dk+VE
NWy/oeEQKTRw2LG52dgxGJW8Nda4n4aK3c7He4ivUOLsFwG4hIbKdBY3h2hg
3Gg5uSCO6WDs9p5LESVrUVVp6oxPSIOTm7lLVaRDSScsWnUSDXeq7rkX9+jR
uDyzEF9Jg1w1ezl/9zUUV2ep1U9TMPGl03Tn2HUUcem9ZRE6CnhS2y8J9Ub0
prXy64oyCghJ9lFxTC+qDt4wgu947bOl0axNga/tWru53ybzQLYzj/38uBGZ
ZuL24nNu8C3c/iAh8jqq43EL1Ar3q34ZkDT6Hul72w0BfbHVi61XUdBAgEJ9
mwTs2WTgU/llVLLvt2TiNAmz8hLvHLqI/jgQvwPPIuHj1sDmPEU7Uv83W0kw
6LbZD2nUjHUPoxxR+pOMsSF2TZi9CPbVNG/ARSRwTpwiVlScgZ8LWrOILhJk
Cn/9/eXN8KLvT0ioa3Hwe3Pa4GW/3fD///4X3G0IuA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.09726596666666676, 0.8926269166666666}, {
                    0.09726596666666676, 1.1073735833333334`}, {
                    0.12363263333333346`, 1.1073735833333334`}, {
                    0.12363263333333346`, 0.8926269166666666}}}]}}, "4"], 
                Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd039Qk3UcB/CHoaGnFQPO4IwOruLCvImsw5DJ1x8gG5EQZ8gPYTngwYgO
Qa4ID1mScvFLd9QYoSCpY2LT4VA42vE2uRDbM0YnHnIaISiR7hl7cIc0lkXk
za7v3fuP11+fz+fu/Q2U5Sdmu1MU5bYQshDeQk5XZyXXppwi0gQmhy63wSEp
1gkf6YjAp3eKOWnDd24TZvXIeXJr5FgZTXH4ijSFX9t9lqTWeN2Nk3BY5tle
Se1rIZcE4uflBzhQP1R07n+ujngOlobrtQu2R5c59oQhcvPj+0wfh+TctWaO
1Lts2HmlSPFZq8vicwW3M2t1sI/68uR6DmHaN1cYozqQmeaXM1nNwQP8/HXz
nfh52I+JozmI1vPMsoFuqFdtSKMFHLq8g6WyHgPuJQm2CO/bIJyNn95zvgcB
yXsdfzXa8LJiPCtTDQz2zsrpd/9jMnTMODPtsujHti2qiOmn+/Qg94Mes7HR
iu7EySpZhgHp/BcjaG8rYh8IlmUJupFwVaqmqlgsKZkbrud3Ylww1Ua/yuI3
t23zf3ro4bNLI1bdsUDpvXpTv1OLvI/WZ5u+tqCnrrRF4XcGh8v4b9GFFiy5
3vbJ94zSZer14fj+eonLGtnALZFeQcT8tYGhzRYE9G2Ka085SewBa0pMcxbM
jRSZtCOt5ECUdGd2Ioviq4+vRXlryaiyf2nOIAuGTPhHuOvI4r2FVmh+LwyS
6FtIeo0l1qixQswj8Zq4pn/9hhVzh28OF04qyZXx8naVkYVcmzpRSleSipqL
B4UKFpQoeHcylUd2vH33nYEkFp4xYw9j6M/R9JLPo4bwhXmxvK0pdL3Lhr5D
f8iCTrvs5TyxQRp2DjNeX66jUlnMbH0vWlmgw/Hl+zXMNyzuVNywOmP0iKbS
Axtus1Ao7Reytl9C26+F46pQK+wHxww/5V0G09rx0NhsRVIOcz2krhNs/qz9
ycppFGcm58qCumCZOhOvKn3mfq/e+XrumSs/zj7esM2G3LGMyCefduLbFQ/S
Jr+wge/o3RGy+jK6fhkV6w22p/3qALNv1XK53Qbf7uBKZ/NFOFVOkfAVDq85
Jjzmyi5ge5LiHhPOwVdeND+Ls6gd2iul3+dQ3ezRmHHkFIT/vEwOTt1GU7q6
weXNY/5mf/0hl8duRFZ5mwrIro2hH9IJHHQl5fQL8qPkhDjkJrOGQ8gRd/3Q
ykay2PelHPKazJKulBay2G+TDf//338Dt3QsgA==
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.09726596666666651, -1.1073730833333333`}, {
                    0.09726596666666651, -0.8926264166666666}, {
                    0.12363263333333321`, -0.8926264166666666}, {
                    0.12363263333333321`, -1.1073730833333333`}}}]}}, "5"], 
                Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"C\"", 
                    SubscriptBox["\"Cl\"", "4"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["5", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["4", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"ClC(Cl)(Cl)Cl\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"VZGDMQKNWNREIO-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"Cl", "C", "Cl", "Cl", "Cl"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{2, 3}, "Single"], 
    Bond[{2, 4}, "Single"], 
    Bond[{2, 5}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.919856245072597*^9, 3.91985628504918*^9, 3.919858528011428*^9, 
   3.920041003078997*^9, 3.920141916938754*^9, 3.9203199532058687`*^9, 
   3.920893689081354*^9, {3.920893783153366*^9, 3.920893790453102*^9}},
 CellLabel->
  "Out[2530]=",ExpressionUUID->"9650d375-486f-452a-885c-828416df314d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"molecule", ",", 
   RowBox[{"Background", "->", "LightBlue"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}, {
  3.920893710306604*^9, 3.920893719195073*^9}},
 CellLabel->
  "In[2531]:=",ExpressionUUID->"01e1039c-4cfa-4f7e-9024-593c7be87c0e"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{-1.0643939727629266`, 1.3972048768662053`, 
    0.29906929931620385`}, {
    2.2644844127175448`*^-9, -4.5928627984890895`*^-9, \
-1.4049972474731197`*^-9}, {1.4834767082432718`, 0.1644797387041208, 
    0.9730373733459565}, {-0.8464447336492776, -1.4998972745937393`, 
    0.45650620103487427`}, {
    0.4273619974017556, -0.06178733942058623, -1.7286128732210404`}, \
{-0.5321969852492211, 0.6986024361366713, 0.1495346489556033}, {
    0.7417383552538781, 0.08223986705562901, 
    0.48651868597047965`}, {-0.4232223656923966, -0.749948639593301, 
    0.2282530998149385}, {
    0.21368099983312, -0.030893672006724514`, -0.8643064373130188}}, {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{2}, 0.34]}, 
      {RGBColor[0.412698, 0.932689, 0.166398], 
       SphereBox[{1, 3, 4, 5}, 0.36000000000000004`]}}, {{
       {RGBColor[0.412698, 0.932689, 0.166398], CylinderBox[{1, 6}, 0.15]}, 
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{6, 2}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 7}, 0.15]}, 
       {RGBColor[0.412698, 0.932689, 0.166398], 
        CylinderBox[{7, 3}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 8}, 0.15]}, 
       {RGBColor[0.412698, 0.932689, 0.166398], 
        CylinderBox[{8, 4}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 9}, 0.15]}, 
       {RGBColor[0.412698, 0.932689, 0.166398], 
        CylinderBox[{9, 5}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Background->RGBColor[0.87, 0.94, 1],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{-0.6551105372810735, 2.051205481655748, 2.605338031037184},
  ViewVertical->{-0.7948853732199607, 
   0.08791980867428781, -0.6003560199445327}]], "Output",
 CellChangeTimes->{
  3.91985625493498*^9, 3.919856288982011*^9, 3.91985852984485*^9, 
   3.920041005584078*^9, 3.920141919249895*^9, 3.9203199577265787`*^9, {
   3.920893691198462*^9, 3.9208937198935204`*^9}, 3.920893793521089*^9},
 CellLabel->
  "Out[2531]=",ExpressionUUID->"849e4c98-3049-4482-805d-87f2b2664e6d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["HF", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331207`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 
  3.9203200052529163`*^9}},ExpressionUUID->"07a6a885-5b39-48f4-bc7e-\
6a79cfcb4134"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<hydrogen fluoride\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725863`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}},
 CellLabel->
  "In[1693]:=",ExpressionUUID->"dc223292-729b-473d-93cc-69a01485c682"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.19846400347948823`, -0.11458324583333329`}, \
{-0.0033189792123181627`, -0.001916213541666656}}]}, {
                  RGBColor[0.385641, 0.57026, 0.27257]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{-0.0033189792123181627`, -0.001916213541666656}, {
                   0.19182604505485187`, 0.11075081874999997`}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.386, 0.57, 0.273], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.32854176456327594`, -0.2322926666666666}, \
{-0.32854176456327594`, -0.09270733333333325}, {-0.23437474789660928`, \
-0.09270733333333325}, {-0.23437474789660928`, -0.10917941666666661`}, \
{-0.3100700645632759, -0.10917941666666661`}, {-0.3100700645632759, \
-0.1524076666666666}, {-0.24456219789660927`, -0.1524076666666666}, \
{-0.24456219789660927`, -0.16887953333333328`}, {-0.3100700645632759, \
-0.16887953333333328`}, {-0.3100700645632759, -0.2322926666666666}}}]}}, "1"],
                 Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.22670989372994257`, 
                    0.09270733333333328}, {0.22670989372994257`, 
                    0.23229266666666662`}, {0.24518148539660925`, 
                    0.23229266666666662`}, {0.24518148539660925`, 
                    0.17497349999999995`}, {0.31773524372994255`, 
                    0.17497349999999995`}, {0.31773524372994255`, 
                    0.23229266666666662`}, {0.33620661872994256`, 
                    0.23229266666666662`}, {0.33620661872994256`, 
                    0.09270733333333328}, {0.31773524372994255`, 
                    0.09270733333333328}, {0.31773524372994255`, 
                    0.15850033333333327`}, {0.24518148539660925`, 
                    0.15850033333333327`}, {0.24518148539660925`, 
                    0.09270733333333328}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"H\"", "\"F\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.19846400347948823`, -0.11458324583333329`}, \
{-0.0033189792123181627`, -0.001916213541666656}}]}, {
                  RGBColor[0.385641, 0.57026, 0.27257]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{-0.0033189792123181627`, -0.001916213541666656}, {
                   0.19182604505485187`, 0.11075081874999997`}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.386, 0.57, 0.273], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.32854176456327594`, -0.2322926666666666}, \
{-0.32854176456327594`, -0.09270733333333325}, {-0.23437474789660928`, \
-0.09270733333333325}, {-0.23437474789660928`, -0.10917941666666661`}, \
{-0.3100700645632759, -0.10917941666666661`}, {-0.3100700645632759, \
-0.1524076666666666}, {-0.24456219789660927`, -0.1524076666666666}, \
{-0.24456219789660927`, -0.16887953333333328`}, {-0.3100700645632759, \
-0.16887953333333328`}, {-0.3100700645632759, -0.2322926666666666}}}]}}, "1"],
                 Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.22670989372994257`, 
                    0.09270733333333328}, {0.22670989372994257`, 
                    0.23229266666666662`}, {0.24518148539660925`, 
                    0.23229266666666662`}, {0.24518148539660925`, 
                    0.17497349999999995`}, {0.31773524372994255`, 
                    0.17497349999999995`}, {0.31773524372994255`, 
                    0.23229266666666662`}, {0.33620661872994256`, 
                    0.23229266666666662`}, {0.33620661872994256`, 
                    0.09270733333333328}, {0.31773524372994255`, 
                    0.09270733333333328}, {0.31773524372994255`, 
                    0.15850033333333327`}, {0.24518148539660925`, 
                    0.15850033333333327`}, {0.24518148539660925`, 
                    0.09270733333333328}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"H\"", "\"F\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"F[H]\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"KRHYYFGTRYWZRS-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"F", "H"}, {
    Bond[{1, 2}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9},
 CellLabel->
  "Out[1693]=",ExpressionUUID->"faa10369-4267-4645-99d7-20e8aed7227b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1694]:=",ExpressionUUID->"2ed700e2-97dc-4bba-b2df-3b12c22f10cb"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{0.04965531140657797, 0., 0.}, {-0.935864688593422, 
    0., 0.}, {-0.443104688593422, 0., 0.}}, {{
      {RGBColor[0.578462, 0.85539, 0.408855], 
       SphereBox[{1}, 0.30000000000000004`]}, 
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{2}, 0.24]}}, {
      {RGBColor[0.578462, 0.85539, 0.408855], CylinderBox[{1, 3}, 0.15]}, 
      {RGBColor[0.65, 0.7, 0.7], CylinderBox[{3, 2}, 0.15]}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0, 0, 3.38},
  ViewVertical->{0.19942090832514256`, 0.41877310146525926`, 
   0.88592346780743}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265778`*^9},
 CellLabel->"Out[1694]=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>", "ImageResolution" -> \
144.],ExpressionUUID->"a14e3c84-97f4-4e56-828d-ec658ce16595"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cl2", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 
  3.920320027492169*^9}},ExpressionUUID->"430ae8c9-a66e-44f7-a843-\
f1e249f73b5a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<chlorine\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}},
 CellLabel->
  "In[1695]:=",ExpressionUUID->"90894a26-aea5-4dba-a00b-06faaf102810"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.260991795404953, -0.15068368333333326`}, {
                   0.260991795404953, 0.15068368333333326`}}]}, {
                  RGBColor[0.275132, 0.621793, 0.110932]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Q0wUcBvAB4jmPINyOulAOEbFjBsSaJmwKwYYI2fTwdI40mEBn1gJM
ByLSuQg1u7NA2JSIW3DLbSV2zYD0CebG3Asve4NtbPste5FOwbNSkZKo7PdH
37vnj8+fz93zXVkq3l4WRqFQQhayaSGhC6H3F6zIL3BDkv18h+wJG5IzMv7Q
1IxDy49QMI/bUH1LGMnzjqO4IueRLMQBrTQx5PuTEyhjbZEyVzuhTA4dr21y
Y6wvnkWZdqJtNKCmNXrAzrr/o0XrQlLcg3Lat17co/hambHj2EorCK9N9pHO
2nknRtPlJ117+YUAzRPAyBHREsqwC3PnzjhdIgJNb5adlzFdYO2JLFV4CLy0
tyKNKXOi7kDEMJUVxNndkwdkvQ6YN0d/R60O4kNh7yJrsx2xq2MuUXuCqH+t
c2pebINEYiSoo0FworxhctYY6cx5fk6KeYT0L3TV4pJpC64I5TNUTRDd785u
TBWboLqj1FMrgqjksm+1vWxEe1j679SVQWRQj8lC1xrQwmKI375CQNr/qUp+
+hrONDYzOWwChcWdCSVVOsR+OTdDOxTABY2+mbVzEPHz7y/XCPx48hF3tO36
ADbMDnbwVvlIZ77YYOHpvKTry83P5J3zYDn3otRYN4gfPh69mqtyY/i48ibr
hg77ez5P4fZP4Gb00W0t+XrsLhK8sow+gSphwlPns4egrQvEq78eB/ufvtdx
cOaELrrBDTHrEuM5hQnS4n2ii2P/2Yj83zx9tM0e/HkyylCaMgT2Yc4s74YH
T68zPbTmGpD2sGN9bb0X6UFp6gahHsGtl9dosidRtYdvqfjpGnZUSuqItT7S
DV1NeXmZftKMiMIR3ooADAWJVymv61HWrq4hbAHsT7J0pr9hAL918TJOLoGo
kIPv7XtrCEm9yUuXSgl015tPiExGMNcZzS4lAUaH7YvUYyZs+qrstMJKoAdu
+xzTAl364QEqQUCtaN1Ycs9KOq4gYmavYYR0kralsjxyDCWhDzI5JgKNKUqx
jGbD2a5F9YpPCAQOHVllvWt7vC8CaTpBIsVmR+urleGcVAK3RXd/tUgcuG0u
mqrpDiBGwP2I+bMD6knDUM20H+u3K47Kdjghz+rt563xw/L3feDEN/cZeoLv
I30hc8xFK5wkLdjGkPPEXuyaMn4my3bCnpb4Tm2fB9UJA0VMlQM8+rPtmnDP
v3unO+DdFRfIOeV+vG87/v/ffwFVgDHZ
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.3357467352255527, -0.3573730833333333}, \
{-0.3357467352255527, -0.1426264166666666}, {-0.309380068558886, \
-0.1426264166666666}, {-0.309380068558886, -0.3573730833333333}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd03tMU2cYBvBy2YY68cIls2UZTMWqqCBgdOoeJFYKw7kZMtgasU7aFbd1
yxbc2ME552WwFJeBTi5TGYtRWNMDE2VkQAoDirSFQs85LW0PtYcK0aALaFAy
tWuy7izZlzx//P77vvd9vrh3P9qrCBEIBEH+wJ9gf9LHCq5q48Yw/8j5LpPX
iIT9h6mM+26czp9sq5obwLg2p5v83o30pOIQ02MD6iI1QxHcGBLPvv+w6lov
dGrd3BdeFm9/23nWt7wHnf2W5dyEC18fXZKirOhGIvFbIdfkxKKnEkvVjS6E
nVIYiXQH7+h0fZvUYOft8hDTngob9oVt+dN3sBvyA+UrpZcY3FmRajBV/YEp
V+XzZCuNz3ckXaw29yBffy6FC6YxmJURb9b0Qf/c6Te4UxTc0vJZBdOPuD0n
PuDmU/C92pEgiDVCeeWlRZzJimOezEfGM2be8q9yx1RCC+/SosaSodLhf+6z
lMIaHJer+kfga82XcBcoSFhPWfKoFaKK7AnPGhpyIu3q09sU1q1/ZyZyhsa2
+g2NG9topGi+KSQeMLC/SaqHdjHYeqflpmfWBvHq86kKisGmGnGLNGIUswL2
XLLIhhfr7iaSmQ7eogOJoWSDk7d9461rumEXPmYvd9R2MfjkmZtLmrtYRHf+
skARzmBq8tn6pmb/Pj/bkZsqo/F4Z+6x8Tw3do6oHyTtp1AXM0xmtroD77WC
a4hf6J1isetW/KFC3QhGtmV/KKn911YsvERHcStYHH3l0Y+DKgrClz+16cpc
mPHWBFezFOIvLq4m7jlR8N121cG9NIqy5q5I1zrRY7EtM2loBIk350SlOXgz
91eV6ZJGea8tLwgi99ghdNyt871GY/qvkNyoGhv6p5aRygEK1w/9rCW8DA77
JB1mKYV5q2TtngIGjWnCrYM1VkwnxG6Rihiomn4Qq/QjgfnQWBkbER08MQxL
cvduTktDvL5FPhT6n9WO4jBLjIV3UyUVkzxuRuUZfR5hp3Gvnow1241Y/fpl
SreBwfal89oUwoFAvxjUFme3+mT9EI+Ze4lwG+I2i15QhhtQaJZNEn02WHYX
OauS+tDYfjus5Es7ymVtoeacXrTnPYwkJaMoUPrPRA8u/HRiQVSMg7d2n3vO
E+vk/STj5CbyiRNZ69TXTSW9OK7SyIhfXYj8/chb1Q19WHyyNFn6HhvouwFE
WsV0s4cN9PsG/v+//wbhQw89
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.5302786685588861, 0.1426269166666666}, {
                    0.5302786685588861, 0.35737358333333324`}, {
                    0.5566453352255527, 0.35737358333333324`}, {
                    0.5566453352255527, 0.1426269166666666}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"Cl\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{-0.260991795404953, -0.15068368333333326`}, {
                   0.260991795404953, 0.15068368333333326`}}]}, {
                  RGBColor[0.275132, 0.621793, 0.110932]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd031Q0wUcBvAB4jmPINyOulAOEbFjBsSaJmwKwYYI2fTwdI40mEBn1gJM
ByLSuQg1u7NA2JSIW3DLbSV2zYD0CebG3Asve4NtbPste5FOwbNSkZKo7PdH
37vnj8+fz93zXVkq3l4WRqFQQhayaSGhC6H3F6zIL3BDkv18h+wJG5IzMv7Q
1IxDy49QMI/bUH1LGMnzjqO4IueRLMQBrTQx5PuTEyhjbZEyVzuhTA4dr21y
Y6wvnkWZdqJtNKCmNXrAzrr/o0XrQlLcg3Lat17co/hambHj2EorCK9N9pHO
2nknRtPlJ117+YUAzRPAyBHREsqwC3PnzjhdIgJNb5adlzFdYO2JLFV4CLy0
tyKNKXOi7kDEMJUVxNndkwdkvQ6YN0d/R60O4kNh7yJrsx2xq2MuUXuCqH+t
c2pebINEYiSoo0FworxhctYY6cx5fk6KeYT0L3TV4pJpC64I5TNUTRDd785u
TBWboLqj1FMrgqjksm+1vWxEe1j679SVQWRQj8lC1xrQwmKI375CQNr/qUp+
+hrONDYzOWwChcWdCSVVOsR+OTdDOxTABY2+mbVzEPHz7y/XCPx48hF3tO36
ADbMDnbwVvlIZ77YYOHpvKTry83P5J3zYDn3otRYN4gfPh69mqtyY/i48ibr
hg77ez5P4fZP4Gb00W0t+XrsLhK8sow+gSphwlPns4egrQvEq78eB/ufvtdx
cOaELrrBDTHrEuM5hQnS4n2ii2P/2Yj83zx9tM0e/HkyylCaMgT2Yc4s74YH
T68zPbTmGpD2sGN9bb0X6UFp6gahHsGtl9dosidRtYdvqfjpGnZUSuqItT7S
DV1NeXmZftKMiMIR3ooADAWJVymv61HWrq4hbAHsT7J0pr9hAL918TJOLoGo
kIPv7XtrCEm9yUuXSgl015tPiExGMNcZzS4lAUaH7YvUYyZs+qrstMJKoAdu
+xzTAl364QEqQUCtaN1Ycs9KOq4gYmavYYR0kralsjxyDCWhDzI5JgKNKUqx
jGbD2a5F9YpPCAQOHVllvWt7vC8CaTpBIsVmR+urleGcVAK3RXd/tUgcuG0u
mqrpDiBGwP2I+bMD6knDUM20H+u3K47Kdjghz+rt563xw/L3feDEN/cZeoLv
I30hc8xFK5wkLdjGkPPEXuyaMn4my3bCnpb4Tm2fB9UJA0VMlQM8+rPtmnDP
v3unO+DdFRfIOeV+vG87/v/ffwFVgDHZ
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.3357467352255527, -0.3573730833333333}, \
{-0.3357467352255527, -0.1426264166666666}, {-0.309380068558886, \
-0.1426264166666666}, {-0.309380068558886, -0.3573730833333333}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}}}, CompressedData["
1:eJxd03tMU2cYBvBy2YY68cIls2UZTMWqqCBgdOoeJFYKw7kZMtgasU7aFbd1
yxbc2ME552WwFJeBTi5TGYtRWNMDE2VkQAoDirSFQs85LW0PtYcK0aALaFAy
tWuy7izZlzx//P77vvd9vrh3P9qrCBEIBEH+wJ9gf9LHCq5q48Yw/8j5LpPX
iIT9h6mM+26czp9sq5obwLg2p5v83o30pOIQ02MD6iI1QxHcGBLPvv+w6lov
dGrd3BdeFm9/23nWt7wHnf2W5dyEC18fXZKirOhGIvFbIdfkxKKnEkvVjS6E
nVIYiXQH7+h0fZvUYOft8hDTngob9oVt+dN3sBvyA+UrpZcY3FmRajBV/YEp
V+XzZCuNz3ckXaw29yBffy6FC6YxmJURb9b0Qf/c6Te4UxTc0vJZBdOPuD0n
PuDmU/C92pEgiDVCeeWlRZzJimOezEfGM2be8q9yx1RCC+/SosaSodLhf+6z
lMIaHJer+kfga82XcBcoSFhPWfKoFaKK7AnPGhpyIu3q09sU1q1/ZyZyhsa2
+g2NG9topGi+KSQeMLC/SaqHdjHYeqflpmfWBvHq86kKisGmGnGLNGIUswL2
XLLIhhfr7iaSmQ7eogOJoWSDk7d9461rumEXPmYvd9R2MfjkmZtLmrtYRHf+
skARzmBq8tn6pmb/Pj/bkZsqo/F4Z+6x8Tw3do6oHyTtp1AXM0xmtroD77WC
a4hf6J1isetW/KFC3QhGtmV/KKn911YsvERHcStYHH3l0Y+DKgrClz+16cpc
mPHWBFezFOIvLq4m7jlR8N121cG9NIqy5q5I1zrRY7EtM2loBIk350SlOXgz
91eV6ZJGea8tLwgi99ghdNyt871GY/qvkNyoGhv6p5aRygEK1w/9rCW8DA77
JB1mKYV5q2TtngIGjWnCrYM1VkwnxG6Rihiomn4Qq/QjgfnQWBkbER08MQxL
cvduTktDvL5FPhT6n9WO4jBLjIV3UyUVkzxuRuUZfR5hp3Gvnow1241Y/fpl
SreBwfal89oUwoFAvxjUFme3+mT9EI+Ze4lwG+I2i15QhhtQaJZNEn02WHYX
OauS+tDYfjus5Es7ymVtoeacXrTnPYwkJaMoUPrPRA8u/HRiQVSMg7d2n3vO
E+vk/STj5CbyiRNZ69TXTSW9OK7SyIhfXYj8/chb1Q19WHyyNFn6HhvouwFE
WsV0s4cN9PsG/v+//wbhQw89
                    "]]}, {
                   RGBColor[0.275, 0.622, 0.111], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}}}, {{{
                    0.5302786685588861, 0.1426269166666666}, {
                    0.5302786685588861, 0.35737358333333324`}, {
                    0.5566453352255527, 0.35737358333333324`}, {
                    0.5566453352255527, 0.1426269166666666}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"Cl\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"ClCl\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"KZBUYRJDOAKODT-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"Cl", "Cl"}, {
    Bond[{1, 2}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9},
 CellLabel->
  "Out[1695]=",ExpressionUUID->"c0d988d2-69f9-4808-9014-8cd4d5fd7552"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1696]:=",ExpressionUUID->"62c29ede-4f31-454d-8035-fed5c1be55f0"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{1.0099998729583306`, 0., 0.}, {-1.0099998729583306`,
     0., 0.}}, {
     {RGBColor[0.412698, 0.932689, 0.166398], 
      SphereBox[{1, 2}, 0.36000000000000004`]}, 
     {RGBColor[0.412698, 0.932689, 0.166398], CylinderBox[{1, 2}, 0.15]}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{1.1952155265318773`, -1.135108063759392, 2.9508286173082863`},
  ViewVertical->{0.04745104948889385, 0.4042186622381011, 
   0.9134307149427604}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9},
 CellLabel->
  "Out[1696]=",ExpressionUUID->"9e489792-9fc5-4056-b0ec-c9c117232e0f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<nitrogen\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725863`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}},
 CellLabel->
  "In[1697]:=",ExpressionUUID->"01a632e1-96e3-47e7-b3d3-0091b1ee8c18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"N#N\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"IJGRMHOSHXDMSA-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"N", "N"}, {
    Bond[{1, 2}, "Triple"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9},
 CellLabel->
  "Out[1697]=",ExpressionUUID->"cf699c3b-7e0a-495b-9071-fe230ec04a50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1698]:=",ExpressionUUID->"729a3816-de1e-4406-9da8-cfe08f817631"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{0.7299997943146732, 0., 0.}, {-0.7299997943146732, 
    0., 0.}, {0.7299997943146732, -0.21, 0.}, {-0.7299997943146732, -0.21, 
    0.}, {0.7299997943146732, 0.21, 0.}, {-0.7299997943146732, 0.21, 0.}}, {
     {RGBColor[0.291989, 0.437977, 0.888609], 
      SphereBox[{1, 2}, 0.32000000000000006`]}, {
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 2}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{3, 4}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{5, 6}, 0.06]}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0.023632724325042584`, -1.0353049259975033`, 
   3.2174501090997945`},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265778`*^9, 3.920320036357765*^9, 3.920320208600456*^9},
 CellLabel->
  "Out[1698]=",ExpressionUUID->"ec498353-2eee-4b9a-8a74-10d4a77f5908"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["He", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.920320027492169*^9}, {3.920889521996196*^9, 
  3.92088952220144*^9}},ExpressionUUID->"c43cea3f-bb97-4ed5-9ba5-\
29245aa88f03"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<helium\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.9208895256330976`*^9, 3.9208895266948967`*^9}},
 CellLabel->
  "In[2520]:=",ExpressionUUID->"be69fc12-d353-47a0-b11f-b092e8c1ae38"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.372, 0.444, 0.444], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.17351075, -0.1056155}, {-0.17351075, 
                    0.10913116666666667`}, {-0.14509291666666668`, 
                    0.10913116666666667`}, {-0.14509291666666668`, 
                    0.020947833333333332`}, {-0.03347175000000002, 
                    0.020947833333333332`}, {-0.03347175000000002, 
                    0.10913116666666667`}, {-0.00505425000000001, 
                    0.10913116666666667`}, {-0.00505425000000001, \
-0.1056155}, {-0.03347175000000002, -0.1056155}, {-0.03347175000000002, \
-0.004395499999999997}, {-0.14509291666666668`, -0.004395499999999997}, \
{-0.14509291666666668`, -0.1056155}}}]}, {
                   RGBColor[0.372, 0.444, 0.444], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQveD7MQGGOYfste6wxl7NWbNfgfPF6osSx+zPbQi8
lq+2bv85xpjFP7qP2s8/MXlJttrm/f9UV/oYth+x39Ys+JslYNv+GpGOjfFc
h+1XcS56xzxhx/5Jm7sE5/QetN9Xz7aO9cKu/SuKbgUX+e2333HonDrrh937
K7zjv+au2wXn1zj0Zmjc3gLnC5x2qDhus8He9f6p/xdVdu0XEEmNiVu20j5B
4vD67L5t+79M9Dihe3mRfXXg7njWH5v2X1hY8kfr8jz7vNa5/lwPVsP5CRu+
yq+5ORfOPzD32XeB9Iz9Br8uFpy6s8i+YHfcLKUDE+0P+DCGmRxeaS9wa8YR
N7cF9kv8Z8ieD9lgf0BiosaWNcvtX1x9ezPh3BZ7GYveW6/iV9tHzPIIy/bb
BeczRHDlTVy4H843aapSmP/3oL3Jy8WVb/cvt5/zzubjnLWH7Qu8L27/VL/A
ni36/8FZsUftA6L/vn5fP8neamLCqpmmx+wZVoR+aU+L2w/nnxFJcDWeA+fP
SF33896Zufv5JoSas5gcs39QavZkvuSC/TJ3pcNOGxyzr+C/UGu5eeH+D9P2
vbodsxbOF2huz7x/Z639hsK/u+2KV+1PWBMz1VB7g338HWML88kb9mvkFvae
T9lk3xuk/zTz2ab9X3TbWnPnbbG/seNf7HzLrftLXJm7r6Vst39fXLPFInnb
/g2bX8zl2rELzk/olIrvM9wL58Piu3T6xr4Le7ZC08sB+4Xn3vMxF2zZ73C4
I8s8/aD966+M0RbKm6Hp7ZD9JtbpC1kENu5HT48AWMlfuA==
                    "], {{0.05881408333333332, -0.012890833333333351`}, {
                    0.1456790833333333, -0.012890833333333351`}, {
                    0.1445074166666666, 0.0001945000000000141}, {0.14118575, 
                    0.010009500000000005`}, {0.13571741666666665`, 
                    0.016552833333333322`}, {0.1273190833333333, 
                    0.026709499999999997`}, {0.11643074999999997`, 
                    0.03178616666666667}, {0.10305241666666665`, 
                    0.03178616666666667}, {0.09094241666666669, 
                    0.03178616666666667}, {0.08076241666666667, 
                    0.027734499999999995`}, {0.07250908333333334, 
                    0.019627833333333317`}, {0.06425741666666662, 
                    0.011522833333333315`}, {0.05969241666666669, 
                    0.000682833333333327}, {
                    0.05881408333333332, -0.012890833333333351`}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"He\""}, "RowDefault"], "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["0", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.372, 0.444, 0.444], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.17351075, -0.1056155}, {-0.17351075, 
                    0.10913116666666667`}, {-0.14509291666666668`, 
                    0.10913116666666667`}, {-0.14509291666666668`, 
                    0.020947833333333332`}, {-0.03347175000000002, 
                    0.020947833333333332`}, {-0.03347175000000002, 
                    0.10913116666666667`}, {-0.00505425000000001, 
                    0.10913116666666667`}, {-0.00505425000000001, \
-0.1056155}, {-0.03347175000000002, -0.1056155}, {-0.03347175000000002, \
-0.004395499999999997}, {-0.14509291666666668`, -0.004395499999999997}, \
{-0.14509291666666668`, -0.1056155}}}]}, {
                   RGBColor[0.372, 0.444, 0.444], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}, {{0, 2, 0}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGDQAmIQveD7MQGGOYfste6wxl7NWbNfgfPF6osSx+zPbQi8
lq+2bv85xpjFP7qP2s8/MXlJttrm/f9UV/oYth+x39Ys+JslYNv+GpGOjfFc
h+1XcS56xzxhx/5Jm7sE5/QetN9Xz7aO9cKu/SuKbgUX+e2333HonDrrh937
K7zjv+au2wXn1zj0Zmjc3gLnC5x2qDhus8He9f6p/xdVdu0XEEmNiVu20j5B
4vD67L5t+79M9Dihe3mRfXXg7njWH5v2X1hY8kfr8jz7vNa5/lwPVsP5CRu+
yq+5ORfOPzD32XeB9Iz9Br8uFpy6s8i+YHfcLKUDE+0P+DCGmRxeaS9wa8YR
N7cF9kv8Z8ieD9lgf0BiosaWNcvtX1x9ezPh3BZ7GYveW6/iV9tHzPIIy/bb
BeczRHDlTVy4H843aapSmP/3oL3Jy8WVb/cvt5/zzubjnLWH7Qu8L27/VL/A
ni36/8FZsUftA6L/vn5fP8neamLCqpmmx+wZVoR+aU+L2w/nnxFJcDWeA+fP
SF33896Zufv5JoSas5gcs39QavZkvuSC/TJ3pcNOGxyzr+C/UGu5eeH+D9P2
vbodsxbOF2huz7x/Z639hsK/u+2KV+1PWBMz1VB7g338HWML88kb9mvkFvae
T9lk3xuk/zTz2ab9X3TbWnPnbbG/seNf7HzLrftLXJm7r6Vst39fXLPFInnb
/g2bX8zl2rELzk/olIrvM9wL58Piu3T6xr4Le7ZC08sB+4Xn3vMxF2zZ73C4
I8s8/aD966+M0RbKm6Hp7ZD9JtbpC1kENu5HT48AWMlfuA==
                    "], {{0.05881408333333332, -0.012890833333333351`}, {
                    0.1456790833333333, -0.012890833333333351`}, {
                    0.1445074166666666, 0.0001945000000000141}, {0.14118575, 
                    0.010009500000000005`}, {0.13571741666666665`, 
                    0.016552833333333322`}, {0.1273190833333333, 
                    0.026709499999999997`}, {0.11643074999999997`, 
                    0.03178616666666667}, {0.10305241666666665`, 
                    0.03178616666666667}, {0.09094241666666669, 
                    0.03178616666666667}, {0.08076241666666667, 
                    0.027734499999999995`}, {0.07250908333333334, 
                    0.019627833333333317`}, {0.06425741666666662, 
                    0.011522833333333315`}, {0.05969241666666669, 
                    0.000682833333333327}, {
                    0.05881408333333332, -0.012890833333333351`}}}]}}, "1"], 
                Annotation[#, 1, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"He\""}, "RowDefault"], "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["0", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"[He]\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"SWQJXJOGLNCZEY-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"He"}, {}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920889528247485*^9},
 CellLabel->
  "Out[2520]=",ExpressionUUID->"f9a8e69d-2523-47e2-8dd5-4e75b6812650"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"molecule", ",", 
   RowBox[{"Background", "->", "Gray"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}, {
  3.920889585226972*^9, 3.920889590040045*^9}},
 CellLabel->
  "In[2522]:=",ExpressionUUID->"df3e9348-c481-4ff7-94b0-f6942413d058"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[{{0., 0., 0.}}, {
     {RGBColor[0.836713, 1., 1.], SphereBox[{1}, 0.27999999999999997`]}, {}, 
     {Opacity[0.7]}}]},
  Background->GrayLevel[0.5],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0, 0, 3.38},
  ViewVertical->{-0.5815498502840886, -0.40415307989285243`, \
-0.706017039204916}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9, 3.920889531607506*^9, 
  3.920889590515196*^9},
 CellLabel->
  "Out[2522]=",ExpressionUUID->"5607b5ca-0845-4a11-82cf-2b0ac0bcd932"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<nitrogen\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}},
 CellLabel->
  "In[1697]:=",ExpressionUUID->"ccca9d9a-0130-4409-a70e-3d5ebfcf94f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"N#N\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"IJGRMHOSHXDMSA-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"N", "N"}, {
    Bond[{1, 2}, "Triple"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9},
 CellLabel->
  "Out[1697]=",ExpressionUUID->"64e2e8d7-3b5c-47b3-83dc-7e97958824c4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1698]:=",ExpressionUUID->"814919bc-9ebc-4f52-abdd-06ee1d3a4548"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{0.7299997943146732, 0., 0.}, {-0.7299997943146732, 
    0., 0.}, {0.7299997943146732, -0.21, 0.}, {-0.7299997943146732, -0.21, 
    0.}, {0.7299997943146732, 0.21, 0.}, {-0.7299997943146732, 0.21, 0.}}, {
     {RGBColor[0.291989, 0.437977, 0.888609], 
      SphereBox[{1, 2}, 0.32000000000000006`]}, {
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 2}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{3, 4}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{5, 6}, 0.06]}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0.023632724325042584`, -1.0353049259975033`, 
   3.2174501090997945`},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9, 3.920320208600456*^9},
 CellLabel->
  "Out[1698]=",ExpressionUUID->"994a4236-7089-4093-830b-be89f42f4fc2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ar", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.920320027492169*^9}, {3.920889521996196*^9, 
  3.92088952220144*^9}, {3.920889644998363*^9, 
  3.920889646282033*^9}},ExpressionUUID->"58d6cedf-ef78-4f5d-9ac4-\
55dd0ba761f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<argon\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.9208895256330976`*^9, 3.9208895266948967`*^9}, {3.92088967486572*^9, 
  3.9208896761289177`*^9}},
 CellLabel->
  "In[2523]:=",ExpressionUUID->"42cfa308-45dc-40d5-9110-afaac1334f4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.364, 0.563, 0.595], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{-0.15227056, -0.10737333333333335`}, \
{-0.06979977333333334, 0.10737333333333332`}, {-0.03918460666666666, 
                    0.10737333333333332`}, {
                    0.04870555999999998, -0.10737333333333335`}, {
                    0.016332226666666644`, -0.10737333333333335`}, \
{-0.008715940000000005, -0.04233433333333336}, {-0.09851077333333333, \
-0.04233433333333336}, {-0.12209477333333334`, -0.10737333333333335`}}, \
{{-0.09030760666666668, -0.019189666666666688`}, {-0.017504940000000024`, \
-0.019189666666666688`}, {-0.03991710666666669, 
                    0.04028333333333331}, {-0.04675294000000001, 
                    0.058349999999999985`}, {-0.05183110666666667, 
                    0.0731933333333333}, {-0.055151439999999996`, 
                    0.08481333333333335}, {-0.05788577333333335, 
                    0.07104499999999994}, {-0.061743273333333334`, 
                    0.05737333333333333}, {-0.06672360666666667, 
                    0.04379833333333333}}}]}, {
                   RGBColor[0.364, 0.563, 0.595], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4m1fTC7+Dd9o3ySoOPtize79MP6BiVJvT69Z
YT9FREVdM3s7Bt/gQIP3W6OZ9rOc5Yx+f99hv0KtYxe/wyL7qJdTTuen7bLf
4LXBYs7PpfbLljj8zdq2235O33GekGPL7T/Fv9FLY9tr/2JK7lnnySvtuTgq
17FW7LNfc9XwYHPlKvuHc88fmsZ6AM7v36zZdlLjIJwfW3ti7qmAQ/Z/7uw9
GcO20t7992rOWbWH7Re8vnqLT2GZva8BUz1zyCF7A2MQmGxvvu7pq0sNB+1v
/Fkj3yE53b69emn0lLUH7DmWVDS94plp/+iTYP/xLfvh/KApWlf1rPfB+euu
ZezleLHH/kJKb1WH23T7QxGtgZa7d9uvSJw5MWTnZPtbtxY+zezbZW/x+FDj
BJ0J9peWehcw7Nhp/+CvcYFuQ5v9up1NH/+Y77R3WNvHKXem2L4kPHTz9/Id
9go7r8d4zCraH7XMTuSr+A57B6Hjy9/69MH5M54bL7jXMwvOh8UPAP0g2gg=

                    "]]}}, "1"], Annotation[#, 1, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Ar\""}, "RowDefault"], "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["0", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.364, 0.563, 0.595], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}}, {{0, 2, 0}, {0, 1, 
                    0}, {1, 3, 3}, {1, 3, 
                    3}}}, {{{-0.15227056, -0.10737333333333335`}, \
{-0.06979977333333334, 0.10737333333333332`}, {-0.03918460666666666, 
                    0.10737333333333332`}, {
                    0.04870555999999998, -0.10737333333333335`}, {
                    0.016332226666666644`, -0.10737333333333335`}, \
{-0.008715940000000005, -0.04233433333333336}, {-0.09851077333333333, \
-0.04233433333333336}, {-0.12209477333333334`, -0.10737333333333335`}}, \
{{-0.09030760666666668, -0.019189666666666688`}, {-0.017504940000000024`, \
-0.019189666666666688`}, {-0.03991710666666669, 
                    0.04028333333333331}, {-0.04675294000000001, 
                    0.058349999999999985`}, {-0.05183110666666667, 
                    0.0731933333333333}, {-0.055151439999999996`, 
                    0.08481333333333335}, {-0.05788577333333335, 
                    0.07104499999999994}, {-0.061743273333333334`, 
                    0.05737333333333333}, {-0.06672360666666667, 
                    0.04379833333333333}}}]}, {
                   RGBColor[0.364, 0.563, 0.595], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {0, 1, 0}}}, CompressedData["
1:eJxTTMoPSmVmYGBgBGJpIGYC4m1fTC7+Dd9o3ySoOPtize79MP6BiVJvT69Z
YT9FREVdM3s7Bt/gQIP3W6OZ9rOc5Yx+f99hv0KtYxe/wyL7qJdTTuen7bLf
4LXBYs7PpfbLljj8zdq2235O33GekGPL7T/Fv9FLY9tr/2JK7lnnySvtuTgq
17FW7LNfc9XwYHPlKvuHc88fmsZ6AM7v36zZdlLjIJwfW3ti7qmAQ/Z/7uw9
GcO20t7992rOWbWH7Re8vnqLT2GZva8BUz1zyCF7A2MQmGxvvu7pq0sNB+1v
/Fkj3yE53b69emn0lLUH7DmWVDS94plp/+iTYP/xLfvh/KApWlf1rPfB+euu
ZezleLHH/kJKb1WH23T7QxGtgZa7d9uvSJw5MWTnZPtbtxY+zezbZW/x+FDj
BJ0J9peWehcw7Nhp/+CvcYFuQ5v9up1NH/+Y77R3WNvHKXem2L4kPHTz9/Id
9go7r8d4zCraH7XMTuSr+A57B6Hjy9/69MH5M54bL7jXMwvOh8UPAP0g2gg=

                    "]]}}, "1"], Annotation[#, 1, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Ar\""}, "RowDefault"], "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["0", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"[Ar]\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"XKRFYHLGVUSROY-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"Ar"}, {}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920889528247485*^9, 
  3.9208896766262283`*^9},
 CellLabel->
  "Out[2523]=",ExpressionUUID->"7e2a4416-34bc-4004-a2d6-bacd397ed458"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", 
  RowBox[{"molecule", ",", 
   RowBox[{"Background", "->", "Gray"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}, {
  3.920889585226972*^9, 3.920889590040045*^9}},
 CellLabel->
  "In[2524]:=",ExpressionUUID->"b790d6f2-88ff-4725-be8b-7e2f34676bbe"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[{{0., 0., 0.}}, {
     {RGBColor[0.546138, 0.844244, 0.892092], SphereBox[{1}, 0.376]}, {}, 
     {Opacity[0.7]}}]},
  Background->GrayLevel[0.5],
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0, 0, 3.38},
  ViewVertical->{-0.5815498502840886, -0.40415307989285243`, \
-0.706017039204916}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9, 3.920889531607506*^9, 
  3.920889590515196*^9, 3.9208896790337877`*^9},
 CellLabel->
  "Out[2524]=",ExpressionUUID->"00d584c5-a59c-47ff-8513-7cd94b0ad5ac"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["N2", "Section",
 CellChangeTimes->{{3.920889666369919*^9, 
  3.920889668186501*^9}},ExpressionUUID->"3afc6e9d-9ae9-4630-a401-\
08403b7aa952"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<nitrogen\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}},
 CellLabel->
  "In[1697]:=",ExpressionUUID->"40abc8a8-8253-4cab-ba0d-9b37e820de79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.34040491666666667`, 8.337515832197097*^-17}, {
                   0.34040491666666667`, -8.337515832197097*^-17}}, \
{{-0.34040491666666667`, 0.09600000000000009}, {0.34040491666666667`, 
                   0.09599999999999992}}, {{-0.34040491666666667`, \
-0.09599999999999992}, {0.34040491666666667`, -0.09600000000000009}}}]}, {
                  RGBColor[0.291989, 0.437977, 0.888609]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{-0.5845950833333333, -0.10737333333333324`}, \
{-0.5845950833333333, 0.10737333333333343`}, {-0.5554445833333334, 
                    0.10737333333333343`}, {-0.4426515833333333, \
-0.061230833333333234`}, {-0.4426515833333333, 
                    0.10737333333333343`}, {-0.4154049166666667, 
                    0.10737333333333343`}, {-0.4154049166666667, \
-0.10737333333333324`}, {-0.4445559166666667, -0.10737333333333324`}, \
{-0.5573489166666666, 
                    0.061376666666666746`}, {-0.5573489166666666, \
-0.10737333333333324`}}}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.292, 0.438, 0.889], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}}}, {{{0.4154049166666667, -0.10737333333333346`}, {
                    0.4154049166666667, 0.10737333333333321`}, {
                    0.44455541666666665`, 0.10737333333333321`}, {
                    0.5573484166666667, -0.061230833333333456`}, {
                    0.5573484166666667, 0.10737333333333321`}, {
                    0.5845950833333333, 0.10737333333333321`}, {
                    0.5845950833333333, -0.10737333333333346`}, {
                    0.5554440833333333, -0.10737333333333346`}, {
                    0.44265108333333336`, 0.061376666666666524`}, {
                    0.44265108333333336`, -0.10737333333333346`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"N\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"N#N\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"IJGRMHOSHXDMSA-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"N", "N"}, {
    Bond[{1, 2}, "Triple"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9},
 CellLabel->
  "Out[1697]=",ExpressionUUID->"4a2d5609-2f31-43ea-81f3-9318bf679587"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1698]:=",ExpressionUUID->"f1c597f4-3b81-4735-aa8b-d2e46810a2d3"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{0.7299997943146732, 0., 0.}, {-0.7299997943146732, 
    0., 0.}, {0.7299997943146732, -0.21, 0.}, {-0.7299997943146732, -0.21, 
    0.}, {0.7299997943146732, 0.21, 0.}, {-0.7299997943146732, 0.21, 0.}}, {
     {RGBColor[0.291989, 0.437977, 0.888609], 
      SphereBox[{1, 2}, 0.32000000000000006`]}, {
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{1, 2}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{3, 4}, 0.06]}, 
      {RGBColor[0.291989, 0.437977, 0.888609], CylinderBox[{5, 6}, 0.06]}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0.023632724325042584`, -1.0353049259975033`, 
   3.2174501090997945`},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9, 3.920320208600456*^9},
 CellLabel->
  "Out[1698]=",ExpressionUUID->"cc477f1a-4ee8-4199-b3d7-e20ec4d749bd"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["O2", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.9198585129844513`*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331207`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.920320027492169*^9}, {3.9203202016100597`*^9, 
  3.9203202020830107`*^9}, {3.920320268550074*^9, 
  3.920320268866459*^9}},ExpressionUUID->"8509ae6f-dcf3-4edb-b8a5-\
54a5652a2618"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<oxygen\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918858`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.9198585260709257`*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725863`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}, {3.920320270978395*^9, 
  3.9203202724686193`*^9}},
 CellLabel->
  "In[1699]:=",ExpressionUUID->"148ed65d-d909-4e61-b546-662b7c3768b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.30913237901987706`, -0.1091956299396003}, {
                   0.2491323790198771, 
                   0.21311867839373294`}}, {{-0.2491323790198771, \
-0.21311867839373294`}, {0.30913237901987706`, 0.1091956299396003}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQnRkr/bVA5eH+qo1c687oXdgP43tHFudOPXt6//It
azO4rj3Yf/+sQ5Ch9Yn9scf+3LO1fLB/3YFartxlR/fLb1n0/aHF/f3PmKYf
nyV4eP+Ua8k+okvu7mdYorzM8PjB/QI/3DlFt9yG89l2pZd45N+C87/t84+s
9rq5X0Q8akN60qH9bJ9PmG10vbHf4u+xI5dnHN7/0q7l0SOH6/uPGAncMzx/
ZL9jMO9/8apr+/l+vExlbDi2/1D4pT7Pj1f3188xSDRZfWK/S8x0ueqMq/s/
OJTHpF87tb/lXuUzYZWr+39mz6/+430WzpdIf3aHge0CnK/6pHne2ayL+6Me
n7ormnN1f8nHJUUMqy7t3yly+5zQn6v7+brteGYdvrw/Ra52r1jPtf0rVG4s
Nb57Zb/fJKPLghHX93faeO5K23R1v4CiPLdQwo39u8+1/TF2vrb/4/z7fKIZ
N/c/TTnfzXDl2n47Hu5PD1tu7f+n+04nXeb6fomw0obqbbfh/C7LyhXrGO/C
+e7celHrNO/tr+3rF0s/c21/6PEOj2q9+/ur/S+9TNO5tn/TwULpJZIP9lcK
iO5N6wG6U1rkfEHNg/1mDRNXMWy6sv/Q26USS/Y/2L96UdB/47mX95cdME+6
zvRwv8RJuYVpHZfg8S1w6rfFrOSL+9HTAwCIdCwF
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ7c+16EOByYP9y/cX6jCZXdgP44fMtKlguHdxf96E
5S8ffru/X3Oy1C0Gncv7+Tvyfj0Uur+fda95G4PClf0b6k25H+nd2//oWYgR
g8jV/VHPfkx6KHB3/5WfdxMZ+q7ul9+y6PvDHbfh/Oo7Giero27B+XJP990U
sbq5/9FWi4CzQlf3a+yz+Lo+/Mb+f7rvdNJlruxXmX9ilWfp9f3Cq9aFMahd
3l+9+DibMMv1/TLuM3+lnbgI53PxHtk0k/kCnP8pLLY969TZ/VUr7hnWmlzf
byPJGZV37fR+3VtVXV5Tr++P3JD+yED71P4H3OKPxb9d38/342UqY8OJ/Rb3
f8asa76x/8GHpo4rJsf3N+hs/Spid3O/2Ss+/zmex/afqCzoq/5xc3/P41mi
KXFH93t5vW5bd/LW/qYdRd/OvTiyn2uW1KR1G2/D+UpTQkU9ft+B8wvOp4g9
Eru33+Z/gLPe6aP7nwTH6Vez3N/vbmt441f/8f0JV3x+i3y6vz+wWjD3eMhJ
eHwET/w+/ZTHmf3o8QUAfzz9Aw==
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ3Xqv8pmwylV7trmvFqctOm8P40cEu3maSl6y5zAI
/f/gwFV7vpn3w9IfXbafw7NdqOrXNftl8gerTupctTd/yntT2OSGfVedyRyj
8mv2hw75tDw4cdP+n+47nXSZ6/ZuCzOOP9hxG84PuO8Rs/bvHTg/4VZCeZXS
PfuSL5fUz5y7Zh+w7PlMF/X79kmNc2SnGV+zN9MVK+cUe2A/59l3gfQZV+25
Fl98kVf5wP4bM7fv//1X7E8pvFe4tveB/b6N6edTV12275zHE2nL9NC+Lf5I
4Jkpl+wzY6W/Fqg8tGf0MjjEGHURzj9laOz27/N5OH+j+Y9DKVpn7f/dKvqZ
z/DQXkh2m9T/1afs/Q69aijc8cD+wcum56crTthX7p3ZmV/wwH7NNv8tM1yP
2bcw7/9XyPXA/kVbbrfR7CP2bhUTjz7muW/fmvSJbUblYfvUnxcOPmC5Z29g
lvjiX/ghe4nepfeEX9yx/79YeZnh8YP2ds7WAVXbbsP5Z+LNNdyzb8H5/H1N
Ze7ON+0ZHj+4ZJh+yJ7xknpHld0Ne5bEaB2j5YftP4menbnW8ro9x/2rrUbP
j9hbJ3cYiZRcs+/7f2fVv9nH7C/vTZm/9u1V+yW7ohhnHD1hnyXhyOOeftX+
dO6hvUbvT8Hj+042R99pi7P26OkBAPs+FU8=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaMl570wy3X7tQ0yy39PPm8P4wedbeP/73zG/gUH
53Phsuv2q26e8v63/KS9u6DTNeGoG/YfWyd8/rf/uP0yyeqjwnY37S2Mwmb/
v37U/s+m7bYiMbfsQ3hcbP4/PmJv/pT3pvCW23D+7T3t7FVCd+F8iy0fvz0w
umdvMaUvPvXWUXu92+W3XUXv2/9frLzM8Phxe6Nfz1XXfL9vf3X1oqD/m0/a
v6v6klJo8sD+cOFZLqP8M3D+86fls878OA/nt4QE7jklddE+70eGv43MA/uE
4t+XTohcstfcb+q2+vp9+4vqZ/rSX12yL+ud+fZu2X37b8zcvv/3X7aX27Wt
2P3lPfu+9n27p6Zesb+W8/vWA7179o+6Km4Y3r5i3yfv4FRVctfeos/o69mA
q/Y8/kc93Rffsd+z+FjLjO6r9j7/p9q5774N55uwRu9eW3gLzn920nuXcNhN
+4SG8HsZUlfti1yDFlZl3LCPSnw+mcniiv23I8lXH1Rdtw91KvecE3oZHh8h
5ixbZt2+aI8eXwCGEe4B
                    "]}]}}, "2"], Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{{-0.30913237901987706`, -0.1091956299396003}, {
                   0.2491323790198771, 
                   0.21311867839373294`}}, {{-0.2491323790198771, \
-0.21311867839373294`}, {0.30913237901987706`, 0.1091956299396003}}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQnRkr/bVA5eH+qo1c687oXdgP43tHFudOPXt6//It
azO4rj3Yf/+sQ5Ch9Yn9scf+3LO1fLB/3YFartxlR/fLb1n0/aHF/f3PmKYf
nyV4eP+Ua8k+okvu7mdYorzM8PjB/QI/3DlFt9yG89l2pZd45N+C87/t84+s
9rq5X0Q8akN60qH9bJ9PmG10vbHf4u+xI5dnHN7/0q7l0SOH6/uPGAncMzx/
ZL9jMO9/8apr+/l+vExlbDi2/1D4pT7Pj1f3188xSDRZfWK/S8x0ueqMq/s/
OJTHpF87tb/lXuUzYZWr+39mz6/+430WzpdIf3aHge0CnK/6pHne2ayL+6Me
n7ormnN1f8nHJUUMqy7t3yly+5zQn6v7+brteGYdvrw/Ra52r1jPtf0rVG4s
Nb57Zb/fJKPLghHX93faeO5K23R1v4CiPLdQwo39u8+1/TF2vrb/4/z7fKIZ
N/c/TTnfzXDl2n47Hu5PD1tu7f+n+04nXeb6fomw0obqbbfh/C7LyhXrGO/C
+e7celHrNO/tr+3rF0s/c21/6PEOj2q9+/ur/S+9TNO5tn/TwULpJZIP9lcK
iO5N6wG6U1rkfEHNg/1mDRNXMWy6sv/Q26USS/Y/2L96UdB/47mX95cdME+6
zvRwv8RJuYVpHZfg8S1w6rfFrOSL+9HTAwCIdCwF
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQ7c+16EOByYP9y/cX6jCZXdgP44fMtKlguHdxf96E
5S8ffru/X3Oy1C0Gncv7+Tvyfj0Uur+fda95G4PClf0b6k25H+nd2//oWYgR
g8jV/VHPfkx6KHB3/5WfdxMZ+q7ul9+y6PvDHbfh/Oo7Giero27B+XJP990U
sbq5/9FWi4CzQlf3a+yz+Lo+/Mb+f7rvdNJlruxXmX9ilWfp9f3Cq9aFMahd
3l+9+DibMMv1/TLuM3+lnbgI53PxHtk0k/kCnP8pLLY969TZ/VUr7hnWmlzf
byPJGZV37fR+3VtVXV5Tr++P3JD+yED71P4H3OKPxb9d38/342UqY8OJ/Rb3
f8asa76x/8GHpo4rJsf3N+hs/Spid3O/2Ss+/zmex/afqCzoq/5xc3/P41mi
KXFH93t5vW5bd/LW/qYdRd/OvTiyn2uW1KR1G2/D+UpTQkU9ft+B8wvOp4g9
Eru33+Z/gLPe6aP7nwTH6Vez3N/vbmt441f/8f0JV3x+i3y6vz+wWjD3eMhJ
eHwET/w+/ZTHmf3o8QUAfzz9Aw==
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQ3Xqv8pmwylV7trmvFqctOm8P40cEu3maSl6y5zAI
/f/gwFV7vpn3w9IfXbafw7NdqOrXNftl8gerTupctTd/yntT2OSGfVedyRyj
8mv2hw75tDw4cdP+n+47nXSZ6/ZuCzOOP9hxG84PuO8Rs/bvHTg/4VZCeZXS
PfuSL5fUz5y7Zh+w7PlMF/X79kmNc2SnGV+zN9MVK+cUe2A/59l3gfQZV+25
Fl98kVf5wP4bM7fv//1X7E8pvFe4tveB/b6N6edTV12275zHE2nL9NC+Lf5I
4Jkpl+wzY6W/Fqg8tGf0MjjEGHURzj9laOz27/N5OH+j+Y9DKVpn7f/dKvqZ
z/DQXkh2m9T/1afs/Q69aijc8cD+wcum56crTthX7p3ZmV/wwH7NNv8tM1yP
2bcw7/9XyPXA/kVbbrfR7CP2bhUTjz7muW/fmvSJbUblYfvUnxcOPmC5Z29g
lvjiX/ghe4nepfeEX9yx/79YeZnh8YP2ds7WAVXbbsP5Z+LNNdyzb8H5/H1N
Ze7ON+0ZHj+4ZJh+yJ7xknpHld0Ne5bEaB2j5YftP4menbnW8ro9x/2rrUbP
j9hbJ3cYiZRcs+/7f2fVv9nH7C/vTZm/9u1V+yW7ohhnHD1hnyXhyOOeftX+
dO6hvUbvT8Hj+042R99pi7P26OkBAPs+FU8=
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQvaMl570wy3X7tQ0yy39PPm8P4wedbeP/73zG/gUH
53Phsuv2q26e8v63/KS9u6DTNeGoG/YfWyd8/rf/uP0yyeqjwnY37S2Mwmb/
v37U/s+m7bYiMbfsQ3hcbP4/PmJv/pT3pvCW23D+7T3t7FVCd+F8iy0fvz0w
umdvMaUvPvXWUXu92+W3XUXv2/9frLzM8Phxe6Nfz1XXfL9vf3X1oqD/m0/a
v6v6klJo8sD+cOFZLqP8M3D+86fls878OA/nt4QE7jklddE+70eGv43MA/uE
4t+XTohcstfcb+q2+vp9+4vqZ/rSX12yL+ud+fZu2X37b8zcvv/3X7aX27Wt
2P3lPfu+9n27p6Zesb+W8/vWA7179o+6Km4Y3r5i3yfv4FRVctfeos/o69mA
q/Y8/kc93Rffsd+z+FjLjO6r9j7/p9q5774N55uwRu9eW3gLzn920nuXcNhN
+4SG8HsZUlfti1yDFlZl3LCPSnw+mcniiv23I8lXH1Rdtw91KvecE3oZHh8h
5ixbZt2+aI8eXwCGEe4B
                    "]}]}}, "2"], Annotation[#, 2, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"O\"", "2"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["1", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"O=O\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"MYMOFIZGZYHOMD-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"O", "O"}, {
    Bond[{1, 2}, "Double"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.9200410030789967`*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9, 
  3.920320273011877*^9},
 CellLabel->
  "Out[1699]=",ExpressionUUID->"b29c507a-f7cf-4742-8e2b-67aa40d2443a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1700]:=",ExpressionUUID->"544c688f-6122-4d57-a32b-08c4269a3d36"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{0.57546, 0., 0.}, {-0.57546, 0., 0.}, {
    0.57546, -0.14, 0.}, {-0.57546, -0.14, 0.}, {0.57546, 0.14, 
    0.}, {-0.57546, 0.14, 0.}}, {
     {RGBColor[0.800498, 0.201504, 0.192061], 
      SphereBox[{1, 2}, 0.31000000000000005`]}, {
      {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{3, 4}, 0.08]}, 
      {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{5, 6}, 0.08]}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0, 0, 3.38},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265778`*^9, 3.920320036357765*^9, 3.920320208600456*^9, 
  3.920320276385767*^9},
 CellLabel->
  "Out[1700]=",ExpressionUUID->"4262004b-10e9-4ad6-a4c6-985b58ffb47d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Water", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.920320027492169*^9}, {3.92032020161006*^9, 
  3.9203202020830116`*^9}, {3.920320268550074*^9, 3.920320268866459*^9}, {
  3.920496040209444*^9, 
  3.9204960408966513`*^9}},ExpressionUUID->"1866d84f-85f1-4d3a-bdc4-\
aba6f1a4f498"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<water\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}, {3.920320270978395*^9, 
  3.92032027246862*^9}, {3.920496044567871*^9, 3.920496045215678*^9}},
 CellLabel->
  "In[1891]:=",ExpressionUUID->"fa1d406f-55e9-44c1-ad77-878cf7be8e64"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.10002220986702241`, -0.1589188168750001}, {
                   0.28665325557590837`, -0.05116733239583346}}], 
                  
                  LineBox[{{-0.10002220986702251`, -0.158918816875}, \
{-0.2866532555759085, -0.05116733239583325}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.28665325557590837`, -0.05116733239583346}, {
                   0.4732843012847944, 0.056584152083333186`}}], 
                  
                  LineBox[{{-0.2866532555759085, -0.05116733239583325}, \
{-0.4732843012847944, 0.05658415208333351}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQbfb6Nou92Mb9a67+mTvpx+n9MP6fF5V3YhhP7j+U
6Byq8Hfd/m/LjQyZ1h/bH93gtjdr3or904TU5zQxHt3/X3Jb00b7RfuvbFj1
4Wfw4f0dZ13uVvBO2f+5/s0s09pD+xlm2Ag4f5Cwh/FnNKuybp7aBeevOKia
+Vt/pv2nWs3dEo8O7fdhbT4n8WSh/YfKxb/vrT68v8H9xXZPg+X23SvXqM4p
PbL/hcDOMCar1fb6FyZff993dL/E5B0s6Yzr7CsUX/y68P3Y/kVcMTdTUzbY
HyyykduUcGK/DsQ/9iEaG5a++XkSzp/Et2V55+HTcL6SYfrihMln9zO5cm5l
i95gv/hr3KtQo/P7Hyh1twScXGu/Qm6BkWnAhf0mXQ6u+XdW2TccEiiwZ7+4
3+7PBPY925fZX7r3+drliRf3PxP9Jv4uaqG9w5PZtz+9v7i/wlzKRvnPdHu+
yo/Zgn6X9l+wXjsn90qH/dFq13cKtZf2MzAIKL3eXrEPxv/A/cCU8WXXfhif
I0L08uOqmfs36u6+r+B5ab/fkxO9szkX7e+cuOyQwsOL+2fIsBsdDV2+P+nr
xKUKlRf3y31k9faMXL2f2a5TUvv1hf3Xn0VUa4us23/+l+Uqe/ML+93fXb3a
lr5h/49eg97lbOfh8W3Fz2zJ0nV2P3p6AADQDiOe
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQrVdmcLs2Z8V+n9n+hz4yntkP41e9LNinpHlu/5zJ
TFYbpZftv+V+ryDs9vn9VeeWfRevWrh/j0TTbJeeC/vXCU3L+rth5v4e3qn/
7mpd3G/zuMhZRbVnv9MB91daVRf3M8w5yzr/jwScHyHrqBTi1mMP418w4Tjd
fWum/aa3pq1iQP1z6rj2trYttJ/kIbT7beeF/dvebL95Rn6Z/ZJUi58dl8/v
77D5MKUpZ4X935SX6Xy85+D8TWfefsg8cBrOL0vfMVnK59T+LiWhFwcKlttH
2t/ml2U/uV9OQfJFYuVS+5/tT/0yPh7fv0FW4QVT02L733MSluy5fWy/lKWc
9cGFC+y325WLVLIc27+icQHfxw0z7U8s2NExJfvofpmJLMvj5SbZ32L69Wf9
pSP7Nf6VvEq3bbYXkQp2cmo7sp/hygLeqM8acH7F7F+37iV37YfxN730c03Z
PmP/ssQNs9Ikj+4329+6xER/4X7dvbcTd9gf29/W9/3ELqZl+zdLsGtypR2H
x0cGb/O8osCT+9HjCwD62erC
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.5081681499598851, 
                    0.038540666666666494`}, {0.5081681499598851, 
                    0.17812599999999984`}, {0.5266397416265518, 
                    0.17812599999999984`}, {0.5266397416265518, 
                    0.12080683333333317`}, {0.5991934999598851, 
                    0.12080683333333317`}, {0.5991934999598851, 
                    0.17812599999999984`}, {0.6176648749598851, 
                    0.17812599999999984`}, {0.6176648749598851, 
                    0.038540666666666494`}, {0.5991934999598851, 
                    0.038540666666666494`}, {0.5991934999598851, 
                    0.10433366666666649`}, {0.5266397416265518, 
                    0.10433366666666649`}, {0.5266397416265518, 
                    0.038540666666666494`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.617664874959885, 
                    0.03854066666666688}, {-0.617664874959885, 
                    0.17812600000000023`}, {-0.5991932832932183, 
                    0.17812600000000023`}, {-0.5991932832932183, 
                    0.12080683333333356`}, {-0.526639524959885, 
                    0.12080683333333356`}, {-0.526639524959885, 
                    0.17812600000000023`}, {-0.508168149959885, 
                    0.17812600000000023`}, {-0.508168149959885, 
                    0.03854066666666688}, {-0.526639524959885, 
                    0.03854066666666688}, {-0.526639524959885, 
                    0.10433366666666688`}, {-0.5991932832932183, 
                    0.10433366666666688`}, {-0.5991932832932183, 
                    0.03854066666666688}}}]}}, "3"], 
                Annotation[#, 3, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"H\"", "2"], "\"O\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.3], {
                StyleBox[{
                  
                  LineBox[{{0.10002220986702241`, -0.1589188168750001}, {
                   0.28665325557590837`, -0.05116733239583346}}], 
                  
                  LineBox[{{-0.10002220986702251`, -0.158918816875}, \
{-0.2866532555759085, -0.05116733239583325}}]}, {
                  RGBColor[0.800498, 0.201504, 0.192061]}, StripOnInput -> 
                 False], 
                StyleBox[{
                  
                  LineBox[{{0.28665325557590837`, -0.05116733239583346}, {
                   0.4732843012847944, 0.056584152083333186`}}], 
                  
                  LineBox[{{-0.2866532555759085, -0.05116733239583325}, \
{-0.4732843012847944, 0.05658415208333351}}]}, {
                  RGBColor[0.433333, 0.466667, 0.466667]}, StripOnInput -> 
                 False]}}, {
               TagBox[
                TooltipBox[{{
                   RGBColor[0.801, 0.202, 0.192], 
                   
                   FilledCurveBox[{{{1, 4, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}}, {{1, 4, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 3}, {1, 3, 
                    3}, {1, 3, 3}}}, {CompressedData["
1:eJxTTMoPSmViYGBQAmIQbfb6Nou92Mb9a67+mTvpx+n9MP6fF5V3YhhP7j+U
6Byq8Hfd/m/LjQyZ1h/bH93gtjdr3or904TU5zQxHt3/X3Jb00b7RfuvbFj1
4Wfw4f0dZ13uVvBO2f+5/s0s09pD+xlm2Ag4f5Cwh/FnNKuybp7aBeevOKia
+Vt/pv2nWs3dEo8O7fdhbT4n8WSh/YfKxb/vrT68v8H9xXZPg+X23SvXqM4p
PbL/hcDOMCar1fb6FyZff993dL/E5B0s6Yzr7CsUX/y68P3Y/kVcMTdTUzbY
HyyykduUcGK/DsQ/9iEaG5a++XkSzp/Et2V55+HTcL6SYfrihMln9zO5cm5l
i95gv/hr3KtQo/P7Hyh1twScXGu/Qm6BkWnAhf0mXQ6u+XdW2TccEiiwZ7+4
3+7PBPY925fZX7r3+drliRf3PxP9Jv4uaqG9w5PZtz+9v7i/wlzKRvnPdHu+
yo/Zgn6X9l+wXjsn90qH/dFq13cKtZf2MzAIKL3eXrEPxv/A/cCU8WXXfhif
I0L08uOqmfs36u6+r+B5ab/fkxO9szkX7e+cuOyQwsOL+2fIsBsdDV2+P+nr
xKUKlRf3y31k9faMXL2f2a5TUvv1hf3Xn0VUa4us23/+l+Uqe/ML+93fXb3a
lr5h/49eg97lbOfh8W3Fz2zJ0nV2P3p6AADQDiOe
                    "], CompressedData["
1:eJxTTMoPSmViYGCQAWIQrVdmcLs2Z8V+n9n+hz4yntkP41e9LNinpHlu/5zJ
TFYbpZftv+V+ryDs9vn9VeeWfRevWrh/j0TTbJeeC/vXCU3L+rth5v4e3qn/
7mpd3G/zuMhZRbVnv9MB91daVRf3M8w5yzr/jwScHyHrqBTi1mMP418w4Tjd
fWum/aa3pq1iQP1z6rj2trYttJ/kIbT7beeF/dvebL95Rn6Z/ZJUi58dl8/v
77D5MKUpZ4X935SX6Xy85+D8TWfefsg8cBrOL0vfMVnK59T+LiWhFwcKlttH
2t/ml2U/uV9OQfJFYuVS+5/tT/0yPh7fv0FW4QVT02L733MSluy5fWy/lKWc
9cGFC+y325WLVLIc27+icQHfxw0z7U8s2NExJfvofpmJLMvj5SbZ32L69Wf9
pSP7Nf6VvEq3bbYXkQp2cmo7sp/hygLeqM8acH7F7F+37iV37YfxN730c03Z
PmP/ssQNs9Ikj+4329+6xER/4X7dvbcTd9gf29/W9/3ELqZl+zdLsGtypR2H
x0cGb/O8osCT+9HjCwD62erC
                    "]}]}}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{0.5081681499598851, 
                    0.038540666666666494`}, {0.5081681499598851, 
                    0.17812599999999984`}, {0.5266397416265518, 
                    0.17812599999999984`}, {0.5266397416265518, 
                    0.12080683333333317`}, {0.5991934999598851, 
                    0.12080683333333317`}, {0.5991934999598851, 
                    0.17812599999999984`}, {0.6176648749598851, 
                    0.17812599999999984`}, {0.6176648749598851, 
                    0.038540666666666494`}, {0.5991934999598851, 
                    0.038540666666666494`}, {0.5991934999598851, 
                    0.10433366666666649`}, {0.5266397416265518, 
                    0.10433366666666649`}, {0.5266397416265518, 
                    0.038540666666666494`}}}]}}, "2"], 
                Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{{
                   RGBColor[0.433, 0.467, 0.467], 
                   
                   FilledCurveBox[{{{0, 2, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 0}, {0, 1, 
                    0}, {0, 1, 0}, {0, 1, 0}}}, {{{-0.617664874959885, 
                    0.03854066666666688}, {-0.617664874959885, 
                    0.17812600000000023`}, {-0.5991932832932183, 
                    0.17812600000000023`}, {-0.5991932832932183, 
                    0.12080683333333356`}, {-0.526639524959885, 
                    0.12080683333333356`}, {-0.526639524959885, 
                    0.17812600000000023`}, {-0.508168149959885, 
                    0.17812600000000023`}, {-0.508168149959885, 
                    0.03854066666666688}, {-0.526639524959885, 
                    0.03854066666666688}, {-0.526639524959885, 
                    0.10433366666666688`}, {-0.5991932832932183, 
                    0.10433366666666688`}, {-0.5991932832932183, 
                    0.03854066666666688}}}]}}, "3"], 
                Annotation[#, 3, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"H\"", "2"], "\"O\""}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["3", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["2", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"O([H])[H]\"", ImageSize -> {{1, 300}, Automatic}, 
                   BaselinePosition -> Baseline, ContentPadding -> False, 
                   FrameMargins -> 0, StripOnInput -> True], 
                  "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"XLYOFNOQVPJJNP-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{"O", "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{1, 3}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9, 
  3.920320273011877*^9, 3.920496046775662*^9},
 CellLabel->
  "Out[1891]=",ExpressionUUID->"3a83dad4-d45f-40ce-933f-3c4c7d24ce81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1892]:=",ExpressionUUID->"6941eba8-bd8b-4ce4-89d9-708e2200bda6"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], 
   GraphicsComplex3DBox[{{7.144631467394594*^-10, 0.06677727800911391, 
    0.}, {-0.7634678806273023, -0.5299452688162898, 0.}, {
    0.7634678692873264, -0.5299452776795566, 
    0.}, {-0.3817339399564196, -0.23158399540358793`, 0.}, {
    0.38173393500089475`, -0.23158399983522132`, 0.}}, {{
      {RGBColor[0.65, 0.7, 0.7], SphereBox[{2, 3}, 0.24]}, 
      {RGBColor[0.800498, 0.201504, 0.192061], 
       SphereBox[{1}, 0.31000000000000005`]}}, {{
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{1, 4}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{4, 2}, 0.15]}}, {
       {RGBColor[0.800498, 0.201504, 0.192061], CylinderBox[{1, 5}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{5, 3}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{0, 0, 3.38},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265797`*^9, 3.920320036357765*^9, 3.920320208600456*^9, 
  3.920320276385767*^9, 3.920496048766617*^9},
 CellLabel->
  "Out[1892]=",ExpressionUUID->"8422861e-4fe7-4d86-90d4-4ed8ebc4695a"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["n-pentane", "Section",
 CellChangeTimes->{{3.91985620993631*^9, 3.919856227119166*^9}, {
  3.919858512984451*^9, 3.919858523724455*^9}, {3.920040993809711*^9, 
  3.9200409944331203`*^9}, {3.920141903568302*^9, 3.920141905404848*^9}, {
  3.920320004375629*^9, 3.920320027492169*^9}, {3.92032020161006*^9, 
  3.9203202020830116`*^9}, {3.920320268550074*^9, 3.920320268866459*^9}, {
  3.920496040209444*^9, 3.9204960408966513`*^9}, {3.920496095792136*^9, 
  3.920496100339872*^9}},ExpressionUUID->"1c87351e-3ed0-4a61-a62d-\
12f73283af8e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"molecule", "=", 
  RowBox[{"Molecule", "[", "\"\<iso-pentane\>\"", "]"}]}]], "Input",
 CellChangeTimes->{{3.919856235939333*^9, 3.9198562438918853`*^9}, {
  3.919856283268107*^9, 3.919856284278471*^9}, {3.919858526070925*^9, 
  3.919858527501472*^9}, {3.920040998131205*^9, 3.920041001188745*^9}, {
  3.9201419123725867`*^9, 3.920141914994022*^9}, {3.920319948465308*^9, 
  3.920319951427289*^9}, {3.920320031292069*^9, 3.920320033520602*^9}, {
  3.920320204291194*^9, 3.920320206241308*^9}, {3.920320270978395*^9, 
  3.92032027246862*^9}, {3.920496044567871*^9, 3.920496045215678*^9}, {
  3.920496106924862*^9, 3.920496109529705*^9}},
 CellLabel->
  "In[1893]:=",ExpressionUUID->"e1ded3cb-fd93-4da1-818e-792f50738f72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["Molecule",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"]], 
              ButtonFunction :> (Typeset`open$$ = True), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-1.3856406460551018`, 
                   3.774758283725532*^-16}, {-0.5196152422706631, 
                   0.5000000000000002}}], 
                  
                  LineBox[{{-0.5196152422706631, 0.5000000000000002}, {
                   0.34641016151377535`, -1.1102230246251577`*^-17}}], 
                  
                  LineBox[{{
                   0.34641016151377535`, -1.1102230246251577`*^-17}, {
                   1.2124355652982142`, 0.49999999999999994`}}], 
                  
                  LineBox[{{
                   0.34641016151377535`, -1.1102230246251577`*^-17}, {
                   0.34641016151377535`, -1.0000000000000004`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-1.3856406460551018`, 3.774758283725532*^-16}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.5196152422706631, 0.5000000000000002}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{0.34641016151377535`, -1.1102230246251577`*^-17}, 
                   0.2]}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.2124355652982142`, 0.49999999999999994`}, 0.2]}, 
                 "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.34641016151377535`, -1.0000000000000004`}, 0.2]},
                  "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "5"], 
                    SubscriptBox["\"H\"", "12"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["17", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["16", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}], True -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              ButtonFunction :> (Typeset`open$$ = False), Appearance -> None, 
              BaseStyle -> {}, Evaluator -> Automatic, Method -> 
              "Preemptive"], Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GraphicsBox[{{
               AbsoluteThickness[1.], {
                StyleBox[{
                  
                  LineBox[{{-1.3856406460551018`, 
                   3.774758283725532*^-16}, {-0.5196152422706631, 
                   0.5000000000000002}}], 
                  
                  LineBox[{{-0.5196152422706631, 0.5000000000000002}, {
                   0.34641016151377535`, -1.1102230246251577`*^-17}}], 
                  
                  LineBox[{{
                   0.34641016151377535`, -1.1102230246251577`*^-17}, {
                   1.2124355652982142`, 0.49999999999999994`}}], 
                  
                  LineBox[{{
                   0.34641016151377535`, -1.1102230246251577`*^-17}, {
                   0.34641016151377535`, -1.0000000000000004`}}]}, {
                  RGBColor[0.4, 0.4, 0.4]}, StripOnInput -> False]}}, {
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{-1.3856406460551018`, 3.774758283725532*^-16}, 
                   0.2]}, "1"], Annotation[#, 1, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{-0.5196152422706631, 0.5000000000000002}, 0.2]}, 
                 "2"], Annotation[#, 2, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  
                  DiskBox[{0.34641016151377535`, -1.1102230246251577`*^-17}, 
                   0.2]}, "3"], Annotation[#, 3, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{1.2124355652982142`, 0.49999999999999994`}, 0.2]}, 
                 "4"], Annotation[#, 4, "Tooltip"]& ], 
               TagBox[
                TooltipBox[{
                  Opacity[0], 
                  EdgeForm[None], 
                  DiskBox[{0.34641016151377535`, -1.0000000000000004`}, 0.2]},
                  "5"], Annotation[#, 5, "Tooltip"]& ]}}, {
             DisplayFunction -> Identity, Frame -> True, FrameStyle -> 
              Directive[
                Opacity[0.5], 
                Thickness[Tiny], 
                GrayLevel[0.7]], FrameTicks -> None, ImageSize -> Dynamic[{
                 UpTo[
                 8.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])], 
                 UpTo[
                 4.1 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])]}]}], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Formula: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{
                    SubscriptBox["\"C\"", "5"], 
                    SubscriptBox["\"H\"", "12"]}, "RowDefault"], 
                  "SummaryItem"]}]}, {
               TagBox[
                TemplateBox[{
                  RowBox[{
                    TagBox["\"Atoms: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["17", "SummaryItem"]}], "\"  \"", 
                  RowBox[{
                    TagBox["\"Bonds: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["16", "SummaryItem"]}]}, "RowDefault"], 
                "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"SMILES: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  PaneBox[
                  "\"C(C(C(C([H])([H])[H])(C([H])([H])[H])[H])([H])[H])([H])([\
H])[H]\"", ImageSize -> {{1, 300}, Automatic}, BaselinePosition -> Baseline, 
                   ContentPadding -> False, FrameMargins -> 0, StripOnInput -> 
                   True], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"InChIKey: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"QWTDNUCVQCZILF-UHFFFAOYSA-N\"", "SummaryItem"]}]}},
              GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, AutoDelete -> 
             False, GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{2}}, "Rows" -> {{Automatic}}},
              BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          BaselinePosition -> {1, 1}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  Molecule[{
   "C", "C", "C", "C", "C", "H", "H", "H", "H", "H", "H", "H", "H", "H", "H", 
    "H", "H"}, {
    Bond[{1, 2}, "Single"], 
    Bond[{2, 3}, "Single"], 
    Bond[{3, 4}, "Single"], 
    Bond[{3, 5}, "Single"], 
    Bond[{1, 6}, "Single"], 
    Bond[{1, 7}, "Single"], 
    Bond[{1, 8}, "Single"], 
    Bond[{2, 9}, "Single"], 
    Bond[{2, 10}, "Single"], 
    Bond[{3, 11}, "Single"], 
    Bond[{4, 12}, "Single"], 
    Bond[{4, 13}, "Single"], 
    Bond[{4, 14}, "Single"], 
    Bond[{5, 15}, "Single"], 
    Bond[{5, 16}, "Single"], 
    Bond[{5, 17}, "Single"]}, {}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.919856245072597*^9, 3.91985628504918*^9, 
  3.919858528011428*^9, 3.920041003078997*^9, 3.920141916938754*^9, 
  3.9203199532058687`*^9, 3.92032003407122*^9, 3.920320206749216*^9, 
  3.920320273011877*^9, 3.920496046775662*^9, 3.920496110567298*^9},
 CellLabel->
  "Out[1893]=",ExpressionUUID->"8fce03d0-438a-4eab-a67f-0ae641e89217"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MoleculePlot3D", "[", "molecule", "]"}]], "Input",
 CellChangeTimes->{{3.9198562484932327`*^9, 3.919856253907021*^9}},
 CellLabel->
  "In[1894]:=",ExpressionUUID->"e1c8855a-9c45-40a2-8c00-0f463060062d"],

Cell[BoxData[
 Graphics3DBox[
  {EdgeForm[None], Specularity[
    GrayLevel[1], 100], GraphicsComplex3DBox[CompressedData["
1:eJwByQI2/SFib1JlAgAAAB0AAAADAAAAlVT4WSeeAEDgq7yfiXlnPxjFNS+d
h70/rOfNeMaK6D+pFzTD9krlPzwsH/Y3TNK/5lEhdx5Z3r+A9g64wWpCPwhT
Ze6bZdU/nag0fFmX+7+jt8WmIxjqP0C9MVkF3XW/YLxfAHj/5L9+hEcoChv3
v0IVyWv0E8G/eYkyu+hiAUBCXRAAjDWqv49ruT2/RPM//YC7JDtiB0AX07+y
h5jiPzTHPYGDU9G/8pCU8lBCAUBO3XFTiyXwv5HX68BOrNK/wR+nhP/45T98
mMrSXlzlPwHExLL/E/a/zoPPaebJ6T9WkfZCpHP7P8Dgto4SnJ0//Am1L4Ez
178AwmdbrC5wvwzAq54Q0fY/X2tnQ3MV+r/yY0twk3/9P6DN+ku5Btc/X2uM
RpNI/r+ddf6aMU/rP7rcqCOaZPG/ChgbNz7oBMCwolqIzyfYP6Ib8O+Vf90/
bu5nd+fE5r+sYUN11w/4v45yKeUxnPO//d4bbnq+xT/zV6Hfo6AAwEDmkE3g
18k/XK8ypP1B+b/FF4PNb+/9v6r62WD1m9E/B2+VCogAAUCEkhRm872Yv+HH
rBA5HeU/yepZPzEABEDDj188AbDSP9yr4Go447O/xHJGJjzwAED4/qGOzhng
v5bMPOrOlLa/toO6/uJB5z8SWP/KqlPlPxCPTLANp+q/vbVOcVYq6T+WTkjS
jwzzPzC+M812csC/8S1r00/G2r9gxstIqMJbv84URZp3Kuw//gnOX2bW+r/i
H9eh0kX1P6sGljZFr8Y//olgYfbv/L+gFuKgqrPqP3gOAil3euG/LLaaevVZ
AcB+hHm1BRbjP61Ui9ohKM0/Z9Xjuy/i5b8Vc8XOcJX3vzaVonKwvuW/Qomx
ybIfz78yGsXzKC78v/yhj8PXh6E/xkYx0tzg8b8iTuX6PIX6vxLg6lX2I7I/
V/d6HQ==
    "], {{
      {RGBColor[0.4, 0.4, 0.4], SphereBox[{1, 2, 3, 4, 5}, 0.34]}, 
      {RGBColor[0.65, 0.7, 0.7], 
       SphereBox[{6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17}, 0.24]}}, {
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 2}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 3}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 4}, 0.15]}, 
      {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 5}, 0.15]}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 18}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{18, 6}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 19}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{19, 7}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{1, 20}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{20, 8}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 21}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{21, 9}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{2, 22}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{22, 10}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{3, 23}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{23, 11}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 24}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{24, 12}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 25}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{25, 13}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{4, 26}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{26, 14}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 27}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{27, 15}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 28}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{28, 16}, 0.15]}}, {
       {RGBColor[0.4, 0.4, 0.4], CylinderBox[{5, 29}, 0.15]}, 
       {RGBColor[0.65, 0.7, 0.7], CylinderBox[{29, 17}, 0.15]}}}, 
     {Opacity[0.7]}}]},
  Boxed->False,
  Lighting->"Neutral",
  Method->{
   "ShrinkWrap" -> True, "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultPlotStyle" -> 
    Automatic},
  ViewPoint->{-0.04406342704033011, -0.004133966383396556, 
   3.3797102427159937`},
  ViewVertical->{0.006447004592449793, 0.13093980414389705`, 
   0.9913693579199141}]], "Output",
 CellChangeTimes->{3.91985625493498*^9, 3.919856288982011*^9, 
  3.91985852984485*^9, 3.920041005584078*^9, 3.920141919249895*^9, 
  3.9203199577265787`*^9, 3.920320036357765*^9, 3.920320208600456*^9, 
  3.920320276385767*^9, 3.920496048766617*^9, 3.920496115947435*^9},
 CellLabel->
  "Out[1894]=",ExpressionUUID->"41330802-d590-47ca-8f32-6c85f891e1d6"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
WindowSize->{1295, 911},
WindowMargins->{{Automatic, 60}, {54, Automatic}},
FrontEndVersion->"14.0 for Mac OS X x86 (64-bit) (December 12, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"a9e6cf4e-f4eb-43ee-ba99-fcd37e2dd3bf"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 154, 3, 69, "Chapter",ExpressionUUID->"c3becc60-a414-4e31-b898-e9ff186ac154"],
Cell[737, 27, 515, 9, 58, "Text",ExpressionUUID->"303d5679-6697-47a0-974f-6e4501a8e4d3"],
Cell[CellGroupData[{
Cell[1277, 40, 153, 3, 67, "Section",ExpressionUUID->"e0af7971-f712-4943-88f3-f88ce517ce80"],
Cell[CellGroupData[{
Cell[1455, 47, 2760, 70, 262, "Input",ExpressionUUID->"d33609fe-c0cf-4c91-8140-f51cfa15855b"],
Cell[4218, 119, 8652, 191, 79, "Output",ExpressionUUID->"e8d089f4-6aea-423c-be2e-4c889f11da58"],
Cell[12873, 312, 777, 16, 48, "Output",ExpressionUUID->"f4025117-86f6-415d-8c7b-1752420e6404"],
Cell[13653, 330, 1312, 37, 48, "Output",ExpressionUUID->"ada7b532-a09d-4d48-b367-fe393cf2148c"],
Cell[14968, 369, 418, 8, 48, "Output",ExpressionUUID->"3d0930b5-c679-473e-a5fa-19c68cdac5fc"],
Cell[15389, 379, 567115, 9783, 619, "Output",ExpressionUUID->"573f3d9e-dbae-463f-89da-740453ff21c5"],
Cell[582507, 10164, 12176, 271, 268, "Output",ExpressionUUID->"5938e6e9-d249-46c1-b94b-d196c5c49521"],
Cell[594686, 10437, 2594, 50, 338, "Output",ExpressionUUID->"d199b256-534e-4a4e-8610-3549b640cc9a"]
}, Closed]],
Cell[CellGroupData[{
Cell[597317, 10492, 287, 6, 26, "Input",ExpressionUUID->"f4c47ce5-00d4-42fc-a4ec-f418d9527eb0"],
Cell[597607, 10500, 125710, 2068, 298, 2300, 44, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"70416196-2aac-4b80-aa1d-37fab140d160"]
}, Open  ]],
Cell[CellGroupData[{
Cell[723354, 12573, 236, 4, 30, "Input",ExpressionUUID->"67d45785-9647-4b4e-9cfe-f9034cd885c1"],
Cell[723593, 12579, 163936, 3148, 5496, "Output",ExpressionUUID->"9a803fcd-64e0-4cb9-912b-749cba6fc545"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[887578, 15733, 151, 3, 53, "Section",ExpressionUUID->"0a688b36-aa4f-4c67-a23a-0f25a1681984"],
Cell[887732, 15738, 216, 4, 35, "Text",ExpressionUUID->"faf8c150-80fb-4e9e-926d-355c02e58f3d"],
Cell[CellGroupData[{
Cell[887973, 15746, 609, 12, 52, "Input",ExpressionUUID->"fcd742e9-eeee-41ef-b469-ac4fbbb7cbd2"],
Cell[888585, 15760, 10307, 230, 75, "Output",ExpressionUUID->"8c63a574-2fa9-4264-a851-5eb5c349d8b6"]
}, Open  ]],
Cell[898907, 15993, 900, 23, 52, "Input",ExpressionUUID->"ee30b9fa-1f82-4294-a86a-e850b8564759"],
Cell[899810, 16018, 1717, 38, 73, "Input",ExpressionUUID->"1126995e-03e0-4d8a-8020-87486757ae1a"],
Cell[CellGroupData[{
Cell[901552, 16060, 1405, 36, 94, "Input",ExpressionUUID->"3aeeea50-2aa6-4dc4-bab6-fd8134858906"],
Cell[902960, 16098, 20107, 457, 270, "Output",ExpressionUUID->"9f870602-ab6e-4a80-bce0-488b266e3248"]
}, Open  ]],
Cell[CellGroupData[{
Cell[923104, 16560, 222, 4, 30, "Input",ExpressionUUID->"db825385-1a91-45d1-8842-59ff7699f445"],
Cell[923329, 16566, 4403, 79, 396, "Output",ExpressionUUID->"7792faf2-7a66-4a62-b9d5-dd41fa311533"]
}, Open  ]],
Cell[CellGroupData[{
Cell[927769, 16650, 480, 13, 30, "Input",ExpressionUUID->"0792312f-3d72-4e95-ab3f-a294946a8468"],
Cell[928252, 16665, 38427, 644, 164, "Output",ExpressionUUID->"bb82a5ea-8bbb-4cb7-9b48-973b9a1e53ac"]
}, Open  ]],
Cell[966694, 17312, 275, 6, 30, "Input",ExpressionUUID->"2f778574-0916-455a-85a5-73483cf43938"],
Cell[CellGroupData[{
Cell[966994, 17322, 226, 4, 30, "Input",ExpressionUUID->"ea8e3bf2-aefd-49c8-9024-11254f8bc356"],
Cell[967223, 17328, 1780178, 30391, 619, "Output",ExpressionUUID->"69e97325-31f0-4cf5-8da4-ca4739665d2c"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2747450, 47725, 201, 4, 53, "Section",ExpressionUUID->"f41b4822-9f9b-4fc9-ba0c-0f3e6e4e7ed2"],
Cell[CellGroupData[{
Cell[2747676, 47733, 260, 5, 30, "Input",ExpressionUUID->"893e0de6-b95f-4f82-b357-d043f418abf4"],
Cell[2747939, 47740, 22990, 443, 79, "Output",ExpressionUUID->"d5dcc0ee-d18f-4572-b2de-bbf62d43447a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2770966, 48188, 419, 8, 73, "Input",ExpressionUUID->"8a5f4ff8-3564-4d31-8c00-6d82a12428a4"],
Cell[2771388, 48198, 725, 17, 70, "Output",ExpressionUUID->"c026eaf9-6a6a-445b-ac96-2d3722836754"],
Cell[2772116, 48217, 1002, 30, 70, "Output",ExpressionUUID->"16d3d05e-6eb8-44f1-b3f4-56dc0ee183a5"],
Cell[2773121, 48249, 243, 5, 48, "Output",ExpressionUUID->"9272fdc0-dd46-4641-a9f4-eb18af9f5870"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2773401, 48259, 226, 4, 30, "Input",ExpressionUUID->"50af2393-9ad9-4499-8790-895ef70f3f14"],
Cell[2773630, 48265, 2903, 57, 321, "Output",ExpressionUUID->"de8b76a3-91bc-4d50-86c0-22cef92c80be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2776570, 48327, 2676, 66, 304, "Input",ExpressionUUID->"a2a0031b-d9d4-4700-a717-345b47be7da9"],
Cell[2779249, 48395, 254886, 4732, 495, "Output",ExpressionUUID->"910c9108-c699-40ad-9881-4e90ffb41a79"],
Cell[3034138, 53129, 12078, 269, 251, "Output",ExpressionUUID->"1aa6ce4e-4fe2-4400-84c3-67cf7271ad73"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3046253, 53403, 236, 4, 30, "Input",ExpressionUUID->"aa85e01f-45f1-403c-a934-98777978da19"],
Cell[3046492, 53409, 163936, 3148, 5496, "Output",ExpressionUUID->"dfc42955-626d-4cb1-b3f7-dc5692a1588c"]
}, Closed]],
Cell[CellGroupData[{
Cell[3210465, 56562, 268, 5, 26, "Input",ExpressionUUID->"16fff5fb-e1cf-48c6-9013-61a5b180317f"],
Cell[3210736, 56569, 206, 4, 48, "Output",ExpressionUUID->"b275f093-33b7-4c36-8d32-e532eeb26a8d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3210991, 56579, 157, 3, 53, "Section",ExpressionUUID->"288da12a-b000-4974-9ccc-651e94d37ae3"],
Cell[CellGroupData[{
Cell[3211173, 56586, 263, 5, 30, "Input",ExpressionUUID->"3ce79f01-3c0a-419c-b321-5958bf54e353"],
Cell[3211439, 56593, 15674, 330, 79, "Output",ExpressionUUID->"cbfe5e2a-4df6-4332-8cf5-6f83201f9601"]
}, Closed]],
Cell[CellGroupData[{
Cell[3227150, 56928, 226, 4, 26, "Input",ExpressionUUID->"5905d160-374c-4b79-86d3-41d3d63bc566"],
Cell[3227379, 56934, 3265, 62, 350, "Output",ExpressionUUID->"413d838c-7210-424d-bb60-0750f36cde2c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3230693, 57002, 204, 4, 53, "Section",ExpressionUUID->"35c5282c-91c6-47c2-b28d-4b0ce10f7540"],
Cell[CellGroupData[{
Cell[3230922, 57010, 357, 7, 30, "Input",ExpressionUUID->"36beec0c-2a93-4e8c-9394-c8bb954f6e11"],
Cell[3231282, 57019, 17773, 350, 79, "Output",ExpressionUUID->"a35327e5-f62b-47eb-ab91-2ff09f0beab8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3249092, 57374, 340, 7, 30, "Input",ExpressionUUID->"cf1b0b8d-fce1-4042-932d-abc608e50527"],
Cell[3249435, 57383, 2105, 42, 265, "Output",ExpressionUUID->"7322ca1b-dffd-4c26-b05e-1e2746a395f7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3251589, 57431, 202, 4, 53, "Section",ExpressionUUID->"5cb6b279-0b3e-4fe6-8741-0dc692a8587c"],
Cell[CellGroupData[{
Cell[3251816, 57439, 357, 7, 30, "Input",ExpressionUUID->"b69778dd-2eb2-435a-ad33-1dd1af1aa8a3"],
Cell[3252176, 57448, 12977, 288, 79, "Output",ExpressionUUID->"5114a5d2-c9d8-4e46-8971-eafa8af108aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3265190, 57741, 226, 4, 30, "Input",ExpressionUUID->"60d418db-de0b-4e26-afab-09c0b3e9ed5a"],
Cell[3265419, 57747, 3496, 64, 342, "Output",ExpressionUUID->"ce808227-359e-411d-a2a1-49433775d82d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3268964, 57817, 246, 4, 53, "Section",ExpressionUUID->"6d95e83f-6c95-4f51-a9c5-9e974bb85f62"],
Cell[CellGroupData[{
Cell[3269235, 57825, 410, 7, 30, "Input",ExpressionUUID->"ab34c2e5-918a-457b-a88d-8d3b09f1fc35"],
Cell[3269648, 57834, 20487, 390, 75, "Output",ExpressionUUID->"eca901ac-fec4-4f79-bf91-b315f1d97351"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3290172, 58229, 226, 4, 30, "Input",ExpressionUUID->"ea51686d-1631-4d20-95fa-1dc6cfcfe956"],
Cell[3290401, 58235, 2038, 43, 103, "Output",ExpressionUUID->"f6768dac-dd84-4b0e-9a8d-cd45fa9f8428"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3292488, 58284, 300, 5, 53, "Section",ExpressionUUID->"55819cbf-6fff-4560-993b-4ca36935f16e"],
Cell[CellGroupData[{
Cell[3292813, 58293, 455, 8, 30, "Input",ExpressionUUID->"26d830e0-9d08-48fe-ab4c-a62aa721b0e4"],
Cell[3293271, 58303, 15911, 363, 75, "Output",ExpressionUUID->"7b487ba1-7090-47df-a45d-40aa6e8e200e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3309219, 58671, 226, 4, 30, "Input",ExpressionUUID->"dc0253b7-9280-4c24-acd6-5cb318ee9e94"],
Cell[3309448, 58677, 119955, 1972, 206, 6275, 108, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"d262c81c-0e9d-4bd2-99a6-4a9a5568f85a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3429452, 60655, 389, 6, 53, "Section",ExpressionUUID->"fa25ef36-aac3-4cf8-a852-819e123487d8"],
Cell[CellGroupData[{
Cell[3429866, 60665, 549, 9, 30, "Input",ExpressionUUID->"46347aef-19a1-4a34-a647-fe1ad886252a"],
Cell[3430418, 60676, 19429, 383, 79, "Output",ExpressionUUID->"b19fa91e-1556-4e4e-850e-3772b3356066"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3449884, 61064, 340, 7, 30, "Input",ExpressionUUID->"337983e7-5aaf-4548-82eb-320dc7c23279"],
Cell[3450227, 61073, 2395, 46, 418, "Output",ExpressionUUID->"f90abd00-4361-489c-b613-9df8e7d7aa5a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3452671, 61125, 437, 6, 53, "Section",ExpressionUUID->"e485ed40-d75b-4312-9bd4-560934ea5179"],
Cell[CellGroupData[{
Cell[3453133, 61135, 613, 10, 30, "Input",ExpressionUUID->"fdd8b27a-d422-45dc-aa2f-34afe99ef27a"],
Cell[3453749, 61147, 28731, 543, 79, "Output",ExpressionUUID->"9650d375-486f-452a-885c-828416df314d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3482517, 61695, 340, 7, 30, "Input",ExpressionUUID->"01e1039c-4cfa-4f7e-9024-593c7be87c0e"],
Cell[3482860, 61704, 2541, 52, 456, "Output",ExpressionUUID->"849e4c98-3049-4482-805d-87f2b2664e6d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3485450, 61762, 345, 6, 53, "Section",ExpressionUUID->"07a6a885-5b39-48f4-bc7e-6a79cfcb4134"],
Cell[CellGroupData[{
Cell[3485820, 61772, 513, 9, 30, "Input",ExpressionUUID->"dc223292-729b-473d-93cc-69a01485c682"],
Cell[3486336, 61783, 11797, 236, 79, "Output",ExpressionUUID->"faa10369-4267-4645-99d7-20e8aed7227b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3498170, 62024, 226, 4, 30, "Input",ExpressionUUID->"2ed700e2-97dc-4bba-b2df-3b12c22f10cb"],
Cell[3498399, 62030, 176936, 2909, 431, 1123, 26, "CachedBoxData", "BoxData", "Output",ExpressionUUID->"a14e3c84-97f4-4e56-828d-ec658ce16595"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3675384, 64945, 342, 6, 53, "Section",ExpressionUUID->"430ae8c9-a66e-44f7-a843-f1e249f73b5a"],
Cell[CellGroupData[{
Cell[3675751, 64955, 548, 9, 30, "Input",ExpressionUUID->"90894a26-aea5-4dba-a00b-06faaf102810"],
Cell[3676302, 64966, 16124, 312, 65, "Output",ExpressionUUID->"c0d988d2-69f9-4808-9014-8cd4d5fd7552"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3692463, 65283, 226, 4, 30, "Input",ExpressionUUID->"62c29ede-4f31-454d-8035-fed5c1be55f0"],
Cell[3692692, 65289, 1287, 29, 147, "Output",ExpressionUUID->"9e489792-9fc5-4056-b0ec-c9c117232e0f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3694016, 65323, 599, 10, 30, "Input",ExpressionUUID->"01a632e1-96e3-47e7-b3d3-0091b1ee8c18"],
Cell[3694618, 65335, 11539, 230, 75, "Output",ExpressionUUID->"cf699c3b-7e0a-495b-9071-fe230ec04a50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3706194, 65570, 226, 4, 30, "Input",ExpressionUUID->"729a3816-de1e-4406-9da8-cfe08f817631"],
Cell[3706423, 65576, 1610, 33, 150, "Output",ExpressionUUID->"ec498353-2eee-4b9a-8a74-10d4a77f5908"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3708082, 65615, 386, 6, 53, "Section",ExpressionUUID->"c43cea3f-bb97-4ed5-9ba5-29245aa88f03"],
Cell[CellGroupData[{
Cell[3708493, 65625, 599, 10, 30, "Input",ExpressionUUID->"be69fc12-d353-47a0-b11f-b092e8c1ae38"],
Cell[3709095, 65637, 13067, 247, 79, "Output",ExpressionUUID->"f9a8e69d-2523-47e2-8dd5-4e75b6812650"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3722199, 65889, 335, 7, 30, "Input",ExpressionUUID->"df3e9348-c481-4ff7-94b0-f6942413d058"],
Cell[3722537, 65898, 1164, 27, 393, "Output",ExpressionUUID->"5607b5ca-0845-4a11-82cf-2b0ac0bcd932"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3723738, 65930, 597, 10, 30, "Input",ExpressionUUID->"ccca9d9a-0130-4409-a70e-3d5ebfcf94f9"],
Cell[3724338, 65942, 11539, 230, 61, "Output",ExpressionUUID->"64e2e8d7-3b5c-47b3-83dc-7e97958824c4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3735914, 66177, 226, 4, 30, "Input",ExpressionUUID->"814919bc-9ebc-4f52-abdd-06ee1d3a4548"],
Cell[3736143, 66183, 1610, 33, 136, "Output",ExpressionUUID->"994a4236-7089-4093-830b-be89f42f4fc2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3737802, 66222, 435, 7, 53, "Section",ExpressionUUID->"58d6cedf-ef78-4f5d-9ac4-55dd0ba761f4"],
Cell[CellGroupData[{
Cell[3738262, 66233, 648, 11, 30, "Input",ExpressionUUID->"42cfa308-45dc-40d5-9110-afaac1334f4a"],
Cell[3738913, 66246, 11142, 220, 79, "Output",ExpressionUUID->"7e2a4416-34bc-4004-a2d6-bacd397ed458"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3750092, 66471, 335, 7, 30, "Input",ExpressionUUID->"b790d6f2-88ff-4725-be8b-7e2f34676bbe"],
Cell[3750430, 66480, 1185, 27, 393, "Output",ExpressionUUID->"00d584c5-a59c-47ff-8513-7cd94b0ad5ac"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3751664, 66513, 147, 3, 53, "Section",ExpressionUUID->"3afc6e9d-9ae9-4630-a401-08403b7aa952"],
Cell[CellGroupData[{
Cell[3751836, 66520, 597, 10, 30, "Input",ExpressionUUID->"40abc8a8-8253-4cab-ba0d-9b37e820de79"],
Cell[3752436, 66532, 11539, 230, 61, "Output",ExpressionUUID->"4a2d5609-2f31-43ea-81f3-9318bf679587"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3764012, 66767, 226, 4, 30, "Input",ExpressionUUID->"f1c597f4-3b81-4735-aa8b-d2e46810a2d3"],
Cell[3764241, 66773, 1610, 33, 136, "Output",ExpressionUUID->"cc477f1a-4ee8-4199-b3d7-e20ec4d749bd"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3765900, 66812, 442, 7, 53, "Section",ExpressionUUID->"8509ae6f-dcf3-4edb-b8a5-54a5652a2618"],
Cell[CellGroupData[{
Cell[3766367, 66823, 648, 11, 30, "Input",ExpressionUUID->"148ed65d-d909-4e61-b546-662b7c3768b4"],
Cell[3767018, 66836, 15066, 295, 79, "Output",ExpressionUUID->"b29c507a-f7cf-4742-8e2b-67aa40d2443a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3782121, 67136, 226, 4, 30, "Input",ExpressionUUID->"544c688f-6122-4d57-a32b-08c4269a3d36"],
Cell[3782350, 67142, 1435, 32, 191, "Output",ExpressionUUID->"4262004b-10e9-4ad6-a4c6-985b58ffb47d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3783834, 67180, 491, 8, 53, "Section",ExpressionUUID->"1866d84f-85f1-4d3a-bdc4-aba6f1a4f498"],
Cell[CellGroupData[{
Cell[3784350, 67192, 688, 11, 30, "Input",ExpressionUUID->"fa1d406f-55e9-44c1-ad77-878cf7be8e64"],
Cell[3785041, 67205, 16972, 330, 61, "Output",ExpressionUUID->"3a83dad4-d45f-40ce-933f-3c4c7d24ce81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3802050, 67540, 226, 4, 30, "Input",ExpressionUUID->"6941eba8-bd8b-4ce4-89d9-708e2200bda6"],
Cell[3802279, 67546, 1780, 37, 235, "Output",ExpressionUUID->"8422861e-4fe7-4d86-90d4-4ed8ebc4695a"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3804108, 67589, 541, 8, 53, "Section",ExpressionUUID->"1c87351e-3ed0-4a61-a62d-12f73283af8e"],
Cell[CellGroupData[{
Cell[3804674, 67601, 743, 12, 30, "Input",ExpressionUUID->"e1ded3cb-fd93-4da1-818e-792f50738f72"],
Cell[3805420, 67615, 11694, 264, 79, "Output",ExpressionUUID->"8fce03d0-438a-4eab-a67f-0ae641e89217"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3817151, 67884, 226, 4, 30, "Input",ExpressionUUID->"e1c8855a-9c45-40a2-8c00-0f463060062d"],
Cell[3817380, 67890, 4134, 75, 297, "Output",ExpressionUUID->"41330802-d590-47ca-8f32-6c85f891e1d6"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

